/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ub){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function sb(tb){var r=tb.a;var s=r.buffer;r.grow=qb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=tb.abort;var M=NaN;var N=Infinity;var O=tb.b;var P=tb.c;var Q=tb.d;var R=tb.e;var S=tb.f;var T=tb.g;var U=tb.h;var V=tb.i;var W=tb.j;var X=tb.k;var Y=tb.l;var Z=tb.m;var _=tb.n;var $=tb.o;var aa=tb.p;var ba=tb.q;var ca=tb.r;var da=tb.s;var ea=tb.t;var fa=tb.u;var ga=tb.v;var ha=tb.w;var ia=tb.x;var ja=tb.y;var ka=tb.z;var la=tb.A;var ma=tb.B;var na=tb.C;var oa=tb.D;var pa=tb.E;var qa=tb.F;var ra=tb.G;var sa=tb.H;var ta=tb.I;var ua=tb.J;var va=tb.K;var wa=tb.L;var xa=tb.M;var ya=tb.N;var za=tb.O;var Aa=tb.P;var Ba=tb.Q;var Ca=tb.R;var Da=tb.S;var Ea=tb.T;var Fa=tb.U;var Ga=tb.V;var Ha=tb.W;var Ia=tb.X;var Ja=tb.Y;var Ka=tb.Z;var La=tb._;var Ma=tb.$;var Na=tb.aa;var Oa=tb.ba;var Pa=tb.ca;var Qa=tb.da;var Ra=tb.ea;var Sa=tb.fa;var Ta=tb.ga;var Ua=tb.ha;var Va=tb.ia;var Wa=tb.ja;var Xa=tb.ka;var Ya=tb.la;var Za=tb.ma;var _a=tb.na;var $a=tb.oa;var ab=tb.pa;var bb=tb.qa;var cb=tb.ra;var db=tb.sa;var eb=tb.ta;var fb=tb.ua;var gb=5709376;var hb=0;var ib=0;var jb=0;
// EMSCRIPTEN_START_FUNCS
function Ct(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,R=0,T=0,V=0,W=0,X=0,Y=C(0),Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=C(0),wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=C(0),Qa=0;_=gb-48|0;gb=_;ma=_+40|0;v[ma>>2]=55308;v[ma>>2]=55208;g=cL(_+32|0);e=cL(_+24|0);d=v[g+4>>2];v[_+16>>2]=v[g>>2];v[_+20>>2]=d;g=v[e+4>>2];v[_+8>>2]=v[e>>2];v[_+12>>2]=g;ga=b;oa=c;b=0;V=gb-128|0;gb=V;M=a;pa=a+24604|0;a=pa;a:{if(!v[a+16>>2]){break a}c=v[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=v[a+28>>2];if(a>>>0>=5){break a}b=23>>>a&1}if(!b){SO(V+112|0,6244,10294,200,45);b=V+112|0;a=gb-160|0;gb=a;v[a+88>>2]=0;g=au(a+88|0);v[22692]=0;c=Q(2,a+120|0,14821)|0;e=v[22692];v[22692]=0;b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22692]=0;U(6,a+104|0,1,14463);e=v[22692];v[22692]=0;if((e|0)==1){break h}v[22692]=0;U(3,a+136|0,c|0,a+104|0);e=v[22692];v[22692]=0;if((e|0)==1){break g}v[22692]=0;ha(33,g|0,b|0,1,10847,a+136|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}vb(a+136|0);vb(a+104|0);vb(c);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(a+136|0)}vb(a+104|0)}vb(c)}S(b|0);L()}gb=a+160|0}a=v[M+480208>>2];i:{if(!ga|a&512){break i}xa=M+8204|0;ya=M+1074332|0;za=M+393352|0;ea=M+12|0;qa=M+1298260|0;Aa=M+1074376|0;g=v[M+1074380>>2];while(1){j:{if(g){break j}K=M;b=a|512;k:{if(a&256){break k}g=0;k=gb-48|0;gb=k;N=gb-32|0;gb=N;o=M;f=o;b=f+1074392|0;a=v[b>>2]+1|0;v[b>>2]=a;l:{m:{j=f+1074376|0;n:{if(ok(j)>>>0>a>>>0){break n}i=f+1074312|0;e=f+1074992|0;c=f+1298224|0;q=f+1074424|0;l=f+484344|0;d=f+484360|0;h=f+1074448|0;m=f+480210|0;while(1){Jz(N+24|0,f,j,(v[f+480208>>2]&524288)>>>19|0);o:{p:{q:{r:{if(!(w[f+480208|0]&32)){b=x[h>>1];a=f;s:{if(sc(Sb(d))>>>0>b>>>0){b=x[rc(Sb(d),x[h>>1])>>1];break s}b=65535}u[a+1074446>>1]=b;t:{if(Re(l)>>>0<=(b&65535)>>>0){break t}if(gi(_b(l,x[f+1074446>>1]))){break t}u[f+1074446>>1]=65534}if(x[f+1074446>>1]>=Re(l)>>>0){while(1){u:{v:{w:{x:{if(x[f+1074446>>1]!=65535){a=x[h>>1];if(sc(Sb(d))>>>0>a>>>0){break x}}b=x[Sb(d)+28>>1];if(b){break v}a=x[h>>1];if(sc(Sb(d))>>>0<a>>>0){break w}a=x[h>>1];if(!a){break w}while(1){b=a;a=a-1|0;if(!a){break w}if(x[rc(Sb(d),a)>>1]!=65535){continue}break}break v}a=x[h>>1]+1|0;u[h>>1]=a;break u}b=0}u[f+1074448>>1]=b;v[f+480208>>2]=v[f+480208>>2]&-524289;y:{if(sc(Sb(d))>>>0<=(b&65535)>>>0){break y}while(1){if(x[rc(Sb(d),x[h>>1])>>1]!=65534){break y}a=x[h>>1]+1|0;u[h>>1]=a;if(sc(Sb(d))>>>0>(a&65535)>>>0){continue}break}}a=x[h>>1];if(sc(Sb(d))>>>0<=a>>>0){break r}if(!Go(Sb(d),x[h>>1])){break r}a=x[h>>1]}b=f;z:{if(sc(Sb(d))>>>0>(a&65535)>>>0){a=x[rc(Sb(d),x[h>>1])>>1];break z}a=65535}u[b+1074446>>1]=a;A:{if(Re(l)>>>0<=(a&65535)>>>0){break A}if(gi(_b(l,x[f+1074446>>1]))){break A}u[f+1074446>>1]=65534}if(x[f+1074446>>1]>=Re(l)>>>0){continue}break}}u[f+1074450>>1]=x[f+1074448>>1]}if(!le(l,x[f+1074446>>1])){break m}if(y[f+1074424>>2]>=y[_b(l,x[f+1074446>>1])+12>>2]){v[q>>2]=0}if(v[f+480208>>2]&32?v[f+480272>>2]!=-1:0){break o}if(!uu(c,x[h>>1],v[q>>2],Dq(N+16|0,e),w[N+24|0])){break o}a=v[f+480272>>2];if(a){if((a|0)>=1){v[f+480272>>2]=a-1}Co(c,1);uu(c,x[h>>1],v[q>>2],Dq(N+16|0,e),w[N+24|0]);break o}if(!(w[m|0]&64)){break r}if(mR(c,h,q,1)){break p}v[f+1074448>>2]=0;v[f+1074424>>2]=0;v[f+1074428>>2]=0;if(w[d+16|0]<(Oi(d)-1|0)){break q}Pi(d,0)}Co(c,1);break m}Pi(d,w[d+16|0]+1&255);Co(c,1)}a=0;while(1){Vm((f+B(a,872)|0)+1074992|0,7,f,a&65535,134217728);a=a+1|0;if((a|0)!=256){continue}break}JO(f);v[f+1074416>>2]=v[f+480196>>2];v[f+1074420>>2]=v[f+480204>>2];v[f+1074456>>2]=v[f+480200>>2];u[f+1074450>>1]=x[f+1074448>>1];v[f+1074428>>2]=v[f+1074424>>2];b=c;r=sc(Sb(d));a=x[f+1074448>>1];if(r>>>0>a>>>0){Na=f,Oa=x[rc(Sb(d),x[f+1074448>>1])>>1],u[Na+1074446>>1]=Oa;a=x[f+1074448>>1]}uu(b,a&65535,v[f+1074424>>2],Dq(N+16|0,e),w[N+24|0]);if(!le(l,x[f+1074446>>1])){break m}}Iz(f,j,(v[f+480208>>2]&32)>>>5|0);b=Wc(_b(l,x[f+1074446>>1]),v[f+1074424>>2],0);a=x[f+480188>>1];if(a){E=(f+B(a,872)|0)+1074992|0;a=e;while(1){Db(N+16|0,i,82);B:{if(!Cb(N+16|0)|w[a+805|0]!=1){break B}r=w[b+3|0];if((r|0)!=3?(r|0)!=2:0){break B}Na=a,Oa=Zg(f,w[a+800|0],u[a+772>>1],v[a+704>>2]),v[Na+700>>2]=Oa}Db(N+16|0,i,91);C:{if(!Cb(N+16|0)){break C}if(de(b)){break C}if(!de(a+788|0)|w[a+791|0]!=19){break C}r=w[a+793|0];if((r&240)!=208|y[f+1074416>>2]>(r&15)>>>0){break C}Na=a,Oa=Zg(f,w[a+788|0],u[a+772>>1],0),v[Na+700>>2]=Oa}Db(N+16|0,i,92);D:{if(!Cb(N+16|0)){break D}Db(N+8|0,i,5);if(Cb(N+8|0)|v[f+1074416>>2]!=1|w[a+791|0]!=17){break D}v[f+1074420>>2]=B(w[a+793|0],1e4)}r=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+788|0]=r;t[a+789|0]=r>>>8;t[a+790|0]=r>>>16;t[a+791|0]=r>>>24;r=w[b+4|0]|w[b+5|0]<<8;t[a+792|0]=r;t[a+793|0]=r>>>8;r=v[a+676>>2];v[a+20>>2]=v[a+672>>2];v[a+24>>2]=r;v[a+88>>2]=v[a+88>>2]&-393217;Db(N+16|0,i,21);if(!Cb(N+16|0)){t[a+831|0]=0}v[a+860>>2]=0;t[a+805|0]=0;b=b+6|0;a=a+872|0;if((E|0)!=(a|0)){continue}break}}a=f;r=a+1074412|0;E:{F:{b=a+484344|0;if(Wl(b,x[a+1074446>>1])){if(IP(_b(b,x[a+1074446>>1]))){break F}}v[a+1074408>>2]=v[a+480216>>2];a=v[a+480220>>2];break E}Na=a+1074408|0,Oa=v[_b(b,x[a+1074446>>1])+16>>2],v[Na>>2]=Oa;a=v[_b(b,x[a+1074446>>1])+20>>2]}v[r>>2]=a;if(!w[N+24|0]){break n}a=v[f+1074416>>2]+1|0;v[f+1074392>>2]=a;if(ok(j)>>>0<=a>>>0){continue}break}}if(!v[f+1074416>>2]){v[f+1074416>>2]=1}b=v[f+480208>>2];a=f;c=a;G:{H:{if(v[a+1074392>>2]){v[f+480208>>2]=b&-4097;if(v[f+480180>>2]&1048580|(w[f+480210|0]&32?0:v[f+480180>>2]==1)){break G}if(y[f+1074392>>2]>=ok(j)>>>0|y[f+1074392>>2]%(v[f+1074400>>2]+v[f+1074416>>2]>>>0)){break G}a=v[f+480208>>2];break H}a=b&-528385}v[c+480208>>2]=a|4096}s=0;n=gb-16|0;gb=n;u[f+1074444>>1]=65535;a=f+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;I=f+480208|0;G=f+1074376|0;if(x[f+480188>>1]){ba=f+1075809|0;H=f+1298260|0;F=f+1074312|0;ca=f+480210|0;while(1){p=f+B(s,872)|0;i=p+1075785|0;E=w[i|0];j=p+1075783|0;b=w[j|0];q=p+1075784|0;h=w[q|0];Z=p+1075782|0;l=w[Z|0];W=p+1075781|0;c=w[W|0];e=v[f+1074392>>2];d=v[f+1074400>>2];r=v[f+1074416>>2];J=p+1075780|0;a=ou(J);X=p+1075843|0;t[X|0]=v[f+480208>>2]>>>12&1|w[X|0]&254;R=(e>>>0)%(d+r>>>0)|0;e=w[J|0];if((e|0)==252){e=w[W|0];d=Cq(J);r=yo(J);I:{if(!e|e-251>>>0<5){break I}e=v[(f+B(e,160)|0)+906140>>2];if(!e){break I}kb[v[v[e>>2]+44>>2]](e,d,C(C(r>>>0)*C(.0010010009864345193)))}e=w[J|0]}J:{if(b&255|z[p+1075852>>2]==C(0)?(e&255)!=251:0){break J}r=v[I>>2]&4096;K:{if(!r){d=w[p+1075862|0];break K}d=w[W|0];t[p+1075862|0]=d}if(!d|d-251>>>0<5){break J}d=(f+B(d,160)|0)+906140|0;if(!v[d>>2]){break J}L:{if(!r){e=x[p+1075860>>1];break L}e=ku(w[Z|0],w[q|0]);u[p+1075860>>1]=e;Y=C(C(ku(w[j|0],w[i|0])>>>0)*C(.0010010009864345193));z[p+1075856>>2]=Y;i=v[d>>2];Na=p+1075852|0,Pa=C(C(Y-C(kb[v[v[i>>2]+48>>2]](i,e)))/C(ok(G)>>>0)),z[Na>>2]=Pa}i=v[f+1074392>>2];j=ok(G);d=v[d>>2];q=e;e=(j|0)==(i+1|0);kb[v[v[d>>2]+(e?44:104)>>2]](d,q,z[(e?p+1075856|0:p+1075852|0)>>2]);e=w[J|0]}q=p+1074992|0;M:{N:{O:{P:{Q:{if(!CP(e&255)){if(w[I+1|0]&16){break P}d=c;break Q}a=gb-16|0;gb=a;u[a+12>>1]=0;v[a+8>>2]=0;_i(a+8|0);b=x[a+12>>1];t[q+792|0]=b;t[q+793|0]=b>>>8;b=v[a+8>>2];t[q+788|0]=b;t[q+789|0]=b>>>8;t[q+790|0]=b>>>16;t[q+791|0]=b>>>24;gb=a+16|0;d=0;l=0;h=0;b=0;E=0;a=0;j=0;i=0;m=0;c=0;e=0;r=0;if(w[I+1|0]&16){break N}}vP(f,q);c=d;break O}if(!c){c=0;break O}v[p+1075752>>2]=0}e=0;d=b&255;R:{S:{T:{if(d-19>>>0>=2){if((d|0)!=33){break T}Db(n+8|0,F,30);e=E>>>4|0;jA(f,s&65535,e+(E&15)|0,Cb(n+8|0));b=33;break S}U:{if(!(!(v[f+480180>>2]&16777250)|E)){E=w[p+1075825|0];break U}t[p+1075825|0]=E}d=E&240;if((d|0)==208){r=E&15;if(!r){if(v[f+480180>>2]&16777248){j=b;i=h;e=1;break R}d=a;j=b;i=h;m=l;r=E;if(v[f+480180>>2]!=2){break N}break M}V:{if(r>>>0<v[f+1074400>>2]+v[f+1074416>>2]>>>0){break V}Db(n+8|0,F,14);if(!Cb(n+8|0)){break V}if(!c){break M}t[p+1075795|0]=c;break M}j=b;i=h;e=r;break R}if(!(w[I+1|0]&16)|(d|0)!=224|(v[f+1074396>>2]?v[f+480180>>2]&16777250:0)){break T}d=E&15;if(d?0:v[f+480180>>2]&2){break T}v[f+1074396>>2]=d+1}}j=b;i=h}d=a;m=l;r=E}$=j&255;b=v[f+480180>>2]==16&($|0)==19&(r&240)==208;T=b?0:e;W:{if(!T|w[J|0]!=255|w[Z|0]!=2){break W}Db(n+8|0,F,74);if(!Cb(n+8|0)){break W}t[Z|0]=0}a=v[f+1074392>>2];Db(n+8|0,F,72);X:{if(Cb(n+8|0)){A=0;if(T>>>0>=y[f+1074416>>2]){break X}}Db(n+8|0,F,88);A=(R|0)==(T|0)|(a|0)==(T|0);if(!(!Cb(n+8|0)|!T)){break X}A=(a|0)==(T|0)}Db(n+8|0,F,44);if(Cb(n+8|0)){t[X|0]=w[X|0]&254|(R|0)==(T|0)}aa=r&15;b=b?aa|144:r;Db(n+8|0,F,66);d=(!T|Cb(n+8|0)^-1)&d;Y:{Z:{if(!(v[f+1074392>>2]|(!(w[ca|0]&32)|!c))){v[p+1075652>>2]=0;if(A){break Z}if(!Mi(q)){break Y}t[p+1075795|0]=c;if(x[f+480190>>1]<c>>>0){break Y}a=f+B(c,104)|0;v[p+1075680>>2]=x[a+484410>>1];u[p+1075764>>1]=t[a+484417|0];break Y}if(!A){break Y}}e=w[J|0];if(c){t[p+1075795|0]=c}_:{$:{if(!ue(e)){break $}Db(n+8|0,F,67);if(!Cb(n+8|0)){break $}a=u[p+1075762>>1];aa:{if(!c|d){break aa}h=Vz(f,e,c);if(!h){break aa}a=t[Ml(f,h)+36|0]}e=(a+e|0)-12>>>0>119?0:e;break _}if(!(v[f+480180>>2]&25165856)|!x[f+480192>>1]){break _}a=e;if(a){a=ue(a)}else{a=1}if(!a){break _}a=c;ba:{if(!a){a=w[p+1075796|0];if(!a){break ba}}if(v[(f+(a<<2)|0)+900380>>2]?x[f+480192>>1]>=a>>>0:0){break _}e=0}c=0}if(!(($|0)!=25|b)){Db(n+8|0,F,55);a=Cb(n+8|0);c=a?0:c;e=a?0:e}Db(n+8|0,F,65);a=(c|0)!=0;h=!e;l=Cb(n+8|0);R=1;ca:{if(v[f+480180>>2]&16777248){break ca}Db(n+8|0,F,107);if(Cb(n+8|0)){break ca}Db(n,F,85);R=0;if(!Cb(n)){break ca}if(Mi(q)){break ca}R=1;r=v[p+1075096>>2];if(!r){break ca}R=Nd(r)^1}r=a&h;E=a&l;da:{ea:{fa:{ga:{ha:{ia:{if(!(v[f+480180>>2]&1048580)){break ia}ja:{if((e|0)!=255){break ja}if(($|0)!=13?(m&255)==1|c:1){Db(n+8|0,F,55);if(Cb(n+8|0)){break ja}}a=v[p+1075648>>2];if(t[a+60|0]&1?a:0){break ja}v[p+1075680>>2]=0;a=p+1075080|0;v[a>>2]=v[a>>2]|2097152;ka:{if(!(v[f+480208>>2]&4096)){break ka}Db(n+8|0,F,86);if(!Cb(n+8|0)){break ka}v[a>>2]=v[a>>2]|4096}c=0;e=0;l=0;a=0;h=0;r=1;if(E){break ea}break da}Db(n+8|0,F,59);if(!Cb(n+8|0)|v[I>>2]&4096){break ia}la:{if(!e){e=w[p+1075789|0]-w[p+1075762|0]|0;break la}if(e>>>0>250){R=0;E=1;e=0;break la}ma:{if(c){break ma}Db(n+8|0,F,98);if(!Cb(n+8|0)){break ma}c=0;break la}R=1;E=1}l=e;d=0;break ha}l=0;h=0;if(!r){break ga}}Db(n+8|0,F,65);if(!Cb(n+8|0)){break fa}e=l;h=1}a=e;l=h;r=1;if(E){break ea}break da}e=l;l=1;r=E}na:{oa:{if(!x[f+480192>>1]){if(x[f+480190>>1]<c>>>0){break na}a=(f+B(c,104)|0)+484380|0;break oa}a=v[p+1075096>>2];if(!a){break na}}pa:{if(u[a+34>>1]<0){break pa}if(v[f+480180>>2]==2){if(!Nd(a)){break pa}}v[p+1075680>>2]=x[a+30>>1]}if(!r){break na}Lo(q,x[a+28>>1],f)}a=e;h=l}Db(n+8|0,F,71);if(!(!Cb(n+8|0)|!c)){t[p+1075831|0]=32}qa:{if(!x[f+480192>>1]){break qa}Db(n+8|0,F,100);if(!Cb(n+8|0)|!c){break qa}if(ue(a&255)){break qa}e=v[I>>2];ra:{if(d){if(e&8){break ra}break qa}if(!(e&4)){break qa}}Gm(q);v[p+1075688>>2]=65536;e=p+1075080|0;v[e>>2]=v[e>>2]|2097152}if(h){Db(n+8|0,F,11);sa:{if(!(Na=Cb(n+8|0),Oa=1,Qa=v[f+480180>>2]!=268435456,Qa?Na:Oa)){break sa}Db(n+8|0,F,87);e=0;if(Cb(n+8|0)){e=Mi(q)^1}ta:{if(x[f+480192>>1]){if(x[f+480192>>1]<c>>>0){break sa}if(v[p+1075648>>2]!=v[(f+(c<<2)|0)+900380>>2]|e){break ta}break sa}if((v[p+1075096>>2]!=((f+B(c,104)|0)+484380|0)|e)!=1){break sa}}a=w[p+1075789|0]}ua:{if(!x[f+480192>>1]|!(v[f+480180>>2]&1048588)){break ua}Gm(q);t[p+1075810|0]=0;v[p+1075748>>2]=0;v[p+1075688>>2]=65536;e=p+1075080|0;v[e>>2]=v[e>>2]&-2101249|2097152;Db(n+8|0,F,86);if(!Cb(n+8|0)){break ua}v[e>>2]=v[e>>2]&-2049}c=R?c:0}r=a&255;va:{if(r>>>0<251){break va}Db(n+8|0,F,50);wa:{if(!Cb(n+8|0)|!c){break wa}e=Vz(f,w[p+1075791|0],c);if(!e){break wa}e=f+B(e,104)|0;if(u[e+484414>>1]<0){break wa}v[p+1075680>>2]=x[e+484410>>1]}Db(n+8|0,F,100);if(Na=Cb(n+8|0),Oa=0,Qa=v[I>>2]&4,Qa?Na:Oa){break va}c=0}xa:{if(!ue(r)){break xa}t[p+1075794|0]=a;t[p+1075791|0]=a;if(!d){yP(f,s&65535,c,r,0)}e=p+1075776|0;a=u[e>>1];if(a){v[p+1075684>>2]=(a&32767)-1;if((a|0)<=-1){a=p+1075080|0;v[a>>2]=v[a>>2]|256}u[e>>1]=0}a=p+1075787|0;e=w[a|0];if(e){t[p+1075830|0]=e-1;t[a|0]=0}a=p+1075788|0;e=w[a|0];if(!e){break xa}t[p+1075829|0]=e-1;t[a|0]=0}ya:{za:{Aa:{Ba:{Ca:{if(c){e=p+1075096|0;h=v[e>>2];xo(f,q,c,d,1,1);a=v[e>>2];Da:{if(!a|!(w[a+35|0]&2)){break Da}if(!Dd(H)){break Da}xu(v[H>>2],s&65535,v[e>>2]+68|0)}Ea:{Fa:{if(v[f+480180>>2]==1){if(!d){break Fa}Db(n+8|0,F,85);if(!Cb(n+8|0)){break Fa}break Ea}Db(n+8|0,F,50);if(!Cb(n+8|0)){break Fa}if(!ue(r)){break Ea}}t[p+1075795|0]=0}Db(n+8|0,F,42);if(Cb(n+8|0)){if(!ue(r)|(h|0)==v[e>>2]){break Ba}break Ca}if(!(!(v[f+480180>>2]&16777248)|(h|0)==v[e>>2])){a=0;if(ue(r)){break Aa}}Db(n+8|0,F,107);Ga:{if(!Cb(n+8|0)|(h|0)==v[e>>2]){break Ga}Ha:{if(!d){if(ue(r)){break Ha}}a=p+1075068|0;if(y[a>>2]>=y[q+4>>2]){break Ga}v[a>>2]=0;break Ba}d=0}Db(n+8|0,F,85);if(!Cb(n+8|0)){break Ba}if(!Mi(q)){break Ca}break Ba}if(!r){a=d;break ya}l=0;E=p+1075795|0;Ia:{if(!w[E|0]){break Ia}if(!ue(r)){break Ia}xo(f,q,w[E|0],d,!(v[p+1075096>>2]?1:v[p+1075648>>2]),!(v[f+480180>>2]&1048580));t[E|0]=0;l=1}a=d;break za}v[q>>2]=0;v[q+4>>2]=0}a=d}l=0;if(!r){break ya}}e=p+1075096|0;d=v[e>>2];Ja:{if(!d|!(w[d+35|0]&2)){break Ja}if(!Dd(H)){break Ja}if(!l){if(zP(v[H>>2],s&65535)){break Ja}}xu(v[H>>2],s&65535,v[e>>2]+68|0)}e=s&65535;lu(f,q,r,a,!(v[f+480180>>2]&1048580),0,e);if(!(!a|(!(v[f+480180>>2]&1048580)|!c))){c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;Gm(q);t[p+1075810|0]=0;v[p+1075748>>2]=0}if(!(v[p+1075080>>2]&512)){break ya}if(!Dd(H)){break ya}Ka:{switch(r-253|0){case 0:Db(n+8|0,F,99);if(Cb(n+8|0)){break ya}break;case 1:case 2:break Ka;default:break ya}}Db(n+8|0,F,110);if(Cb(n+8|0)){PA(v[H>>2],e,0,1,0)}pk(v[H>>2],e)}La:{Ma:{switch((m&255)-1|0){case 0:i=i>>>0<64?i:64;v[p+1075680>>2]=i<<2;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;break La;case 1:break Ma;default:break La}}Im(f,q,i,6)}if(x[f+480192>>1]){hO(f,s&65535)}d=a}Db(n+8|0,F,77);if(Na=Cb(n+8|0),Oa=0,Qa=v[(f+(s<<5)|0)+480280>>2]&1024,Qa?Na:Oa){break M}a=v[f+1074392>>2];Db(n+8|0,F,75);e=a>>>0>=T>>>0;Na:{Oa:{Pa:{Qa:{if(!Cb(n+8|0)|!T){break Qa}c=v[f+1074392>>2];if(!c){break Pa}e=1;if((c|0)!=(T|0)){break Qa}e=!w[W|0]&(m&255)!=11}a=m&255;if(!e|a>>>0<3){break Pa}if((a|0)==11){rA(n+8|0,f,J,T);a=w[Te(n+8|0)|0];to(f,q,x[n+8>>1]);if(a){break Oa}m=11;break Pa}Db(n+8|0,F,62);Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{if(!(!Cb(n+8|0)|i)){i=0;m=0;Ya:{switch(a-8|0){case 0:break Xa;case 1:break Ya;default:break Pa}}if(w[I+1|0]&16){break Pa}v[p+1075684>>2]=0;break Pa}Db(n+8|0,F,41);Za:{if(Cb(n+8|0)){break Za}if(i){t[p+1075826|0]=i;break Za}i=w[p+1075826|0]}_a:{switch(a-3|0){case 0:case 1:$a:{ab:{if(i){break ab}Db(n+8|0,F,41);if(!Cb(n+8|0)){break ab}i=w[p+1075826|0];if(i){break $a}i=0;break Pa}t[p+1075826|0]=i}wo(f,q,((a|0)==3?i<<4:i)&255);break Pa;case 2:if((T|0)!=v[f+1074392>>2]){Db(n+8|0,F,41);m=5;if(Cb(n+8|0)){break Pa}}Db(n+8|0,F,41);Bq(f,q,i,Cb(n+8|0));m=5;break Pa;case 3:if((T|0)!=v[f+1074392>>2]){Db(n+8|0,F,41);m=6;if(Cb(n+8|0)){break Pa}}Db(n+8|0,F,41);Aq(f,q,i,Cb(n+8|0));m=6;break Pa;case 11:break Ra;case 12:break Sa;case 10:break Ta;case 9:break Ua;case 7:break Va;case 6:break Wa;case 5:break Xa;case 4:break _a;default:break Pa}}Db(n+8|0,F,53);if(Cb(n+8|0)){t[p+1075815|0]=i&15;m=7;break Pa}Al(q,i<<4);m=7;break Pa}Al(q,i);m=8;break Pa}Db(n+8|0,F,62);iA(f,q,i,Cb(n+8|0)^1);m=9;break Pa}Db(n+8|0,F,62);iA(f,q,i<<4&240,Cb(n+8|0)^1);m=10;break Pa}m=12;Db(n+8|0,F,12);uP(f,s&65535,i<<2&252,Cb(n+8|0));break Pa}Db(n+8|0,F,12);tP(f,s&65535,i<<2&252,Cb(n+8|0));m=13;break Pa}m=15;if(!A){break Pa}a=p+1075096|0;if(!v[a>>2]|i>>>0>9){break Pa}bb:{if(!i){c=v[p+1075656>>2];break bb}c=v[(v[a>>2]+(i<<2)|0)- -64>>2];v[p+1075656>>2]=c}Hm(f,q,c);break Pa}m=14;if(i>>>0>1){break Pa}t[X|0]=w[X|0]&251|!i<<2}c=b;cb:{db:{eb:{fb:{switch($-1|0){case 12:if(!(w[I+1|0]&16)){break Oa}a=f+B(s,872)|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Oa;case 1:if(!b){c=0;if(v[f+480180>>2]&1){break Na}}uP(f,s&65535,b,0);break Oa;case 2:if(!b){c=0;if(v[f+480180>>2]&1){break Na}}tP(f,s&65535,b,0);break Oa;case 10:if(!b){c=0;if(v[f+480180>>2]==1){break Na}}wo(f,q,b);break Oa;case 3:to(f,q,b);break Oa;case 5:if(v[f+480180>>2]==1?b:1){wo(f,q,b)}to(f,q,0);break Oa;case 4:Al(q,b);break Oa;case 6:if(v[f+480180>>2]==1?b:1){wo(f,q,b)}Al(q,0);break Oa;case 15:if(!(w[I+1|0]&16)){break Oa}break cb;case 16:Db(n+8|0,F,5);if(Cb(n+8|0)){if(!(w[I+1|0]&16)){break Oa}if(b){break cb}break Oa}c=Jm(f,x[f+1074446>>1],v[f+1074424>>2],s&65535,0);gb:{if(!(v[f+480180>>2]&16777250)){break gb}if(c){t[(f+B(s,872)|0)+1075827|0]=c;break gb}c=w[(f+B(s,872)|0)+1075827|0]}v[n+8>>2]=B(c,1e4);tc(n+8|0,B(v[v[f+8>>2]+24>>2],1e4));b=gb-16|0;gb=b;d=v[n+8>>2];v[b+8>>2]=d;a=f;e=v[a+8>>2];hb:{if(d>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){d=v[a+480208>>2];Db(b,a+1074312|0,92);if((Cb(b)|0)==((d&4096)>>>12|0)){break hb}v[b>>2]=B(v[e+24>>2],1e4);e=a+1074420|0;a=b+8|0;Na=e,Oa=v[(sn(b,a)?b:a)>>2],v[Na>>2]=Oa;break hb}if(w[a+480209|0]&16){break hb}h=a+1074420|0;d=(d>>>0)/1e4|0;l=B(d&15,1e4);v[h>>2]=v[h>>2]+((d&240)==16?l:0-l|0);d=v[e+20>>2];e=v[e+24>>2];Db(b,a+1074312|0,8);Ap(h,B(d,1e4),Cb(b)?255e4:B(e,1e4))}gb=b+16|0;break Na;case 9:if(!A|(v[f+480180>>2]==4?d:0)){break Oa}HP(f,q,s&65535,G);break Oa;case 43:if(!A){break Oa}c=jqa(v[(f+B(s,872)|0)+1075068>>2],0,b,0);a=jb;e=a>>>8|0;Hm(f,q,Qc((a&255)<<24|c>>>8,e));break Oa;case 0:if(v[f+1074392>>2]){break Oa}a=f+B(s,872)|0;ib:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break ib}a=v[a+1075648>>2];if(a){if(Ej(a)){break ib}}Db(n+8|0,F,13);if(Cb(n+8|0)){break ib}if(v[f+480180>>2]&16777248){break Oa}}if(!b){c=0;if(v[f+480180>>2]&5){break Na}t[(f+B(s,872)|0)+1075797|0]=1;break Na}a=f+B(s,872)|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Oa;case 14:if(v[f+480180>>2]&1048580){b=b&240?b:w[(f+B(s,872)|0)+1075799|0]&240|b;if(!(b&15)){b=w[(f+B(s,872)|0)+1075799|0]&15|b}b=b|256}c=b;Db(n+8|0,F,23);if(Cb(n+8|0)){b=f;e=s&65535;if(c){t[(f+B(s,872)|0)+1075799|0]=c;a=c}else{a=w[(f+B(s,872)|0)+1075799|0]}hA(b,e,a&255,(m&255)==15?i+1|0:0);break Na}jb:{if(c){t[(f+B(s,872)|0)+1075799|0]=c;break jb}c=w[(f+B(s,872)|0)+1075799|0]}hA(f,s&65535,c,(m&255)==15?i+1|0:0);break Na;case 17:if(!(w[I+1|0]&16)){break Oa}Db(n+8|0,F,22);kb:{lb:{if(Cb(n+8|0)){if(!b){b=0;break lb}if(w[I|0]&4){break lb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;break lb}Db(n+8|0,F,71);if(!Cb(n+8|0)){break kb}}a=(f+B(s,872)|0)+1075831|0;t[a|0]=w[a|0]|128}a=f+B(s,872)|0;t[a+1075797|0]=18;if(!b){c=0;break Na}t[a+1075832|0]=b;break Oa;case 22:if(!(w[I+1|0]&16)){break Oa}c=b<<!(v[f+480180>>2]&59593760);if(c>>>0<=128){v[f+1074456>>2]=c<<1;break Na}if(v[f+480180>>2]&16777250){break Na}v[f+1074456>>2]=256;break Na;case 23:Db(n+8|0,F,9);if(Cb(n+8|0)){sP(f,b,(f+B(s,872)|0)+1075809|0);break Oa}sP(f,b,ba);break Oa;case 8:if(!(w[I+1|0]&16)){break Oa}Im(f,q,b,8);break Oa;case 28:iA(f,q,b,1);break Oa;case 7:KP(q,b);break Oa;case 25:LP(f,q,b);break Oa;case 18:a=f;i=a+1074376|0;d=s&65535;l=B(d,872);h=(i+l|0)+616|0;e=b&15;mb:{nb:{switch(b>>>4|0){case 0:if(!x[a+480188>>1]){break mb}c=(c&1)<<14;d=0;while(1){e=(a+B(d,872)|0)+1075080|0;v[e>>2]=(c|v[e>>2]&-16385)^16384;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break};break mb;case 1:if(!(v[a+480180>>2]&1048580?1:e)){break mb}jP(a,h,e);break mb;case 2:if(!(v[a+480180>>2]&1048580?1:e)){break mb}iP(a,h,e);break mb;case 3:a=(a+l|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break mb;case 4:t[(a+l|0)+1075814|0]=c&7;break mb;case 5:if(!(w[a+480209|0]&16)){break mb}if(v[a+480180>>2]&69206025){c=a+B(d,872)|0;h=c+1075764|0;u[h>>1]=e<<28>>24;e=c+1075692|0;if(!v[e>>2]){break mb}if(!de(c+1075780|0)){break mb}c=a;a=a+B(d,872)|0;Na=e,Oa=Zg(c,w[a+1075789|0],u[h>>1],v[a+1075696>>2]),v[Na>>2]=Oa;break mb}l=v[a+480180>>2];h=de((a+B(d,872)|0)+1075780|0);if((l|0)==16){if(!h){break mb}c=a+B(d,872)|0;h=v[c+1075096>>2];if(!h){break mb}t[h+37|0]=e;u[c+1075764>>1]=e;c=c+1075692|0;if(!v[c>>2]){break mb}h=a;a=a+B(d,872)|0;Na=c,Oa=Zg(h,w[a+1075789|0],e,v[a+1075696>>2]),v[Na>>2]=Oa;break mb}if(!h){break mb}e=a+B(d,872)|0;c=(c<<4^-128)<<24>>24;u[e+1075764>>1]=c;d=e+1075692|0;if(!v[d>>2]){break mb}Na=d,Oa=Zg(a,w[e+1075789|0],c,v[e+1075696>>2]),v[Na>>2]=Oa;break mb;case 6:if(!(w[a+480209|0]&16)){break mb}mu(a,i,h,e);break mb;case 7:t[(a+l|0)+1075817|0]=c&7;break mb;case 8:if(!(w[a+480209|0]&16)){break mb}Im(a,h,e,4);break mb;case 9:hA(a,d,e,0);break mb;case 10:if(!(v[a+480180>>2]&1048580?1:e)){break mb}Bq(a,h,e,0);break mb;case 11:if(!(v[a+480180>>2]&1048580?1:e)){break mb}Aq(a,h,e,0);break mb;case 12:jA(a,d,e,0);break mb;case 15:break nb;default:break mb}}if(v[a+480180>>2]==1){t[(a+B(d,872)|0)+1075838|0]=e;if(!(w[a+480209|0]&16)){break mb}vP(a,h);break mb}t[(a+B(d,872)|0)+1075836|0]=e}break Oa;case 19:Db(n+8|0,F,78);a=f;e=s&65535;c=b;ob:{if(!Cb(n+8|0)){break ob}c=b;if(b){break ob}c=w[(f+B(s,872)|0)+1075798|0]}rP(a,e,c);break Na;case 24:Db(n+8|0,F,55);if(Cb(n+8|0)){if(v[f+1074392>>2]!=(b|0)){break Oa}a=v[(f+B(s,872)|0)+1075648>>2];if(t[a+60|0]&1?a:0){break db}if(!(!(w[Z|0]?1:w[W|0])|b)){a=(f+B(s,872)|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break db}a=f+B(s,872)|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break db}if(w[I+1|0]&16){break db}break Oa;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Oa}if(!(1<<a&880)){if(!a){break eb}if((a|0)!=1){break Oa}qP(f,q,b&15);break Oa}Db(n+8|0,F,58);if(Cb(n+8|0)){break Oa}rP(f,s&65535,b);break Oa;case 34:case 35:if(!((j&255)!=36?w[I+1|0]&16:1)){break Oa}a=s&65535;FP(f,a,G,(j&255)==36);c=hu(f,a);if(!c){break Oa}kb[v[v[c>>2]+80>>2]](c,x[q+774>>1]>>>2^8192,a);break Oa;case 20:if(!(w[I+1|0]&16)|b>>>0>64){break Oa}a=f+B(s,872)|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Oa;case 21:e=f;c=q;a=b;pb:{if(a){t[c+816|0]=a;break pb}a=w[c+816|0]}l=a&255;d=c;i=a&240;h=a&15;qb:{rb:{if(!(!i|(h|0)!=15)){if(!(w[e+480209|0]&16)){break qb}a=l>>>4|0;break rb}j=v[e+480208>>2]&4096;if(!(!h|(i|0)!=240)){if(!j){break qb}a=0-h|0;break rb}if(j){break qb}if(h){a=0-h|0;if(!(v[e+480180>>2]&25690144)|!i){break rb}break qb}if((a&255)>>>0<16){break qb}a=l>>>4|0}Na=d,Oa=Mb(a+v[c+748>>2]|0,0,64),v[Na+748>>2]=Oa}break Oa;case 26:JP(q,b);break Oa;case 29:if(!(w[I+1|0]&16)){break Oa}a=f+B(s,872)|0;v[a+1075716>>2]=b;Db(n+8|0,F,60);if(Na=0,Oa=Cb(n+8|0),Qa=w[a+1075722|0]&4,Qa?Na:Oa){break Oa}a=f+B(s,872)|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Oa;case 11:qA(f,G,s&65535);break Oa;case 13:a=pA(f,G,s&65535,b);if((a|0)==-1){break Oa}v[f+1074436>>2]=a;if(!(w[f+480208|0]&32)){break Oa}u[f+1074444>>1]=x[f+1074448>>1];break Oa;case 37:case 38:case 39:case 40:a=q;e=b;c=j&255;d=(c|0)==38|(c|0)==40;h=(j&254)==40;c=f;sb:{if(w[c+480209|0]&16){c=w[a+848|0];d=e&240;if(d){c=d|c&15;t[a+848|0]=c}e=e&15;if(e){c=e|c&-16;t[a+848|0]=c}t[a+849|0]=(c&240)>>>4;break sb}e=w[a+849|0]-1|0;t[a+849|0]=e;tb:{if(e&255){break tb}e=w[a+848|0];t[a+849|0]=e>>>4;e=e&15;e=d?e:0-e|0;ub:{if(Gj(a)){v[a+852>>2]=v[a+852>>2]+B(e,v[v[v[a+656>>2]+44>>2]+36>>2]);break ub}Na=a,Oa=Zg(c,gu(c,v[a+700>>2],0,0)+e|0,8363,0),v[Na+700>>2]=Oa}if(!h){break tb}v[a>>2]=0;v[a+4>>2]=0}}break Oa;case 41:nA(q,b);break Oa;case 42:break fb;default:break Na}}if(v[f+1074392>>2]|aa>>>0>2|b>>>0>31){break Oa}a=(b&240)==16;c=a?0:s;e=(a?x[f+480188>>1]-1|0:s)&65535;if((c&65535)>>>0>e>>>0){break Oa}a=((aa|0)==1)<<26;while(1){d=c&65535;h=(f+(d<<5)|0)+480280|0;v[h>>2]=a|v[h>>2]&-67108865;d=(f+B(d,872)|0)+1075080|0;v[d>>2]=a|v[d>>2]&-67108865;c=c+1|0;if(e>>>0>=(c&65535)>>>0){continue}break}break Oa}pP(f,q,b&15);break Oa}vo(f,q);break Oa}MP(f,G,b)}c=b}Db(n+8|0,F,78);if(!(!Cb(n+8|0)|!c)){a=c&255;t[q+840|0]=a;t[q+812|0]=a;t[q+811|0]=a;t[q+809|0]=a;t[q+807|0]=a;t[q+806|0]=a;t[q+826|0]=a>>>4;t[q+827|0]=a<<2&60}a=w[W|0];if(!a){break M}t[p+1075796|0]=a}s=s+1|0;if(s>>>0<x[f+480188>>1]){continue}break}}vb:{if(!(w[I+1|0]&16)){break vb}if(!EP(f,G,1)){break vb}v[I>>2]=v[I>>2]|524288}gb=n+16|0;a=1;break l}a=0}gb=N+32|0;wb:{if(!a|!v[o+1074420>>2]){break wb}a=EO(o,o+1074376|0);v[o+1074380>>2]=a;v[o+1074404>>2]=a;b=Gd(x[o+480188>>1],1,31);F=o+1074332|0;xb:{if(w[F+34|0]){a=v[o+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}l=((B(v[o+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+38400|0]|0;break xb}l=v[o+480228>>2]}u[o+480212>>1]=0;E=o+1298260|0;r=o+1074312|0;N=o+480210|0;T=o+480209|0;i=0;while(1){j=o+B(i,872)|0;q=j+1075080|0;yb:{if(!(v[q>>2]&4096)|(v[j+1075016>>2]|(v[j+1075012>>2]|v[j+1075688>>2]))){break yb}Db(k+16|0,r,64);if(Cb(k+16|0)){break yb}v[j+1075068>>2]=0;a=j+1075084|0;v[a>>2]=0;v[a+4>>2]=0}e=x[o+480188>>1];b=v[q>>2];zb:{if(v[j+1075068>>2]|e>>>0>i>>>0?b&1024:1){if(e>>>0>i>>>0){oO(o,i&65535)}u[j+1075834>>1]=0;break zb}c=0;J=j+1075712|0;v[J>>2]=0;n=j+1075672|0;v[n>>2]=0;p=j+1075e3|0;a=p;v[a>>2]=0;v[a+4>>2]=0;v[j+1075092>>2]=0;v[k+44>>2]=1065353216;u[k+42>>1]=0;H=j+1075648|0;I=v[H>>2];v[k+36>>2]=0;g=0;A=j+1075692|0;g=v[A>>2]?v[j+1075068>>2]!=0:g;a=j+1074992|0;Ab:{Bb:{Cb:{if(e>>>0<=i>>>0){break Cb}if(w[(o+(i<<5)|0)+480288|0]){break Bb}if(!I){break Cb}c=w[I+34|0]!=0}if((c|g)!=1){break Ab}}v[k+8>>2]=v[j+1075680>>2];v[k+32>>2]=v[j+1075744>>2];Db(k+16|0,r,28);b=a;c=Cb(k+16|0)?k+32|0:k+8|0;e=gb-16|0;gb=e;d=o+1074312|0;Db(e+8|0,d,28);Db:{if(Cb(e+8|0)){v[c>>2]=v[c>>2]+u[b+776>>1];Sd(c,0,64);break Db}Db(e+8|0,d,1);f=Cb(e+8|0);d=u[b+776>>1];if(f){v[c>>2]=d+v[c>>2];Sd(c,0,256);break Db}v[b+688>>2]=d+v[b+688>>2];Sd(b+688|0,0,256);v[c>>2]=v[b+688>>2];u[b+776>>1]=0}gb=e+16|0;c=gb-16|0;gb=c;e=o+1074312|0;Db(c+8|0,e,28);Eb:{Fb:{if(!Cb(c+8|0)){Db(c,e,1);if(!Cb(c)){break Fb}}v[b+684>>2]=v[b+692>>2]+u[b+778>>1];Sd(b+684|0,0,256);break Eb}v[b+692>>2]=v[b+692>>2]+u[b+778>>1];Sd(b+692|0,0,256);u[b+778>>1]=0;v[b+684>>2]=v[b+692>>2]}gb=c+16|0;f=gb-16|0;gb=f;b=o;Gb:{if(!(w[a+90|0]&4)|(v[b+480208>>2]&2101248)==2101248){break Gb}e=a;Hb:{if(v[k+8>>2]<=0){Db(f+8|0,b+1074312|0,21);if(!Cb(f+8|0)){break Hb}}h=5;if(!(v[b+480180>>2]&5)){Db(f+8|0,b+1074312|0,21);h=Cb(f+8|0)?5:6}c=Hz(b,w[e+825|0],w[e+820|0]);Ib:{if((w[e+825|0]&3)!=1){break Ib}Db(f+8|0,b+1074312|0,89);if(!Cb(f+8|0)){break Ib}c=w[e+819|0];m=w[e+820|0];d=m<<2&124;c=(!(w[e+90|0]&2)|w[b+480209|0]&16?c:w[e+823|0]+c|0)&32?d^127:d;c=m&32?0-c|0:c}d=k;if(v[b+480180>>2]!=131072){c=v[k+8>>2]+((B(w[e+827|0],c)|0)/(1<<h)|0)|0}else{h=64-c|0;c=v[k+8>>2];c=((B(w[e+827|0],B(h,c))|0)/-8192|0)+c|0}v[d+8>>2]=c}if(!(v[b+480180>>2]&16777248)|w[b+480208|0]&4?w[b+480209|0]&16:0){break Gb}Db(f+8|0,b+1074312|0,21);b=Cb(f+8|0);d=e;c=w[e+826|0];e=w[e+820|0];t[d+820|0]=(b?c<<2:e)+(b?e:c)}gb=f+16|0;f=i&65535;d=f;h=gb-16|0;gb=h;b=o;c=b+1074312|0;Db(h+8|0,c,71);Jb:{if(Cb(h+8|0)){e=(b+B(d,872)|0)+1075831|0;c=t[e|0];if((c|0)>-1){break Jb}if(!(w[b+480209|0]&16|w[(b+B(d,872)|0)+1075797|0]!=18)){m=c&-33;t[e|0]=m;Kb:{Lb:{if((m|0)!=-64){c=c&223;if((c|0)!=128){break Lb}c=w[(b+B(d,872)|0)+1075832|0]>>>4|-64;break Kb}c=w[(b+B(d,872)|0)+1075832|0]&15|-128;break Kb}c=c-1|0}t[e|0]=c;e=(b+B(d,872)|0)+1075080|0;v[e>>2]=v[e>>2]|2097152}if((c&224)!=128){break Jb}v[k+8>>2]=0;break Jb}if(w[(b+B(d,872)|0)+1075797|0]!=18){break Jb}Db(h+8|0,c,22);Mb:{if(Cb(h+8|0)){s=b+B(d,872)|0;e=s+1075831|0;m=w[e|0];c=m<<24>>24;if(!((c|0)>-1|!v[s+1075068>>2])){Nb:{Ob:{if((m|0)!=192){if((m|0)!=128){break Ob}c=w[(b+B(d,872)|0)+1075832|0]>>>4|-64;break Nb}c=w[(b+B(d,872)|0)+1075832|0]&15|-128;break Nb}c=c-1|0}t[e|0]=c}if((c&192)!=128){break Mb}v[k+8>>2]=0;break Mb}c=w[(b+B(d,872)|0)+1075832|0];m=c>>>4|0;G=m+(c&15)|0;if(!(w[b+480208|0]&4?0:v[b+480180>>2]&16777248)){G=G+2|0;m=m+1|0}e=(b+B(d,872)|0)+1075831|0;c=w[e|0];if(!(v[b+480180>>2]&4)){c=(c&255)>>>0<G>>>0?c:0;if((c&255)>>>0>=m>>>0){v[k+8>>2]=0}t[e|0]=c+1;break Mb}Pb:{if(w[b+480209|0]&16){c=c&255?c-1|0:0;break Pb}t[e|0]=c+1}if(((c&255)>>>0)%(G>>>0)>>>0<m>>>0){break Mb}v[k+8>>2]=0}c=(b+B(d,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}c=b+B(d,872)|0;Qb:{if(w[c+1075797|0]!=18){break Qb}m=c+1075648|0;c=v[m>>2];if(!c|!w[c+34|0]|w[c+15|0]&2){break Qb}c=b+B(d,872)|0;if(v[c+1075080>>2]&134218752){break Qb}e=c+1075791|0;if(!ue(w[e|0])){break Qb}m=v[m>>2];c=v[(b+B(w[m+34|0],160)|0)+906140>>2];if(!c){break Qb}s=kb[v[v[c>>2]+100>>2]](c,w[e|0],d)|0;G=v[k+8>>2];if(!(!s|G)){kb[v[v[c>>2]+92>>2]](c,m,w[e|0]+255|0,0,d);break Qb}if(s|!G){break Qb}kb[v[v[c>>2]+92>>2]](c,m,w[e|0],x[(b+B(d,872)|0)+1075680>>1],d)}gb=h+16|0;Sd(k+8|0,0,256);v[k+8>>2]=v[k+8>>2]<<6;Rb:{if(I){Db(k+16|0,r,31);if(Cb(k+16|0)){Xt(o,a)}e=gb-16|0;gb=e;Sb:{if(!Gz(o,a,0)){break Sb}c=a;d=v[a+656>>2];h=b+1074312|0;Db(e+8|0,h,31);Tb:{if(Cb(e+8|0)){b=v[c+724>>2];if(b){break Tb}break Sb}b=v[c+724>>2]}Db(e+8|0,h,31);m=d+48|0;G=b-Cb(e+8|0)|0;b=Rq(m,G,256,64);s=w[d+65|0];Ub:{if((s|0)==255){break Ub}c=u[c+728>>1];if((c|0)==-1){break Ub}s=w[Lb(m,s)+2|0];m=x[Lb(m,w[d+65|0])>>1];Db(e+8|0,h,94);d=s<<2;b=(m|0)==(G|0)?d:b;if(Cb(e+8|0)){b=c+(b-d<<1)|0;break Ub}if(!s){b=0;break Ub}b=(B(b,c)|0)/(d|0)|0}Na=k,Oa=(B(v[k+8>>2],Mb(b,0,512))|0)/256|0,v[Na+8>>2]=Oa}gb=e+16|0;nO(a,k+8|0);e=gb-16|0;gb=e;b=o;Vb:{if(!Gz(b,a,1)){break Vb}c=a;d=v[a+656>>2];h=b+1074312|0;Db(e+8|0,h,31);Wb:{if(Cb(e+8|0)){b=v[c+732>>2];if(b){break Wb}break Vb}b=v[c+732>>2]}Db(e+8|0,h,31);d=Rq(d+68|0,b-Cb(e+8|0)|0,64,64)-32|0;b=v[c+684>>2];Na=c,Oa=Mb(((B(d,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Na+684>>2]=Oa}gb=e+16|0;c=v[a+656>>2];e=t[c+26|0];Xb:{if(!e){break Xb}b=a;d=w[a+797|0];if(!d){break Xb}Na=b,Oa=Mb(v[b+684>>2]+((B(e,d+(w[c+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Na+684>>2]=Oa}break Rb}if(!(w[q+1|0]&16)){break Rb}v[j+1075688>>2]=0;v[k+8>>2]=0}Yb:{if(w[j+1075843|0]&4){v[k+8>>2]=0;break Yb}b=v[k+8>>2];if(!b){break Yb}if(w[q+3|0]&8){v[n>>2]=0;break Yb}if(w[F+33|0]){c=B(v[k+32>>2],v[j+1075740>>2]);b=b<<8;Na=n,Oa=Ac(kqa(jqa(c,c>>31,b,b>>31),jb,1048576,0),jb),v[Na>>2]=Oa;break Yb}c=B(v[k+32>>2],v[j+1075740>>2]);b=B(b,v[o+1074456>>2]);Na=n,Oa=Ac(kqa(jqa(c,c>>31,b,b>>31),jb,1048576,0),jb),v[Na>>2]=Oa}v[J>>2]=v[k+8>>2];Zb:{_b:{if(v[o+480180>>2]==2|v[A>>2]>=v[o+480260>>2]){break _b}if(mk(o)){break _b}v[A>>2]=v[o+480260>>2];break Zb}if(v[A>>2]<v[o+480264>>2]){break Zb}Db(k+16|0,r,113);if(!Cb(k+16|0)){break Zb}v[A>>2]=v[o+480264>>2]}Db(k+16|0,r,73);if(Cb(k+16|0)){Mb(v[A>>2],1,31999)}b=v[A>>2];v[k+36>>2]=b;$b:{if((v[q>>2]&1572864)!=1572864){break $b}if(w[N|0]&32){if(!ou(j+1075780|0)|w[T|0]&16){break $b}b=v[k+36>>2]}c=j+1075704|0;ac:{if(v[c>>2]==(b|0)){b=v[j+1075708>>2];break ac}v[c>>2]=b;e=b;b=j+1075764|0;c=j+1075696|0;b=Zg(o,gu(o,e,u[b>>1],v[c>>2]),u[b>>1],v[c>>2]);v[j+1075708>>2]=b}v[k+36>>2]=b}m=gb-16|0;gb=m;d=o;G=d+B(f,872)|0;c=v[G+1075648>>2];bc:{if(!c){break bc}b=w[c+34|0];if(!b|w[c+15|0]&2|(!v[(d+B(b,160)|0)+906140>>2]|v[(d+B(f,872)|0)+1075080>>2]&134218752)){break bc}e=d+B(f,872)|0;W=e+1075783|0;R=w[W|0];b=0;h=e+1075791|0;if(ue(w[h|0])){b=w[lc(c+108|0,w[h|0]-1|0)|0]}s=e+1075780|0;cc:{dc:{if((R|0)==1){h=0;ec:{fc:{switch((y[d+1074392>>2]%3|0)-1|0){case 0:h=w[(d+B(f,872)|0)+1075798|0]>>>4|0;break ec;case 1:break fc;default:break ec}}h=w[(d+B(f,872)|0)+1075798|0]&15}c=d+B(f,872)|0;t[c+1075793|0]=b;if(w[c+1075792|0]==(b+h|0)){break cc}if(!(w[d+480209|0]&16)){break dc}if(!de(s)){break dc}break cc}h=0;if(w[s|0]|!w[(d+B(f,872)|0)+1075792|0]){break cc}}c=d+B(f,872)|0;Fm(d,f,w[c+1075793|0]+h|0,x[c+1075680>>1])}e=(d+B(f,872)|0)+1075792|0;c=w[e|0];gc:{if(!c){if(!(w[d+480209|0]&16)|(R|0)!=1){break gc}if(de(s)){break gc}c=b;if(!ue(b)){break gc}}Fm(d,f,(c&255)+255|0,0)}t[e|0]=w[W|0]==1?w[(d+B(f,872)|0)+1075793|0]+h|0:0}hc:{if(w[G+1075797|0]!=1){break hc}if(Gj(G+1074992|0)){b=0;ic:{jc:{kc:{switch(y[d+1074392>>2]%3|0){case 1:b=w[(d+B(f,872)|0)+1075798|0]>>>4|0;break jc;case 0:break jc;case 2:break kc;default:break ic}}b=w[(d+B(f,872)|0)+1075798|0]&15}u[k+42>>1]=b}b=(d+B(f,872)|0)+1075843|0;t[b|0]=w[b|0]|48;break hc}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){b=d+B(f,872)|0;c=Zg(d,w[b+1075789|0],u[b+1075764>>1],v[b+1075696>>2]);v[k+36>>2]=c;v[b+1075692>>2]=c}e=d+1074312|0;Db(m+8|0,e,13);if(Cb(m+8|0)){b=w[(d+B(f,872)|0)+1075798|0];if(!b){break hc}e=65536;lc:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:e=v[((b&240)<<2)+43568>>2];break;default:break lc}}f=mk(d);b=v[k+36>>2];c=b;b=b>>31;d=k;if(f){c=jqa(c,b,e,e>>31)+32768|0;b=jb;b=kqa(c,c>>>0<32768?b+1|0:b,65536,0)}else{f=(e|0)/2|0;h=f;s=f>>31;f=c;c=b<<16|c>>>16;f=f<<16;b=f+h|0;c=c+s|0;b=kqa(b,b>>>0<f>>>0?c+1|0:c,e,e>>31)}c=jb;Na=d,Oa=Ac(b,c),v[Na+36>>2]=Oa;break hc}Db(m+8|0,e,51);if(Cb(m+8|0)){if(w[d+480209|0]&16){break hc}mc:{nc:{b=v[d+1074416>>2];b=b-(y[d+1074392>>2]%(b>>>0)|0)|0;if((b|0)>16){break nc}if((b|0)==16){break hc}h=0;oc:{switch((b|0)%3|0){case 0:break hc;case 2:break nc;case 1:break oc;default:break mc}}h=w[(d+B(f,872)|0)+1075798|0]>>>4|0;break mc}h=w[(d+B(f,872)|0)+1075798|0]&15}b=d+B(f,872)|0;c=b+1075764|0;b=b+1075696|0;e=gu(d,v[k+36>>2],u[c>>1],v[b>>2])+h|0;c=Zg(d,e,u[c>>1],v[b>>2]);v[k+36>>2]=c;if(e>>>0<109){break hc}v[m+8>>2]=c;Na=m,Oa=Zg(d,109,0,v[b>>2]),v[Na+4>>2]=Oa;Na=k,Oa=v[Mc(m+8|0,m+4|0)>>2],v[Na+36>>2]=Oa;break hc}b=v[d+1074392>>2];if(v[d+480180>>2]!=1){h=w[(d+B(f,872)|0)+1075789|0]}else{c=d+B(f,872)|0;h=gu(d,v[k+36>>2],u[c+1075764>>1],v[c+1075696>>2])}pc:{qc:{switch((((v[d+480180>>2]&67633152?b+2|0:b)>>>0)%3|0)-1|0){case 0:h=(w[(d+B(f,872)|0)+1075798|0]>>>4|0)+h|0;break pc;case 1:break qc;default:break pc}}h=(w[(d+B(f,872)|0)+1075798|0]&15)+h|0}if(!(v[d+480180>>2]&67633408|w[(d+B(f,872)|0)+1075789|0]!=(h&255))){Db(m+8|0,e,82);if(!Cb(m+8|0)){break hc}}c=k;X=d;if(w[d+480210|0]&32){s=h&255;if((s|0)==85){v[k+36>>2]=2147483647;break hc}h=s>>>0>85?h-37|0:h}b=d+B(f,872)|0;Na=c,Oa=Zg(X,h&255,u[b+1075764>>1],v[b+1075696>>2]),v[Na+36>>2]=Oa;if(v[d+480180>>2]&71827712){v[b+1075692>>2]=v[k+36>>2];break hc}Db(m+8|0,e,82);if(!Cb(m+8|0)){break hc}t[(d+B(f,872)|0)+1075792|0]=h}gb=m+16|0;if(!(!(w[N|0]&33)|v[k+36>>2]==2147483647)){rc:{if(v[o+480180>>2]==2){b=452;c=3424;break rc}c=B(x[j+1075764>>1]>>>4&15,24);b=x[c+39302>>1];b=b>>>0<904?452:b>>>1|0;c=x[c+39280>>1]<<1}Sd(k+36|0,b,c);Sd(A,b,c)}Lz(o,a);b=v[q>>2]}sc:{if(!(b&256)|w[T|0]&64){break sc}Db(k+16|0,r,37);if(!Cb(k+16|0)){break sc}v[j+1075676>>2]=128}m=i&65535;oO(o,m);tc:{if(!g){break tc}b=mO(o,a,k+36|0);if((b|0)<0|!(w[q+1|0]&2)){break tc}if(!Dd(E)){break tc}Mq(v[E>>2],m,b>>>2&255,1)}uc:{if(w[j+1075782|0]!=8){break uc}vc:{wc:{b=w[j+1075783|0];switch(b-5|0){case 1:break uc;case 0:case 2:break vc;default:break wc}}if((b|0)!=26){break uc}}if(v[o+480180>>2]==4){if(w[T|0]&16){break uc}b=j+1075811|0;t[b|0]=w[b|0]+w[j+1075815|0];break uc}if(!(v[o+480180>>2]&16777248)){break uc}Al(a,w[j+1075784|0]);lO(o,m,k+36|0,k+44|0)}lO(o,m,k+36|0,k+44|0);xc:{if(!g){break xc}v[k+32>>2]=0;e=o;c=k+36|0;A=gb-16|0;gb=A;h=v[a+104>>2];yc:{if(!h|!w[h+40|0]){break yc}b=a;R=Gj(a);d=mk(e);Db(A+8|0,e+1074312|0,21);g=d?44592:43568;f=d?43568:44592;if(!(R|!Cb(A+8|0)|v[e+480180>>2]==1048576)){if(!w[h+41|0]){break yc}s=w[b+818|0];v[A+4>>2]=v[b+756>>2]+w[h+39|0];Zj(A+4|0,w[h+40|0]<<8);G=v[A+4>>2];v[b+756>>2]=G;G=(G|0)/256|0;v[A+4>>2]=G;t[b+818|0]=w[b+818|0]+w[h+41|0];zc:{Ac:{switch(w[h+38|0]-1|0){case 3:b=jO(uo(e))+-64|0;G=v[A+4>>2];break zc;case 2:b=64-(s+1>>>1|0)|0;break zc;case 1:b=(s+1>>>1|0)+-64|0;break zc;case 0:b=(s>>>1^-1)&64;break zc;default:break Ac}}b=t[s+39872|0]}Zj(c,8388607);h=v[c>>2]<<8;v[c>>2]=h;G=B(b,G);e=(G|0)/64|0;b=e>>31;s=b^b+e;b=s>>>2|0;e=c;Bc:{if((G|0)<=-64){b=v[(b<<2)+g>>2];g=Ac(kqa(jqa(b,b>>31,h,h>>31),jb,65536,0),jb);b=v[c>>2];f=g-b|0;g=f;h=s&3;if(!h){break Bc}g=v[(h<<2)+(d?43504:43440)>>2];g=Ac(kqa(jqa(g,g>>31,b,b>>31),jb,65536,0),jb)+f|0;b=v[c>>2];g=g-b|0;break Bc}b=v[f+(b<<2)>>2];g=Ac(kqa(jqa(b,b>>31,h,h>>31),jb,65536,0),jb);b=v[c>>2];f=g-b|0;g=f;h=s&3;if(!h){break Bc}g=v[(h<<2)+(d?43440:43504)>>2];g=Ac(kqa(jqa(g,g>>31,b,b>>31),jb,65536,0),jb)+f|0;b=v[c>>2];g=g-b|0}v[e>>2]=(b+g|0)/256;v[k+32>>2]=g&255;break yc}Cc:{if(!(w[h+39|0]|v[e+480180>>2]&16777248)){v[b+756>>2]=w[h+40|0]<<8;break Cc}Dc:{Ec:{if(v[e+480180>>2]&16777248){s=w[h+39|0]<<1;G=v[b+756>>2];d=b+756|0;break Ec}if(w[b+89|0]&8){break Dc}G=((w[h+40|0]<<8&65280)>>>0)/w[h+39|0]|0;s=v[b+756>>2];d=b+756|0}v[d>>2]=s+G}Zj(b+756|0,w[h+40|0]<<8)}d=w[b+818|0]+w[h+41|0]|0;t[b+818|0]=d;d=d<<24>>24;Fc:{Gc:{switch(w[h+38|0]-1|0){case 3:t[b+818|0]=d+1;s=t[(d&63)+39808|0];break Fc;case 2:s=(64-(d>>>1|0)&127)+-64|0;break Fc;case 1:s=((d>>>1|0)- -64&127)+-64|0;break Fc;case 0:s=(d|0)>-1?-64:64;break Fc;default:break Gc}}d=w[b+818|0];s=0-t[d+39872|0]|0;if(v[e+480180>>2]!=1048576){break Fc}s=(64-t[(d+-64&255)+39872|0]|0)/2<<16>>16}d=s;s=B(d,v[b+756>>2]);G=(s|0)/256|0;if(R){z[k+44>>2]=C(C(C(d|0)*C(1220703143189894e-20))*C(w[h+40|0]))+z[k+44>>2];t[b+851|0]=w[b+851|0]|32;break yc}if(v[e+480180>>2]!=4){Hc:{if((s|0)<=-256){G=0-G|0;b=0-s>>>16|0;e=(b<<2)+g|0;break Hc}g=f;b=(s|0)/65536|0;e=f+(b<<2)|0}d=v[c>>2];g=v[((b<<2)+g|0)+4>>2];b=v[e>>2];b=((B(g-b|0,(G|0)/4&63)|0)/64|0)+b|0;b=Ac(kqa(jqa(d,d>>31,b,b>>31),jb,256,0),jb);v[c>>2]=b;v[k+32>>2]=b&255;v[c>>2]=v[c>>2]/256;break yc}v[c>>2]=v[c>>2]+((s|0)/16384|0)}gb=A+16|0;if(v[k+36>>2]<=v[o+480260>>2]){Db(k+16|0,r,81);if(Cb(k+16|0)){v[j+1075068>>2]=0}v[k+36>>2]=v[o+480260>>2]}Ic:{if(!Gj(a)){break Ic}b=j+1075843|0;c=w[b|0];if(!(v[o+1074392>>2]|!(c&16)?c&32:1)){break Ic}GS(a,z[k+44>>2],u[k+42>>1],o);c=b;b=w[b|0];t[c|0]=(b&32?-33:-17)&b}Kz(k+16|0,o,a,v[k+36>>2],v[k+32>>2]);c=jqa(v[k+16>>2],v[k+20>>2],v[o+480240>>2],0);e=jb;g=kqa(c,e,65536,0);d=jb;b=k;c=c+65535|0;e=c>>>0<65535?e+1|0:e;c=!e&c>>>0<131071;g=c?1:g;v[b+16>>2]=g;b=c?0:d;v[k+20>>2]=b;v[p>>2]=g;v[p+4>>2]=b;if((v[q>>2]&134219264)!=512){break xc}if(!Dd(E)){break xc}Db(k+8|0,r,99);if(Na=Cb(k+8|0)|!(w[q+1|0]&16),Oa=1,Qa=v[o+480180>>2]!=2,Qa?Na:Oa){Jc:{if(w[q+1|0]&8?v[o+480180>>2]==2:0){break Jc}b=jqa(v[k+24>>2],0,261625,0)+66904|0;g=jb;c=Qc(mqa(b,b>>>0<66904?g+1|0:g,133808,0),jb);g=v[q>>2];b=1;Kc:{if(g&2048){break Kc}b=0;if(!(g&4096)){break Kc}b=!v[j+1075688>>2]}Db(k+8|0,r,110);if(Na=Cb(k+8|0),Oa=0,Qa=b,Qa?Na:Oa){break Jc}g=v[E>>2];Db(k+8|0,r,95);PA(g,m,c,b,Cb(k+8|0))}c=v[E>>2];b=jqa(B(v[j+1075744>>2],B(v[j+1075740>>2],v[J>>2])),0,63,0)+33554432|0;e=jb;e=b>>>0<33554432?e+1|0:e;Mq(c,m,Qc((e&67108863)<<6|b>>>26,e>>>26|0)&255,0);b=j+1075676|0;d=b;c=v[b>>2];g=0;b=v[E>>2];e=Gl(b,m);Lc:{if((e|0)==255){break Lc}if(qk(b)){break Lc}g=lc(QA(b+314|0,e),10);f=v[b>>2];e=yu(e)|192;b=w[g|0]&-49;b=(c|0)<171?b|16:b;b=((c|0)>84?b|32:b)&255;Yh(f,e,b);g=(b>>>5&1)+(b<<27>>31)|0}v[d>>2]=(g<<7)+128}Mc:{b=v[H>>2];if(!b|(w[b+60|0]&7)!=1){break Mc}b=b+48|0;if(bd(b)){break Mc}c=v[kO(a,0)>>2];b=oo(b);if(c>>>0<x[b>>1]|w[b+2|0]){break Mc}Ni(v[E>>2],m,1);Db(k+8|0,r,109);b=Cb(k+8|0);c=v[q>>2];v[q>>2]=(b?c:c&-4609)|4096;v[j+1075688>>2]=0;break xc}Db(k+8|0,r,99);if(!Cb(k+8|0)|!(w[q+1|0]&16)|v[j+1075688>>2]){break xc}Ni(v[E>>2],m,1);v[q>>2]=v[q>>2]&-513}Nc:{if(!I){break Nc}Db(k+16|0,r,31);if(Cb(k+16|0)){break Nc}Xt(o,a)}c=v[q>>2];b=c&-65537;h=j+1075012|0;m=j+1075016|0;v[q>>2]=v[h>>2]|(v[m>>2]|v[n>>2])?(b|c<<7&65536)^65536:b;e=j+1075664|0;v[e>>2]=0;v[e+4>>2]=0;d=j+1075834|0;c=w[d|0];b=c-4|0;t[d|0]=b>>>0>c>>>0?0:b;f=j+1075835|0;c=w[f|0];b=c-4|0;t[f|0]=b>>>0>c>>>0?0:b;Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{b=j+1075096|0;c=v[b>>2];Uc:{if(!c){break Uc}if(!Nd(c)|!v[j+1075068>>2]){break Uc}if(Mi(a)){break Tc}}c=j+1075008|0;v[c>>2]=0;break Sc}c=j+1075008|0;b=v[v[b>>2]+20>>2];v[c>>2]=b;if(b){break Rc}}if(!nk(a)|w[q+1|0]&24){break Qc}}s=v[n>>2];A=v[j+1075676>>2];b=(B(s,256-A|0)|0)/16384|0;g=b>>>0<127?b:127;b=t[d|0];if((b|0)<=-1){t[d|0]=g;I=g}else{I=b}b=g>>>1|0;if((I&255)>>>0<b>>>0){t[d|0]=b}b=(B(s,A)|0)/16384|0;b=b>>>0<127?b:127;g=b>>>1|0;A=g;d=t[f|0];if((d|0)<=-1){t[f|0]=b}else{b=d}if((b&255)>>>0<A>>>0){break Pc}break Oc}if(w[d|0]>=129){t[d|0]=0}g=0;if(w[f|0]<129){break Oc}}t[f|0]=g}Vc:{Wc:{if(v[c>>2]){b=j+1075668|0;Xc:{if(y[o+24624>>2]>=2){v[k+16>>2]=v[j+1075676>>2];Sd(k+16|0,0,256);d=B(l,v[n>>2])>>>(w[F+34|0]?7:8)|0;c=b;Yc:{Zc:{_c:{switch(w[F+32|0]){case 0:if(!(w[o+24616|0]&16)){break Zc}case 1:g=v[k+16>>2];if((g|0)<=127){v[e>>2]=d>>>1;g=(B(d,g)|0)/256|0;break Yc}v[e>>2]=(B(d,256-g|0)|0)/256;g=d>>>1|0;break Yc;case 3:break _c;default:break Zc}}Zj(k+16|0,255);g=e;f=v[k+16>>2];if((f|0)<1){h=65536}else{h=x[(0-f<<1)+46128>>1]}v[g>>2]=B(h,d)>>>16;g=B(d,x[(f<<1)+45616>>1])>>>16|0;break Yc}g=v[k+16>>2];v[e>>2]=(B(d,256-g|0)|0)/256;g=(B(d,g)|0)/256|0}v[c>>2]=g;break Xc}c=B(l,v[n>>2])>>>8|0;v[e>>2]=c;v[b>>2]=c}f=j+1075786|0;g=f;$c:{ad:{c=v[H>>2];if(!c){break ad}if(!rp(w[c+14|0])){break ad}c=w[v[H>>2]+14|0];break $c}if(rp(w[o+480268|0])){c=w[o+480268|0];break $c}c=w[o+24648|0];c=w[N|0]&128?v[o+24668>>2]?-1:c:c}t[g|0]=c;d=v[q>>2];g=v[p>>2];h=v[p+4>>2];if(!(d&131072|((g|0)!=0|(h|0)!=1)|(v[j+1075748>>2]|(c&255)==255))){t[f|0]=0}c=1<<v[F+28>>2];v[e>>2]=v[e>>2]/(c|0);c=v[b>>2]/(c|0)|0;v[b>>2]=c;if(!(!(d&256)|v[o+24624>>2]!=2)){v[b>>2]=0-c}if(d&128){v[p>>2]=0-g;v[p+4>>2]=0-(((g|0)!=0)+h|0)}f=o;G=0;d=gb-16|0;gb=d;e=a;v[a+28>>2]=0;v[a+32>>2]=0;h=a;bd:{cd:{c=v[a+88>>2];if(!(c&65536)){a=v[e+676>>2];b=v[e+672>>2];break cd}b=v[e+20>>2];A=v[e+672>>2];dd:{if((b|0)!=(A|0)){a=v[e+24>>2];g=v[e+676>>2];break dd}a=v[e+24>>2];g=v[e+676>>2];if((a|0)==(g|0)){break cd}}m=f+24604|0;c=d;g=(b|0)<(A|0)|(a|0)<(g|0);ed:{if(g){a=JS(m);break ed}a=IS(m)}v[c+12>>2]=a;Db(d,f+1074312|0,4);if(!(!Cb(d)|!(v[f+480180>>2]&4))){a=v[f+24620>>2];a=jqa(a,a>>31,5,0)+500|0;c=jb;a=Ac(kqa(a,a>>>0<500?c+1|0:c,1e3,0),jb)}c=v[e+656>>2];fd:{if(!c){b=a;break fd}b=a;if(!g){break fd}c=x[c+12>>1];if(c){b=(B(c,v[f+24620>>2])>>>0)/1e5|0}G=(c|0)!=0}m=b?b:1;c=v[e+676>>2];b=v[e+24>>2];A=c-b<<12;g=v[e+672>>2];n=v[e+20>>2];p=g-n<<12;if(!(w[e+90|0]&32|(!(c|g)|(!(b|n)|G)))){v[d+12>>2]=v[f+1074380>>2];Sd(d+12|0,a,2048);g=v[e+672>>2];m=v[d+12>>2];c=v[e+676>>2]}f=(A|0)/(m|0)|0;v[e+32>>2]=f;A=(p|0)/(m|0)|0;v[e+28>>2]=A;a=((B(f,m)|0)/-4096|0)+c|0;v[e+24>>2]=a;b=((B(m,A)|0)/-4096|0)+g|0;v[e+20>>2]=b;if(f|A){v[e+100>>2]=m;c=v[e+88>>2];break bd}v[e+24>>2]=c;v[e+20>>2]=g;a=c;b=g;c=v[e+88>>2]&-65537;break bd}v[e+24>>2]=a;v[e+20>>2]=b;c=c&-65537}v[h+88>>2]=c&-2097153;v[e+40>>2]=a<<12;v[e+36>>2]=b<<12;gb=d+16|0;if(!(w[q+1|0]&2)){break Wc}break Vc}v[h>>2]=0;v[m>>2]=0;v[j+1075068>>2]=0;if(v[j+1075088>>2]){break Wc}if(!v[j+1075084>>2]){break Vc}}a=x[o+480212>>1];u[o+480212>>1]=a+1;u[(o+(a<<1)|0)+1074478>>1]=i}v[j+1075660>>2]=v[q>>2]}i=i+1|0;if((i|0)!=256){continue}break}g=1;if(y[o+24608>>2]>x[o+480212>>1]){break wb}a=o+1074478|0;b=a+(v[o+24608>>2]<<1)|0;l=a+(x[o+480212>>1]<<1)|0;f=gb-16|0;gb=f;v[f+8>>2]=o;h=f+8|0;d=h;c=a;e=b-a|0;if((e|0)>=3){o=e>>1;e=(o-2|0)/2|0;while(1){Dz(c,d,o,c+(e<<1)|0);i=(e|0)>0;e=e-1|0;if(i){continue}break}}if((b|0)!=(l|0)){c=b-a>>1;d=b;while(1){if(qq(h,x[d>>1],x[a>>1])){Ez(d,a);Dz(a,h,c,a)}d=d+2|0;if((l|0)!=(d|0)){continue}break}}c=b-a|0;if((c|0)>=3){d=c>>>1|0;while(1){Ez(a,b-2|0);Dz(a,h,d-1|0,a);b=b-2|0;c=(d|0)>2;d=d-1|0;if(c){continue}break}}gb=f+16|0}gb=k+48|0;if(g){a=v[M+480208>>2];break j}b=v[M+480208>>2]|512;if(w[M+1298380|0]){break k}a=0;b=M;c=v[b+24620>>2]/10|0;c=Ac(c,c>>31);gd:{if(!c){break gd}g=c>>>0<1048576?c:1048576;v[b+1074380>>2]=g;d=x[b+480212>>1];if(!d){break gd}e=b+1074376|0;while(1){b=e+B(x[(e+(a<<1)|0)+102>>1],872)|0;f=b+1288|0;v[f>>2]=0;v[f+4>>2]=0;v[b+716>>2]=g;f=v[b+640>>2]<<12;v[b+656>>2]=f;h=v[b+636>>2]<<12;v[b+652>>2]=h;v[b+704>>2]=v[b+704>>2]|65536;v[b+644>>2]=(0-h|0)/(g|0);v[b+648>>2]=(0-f|0)/(g|0);a=a+1|0;if((d|0)!=(a|0)){continue}break}}a=v[M+480208>>2];b=a|256;if(c){break k}b=a|512}a=b;v[K+480208>>2]=a}if(a&512){Na=M+1074392|0,Oa=ok(Aa),v[Na>>2]=Oa;break i}v[V+112>>2]=512;a=v[M+1074380>>2];v[V+108>>2]=3;v[V+120>>2]=ga;v[V+116>>2]=a;v[V+104>>2]=V+112;a=v[V+108>>2];v[V+48>>2]=v[V+104>>2];v[V+52>>2]=a;f=MX(V+48|0);if(v[M+24632>>2]){a=M;b=ma;c=0;d=gb-48|0;gb=d;g=f;l=f<<2;while(1){v[d+32>>2]=0;e=(a+(c<<11)|0)+16396|0;h=(l+e|0)-e>>2;if((h|0)>=1){while(1){v[e>>2]=v[d+32>>2];e=e+4|0;o=(h|0)>1;h=h-1|0;if(o){continue}break}}c=c+1|0;if((c|0)!=4){continue}break}c=0;while(1){v[(d+32|0)+(c<<2)>>2]=(a+(c<<11)|0)+16396;c=c+1|0;if((c|0)!=4){continue}break}a=kg(d+16|0,d+32|0,v[a+24632>>2],g);c=v[v[b>>2]+8>>2];v[d+8>>2]=v[a+8>>2];g=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=g;kb[c|0](b,d);gb=d+48|0}if(w[_+12|0]){a=0;while(1){v[(V+112|0)+(a<<2)>>2]=((a<<11)+M|0)+16396;a=a+1|0;if((a|0)!=4){continue}break}b=v[_+8>>2];a=kg(V+88|0,V+112|0,v[M+24632>>2],f);c=v[v[b>>2]+8>>2];v[V+40>>2]=v[a+8>>2];g=v[a+4>>2];v[V+32>>2]=v[a>>2];v[V+36>>2]=g;kb[c|0](b,V+32|0)}r=M;E=0;d=gb-112|0;gb=d;q=f;if(f){K=r+12|0;n=r+24592|0;p=r+24588|0;Mo(K,q,n,p);if(y[r+24624>>2]>=3){Mo(r+8204|0,q,r+24600|0,r+24596|0)}u[d+30>>1]=0;na=r+1074312|0;Db(d+8|0,na,33);a=Cb(d+8|0);if(x[r+480212>>1]){Ba=a?2:1;Ca=r+24648|0;F=r+24596|0;Da=r+24600|0;Ea=r+8204|0;s=r+397460|0;I=r+397456|0;N=r+393352|0;ra=r+1074376|0;while(1){j=ra+(E<<1)|0;a=B(x[j+102>>1],872);l=a+ra|0;X=l;hd:{id:{if(v[l+632>>2]){break id}b=a+r|0;if(v[b+1075088>>2]){break id}if(!v[b+1075084>>2]){break hd}}i=a+r|0;a=w[i+1075786|0]+1|0;if((a&255)>>>0<6){o=v[(a<<24>>24<<2)+34064>>2]}else{o=0}e=F;H=i+1075080|0;h=v[H>>2];jd:{if(!(!(h&16777216)&w[r+24612|0]>>>5)){c=K;b=p;g=h;a=n;if(!(g&8388608)){break jd}}b=q;a=N;if(!w[a+4116|0]){Mo(a+8|0,b,a+4104|0,a+4108|0)}t[a+4116|0]=1;c=a+8|0;g=v[H>>2];b=s;a=I}k=b;b=g>>>8&y[r+24624>>2]>2;W=b?e:k;Z=b?Da:a;b=b?Ea:c;ca=Em(r,x[j+102>>1],2,1);kd:{if((!ca|0)==(ca>>>0<251|0)){break kd}c=v[(r+B(ca,160)|0)+906140>>2];if(!c){break kd}a=v[c+24>>2];if(!a){break kd}W=c+36|0;Z=c+40|0;if(!(t[c+28|0]&1)){Mo(a,q,Z,W);v[c+28>>2]=v[c+28>>2]|1}b=a}l=l+616|0;if(w[i+1075843|0]&4){KS(l,b,q);a=i+1075084|0;v[Z>>2]=v[Z>>2]+v[a>>2];v[W>>2]=v[W>>2]+v[i+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break hd}G=0;a=d+8|0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;c=l;if(v[c+16>>2]){fF(a,c);g=v[c+12>>2];m=g>>31;c=m+v[c+8>>2]|0;e=g>>31;g=e+g|0;g=c>>>0<m>>>0?g+1|0:g;c=e^g;v[a+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}Fa=h>>>12&8|(h>>>5&2|(o|h&1));sa=i+1075795|0;Ga=i+1075778|0;Ha=i+1075688|0;Ia=i+1075024|0;Ja=i+1075020|0;Ka=i+1075668|0;La=i+1075664|0;J=i+1075e3|0;$=i+1075088|0;aa=i+1075084|0;ta=i+1075016|0;ua=i+1075012|0;fa=i+1075096|0;da=i+1075076|0;R=i+1075068|0;ka=i+1075072|0;ba=i+1075092|0;T=a;a=q;while(1){ld:{c=v[ba>>2];la=c?a>>>0>c>>>0?c:a:a;v[d+68>>2]=la;ia=v[ka>>2];c=v[H>>2];k=v[J+4>>2];h=v[J>>2];v[d+56>>2]=h;v[d+60>>2]=k;md:{nd:{if(!la|!(h|k)){break nd}A=v[R>>2];if(!A){break nd}g=v[d+8>>2];if(!g){break nd}v[X+632>>2]=g;g=v[l+4>>2];i=g;od:{pd:{o=v[l>>2];m=ia&c<<30>>31;e=g;qd:{if((m|0)>(e|0)){if((k|0)<-1?1:(k|0)<=-1){v[d+104>>2]=0;c=m;v[d+108>>2]=c<<1;o=Pg(d+104|0,l);g=jb;i=g;v[l>>2]=o;v[l+4>>2]=g;if(!(g>>>0<c+v[R>>2]>>>1>>>0?(c|0)<=(g|0):0)){g=l;o=0;v[g>>2]=o;v[g+4>>2]=c;i=c}c=h;g=0-(((c|0)!=0)+k|0)|0;j=0-c|0;v[d+56>>2]=j;v[d+60>>2]=g;v[J>>2]=j;v[J+4>>2]=g;c=v[H>>2];rd:{if(c&4){c=c&-129;v[H>>2]=c;break rd}c=c|128;v[H>>2]=c;e=v[R>>2]-1|0;i=e;v[l>>2]=o;v[l+4>>2]=e;v[J>>2]=h;v[J+4>>2]=k}if(!(c&2)){break nd}if(i>>>0<y[R>>2]){break od}break nd}if((i|0)>-1){break qd}c=0;i=c;v[l>>2]=o;v[l+4>>2]=c;break qd}if(e>>>0>=A>>>0){break pd}}j=h;g=k;break od}if(!(c&2)){break nd}if(c&4){sd:{if((k|0)<0?1:(k|0)<=0?h>>>0<1:0){j=h;g=k;break sd}j=0-h|0;v[d+56>>2]=j;g=0-(((h|0)!=0)+k|0)|0;v[d+60>>2]=g;v[J>>2]=j;v[J+4>>2]=g}v[H>>2]=c|128;c=e;e=1-((o|0)!=0)|0;o=0-o|0;h=(A<<1)-(c+e|0)|0;e=h;i=e;c=l;v[c>>2]=o;v[c+4>>2]=e;if(e>>>0<A>>>0?e>>>0>ia>>>0:0){break od}v[d+104>>2]=Ba;e=A-v[Fb(R,d+104|0)>>2]|0;o=v[l>>2];i=e;v[l>>2]=o;v[c+4>>2]=e;break od}td:{if((k|0)>-1){j=h;g=k;break td}j=0-h|0;v[d+56>>2]=j;g=0-(((h|0)!=0)+k|0)|0;v[d+60>>2]=g;v[J>>2]=j;v[J+4>>2]=g}v[d+104>>2]=0;v[d+108>>2]=m-A;Ub(l,d+104|0);v[H>>2]=v[H>>2]|8192;o=v[l>>2];i=v[l+4>>2]}v[d+48>>2]=o;c=i;v[d+52>>2]=c;ud:{vd:{A=c;if((c|0)<(m|0)){c=0;if((i|0)<0|(g|0)<0){break ud}break vd}if((i|0)>0?1:(i|0)>=0){break vd}c=0;break ud}c=0;if(A>>>0>=y[R>>2]){break ud}v[d+44>>2]=la;tc(d+68|0,v[d+20>>2]);Na=d,Oa=sw(d+56|0,v[d+68>>2]-1|0),v[Na+32>>2]=Oa;v[d+36>>2]=jb;c=g;k=c>>31;e=j+k|0;g=c>>31;c=g+c|0;c=e>>>0<k>>>0?c+1|0:c;Ma=e;h=v[ka>>2];ia=h+16|0;e=v[d+36>>2]+v[d+52>>2]|0;ja=v[d+48>>2];j=ja+v[d+32>>2]|0;e=j>>>0<ja>>>0?e+1|0:e;ja=h>>>0>A>>>0;if(A>>>0<ia>>>0?ja:1){v[H>>2]=v[H>>2]&-8193}j=k^Ma;k=c^g;wd:{xd:{yd:{if(!v[d+12>>2]){g=v[d+60>>2];break yd}c=v[d+16>>2];if(c>>>0<=A>>>0){g=d;e=v[d+60>>2];zd:{if((e|0)<-1?1:(e|0)<=-1){v[d+96>>2]=o;v[d+100>>2]=i;v[d+104>>2]=0;v[d+108>>2]=c;Na=d,Oa=Pg(d+96|0,d+104|0),v[Na+80>>2]=Oa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Na=d,Oa=Pg(d+80|0,d+72|0),v[Na+88>>2]=Oa;v[d+92>>2]=jb;c=Bn(d+88|0,j,k);break zd}c=v[da>>2];v[d+104>>2]=o;v[d+108>>2]=i;v[d+96>>2]=0;v[d+100>>2]=c;Na=d,Oa=Pg(d+96|0,d+104|0),v[Na+80>>2]=Oa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Na=d,Oa=Pg(d+80|0,d+72|0),v[Na+88>>2]=Oa;v[d+92>>2]=jb;c=Bn(d+88|0,j,k)}v[g+44>>2]=c+1;v[X+632>>2]=v[d+12>>2];break wd}if(!(!(w[H+1|0]&32)|ja|A>>>0>=ia>>>0)){v[d+104>>2]=o;v[d+108>>2]=i;v[d+96>>2]=0;v[d+100>>2]=m+16;Na=d,Oa=Pg(d+96|0,d+104|0),v[Na+80>>2]=Oa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Na=d,Oa=Pg(d+80|0,d+72|0),v[Na+88>>2]=Oa;v[d+92>>2]=jb;Na=d,Oa=Bn(d+88|0,j,k)+1|0,v[Na+44>>2]=Oa;Na=X,Oa=v[d+12>>2]+B(v[da>>2]-m|0,gj(v[fa>>2]))|0,v[Na+632>>2]=Oa;break wd}A=v[d+60>>2];g=A;if((g|0)<0?1:(g|0)<=0?y[d+56>>2]<1:0){break yd}if(la>>>0<2|c>>>0>e>>>0){break xd}v[d+104>>2]=o;v[d+108>>2]=i;v[d+96>>2]=0;v[d+100>>2]=c;Na=d,Oa=Pg(d+96|0,d+104|0),v[Na+80>>2]=Oa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Na=d,Oa=Pg(d+80|0,d+72|0),v[Na+88>>2]=Oa;v[d+92>>2]=jb;Na=d,Oa=Bn(d+88|0,j,k)+1|0,v[Na+44>>2]=Oa;break wd}if((g|0)>-1){break xd}if((e|0)>=(m|0)){break wd}v[d+96>>2]=o;v[d+100>>2]=i;v[d+104>>2]=0;v[d+108>>2]=h;Na=d,Oa=Pg(d+96|0,d+104|0),v[Na+80>>2]=Oa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Na=d,Oa=Pg(d+80|0,d+72|0),v[Na+88>>2]=Oa;v[d+92>>2]=jb;Na=d,Oa=Bn(d+88|0,j,k)+1|0,v[Na+44>>2]=Oa;break wd}c=e;e=v[R>>2];if((c|0)<(e|0)){break wd}v[d+104>>2]=o;v[d+108>>2]=i;v[d+96>>2]=0;v[d+100>>2]=e;Na=d,Oa=Pg(d+96|0,d+104|0),v[Na+80>>2]=Oa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Na=d,Oa=Pg(d+80|0,d+72|0),v[Na+88>>2]=Oa;v[d+92>>2]=jb;Na=d,Oa=Bn(d+88|0,j,k)+1|0,v[Na+44>>2]=Oa}Ap(d+44|0,1,v[d+68>>2]);c=v[d+44>>2]}if((c|0)>0){break md}}v[X+632>>2]=0;v[R>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[ba>>2]=0;KS(l,b,a);v[Z>>2]=v[Z>>2]+v[aa>>2];v[W>>2]=v[W>>2]+v[$>>2];v[$>>2]=0;v[aa>>2]=0;v[H>>2]=v[H>>2]&-129;e=x[d+30>>1];break ld}Ad:{Bd:{e=x[d+30>>1];if(e>>>0<y[r+24608>>2]){G=4;if(v[ba>>2]){break Bd}G=0;if(v[ta>>2]|v[ua>>2]){break Bd}}Na=d,Oa=jqa(v[J>>2],v[J+4>>2],c,c>>31),v[Na+104>>2]=Oa;v[d+108>>2]=jb;Ub(l,d+104|0);G=0;v[$>>2]=0;v[aa>>2]=0;b=(c<<3)+b|0;break Ad}g=(c<<3)+b|0;h=g-8|0;v[aa>>2]=0-v[h>>2];o=g-4|0;v[$>>2]=0-v[o>>2];kb[v[((G|Fa)<<2)+33680>>2]](l,Ca,b,c);v[aa>>2]=v[aa>>2]+v[h>>2];v[$>>2]=v[$>>2]+v[o>>2];G=1;b=g}g=v[ba>>2];Cd:{if(!g){break Cd}if(c>>>0>=g>>>0){v[ba>>2]=0;v[ua>>2]=v[La>>2];v[ta>>2]=v[Ka>>2];v[Ja>>2]=0;v[Ia>>2]=0;if(v[Ha>>2]|!(w[H+1|0]&16)){break Cd}v[R>>2]=0;v[X+632>>2]=0;break Cd}v[ba>>2]=g-c}g=0;m=0;h=v[l+4>>2];m=h>>>0>=y[da>>2]?(w[H|0]&2)>>>1|0:m;j=h;h=v[R>>2];g=j>>>0<h>>>0|(!h|w[H|0]&2)?g:!x[Ga>>1];a=a-c|0;Db(d+104|0,na,85);Dd:{Ed:{Fd:{Gd:{if(!Cb(d+104|0)){break Gd}c=w[sa|0];if(!c|c>>>0>x[r+480190>>1]){break Gd}j=!(g|m);c=r+B(w[sa|0],104)|0;g=c+484380|0;h=v[fa>>2];if(j|(g|0)==(h|0)){break Fd}v[fa>>2]=g;v[X+632>>2]=v[c+484400>>2];g=x[c+484414>>1];v[H>>2]=g|v[H>>2]&-768;h=g<<30>>31;g=v[c+484388>>2];v[R>>2]=h&g;c=v[c+484384>>2];v[ka>>2]=c;v[da>>2]=g;v[l+4>>2]=c;fF(T,l);if(!v[X+632>>2]){break ld}if((a|0)>0){continue}break ld}if(m){break Ed}break Dd}if(!m|(g|0)!=(h|0)){break Dd}}Db(d+104|0,na,83);if(!Cb(d+104|0)|v[ka>>2]){break Dd}v[l>>2]=v[l>>2];v[l+4>>2]=0;c=v[v[fa>>2]+8>>2];v[R>>2]=c;v[da>>2]=c}if((a|0)>0){continue}}break}v[X+632>>2]=v[d+8>>2];u[d+30>>1]=e+G;if(!G|!ca|ca>>>0>250){break hd}a=v[(r+B(ca,160)|0)+906140>>2];if(!a){break hd}kb[v[v[a>>2]+148>>2]](a)}E=E+1|0;if(E>>>0<x[r+480212>>1]){continue}break}}Na=r,Oa=x[Je(r+480214|0,d+30|0)>>1],u[Na+480214>>1]=Oa}gb=d+112|0;if(Dd(qa)){a=ea;g=f;b=(B(v[M+480232>>2],v[M+480236>>2])>>>0)/48|0;q=gb-16|0;gb=q;F=v[qa>>2];Hd:{if(!w[F+530|0]){break Hd}c=jqa(b,0,6169,0);b=jb;e=b>>>16|0;n=Qc((b&65535)<<16|c>>>16,e);if(!g){break Hd}while(1){b=v[F>>2];d=v[b>>2];c=v[b+4>>2];if((d|0)<=(c|0)){h=b+14|0;l=b+12|0;while(1){v[b+8>>2]=v[b+12>>2];c=b;d=l;o=h;m=0;G=0;r=0;e=gb-16|0;gb=e;while(1){j=c+B(r,44)|0;Id:{if(!w[j+56|0]){u[e+12>>1]=0;u[e+14>>1]=0;break Id}k=v[j+32>>2];i=x[k+3840>>1];if(i&3){k=(x[j+36>>1]>>>7&7)>>>(w[k+3844|0]^1)>>>(i&1)|0;i=(i&4?0-k|0:k)&65535}else{i=0}k=i<<x[j+38>>1];i=e;E=v[j+52>>2];Jd:{if(E){s=x[E+32>>1];p=x[j+48>>1];E=ig(v[j+16>>2],v[j+40>>2],k<<16>>16,0,u[j+46>>1]);A=v[j+40>>2];K=v[j+20>>2];if(!s){if(!p){k=k<<16>>16;E=ig(K,A,k,E,0);E=ig(v[j+24>>2],v[j+40>>2],k,E,0);k=ig(v[j+28>>2],v[j+40>>2],k,E,0);break Jd}k=k<<16>>16;A=ig(K,A,k,0,0);A=ig(v[j+24>>2],v[j+40>>2],k,A,0);k=ig(v[j+28>>2],v[j+40>>2],k,A,0)+E|0;break Jd}if(!p){k=k<<16>>16;E=ig(K,A,k,E,0);A=ig(v[j+24>>2],v[j+40>>2],k,0,0);k=ig(v[j+28>>2],v[j+40>>2],k,A,0)+E|0;break Jd}k=k<<16>>16;A=ig(K,A,k,0,0);k=(ig(v[j+24>>2],v[j+40>>2],k,A,0)+E|0)+ig(v[j+28>>2],v[j+40>>2],k,0,0)|0;break Jd}p=x[j+48>>1];k=k<<16>>16;E=ig(v[j+16>>2],v[j+40>>2],k,0,u[j+46>>1]);A=v[j+40>>2];K=v[j+20>>2];if(!p){k=ig(K,A,k,E,0);break Jd}k=ig(K,A,k,0,0)+E|0}u[i+14>>1]=w[j+57|0]?k:0;u[e+12>>1]=w[j+58|0]?k:0}m=u[e+12>>1]+m|0;G=u[e+14>>1]+G|0;r=r+1|0;if((r|0)!=18){continue}break}j=d;d=(G|0)<32767?G:32767;u[j>>1]=(d|0)>-32768?d:-32768;d=(m|0)<32767?m:32767;u[o>>1]=(d|0)>-32768?d:-32768;u[c+3832>>1]=x[c+3832>>1]+1;d=(x[c+3834>>1]+1>>>0)%13440|0;u[c+3834>>1]=d;d=d>>>0<6720?d:13440-d|0;u[c+3836>>1]=d>>>8;if(!w[c+3843|0]){u[c+3836>>1]=d>>>10}d=x[c+3838>>1]+1|0;u[c+3838>>1]=d;if((d&65535)>>>0>=1024){u[c+3838>>1]=0;u[c+3840>>1]=x[c+3840>>1]+1&7}gb=e+16|0;d=v[b>>2];c=v[b+4>>2]-d|0;v[b+4>>2]=c;if((c|0)>=(d|0)){continue}break}}e=d-c|0;u[q+14>>1]=(B(u[b+12>>1],c)+B(e,u[b+8>>1])|0)/(d|0);u[q+12>>1]=(B(u[b+14>>1],c)+B(e,u[b+10>>1])|0)/(d|0);v[b+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(n,u[q+14>>1]);v[a+4>>2]=v[a+4>>2]+B(n,u[q+12>>1]);a=a+8|0;g=g-1|0;if(g){continue}break}}gb=q+16|0}b=ea;a=f;g=za;Kd:{if(!w[g+4116|0]){if(!v[g+4120>>2]){break Kd}Mo(g+8|0,a,g+4104|0,g+4108|0)}d=v[g>>2];h=v[g+4184>>2];c=B(d,h)>>>4|0;c=c>>>0<32767?c:32767;u[g+4202>>1]=c;u[g+4200>>1]=c;l=v[g+54052>>2];c=B(l,d)>>>4|0;c=c>>>0<65536?c:65536;e=c+127>>>3|0;u[g+54050>>1]=e;c=c+255>>>4|0;u[g+54048>>1]=c;u[g+54046>>1]=c;u[g+54044>>1]=e;e=b;c=g+8|0;o=c;h=(h|0)>(l|0)?h:l;d=36-d>>>1|0;d=d>>>0>8?d:8;h=16-(B((h|0)<32768?h:32768,(d|0)<16?16-d|0:0)>>15)|0;l=0;d=a;if(a){while(1){i=l<<3;j=i+e|0;v[j>>2]=v[j>>2]+B(h,v[i+o>>2]>>4);i=i|4;j=i+e|0;v[j>>2]=v[j>>2]+B(h,v[i+o>>2]>>4);l=l+1|0;if((d|0)!=(l|0)){continue}break}}k=g+4172|0;l=c;d=0;e=g;h=v[e+4144>>2];j=v[e+4140>>2];if(a){o=u[e+4188>>1];while(1){i=d<<3;q=(i|4)+l|0;r=v[q>>2];i=i+l|0;m=v[i>>2]>>12;j=(B(o,m-j|0)>>15)+m|0;v[i>>2]=j;i=r>>12;h=(B(o,i-h|0)>>15)+i|0;v[q>>2]=h;d=d+1|0;if((a|0)!=(d|0)){continue}break}}v[e+4144>>2]=h;v[e+4140>>2]=j;Ld:{if(!a){h=v[k>>2];break Ld}q=g+53996|0;d=a;e=k;m=v[e>>2]-1|0;h=x[e+22>>1];o=u[e+26>>1];n=u[e+18>>1];j=v[e+4>>2];i=x[e+20>>1];r=u[e+24>>1];p=u[e+16>>1];E=e+32928|0;while(1){A=Mb(v[l>>2],-32768,32767);K=Mb(v[l+4>>2],-32768,32767);i=Mb((i<<16>>16)-A|0,-32768,32767);h=Mb((h<<16>>16)-K|0,-32768,32767);i=Uc(Mb((B(i,p)|0)/65536<<1,-32768,32767)+A|0);h=Uc(Mb((B(h,n)|0)/65536<<1,-32768,32767)+K|0);K=E+(j<<2)|0;A=u[K+2>>1];F=u[K>>1];K=Uc(((B(F,r)|0)/-65536|0)+i|0);j=j+1&127;s=E+(j<<2)|0;I=Uc(((B(o,A)|0)/-65536|0)+h|0);u[s+2>>1]=I;u[s>>1]=K;m=m+1&8191;s=e+(m<<2)|0;Na=s,Oa=Uc(F+((B(r,K)|0)/65536|0)|0),u[Na+160>>1]=Oa;Na=s,Oa=Uc(A+((B(o,I)|0)/65536|0)|0),u[Na+162>>1]=Oa;l=l+8|0;d=d-1|0;if(d){continue}break}u[e+22>>1]=h;u[e+20>>1]=i;v[e+4>>2]=j;l=v[g+4180>>2];F=g+37612|0;e=c;d=a;while(1){i=l&4095;o=F+(i<<2)|0;h=e;K=l-v[g+53996>>2]&4095;l=4096-(i>>>0>K>>>0?i:K)|0;l=d>>>0>l>>>0?l:d;j=l>>>0<64?l:64;r=j;i=0;E=gb-32|0;gb=E;l=k;m=v[k>>2];while(1){v[E+(i<<2)>>2]=m+(v[(l+(i<<4)|0)+32>>2]^-1);i=i+1|0;if((i|0)!=7){continue}break}i=u[l+28>>1]/8|0;if(r){n=i<<16>>16;while(1){m=0;G=0;i=0;while(1){A=E+(i<<2)|0;p=v[A>>2]+1&8191;v[A>>2]=p;p=l+(p<<2)|0;s=u[p+160>>1];A=l+(i<<4)|0;p=u[p+162>>1];G=(B(s,u[A+44>>1])+G|0)+B(p,u[A+46>>1])|0;m=(B(s,u[A+40>>1])+m|0)+B(p,u[A+42>>1])|0;i=i+1|0;if((i|0)!=4){continue}break}W=0;i=4;s=Uc((m|0)/32768|0);I=Uc((G|0)/32768|0);m=0;while(1){A=E+(i<<2)|0;p=v[A>>2]+1&8191;v[A>>2]=p;T=m;m=l+(p<<2)|0;p=u[m+160>>1];A=l+(i<<4)|0;N=u[m+162>>1];m=(T+B(p,u[A+44>>1])|0)+B(N,u[A+46>>1])|0;W=(B(p,u[A+40>>1])+W|0)+B(N,u[A+42>>1])|0;i=i+1|0;if((i|0)!=7){continue}break}i=Uc(s+((W|0)/32768|0)|0);u[o>>1]=i;v[h>>2]=B(i,n);i=Uc(I+((m|0)/32768|0)|0);u[o+2>>1]=i;v[h+4>>2]=B(i,n);h=h+8|0;o=o+4|0;r=r-1|0;if(r){continue}break}}gb=E+32|0;o=F+(K<<2)|0;h=e;l=q;m=v[l+4>>2];G=m&2047;i=j;if(i){r=l+8256|0;E=l- -64|0;A=l+24640|0;K=l+16448|0;while(1){s=u[(r+((m+754&2047)<<2)|0)+2>>1];I=u[r+((m+1206&2047)<<2)>>1];p=u[(E+((m+1602&2047)<<2)|0)+2>>1];N=u[E+((m+1750&2047)<<2)>>1];T=A+((m+22&2047)<<2)|0;n=u[T+2>>1];T=u[T>>1];J=A+((m+502&2047)<<2)|0;H=u[J+2>>1];R=u[o>>1];W=u[o+2>>1];J=u[J>>1];X=Mb(u[l+32>>1]-J|0,-32768,32767);Z=u[l+24>>1];$=Mb(u[l+34>>1]-H|0,-32768,32767);aa=u[l+26>>1];ba=Mb(u[l+36>>1]-T|0,-32768,32767);ca=u[l+28>>1];da=Mb(u[l+38>>1]-n|0,-32768,32767);fa=u[l+30>>1];Na=l,Oa=Uc(Mb((B(X,Z)|0)/65536<<1,-32768,32767)+J|0),u[Na+32>>1]=Oa;Na=l,Oa=Uc(Mb((B($,aa)|0)/65536<<1,-32768,32767)+H|0),u[Na+34>>1]=Oa;Na=l,Oa=Uc(Mb((B(ba,ca)|0)/65536<<1,-32768,32767)+T|0),u[Na+36>>1]=Oa;Na=l,Oa=Uc(Mb((B(da,fa)|0)/65536<<1,-32768,32767)+n|0),u[Na+38>>1]=Oa;n=Mb((B(u[l+32>>1],u[l+16>>1])|0)/32768|0,-32768,32767);H=Mb((B(u[l+38>>1],u[l+22>>1])|0)/32768|0,-32768,32767);T=Mb(n+((R|0)/4<<16>>16)|0,-32768,32767);H=Mb(H+((W|0)/4<<16>>16)|0,-32768,32767);J=Mb(T+((B(N,u[l+8>>1])|0)/-65536|0)|0,-32768,32767);n=G<<2;R=n+E|0;W=Mb(H+((B(p,u[l+10>>1])|0)/-65536|0)|0,-32768,32767);u[R+2>>1]=W;u[R>>1]=J;N=Mb(N+((B(J,u[l+8>>1])|0)/65536|0)|0,-32768,32767);J=n+K|0;p=Mb(p+((B(W,u[l+10>>1])|0)/65536|0)|0,-32768,32767);u[J+2>>1]=p;u[J>>1]=N;N=Mb(N+T|0,-32768,32767);T=Mb(p+H|0,-32768,32767);p=K+((m+426&2047)<<2)|0;H=u[p+2>>1];J=u[p>>1];m=K+((m+682&2047)<<2)|0;R=u[m+2>>1];W=u[m>>1];m=Mb((B(R,u[l+42>>1])+B(W,u[l+40>>1])|0)/32768|0,-32768,32767);p=Mb((B(H,u[l+46>>1])+B(J,u[l+44>>1])|0)/32768|0,-32768,32767);W=Mb(Mb(N+W|0,-32768,32767)-m|0,-32768,32767);R=Mb(Mb(R+T|0,-32768,32767)-p|0,-32768,32767);N=Mb(Mb(N+J|0,-32768,32767)-m|0,-32768,32767);T=Mb(Mb(H+T|0,-32768,32767)-p|0,-32768,32767);m=Mb(m+((B(I,u[l+8>>1])|0)/-65536|0)|0,-32768,32767);H=u[l+8>>1];J=u[l+10>>1];X=n+r|0;p=Mb(p+((B(s,u[l+10>>1])|0)/-65536|0)|0,-32768,32767);u[X+2>>1]=p;u[X>>1]=m;X=I;I=(B(m,H)|0)/65536|0;m=Mb(X+I|0,-32768,32767);n=n+A|0;p=(B(p,J)|0)/65536|0;s=Mb(p+s|0,-32768,32767);u[n+2>>1]=s;u[n>>1]=m;m=Mb(m+W|0,-32768,32767);Na=h,Oa=(v[h>>2]+B(m,u[l+48>>1])|0)+B(Mb(s+R|0,-32768,32767),u[l+50>>1])|0,v[Na>>2]=Oa;m=Mb(Mb(I,-32768,32767)+N|0,-32768,32767);n=u[l+52>>1];p=Mb(p,-32768,32767);Na=h,Oa=(v[h+4>>2]+B(m,n)|0)+B(Mb(p+T|0,-32768,32767),u[l+54>>1])|0,v[Na+4>>2]=Oa;h=h+8|0;o=o+4|0;m=G+1|0;G=m&2047;i=i-1|0;if(i){continue}break}}v[l+4>>2]=G;l=j+v[g+4180>>2]&4095;v[g+4180>>2]=l;h=j+v[g+4172>>2]&8191;v[g+4172>>2]=h;e=(j<<3)+e|0;d=d-j|0;if(d){continue}break}}v[g+4172>>2]=h&8191;e=c;c=0;l=0;o=g;i=v[g+4160>>2];k=v[g+4156>>2];d=a;if(a){h=v[o+4164>>2];j=v[o+4168>>2];while(1){c=v[e>>2];q=i;l=v[e+4>>2];i=j-l|0;i=q+(((i|0)/1024|0)-i|0)|0;v[b+4>>2]=i+v[b+4>>2];h=h-c|0;h=(((h|0)/1024|0)-h|0)+k|0;v[b>>2]=h+v[b>>2];i=i+((i|0)/-512|0)|0;k=h+((h|0)/-512|0)|0;b=b+8|0;e=e+8|0;j=l;h=c;d=d-1|0;if(d){continue}break}}v[o+4168>>2]=l;v[o+4164>>2]=c;v[o+4160>>2]=i;v[o+4156>>2]=k;Md:{if(w[g+4116|0]){v[g+4120>>2]=v[g+4124>>2];break Md}b=v[g+4120>>2];if(b>>>0>a>>>0){v[g+4120>>2]=b-a;break Md}ML(g);v[g+4120>>2]=0}t[g+4116|0]=0}if(v[M+946300>>2]){i=0;m=0;e=f;g=e<<2;d=M;r=x[d+480214>>1]!=0;a=d+1074332|0;Y=z[a>>2];va=z[a+4>>2];while(1){h=(d+B(i,160)|0)+906300|0;a=v[h>>2];Nd:{if(!a|!v[a+24>>2]){break Nd}if(!ki(a+44|0)){break Nd}a=v[h>>2];if(!(kb[v[v[a>>2]+112>>2]](a)|0)){kb[v[v[a>>2]+108>>2]](a,1);kb[v[v[a>>2]+120>>2]](a)}c=a+44|0;b=Od(c,0);c=Od(c,1);Od:{if(t[a+28|0]&1){eB(v[a+24>>2],b,c,e,Y);break Od}l=a+40|0;if(v[a+36>>2]?1:v[l>>2]){Mo(v[a+24>>2],e,l,a+36|0);eB(v[a+24>>2],b,c,e,Y);break Od}Qb(b,0,g);Qb(c,0,g)}v[a+28>>2]=v[a+28>>2]&-2;if(rw(h)){break Nd}r=!(w[a+28|0]&4)|r}i=i+1|0;if((i|0)!=250){continue}break}o=d+12|0;h=d+12300|0;l=d+14348|0;eB(o,h,l,e,Y);b=d+1074476|0;a=w[b|0];t[b|0]=0;j=a;a=h;g=l;while(1){k=(d+B(m,160)|0)+906300|0;b=v[k>>2];Pd:{if(!b|!v[b+24>>2]){break Pd}if(!ki(b+44|0)){break Pd}E=v[k>>2];Qd:{if(rw(k)){break Qd}b=v[k>>2];if(kb[v[v[b>>2]+144>>2]](b)|w[v[k>>2]+28|0]&2){break Qd}i=0;if(!m){break Pd}while(1){if((Ok((d+B(i,160)|0)+906300|0)|0)==(m|0)){break Qd}i=i+1|0;if((m|0)!=(i|0)){continue}break}break Pd}b=E+44|0;A=Od(b,0);n=Od(b,1);q=v[k>>2];K=(a|0)==(A|0);a=K?h:a;b=a;g=K?l:g;c=g;Rd:{if(!(w[k+28|0]|w[k+29|0]<<8|(w[k+30|0]<<16|w[k+31|0]<<24))){break Rd}b=a;i=Ok(k);c=g;if((i|0)==255){break Rd}c=g;if(i>>>0<=m>>>0){break Rd}i=v[(d+B(i,160)|0)+906300>>2];c=g;if(!i){break Rd}if(!(w[q+28|0]&4)){kb[v[v[i>>2]+148>>2]](i)}i=i+44|0;c=g;if(!ki(i)){break Rd}b=Od(i,0);c=Od(i,1)}Sd:{if(!rw(k)){break Sd}Td:{if(K){break Td}i=0;if(!e){break Td}while(1){K=i<<2;p=K+A|0;I=p;Y=z[p>>2];p=a+K|0;z[I>>2]=Y+z[p>>2];F=n+K|0;K=g+K|0;z[F>>2]=z[F>>2]+z[K>>2];v[p>>2]=0;v[K>>2]=0;i=i+1|0;if((e|0)!=(i|0)){continue}break}}g=c;a=b;if(!(r&1)){break Sd}a=v[k>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}a=b;i=Ok(k);if(i>>>0>249|i>>>0<=m>>>0){break Sd}while(1){g=i&255;a=(d+B(g,160)|0)+906300|0;i=Ok(a);a=v[a>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}if(g>>>0<i>>>0?i>>>0<=249:0){continue}break}g=c;a=b}Ud:{Vd:{if(!((w[k+24|0]&2)>>>1|0)){if(!dF(k)|!(w[q+28|0]&4)){break Vd}}i=0;if(!e){break Ud}while(1){k=i<<2;E=k+b|0;z[E>>2]=z[E>>2]+z[k+A>>2];E=c+k|0;z[E>>2]=z[E>>2]+z[k+n>>2];i=i+1|0;if((e|0)!=(i|0)){continue}break}break Ud}if(j){kb[v[v[E>>2]+128>>2]](E)}kb[v[v[E>>2]+60>>2]](E,b,c,e);v[q+32>>2]=e+v[q+32>>2];if(!dF(k)){break Ud}if((kb[v[v[E>>2]+156>>2]](E)|0)<1|y[q+32>>2]<v[d+24620>>2]<<2>>>0){break Ud}i=0;Wd:{if(!e){break Wd}while(1){Xd:{k=i<<2;Y=z[k+b>>2];if(Y>=C(1.1920928955078125e-7)|Y<=C(-1.1920928955078125e-7)){break Xd}Y=z[c+k>>2];if(Y>=C(1.1920928955078125e-7)|!(Y>C(-1.1920928955078125e-7))){break Xd}i=i+1|0;if((e|0)!=(i|0)){continue}break Wd}break}v[q+32>>2]=0;break Ud}v[q+28>>2]=v[q+28>>2]|4}v[q+28>>2]=v[q+28>>2]&-3}m=m+1|0;if((m|0)!=250){continue}break}b=0;if(e){while(1){c=o;Y=C(z[a>>2]*va);Yd:{if(C(D(Y))<C(2147483648)){d=~~Y;break Yd}d=-2147483648}v[c>>2]=d;c=o;Y=C(z[g>>2]*va);Zd:{if(C(D(Y))<C(2147483648)){d=~~Y;break Zd}d=-2147483648}v[c+4>>2]=d;o=o+8|0;g=g+4|0;a=a+4|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}}}if(v[M+24624>>2]==1){a=ea;g=0;b=f;if(b){while(1){c=g<<3;v[a+(g<<2)>>2]=(v[a+(c|4)>>2]+v[a+c>>2]|0)/2;g=g+1|0;if((b|0)!=(g|0)){continue}break}}}if(w[ya+33|0]){c=f;l=gb-16|0;gb=l;_d:{$d:{a=M;ae:{if(!v[a+1074376>>2]){b=a+1074460|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074468>>2]=v[a+1074456>>2];break ae}e=v[a+1074468>>2];b=v[a+1074456>>2];be:{if((e|0)==(b|0)){g=v[a+1074460>>2];break be}v[a+1074468>>2]=b;g=a+24604|0;d=a+1074460|0;ce:{if((b|0)>(e|0)){g=JS(g);break ce}g=IS(g)}v[d>>2]=g;v[a+1074464>>2]=g}b=a+1074460|0;if((g|0)>=1){break $d}}d=0;break _d}h=(v[a+1074468>>2]<<12)-v[a+1074472>>2]|0;d=(h|0)/(g|0)|0;if(w[a+1074368|0]!=2){break _d}v[l+12>>2]=50;g=a+1074464|0;v[l+8>>2]=1e4/(v[g>>2]+1|0);o=v[Gf(l+12|0,l+8|0)>>2];e=d>>31;if((o|0)>=(e+d^e)){break _d}i=v[g>>2];g=v[b>>2];while(1){g=g+i|0;d=(h|0)/(g|0)|0;e=d>>31;if((o|0)<(e^d+e)){continue}break}v[b>>2]=g}de:{ee:{switch(v[a+24624>>2]-1|0){case 0:if((c|0)<1){break de}g=v[a+1074456>>2];i=g<<12;h=g;j=g>>31;g=a+12|0;e=0;while(1){fe:{if(v[b>>2]>=1){o=v[a+1074472>>2]+d|0;v[a+1074472>>2]=o;k=v[g>>2];Na=g,Oa=Ac(kqa(jqa(k,k>>31,o,o>>31),jb,1048576,0),jb),v[Na>>2]=Oa;v[a+1074460>>2]=v[a+1074460>>2]-1;break fe}o=v[g>>2];Na=g,Oa=Ac(kqa(jqa(o,o>>31,h,j),jb,256,0),jb),v[Na>>2]=Oa;v[a+1074472>>2]=i}g=g+4|0;e=e+1|0;if((c|0)!=(e|0)){continue}break};break de;case 1:if((c|0)<1){break de}g=v[a+1074456>>2];j=g<<12;h=g;o=g>>31;g=a+12|0;e=0;while(1){ge:{if(v[b>>2]>=1){i=v[a+1074472>>2]+d|0;v[a+1074472>>2]=i;k=v[g>>2];Na=g,Oa=Ac(kqa(jqa(k,k>>31,i,i>>31),jb,1048576,0),jb),v[Na>>2]=Oa;i=v[a+1074472>>2];k=i;q=i>>31;i=v[g+4>>2];Na=g,Oa=Ac(kqa(jqa(k,q,i,i>>31),jb,1048576,0),jb),v[Na+4>>2]=Oa;v[a+1074460>>2]=v[a+1074460>>2]-1;break ge}i=v[g>>2];Na=g,Oa=Ac(kqa(jqa(i,i>>31,h,o),jb,256,0),jb),v[Na>>2]=Oa;i=v[g+4>>2];Na=g,Oa=Ac(kqa(jqa(i,i>>31,h,o),jb,256,0),jb),v[Na+4>>2]=Oa;v[a+1074472>>2]=j}g=g+8|0;e=e+1|0;if((c|0)!=(e|0)){continue}break};break de;case 3:break ee;default:break de}}if((c|0)<1){break de}g=v[a+1074456>>2];k=g<<12;h=g;o=g>>31;g=a+12|0;e=a+8204|0;i=0;while(1){he:{if(v[b>>2]>=1){j=v[a+1074472>>2]+d|0;v[a+1074472>>2]=j;q=v[g>>2];Na=g,Oa=Ac(kqa(jqa(q,q>>31,j,j>>31),jb,1048576,0),jb),v[Na>>2]=Oa;j=v[a+1074472>>2];q=j;r=j>>31;j=v[g+4>>2];Na=g,Oa=Ac(kqa(jqa(q,r,j,j>>31),jb,1048576,0),jb),v[Na+4>>2]=Oa;j=v[a+1074472>>2];q=j;r=j>>31;j=v[e>>2];Na=e,Oa=Ac(kqa(jqa(q,r,j,j>>31),jb,1048576,0),jb),v[Na>>2]=Oa;j=v[a+1074472>>2];q=j;r=j>>31;j=v[e+4>>2];Na=e,Oa=Ac(kqa(jqa(q,r,j,j>>31),jb,1048576,0),jb),v[Na+4>>2]=Oa;v[a+1074460>>2]=v[a+1074460>>2]-1;break he}j=v[g>>2];Na=g,Oa=Ac(kqa(jqa(j,j>>31,h,o),jb,256,0),jb),v[Na>>2]=Oa;j=v[g+4>>2];Na=g,Oa=Ac(kqa(jqa(j,j>>31,h,o),jb,256,0),jb),v[Na+4>>2]=Oa;j=v[e>>2];Na=e,Oa=Ac(kqa(jqa(j,j>>31,h,o),jb,256,0),jb),v[Na>>2]=Oa;j=v[e+4>>2];Na=e,Oa=Ac(kqa(jqa(j,j>>31,h,o),jb,256,0),jb),v[Na+4>>2]=Oa;v[a+1074472>>2]=k}e=e+8|0;g=g+8|0;i=i+1|0;if((c|0)!=(i|0)){continue}break}}gb=l+16|0}if(v[pa>>2]!=128){c=M+12|0;g=M+8204|0;a=f;b=v[M+24604>>2];e=v[M+24624>>2];ie:{if((b|0)==128|e>>>0<2){break ie}gO(c,a,b);if(e>>>0<4){break ie}gO(g,a,b)}}if(v[M+24624>>2]==4){a=ea;b=xa;g=f-1|0;if((g|0)>-1){while(1){c=g<<4;e=g<<3;d=e|4;v[a+(c|12)>>2]=v[d+b>>2];v[a+(c|8)>>2]=v[b+e>>2];v[a+(c|4)>>2]=v[a+d>>2];v[a+c>>2]=v[a+e>>2];c=(g|0)>0;g=g-1|0;if(c){continue}break}}}if(w[_+20|0]){b=v[_+16>>2];a=kg(V+72|0,ea,v[M+24624>>2],f);c=v[v[b>>2]+8>>2];v[V+24>>2]=v[a+8>>2];g=v[a+4>>2];v[V+16>>2]=v[a>>2];v[V+20>>2]=g;kb[c|0](b,V+16|0)}a=kg(V+56|0,ea,v[M+24624>>2],f);b=v[v[oa>>2]+8>>2];v[V+8>>2]=v[a+8>>2];c=v[a+4>>2];v[V>>2]=v[a>>2];v[V+4>>2]=c;kb[b|0](oa,V);g=v[M+1074380>>2]-f|0;v[M+1074380>>2]=g;v[M+1074376>>2]=f+v[M+1074376>>2];wa=f+wa|0;a=v[M+480208>>2];if(a&512){break i}ga=ga-f|0;if(ga){continue}break}}gb=V+128|0;gb=_+48|0;return wa}function Ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-496|0;gb=d;vc(b);g=gb-32|0;gb=g;h=d+304|0;Mr(g+24|0,h);j=yb(g+24|0);f=v[g+28>>2];i=v[g+24>>2];v[g+8>>2]=i;v[g+12>>2]=f;v[g>>2]=i;v[g+4>>2]=f;f=b;cc(g+16|0,f,g);i=yb(g+16|0);if((i|0)==(j|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){QW(h)}a:{b:{c:{if(!f){break c}if(!mX(d+304|0)){break c}if(!Pb(b,Qc(lX(d+304|0),jb))){break c}if(!c){e=1;break c}Id(a,32);t[d+303|0]=0;j=Kb(d+288|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if(v[d+304>>2]==778924148){v[22692]=0;R(554,a|0,16777216);e=v[22692];v[22692]=0;if((e|0)==1){break b}v[22692]=0;e=T(193,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(188,b|0,e-4|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}v[22692]=0;s=T(190,b|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break G}break b}H:{I:{J:{K:{L:{M:{if((w[d+344|0]|w[d+345|0]<<8)>>>0<2185|(w[d+344|0]|w[d+345|0]<<8)>>>0>4095){break M}v[22692]=0;e=T(193,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(188,b|0,e-4|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}v[22692]=0;s=T(190,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(s>>>0<256){break M}v[22692]=0;e=T(193,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break M}v[22692]=0;e=Q(188,b|0,s|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(!e){break M}v[22692]=0;e=T(555,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(!e){break M}v[22692]=0;R(554,a|0,16777216);e=v[22692];v[22692]=0;if((e|0)==1){break b}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=4096){v[22692]=0;b=Q(2,d+104|0,13565)|0;c=v[22692];v[22692]=0;if((c|0)==1){break F}v[22692]=0;U(556,a|0,1,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);e=0;break d}a=P()|0;O()|0;vb(b);break a}if((w[d+344|0]|w[d+345|0]<<8)>>>0<2194){break M}v[22692]=0;e=Q(2,d+104|0,13094)|0;f=v[22692];v[22692]=0;if((f|0)==1){break L}v[22692]=0;U(556,a|0,4,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break K}vb(e)}if(v[a+480180>>2]!=32){break G}if(((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break H}f=(w[d+344|0]|w[d+345|0]<<8)&4095;e=f<<16;if(v[d+364>>2]!=1414548815){break J}t[d+303|0]=1;break I}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}if(f>>>0<297){break I}e=w[d+364|0]|w[d+365|0]<<8|e}v[a+1074308>>2]=e;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=2184?(w[d+346|0]|w[d+347|0]<<8)!=2184:0)){t[d+303|0]=1;v[a+1074308>>2]=18284544;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=535|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[22692]=0;e=sv(d+368|0,255,64);f=v[22692];v[22692]=0;if((f|0)==1){break b}N:{if(e){v[a+1074308>>2]=18219008;v[22692]=0;h=Q(2,d+104|0,11973)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break N}a=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22692]=0;h=Q(2,d+104|0,13916)|0;e=v[22692];v[22692]=0;if((e|0)==1){break E}}Eb(j,h);vb(h);t[d+303|0]=1;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=514|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[a+1074308>>2]=17367040;v[22692]=0;e=Q(2,d+104|0,11865)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Eb(j,e);vb(e);t[d+303|0]=1;break G}a=P()|0;O()|0;break a}if((w[d+344|0]|w[d+345|0]<<8)!=768|(w[d+346|0]|w[d+347|0]<<8)!=768|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|(w[d+336|0]|w[d+337|0]<<8)!=256)){break G}if(w[d+357|0]|w[d+356|0]!=128){break G}v[a+1074308>>2]=18285088;t[d+303|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+348|0]|w[d+349|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+348|0]|w[d+349|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+348|0]|w[d+349|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+348|0]|w[d+349|0]<<8)<<3&32768;v[22692]=0;xp(d+216|0,3,d+304|4);e=v[22692];v[22692]=0;if((e|0)==1){break D}v[22692]=0;R(324,d+104|0,d+216|0);e=v[22692];v[22692]=0;if((e|0)==1){break D}Eb(a+1298268|0,d+104|0);vb(d+104|0);if(!(!(w[d+350|0]&4)|v[a+1074308>>2]-1>>>0<18285313)){v[a+480216>>2]=w[d+334|0];v[a+480220>>2]=w[d+335|0]}e=w[d+352|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+354|0]){v[a+480196>>2]=w[d+354|0]}t[d+104|0]=31;e=w[d+355|0];v[22692]=0;t[d+216|0]=e;e=Bf(d+104|0,d+216|0);f=v[22692];v[22692]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);t[d+104|0]=w[d+353|0];v[22692]=0;t[d+216|0]=128;e=ac(d+104|0,d+216|0);f=v[22692];v[22692]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];e=0;while(1){i=(d+304|0)+e|0;g=i- -64|0;O:{if(w[g|0]==255){break O}v[22692]=0;h=(e<<5)+a|0;f=h+480280|0;Ue(f);l=v[22692];v[22692]=0;if((l|0)==1){break C}E=h+480286|0,F=Gd(w[i+128|0],0,64),u[E>>1]=F;if(t[g|0]<=-1){v[f>>2]=v[f>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break O}if((g|0)!=100){break O}v[f>>2]=v[f>>2]|256}e=e+1|0;if((e|0)!=64){continue}break}v[22692]=0;Q(188,b|0,192)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}P:{if(!(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2187|(w[d+344|0]|w[d+345|0]<<8)>>>0>2189)){e=0;v[22692]=0;f=T(287,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break B}if(f){break d}v[22692]=0;f=T(190,b|0)|0;g=v[22692];v[22692]=0;Q:{if((g|0)==1){break Q}if(f>>>0>4e3){break d}g=Sb(a+484360|0);v[22692]=0;f=W(559,g|0,b|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Q}if(!f){break d}break P}a=P()|0;O()|0;break a}e=Sb(a+484360|0);f=w[d+336|0]|w[d+337|0]<<8;v[22692]=0;fa(519,e|0,b|0,f|0,255,254)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}}r=mc(d+272|0);q=mc(d+256|0);n=mc(d+240|0);f=w[d+338|0]|w[d+339|0]<<8;e=0;v[22692]=0;f=W(560,b|0,r|0,f|0)|0;g=v[22692];v[22692]=0;R:{if((g|0)==1){break R}if(!f){break z}f=w[d+340|0]|w[d+341|0]<<8;v[22692]=0;f=W(560,b|0,q|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break R}if(!f){break z}f=w[d+342|0]|w[d+343|0]<<8;v[22692]=0;f=W(560,b|0,n|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break R}if(!f){break z}v[d+236>>2]=-1;E=d,F=Vb(r),v[E+104>>2]=F;E=d,F=Zb(r),v[E+216>>2]=F;if(!Gb(d+104|0,d+216|0)){break A}while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}Oe(d+104|0);if(Gb(d+104|0,d+216|0)){continue}break}break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}E=d,F=Vb(q),v[E+104>>2]=F;E=d,F=Zb(q),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}Oe(d+104|0);if(Gb(d+104|0,d+216|0)){continue}break}}E=d,F=Vb(n),v[E+104>>2]=F;E=d,F=Zb(n),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}Oe(d+104|0);if(Gb(d+104|0,d+216|0)){continue}break}}S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if(t[d+350|0]&1){e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22692]=0;v[d+104>>2]=e;e=Fb(d+236|0,d+104|0);f=v[22692];v[22692]=0;if((f|0)==1){break ba}v[d+236>>2]=v[e>>2]}e=0;ca:{if((w[d+346|0]|w[d+347|0]<<8)!=532|(w[d+344|0]|w[d+345|0]<<8?(w[d+344|0]|w[d+345|0]<<8)!=532:0)|(w[d+335|0]|w[d+334|0])){break ca}if(w[d+348|0]&192|(w[d+357|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break ca}da:{if(!(w[d+340|0]|w[d+341|0]<<8)|(w[d+338|0]|w[d+339|0]<<8)){break da}if((v[b+8>>2]+(Nb(q)<<2)|0)+2>>>0>y[d+236>>2]){break da}if(w[d+340|0]|w[d+341|0]<<8){g=0;while(1){v[22692]=0;e=T(190,b|0)|0;f=v[22692];v[22692]=0;ea:{if((f|0)!=1){if(!e){break ea}ng(b,((g&65535)<<2)+4|0);break da}a=P()|0;O()|0;break g}g=g+1|0;if((g&65535)>>>0<(w[d+340|0]|w[d+341|0]<<8)>>>0){continue}break}}v[22692]=0;e=Q(2,d+104|0,12117)|0;f=v[22692];v[22692]=0;if((f|0)==1){break $}Eb(j,e);vb(e)}e=1;if(w[d+344|0]|w[d+345|0]<<8){break ca}v[22692]=0;f=Q(2,d+104|0,12514)|0;g=v[22692];v[22692]=0;if((g|0)==1){break _}Eb(j,f);vb(f)}fa:{if(w[d+350|0]&2){v[22692]=0;f=T(287,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Z}v[22692]=0;g=f<<3;h=Q(189,b|0,g|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break Z}if(!(!h|y[d+236>>2]<g+v[b+8>>2]>>>0)){v[22692]=0;g=a+1298368|0;R(561,g|0,f|0);h=v[22692];v[22692]=0;if((h|0)==1){break Z}E=d,F=Vb(g),v[E+216>>2]=F;E=d,F=Zb(g),v[E+192>>2]=F;if(Gb(d+216|0,d+192|0)){while(1){g=v[d+216>>2];v[22692]=0;R(562,b|0,d+104|0);h=v[22692];v[22692]=0;if((h|0)==1){break Y}v[22692]=0;NE(d+104|0,g);g=v[22692];v[22692]=0;if((g|0)==1){break Y}v[d+216>>2]=v[d+216>>2]+48;if(Gb(d+216|0,d+192|0)){continue}break}}if(!(!f&e)){break fa}if(w[d+350|0]&4){v[22692]=0;e=Q(2,d+104|0,12547)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}v[22692]=0;e=Q(2,d+104|0,12139)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}ng(b,2);break fa}if(!e|(w[d+350|0]|w[d+351|0]<<8)>>>0>1){break fa}v[22692]=0;e=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break aa}if(!e){v[22692]=0;e=Q(2,d+104|0,12117)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}ng(b,2)}ga:{if(!(w[d+350|0]&8?1:w[d+348|0]&128)){break ga}v[22692]=0;e=a+901404|0;f=Q(564,b|0,e|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break h}if(!f){break ga}v[22692]=0;Du(e);e=v[22692];v[22692]=0;if((e|0)==1){break h}}if((w[d+344|0]|w[d+345|0]<<8)>>>0<=531){v[22692]=0;Oo(a+901404|0);e=v[22692];v[22692]=0;if((e|0)==1){break h}}v[22692]=0;z=T(214,d+216|0)|0;e=v[22692];v[22692]=0;ha:{ia:{ja:{ka:{la:{ma:{if((e|0)!=1){v[22692]=0;e=Q(551,b|0,11103)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ma}if(e){v[22692]=0;e=T(190,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break la}v[22692]=0;U(288,d+192|0,b|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break la}e=jc(d+104|0,d+192|0);qd(z,e);xb(e);xb(d+192|0)}u[a+480188>>1]=1;v[22692]=0;e=Q(551,b|0,11108)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ma}if(e){v[22692]=0;e=T(190,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ka}v[22692]=0;U(288,d+192|0,b|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break ka}f=jc(d+104|0,d+192|0);xb(d+192|0);v[22692]=0;e=T(193,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ja}v[22692]=0;u[d+192>>1]=(e>>>0)/20;e=Pc(28852,d+192|0);g=v[22692];v[22692]=0;if((g|0)==1){break ja}g=x[e>>1];u[a+480188>>1]=g;if(g){e=0;while(1){v[22692]=0;W(567,f|0,((e<<5)+a|0)+480289|0,20)|0;h=v[22692];v[22692]=0;if((h|0)==1){break ja}e=e+1|0;if((g|0)!=(e|0)){continue}break}}xb(f)}if(y[b+8>>2]>y[d+236>>2]){break ia}e=v[d+236>>2]-v[b+8>>2]|0;break ha}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;xb(f);break i}v[22692]=0;e=T(465,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break X}}v[22692]=0;U(288,d+104|0,b|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break X}A=jc(d+192|0,d+104|0);xb(d+104|0);v[22692]=0;D=Q(568,a|0,A|0)|0;e=v[22692];v[22692]=0;na:{oa:{if((e|0)==1){break oa}if(!(t[d+350|0]&1)|!(w[d+358|0]|w[d+359|0]<<8)){break na}e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22692]=0;e=Q(188,b|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break oa}if(!e){break na}e=w[d+358|0]|w[d+359|0]<<8;v[22692]=0;ca(507,a+1298292|0,b|0,e|0,4)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break na}}a=P()|0;O()|0;break j}e=0;u[a+480192>>1]=0;if(w[d+348|0]&4){u[d+104>>1]=w[d+338|0]|w[d+339|0]<<8;v[22692]=0;u[d+32>>1]=255;f=Pc(d+104|0,d+32|0);g=v[22692];v[22692]=0;if((g|0)==1){break W}u[a+480192>>1]=x[f>>1]}pa:{qa:{ra:{sa:{if(x[a+480192>>1]){while(1){f=Lb(r,e);ta:{if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break ta}f=Lb(r,e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22692]=0;f=Q(188,b|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break sa}if(!f){break ta}v[22692]=0;f=Q(189,b|0,554)|0;g=v[22692];v[22692]=0;if((g|0)==1){break sa}if(!f){break ta}v[22692]=0;f=W(376,a|0,e+1&65535,0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ra}if(!f){break ta}g=w[d+346|0]|w[d+347|0]<<8;v[22692]=0;ca(569,a|0,b|0,f|0,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ra}t[f+33|0]=w[d+357|0]}e=e+1|0;if(e>>>0<x[a+480192>>1]){continue}break}}v[d+188>>2]=0;if(w[d+340|0]|w[d+341|0]<<8){e=Lb(q,(w[d+340|0]|w[d+341|0]<<8)-1|0);v[d+188>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}u[d+104>>1]=w[d+340|0]|w[d+341|0]<<8;v[22692]=0;u[d+32>>1]=3999;e=Pc(d+104|0,d+32|0);f=v[22692];v[22692]=0;if((f|0)==1){break qa}u[a+480190>>1]=x[e>>1];e=0;if(x[a+480190>>1]){break pa}f=0;h=0;break S}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}l=c&2;k=d+124|0;h=0;f=0;while(1){g=Lb(q,e);ua:{if(!(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break ua}g=Lb(q,e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22692]=0;g=Q(188,b|0,g|0)|0;i=v[22692];v[22692]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((i|0)==1){break Ba}if(!g){break ua}v[22692]=0;g=Q(570,b|0,d+104|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break Ba}if(!g){break ua}v[22692]=0;g=e+1|0;o=B(g,104)+a|0;i=o+484380|0;p=Q(571,d+104|0,i|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break Aa}v[22692]=0;xp(d+88|0,3,k);m=v[22692];v[22692]=0;if((m|0)==1){break za}v[22692]=0;R(324,d+32|0,d+88|0);m=v[22692];v[22692]=0;if((m|0)==1){break za}v[22692]=0;Q(301,((g<<5)+a|0)+946304|0,d+32|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break ya}vb(d+32|0);v[22692]=0;p=Q(188,b|0,p|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break Aa}if(!p){break ua}f=x[o+484414>>1];if(!(f&512)){break xa}v[22692]=0;f=Q(572,b|0,d+32|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){if(!f){break wa}v[d+16>>2]=v[d+40>>2];v[22692]=0;f=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=f;U(573,i|0,1,d+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){break wa}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+32|0);break j}if(!(f&16384)){f=w[d+344|0]|w[d+345|0]<<8;v[22692]=0;OE(d+32|0,d+104|0,f);f=v[22692];v[22692]=0;if((f|0)==1){break T}Ca:{if(l){g=0;v[22692]=0;W(329,d+32|0,i|0,b|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break Ca}break T}g=1;f=w[d+35|0];if(f>>>0>18){break Ca}f=1<<f;Da:{if(!(f&126991)){if(f&396800){break Da}break Ca}if(!w[d+32|0]){break Ca}}f=v[i>>2];v[22692]=0;f=rv(d+32|0,f);g=v[22692];v[22692]=0;if((g|0)==1){break T}g=0;v[22692]=0;Q(318,b|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break T}}if(w[d+35|0]!=1){break va}h=v[i>>2]!=0|h;break va}v[22692]=0;Q(576,b|0,d+84|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break U}f=v[d+84>>2];if(!(!l|!f)){f=Kb(d+32|0);v[22692]=0;W(413,b|0,f|0,v[d+84>>2])|0;i=v[22692];v[22692]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((i|0)!=1){v[22692]=0;R(577,d+72|0,13487);i=v[22692];v[22692]=0;if((i|0)==1){break Ka}v[d+68>>2]=g;v[22692]=0;U(13,d+56|0,0,f|0);g=v[22692];v[22692]=0;if((g|0)==1){break Ja}v[22692]=0;Y(578,d+88|0,d+72|0,d+68|0,d+56|0);g=v[22692];v[22692]=0;if((g|0)==1){break Ia}v[22692]=0;U(556,a|0,2,d+88|0);g=v[22692];v[22692]=0;if((g|0)==1){break Ha}vb(d+88|0);vb(d+56|0);Hb(d+72|0);vb(f);break wa}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Fa}a=P()|0;O()|0;break Ga}a=P()|0;O()|0;vb(d+88|0)}vb(d+56|0)}Hb(d+72|0)}vb(f);break j}v[22692]=0;Q(318,b|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break U}}g=0}f=v[b+8>>2];v[22692]=0;v[d+32>>2]=f;f=Mc(d+188|0,d+32|0);i=v[22692];v[22692]=0;if((i|0)==1){break V}v[d+188>>2]=v[f>>2];f=(g|0)!=0}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}break S}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}u[d+104>>1]=1;e=x[a+480190>>1];v[22692]=0;u[d+32>>1]=e;e=Je(d+104|0,d+32|0);g=v[22692];v[22692]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((g|0)!=1){u[a+480190>>1]=x[e>>1];Va:{if(!(h&1)|(w[d+344|0]|w[d+345|0]<<8)!=516|(w[d+350|0]|w[d+351|0]<<8|(w[d+346|0]|w[d+347|0]<<8)!=512)){break Va}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&65527)!=21|(w[d+352|0]!=128|w[d+353|0]!=48)){break Va}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8)){break Va}h=d+432|0;g=d+368|0;e=1;while(1){e=(w[g|0]|128)!=160?0:e;g=g+1|0;if((h|0)!=(g|0)){continue}break}h=d+496|0;g=d+432|0;while(1){e=w[g|0]==64&e;g=g+1|0;if((h|0)!=(g|0)){continue}break}g=20;while(1){e=!w[(d+g|0)+308|0]&e;g=g+1|0;if((g|0)!=26){continue}break}if(!e){break Va}v[22692]=0;e=Q(2,d+104|0,7079)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Ma}Eb(j,e);vb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;E=d,F=Nb(n),u[E+104>>1]=F;e=v[a+8>>2];v[22692]=0;e=Pc(d+104|0,e+10|0);g=v[22692];v[22692]=0;if((g|0)==1){break Ua}e=x[e>>1];u[d+84>>1]=e;if((Nb(n)|0)!=(e|0)){v[22692]=0;_(580,d+32|0);e=v[22692];v[22692]=0;if((e|0)==1){break Ta}e=Nb(n);v[22692]=0;v[d+88>>2]=e;Y(581,d+104|0,d+32|0,d+88|0,d+84|0);e=v[22692];v[22692]=0;if((e|0)==1){break Sa}v[22692]=0;U(556,a|0,2,d+104|0);e=v[22692];v[22692]=0;if((e|0)==1){break Ra}vb(d+104|0);Hb(d+32|0)}if(c&1){break Pa}u[d+84>>1]=0;break Oa}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}if(!x[d+84>>1]){break Oa}e=0;while(1){c=Lb(n,e);Wa:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Wa}c=Lb(n,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22692]=0;c=Q(188,b|0,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Na}if(!c){break Wa}v[22692]=0;c=T(287,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break k}v[22692]=0;i=T(287,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break l}if((i-1&65535)>>>0>1023){break Wa}v[22692]=0;g=Q(318,b|0,4)|0;h=v[22692];v[22692]=0;if((h|0)==1){break l}if(!g){break Wa}v[22692]=0;U(288,d+32|0,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break m}l=jc(d+104|0,d+32|0);xb(d+32|0);g=0;c=x[a+480188>>1];v[22692]=0;c=Q(582,d+32|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}while(1){Xa:{v[22692]=0;h=Q(189,d+104|0,1)|0;k=v[22692];v[22692]=0;Ya:{Za:{if((k|0)!=1){if(!h){break Xa}v[22692]=0;h=T(374,l|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break p}k=h<<24>>24;if(k){break Za}g=g+1|0;break Ya}break p}_a:{h=k&127;o=h?h-1|0:0;h=o&65535;if(pc(c)>>>0>h>>>0){break _a}v[22692]=0;t[d+88|0]=0;U(583,c|0,h+1|0,d+88|0);p=v[22692];v[22692]=0;if((p|0)!=1){break _a}break p}if((k|0)<=-1){v[22692]=0;k=T(374,l|0)|0;p=v[22692];v[22692]=0;if((p|0)==1){break p}E=kc(c,h),F=k,t[E|0]=F}if(!(!(w[kc(c,h)|0]&15)|h>>>0<x[a+480188>>1])){u[a+480188>>1]=o+1}if(t[kc(c,h)|0]&1){v[22692]=0;Q(318,d+104|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break p}}if(w[kc(c,h)|0]&2){v[22692]=0;Q(318,d+104|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break p}}if(w[kc(c,h)|0]&4){v[22692]=0;Q(318,d+104|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break p}}if(!(w[kc(c,h)|0]&8)){break Ya}v[22692]=0;Q(318,d+104|0,2)|0;h=v[22692];v[22692]=0;if((h|0)==1){break p}}if(g>>>0<i>>>0){continue}}break}g=v[b+8>>2];v[22692]=0;v[d+88>>2]=g;g=Mc(d+188|0,d+88|0);h=v[22692];v[22692]=0;if((h|0)==1){break p}v[d+188>>2]=v[g>>2];gc(c);xb(d+104|0)}e=e+1|0;if(e>>>0<x[d+84>>1]){continue}break}}c=v[d+188>>2];if(!c){break La}v[22692]=0;Q(188,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}if(!(f&1)){break La}while(1){$a:{v[22692]=0;c=Q(189,b|0,4)|0;e=v[22692];v[22692]=0;if((e|0)==1){break $a}if(!c){break La}v[22692]=0;c=Q(551,b|0,11082)|0;e=v[22692];v[22692]=0;if((e|0)==1){break $a}ab:{if(!c){v[22692]=0;c=Q(551,b|0,11087)|0;e=v[22692];v[22692]=0;if((e|0)==1){break $a}if(!c){break ab}}v[22692]=0;c=T(190,b|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){ng(b,8);if(!(c&1616928864)|c&-2139062144){break ab}break La}a=P()|0;O()|0;break j}v[22692]=0;c=T(287,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break $a}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22692]=0;c=Q(584,a|0,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break q}c=c|w[d+303|0];t[d+303|0]=c;if(!(!c|D)){qv(a+1074312|0);t[a+1074368|0]=0}v[22692]=0;Y(585,a|0,b|0,0,d+303|0);c=v[22692];v[22692]=0;if((c|0)==1){break q}v[22692]=0;o=a+484344|0;R(330,o|0,x[d+84>>1]);c=v[22692];v[22692]=0;if((c|0)==1){break q}e=0;u[d+68>>1]=0;bb:{if(!x[d+84>>1]){break bb}while(1){cb:{db:{c=Lb(n,e&65535);eb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Lb(n,x[d+68>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22692]=0;c=Q(188,b|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break eb}if(c){break db}}v[22692]=0;c=W(331,o|0,x[d+68>>1],64)|0;e=v[22692];v[22692]=0;if((e|0)==1){break eb}if(!c){v[22692]=0;_(586,d+32|0);c=v[22692];v[22692]=0;fb:{gb:{hb:{if((c|0)!=1){v[22692]=0;U(587,d+104|0,d+32|0,d+68|0);c=v[22692];v[22692]=0;if((c|0)==1){break hb}v[22692]=0;U(556,a|0,2,d+104|0);c=v[22692];v[22692]=0;if((c|0)==1){break gb}vb(d+104|0);Hb(d+32|0);break bb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break fb}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}c=_b(o,x[d+68>>1]);v[22692]=0;R(588,c|0,z|0);c=v[22692];v[22692]=0;if((c|0)!=1){break cb}}a=P()|0;O()|0;break j}v[22692]=0;c=T(287,b|0)|0;e=v[22692];v[22692]=0;ib:{jb:{if((e|0)!=1){v[22692]=0;p=T(287,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break jb}v[22692]=0;e=Q(318,b|0,4)|0;f=v[22692];v[22692]=0;if((f|0)==1){break jb}if(!e){break cb}v[22692]=0;e=W(331,o|0,x[d+68>>1],p|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break jb}if(e){break ib}break cb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22692]=0;U(288,d+32|0,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){k=jc(d+104|0,d+32|0);xb(d+32|0);c=_b(o,x[d+68>>1]);v[22692]=0;R(588,c|0,z|0);c=v[22692];v[22692]=0;kb:{if((c|0)!=1){c=x[a+480188>>1];v[22692]=0;l=Q(582,d+32|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){c=x[a+480188>>1];Eh(d+72|0);v[22692]=0;i=W(589,d+88|0,c|0,d+72|0)|0;c=v[22692];v[22692]=0;lb:{if((c|0)!=1){E=d,F=Vb(_b(o,x[d+68>>1])),v[E+56>>2]=F;m=0;mb:{if(!p){break mb}while(1){v[22692]=0;c=Q(189,d+104|0,1)|0;e=v[22692];v[22692]=0;nb:{if((e|0)!=1){ob:{if(!c){break mb}v[22692]=0;c=T(374,k|0)|0;e=v[22692];v[22692]=0;pb:{if((e|0)!=1){c=c<<24>>24;if(c){break pb}wX(d+56|0,x[a+480188>>1]);m=m+1|0;break nb}break ob}qb:{e=c&127;h=e?e-1&65535:0;if(pc(l)>>>0>h>>>0){break qb}v[22692]=0;t[d+72|0]=0;e=h+1|0;U(583,l|0,e|0,d+72|0);f=v[22692];v[22692]=0;if((f|0)==1){break ob}Eh(d+72|0);v[22692]=0;U(590,i|0,e|0,d+72|0);e=v[22692];v[22692]=0;if((e|0)!=1){break qb}break ob}if((c|0)<=-1){v[22692]=0;c=T(374,k|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break ob}E=kc(l,h),F=c,t[E|0]=F}Eh(d+72|0);e=d+72|0;if(h>>>0<x[a+480188>>1]){e=$c(d+56|0,h)}if(w[kc(l,h)|0]&16){E=e,F=w[$c(i,h)|0],t[E|0]=F}if(w[kc(l,h)|0]&32){E=e,F=w[$c(i,h)+1|0],t[E+1|0]=F}if(w[kc(l,h)|0]&64){E=e,F=w[$c(i,h)+2|0],t[E+2|0]=F;E=e,F=w[$c(i,h)+4|0],t[E+4|0]=F}if(t[kc(l,h)|0]<=-1){E=e,F=w[$c(i,h)+3|0],t[E+3|0]=F;E=e,F=w[$c(i,h)+5|0],t[E+5|0]=F}if(t[kc(l,h)|0]&1){v[22692]=0;c=T(374,k|0)|0;f=v[22692];v[22692]=0;C=e;rb:{sb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break sb}f=c;break rb}break ob}f=253;if((c-121&255)>>>0<132){break rb}f=(c&255)==253?0:c}t[C|0]=f;E=$c(i,h),F=f,t[E|0]=F}if(w[kc(l,h)|0]&2){v[22692]=0;c=T(374,k|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ob}t[e+1|0]=c;E=$c(i,h),F=c,t[E+1|0]=F}if(w[kc(l,h)|0]&4){v[22692]=0;g=T(374,k|0)|0;f=v[22692];v[22692]=0;C=e;tb:{ub:{vb:{if((f|0)!=1){if(g>>>0>64){break vb}t[e+4|0]=g;f=1;break ub}break ob}if(!(g<<24>>24>-1|g>>>0>192)){f=2;t[e+2|0]=2;t[e+4|0]=g^128;break tb}if(g>>>0<=74){f=5;t[e+2|0]=5;t[e+4|0]=g-65;break tb}if(g>>>0<=84){f=6;t[e+2|0]=6;t[e+4|0]=g-75;break tb}if(g>>>0<=94){f=3;t[e+2|0]=3;t[e+4|0]=g-85;break tb}if(g>>>0<=104){f=4;t[e+2|0]=4;t[e+4|0]=g-95;break tb}if(g>>>0<=114){f=13;t[e+2|0]=13;t[e+4|0]=g-105;break tb}if(g>>>0<=124){f=12;t[e+2|0]=12;t[e+4|0]=g-115;break tb}f=g+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;f=11;break ub}f=g+53|0;c=f&255;if(c>>>0<=9){t[e+4|0]=f;f=8;t[e+2|0]=8;if(!c|v[a+1074308>>2]-1>>>0>18285139){break tb}f=7;break ub}f=g+33|0;if((f&255)>>>0>=10){f=w[e+2|0];break tb}t[e+4|0]=f;f=15}t[C+2|0]=f}E=$c(i,h),F=f,t[E+2|0]=F;c=w[e+4|0];E=$c(i,h),F=c,t[E+4|0]=F}if(!(w[kc(l,h)|0]&8)){break nb}v[22692]=0;R(403,d+24|0,k|0);c=v[22692];v[22692]=0;if((c|0)!=1){wb:{c=od(d+24|0);t[e+3|0]=w[d+24|0];t[e+5|0]=w[c|0];v[22692]=0;Pu(e,1);c=v[22692];v[22692]=0;if((c|0)==1){break wb}c=w[e+3|0];E=$c(i,h),F=c,t[E+3|0]=F;c=w[e+5|0];E=$c(i,h),F=c,t[E+5|0]=F;break nb}}}}a=P()|0;O()|0;dn(i);break lb}if(m>>>0<p>>>0){continue}break}}dn(i);gc(l);xb(d+104|0);break cb}a=P()|0;O()|0}gc(l);break kb}a=P()|0;O()|0;break kb}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}e=x[d+68>>1]+1|0;u[d+68>>1]=e;if(x[d+84>>1]>(e&65535)>>>0){continue}break}}c=a+1074308|0;xb:{yb:{zb:{if(v[a+1074308>>2]){break zb}if((w[d+344|0]|w[d+345|0]<<8)==2184){v[a+1074308>>2]=18284544;break zb}if(!v[c>>2]){break yb}}if(!ed(j)){break yb}v[22692]=0;e=Q(2,d+32|0,14692)|0;f=v[22692];v[22692]=0;Ab:{Bb:{Cb:{Db:{Eb:{Fb:{if((f|0)!=1){v[22692]=0;R(160,d+88|0,c|0);f=v[22692];v[22692]=0;if((f|0)==1){break Fb}v[22692]=0;U(3,d+104|0,e|0,d+88|0);f=v[22692];v[22692]=0;if((f|0)==1){break Eb}Eb(j,d+104|0);vb(d+104|0);vb(d+88|0);vb(e);if(v[d+364>>2]==1414548815|((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break Ab}v[22692]=0;c=Q(2,d+104|0,13928)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Cb}v[22692]=0;Q(113,j|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Bb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Db}a=P()|0;O()|0;vb(d+88|0)}vb(e);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if(!bH(c)){break xb}v[22692]=0;c=Q(2,d+104|0,14164)|0;e=v[22692];v[22692]=0;Gb:{if((e|0)!=1){v[22692]=0;Q(113,j|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Gb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if((w[d+344|0]|w[d+345|0]<<8)==8191){c=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)}else{c=(w[d+344|0]|w[d+345|0]<<8)-4176|0}Hb:{switch((w[d+344|0]|w[d+345|0]<<8)>>>12|0){case 0:if(D){v[22692]=0;c=Q(2,d+104|0,5458)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Ib:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+350|0]|w[d+351|0]<<8|(w[d+348|0]|w[d+349|0]<<8)!=9)){break Ib}if(w[d+335|0]|w[d+334|0]|(w[d+338|0]|w[d+339|0]<<8|((w[d+342|0]|w[d+343|0]<<8)+1|0)!=(w[d+336|0]|w[d+337|0]<<8))){break Ib}if(w[d+352|0]!=128|w[d+353|0]!=100|(w[d+354|0]!=1|w[d+356|0]!=128)){break Ib}if(w[d+357|0]|(w[d+358|0]|w[d+359|0]<<8)|(w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24)|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break Ib}v[22692]=0;c=Q(2,d+104|0,7060)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Jb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+335|0]|w[d+334|0])){break Jb}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break Jb}v[a+1074308>>2]=16777381;v[22692]=0;c=Q(2,d+104|0,12054)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);t[d+303|0]=1;break xb}a=P()|0;O()|0;break j}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|v[d+364>>2]!=1229080643)){v[22692]=0;c=Q(2,d+104|0,5510)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);v[22692]=0;Q(410,a+1074312|0,38)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break xb}break r}a=P()|0;O()|0;break j}Kb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|(w[d+357|0]|(w[d+350|0]|w[d+351|0]<<8)>>>0>1)){break Kb}if(!x[a+480190>>1]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&4294)!=4)){break Kb}v[22692]=0;c=Q(70,d+104|0,10760)|0;e=v[22692];v[22692]=0;Lb:{Mb:{if((e|0)!=1){v[22692]=0;e=Q(592,a+484527|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Mb}vb(c);if(!e){break Kb}v[22692]=0;c=Q(2,d+104|0,5536)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Lb}Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}Nb:{if(w[d+344|0]|w[d+345|0]<<8){break Nb}if(!ed(j)){break Nb}v[22692]=0;c=Q(2,d+104|0,6846)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}if((w[d+346|0]|w[d+347|0]<<8)>>>0>767){break xb}if(!ed(j)){break xb}Ob:{Pb:{Qb:{Rb:{Sb:{if((w[d+346|0]|w[d+347|0]<<8)>>>0>=533){v[22692]=0;c=Q(2,d+104|0,12087)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);break Sb}a=P()|0;O()|0;break j}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=533){v[22692]=0;R(593,d+32|0,1124);c=v[22692];v[22692]=0;Tb:{if((c|0)!=1){c=w[d+344|0]|w[d+345|0]<<8;v[22692]=0;v[d+88>>2]=c-532;U(594,d+104|0,d+32|0,d+88|0);c=v[22692];v[22692]=0;if((c|0)==1){break Tb}Eb(j,d+104|0);vb(d+104|0);Hb(d+32|0);break Sb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j}v[22692]=0;R(411,d+32|0,1423);c=v[22692];v[22692]=0;if((c|0)==1){break Rb}v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22692]=0;v[d+56>>2]=c;R(595,d+88|0,d+56|0);c=v[22692];v[22692]=0;if((c|0)==1){break Qb}v[22692]=0;Y(578,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22692];v[22692]=0;if((c|0)==1){break Pb}Eb(j,d+104|0);vb(d+104|0);vb(d+88|0);Hb(d+32|0)}c=a+1298368|0;if(!bd(c)|!(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))){break xb}e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22692]=0;e=kw(e,f);f=v[22692];v[22692]=0;if((f|0)==1){break u}f=Ar(d+104|0);v[f+44>>2]=e;v[22692]=0;R(597,c|0,f|0);c=v[22692];v[22692]=0;if((c|0)!=1){break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Ob}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 1:e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22692]=0;U(598,d+104|0,e|0,f|0);e=v[22692];v[22692]=0;Ub:{Vb:{Wb:{Xb:{if((e|0)!=1){Eb(j,d+104|0);vb(d+104|0);if((c|0)>1915){break Xb}g=v[a+480208>>2];if(!(g&16)){break Wb}v[22692]=0;Q(410,a+1074312|0,7)|0;c=v[22692];v[22692]=0;if((c|0)==1){break r}break Vb}a=P()|0;O()|0;break j}if((c|0)>4200){break xb}g=v[a+480208>>2]}if(!(g&16)){v[22692]=0;Q(410,a+1074312|0,7)|0;e=v[22692];v[22692]=0;if((e|0)==1){break r}}if((c|0)>2385){break Ub}}v[22692]=0;Q(410,a+1074312|0,38)|0;c=v[22692];v[22692]=0;if((c|0)==1){break r}}v[22692]=0;c=a+1074312|0;Q(410,c|0,102)|0;e=v[22692];v[22692]=0;if((e|0)==1){break r}v[22692]=0;Q(410,c|0,48)|0;c=v[22692];v[22692]=0;if((c|0)==1){break r}break xb;case 4:v[22692]=0;R(599,d+32|0,1487);c=v[22692];v[22692]=0;Yb:{Zb:{_b:{if((c|0)!=1){v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22692]=0;v[d+56>>2]=c;R(595,d+88|0,d+56|0);c=v[22692];v[22692]=0;if((c|0)==1){break _b}v[22692]=0;Y(578,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22692];v[22692]=0;if((c|0)==1){break Zb}Eb(j,d+104|0);vb(d+104|0);vb(d+88|0);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Yb}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 6:v[22692]=0;c=Q(2,d+104|0,5458)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j;case 7:if(!((w[d+344|0]|w[d+345|0]<<8)!=32767|(w[d+346|0]|w[d+347|0]<<8)!=533)){v[22692]=0;c=Q(2,d+104|0,2138)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}v[22692]=0;R(156,d+32|0,1259);c=v[22692];v[22692]=0;$b:{if((c|0)!=1){v[d+88>>2]=w[d+345|0]&15;v[d+72>>2]=(w[d+344|0]|w[d+345|0]<<8)>>>4&15;c=w[d+344|0]|w[d+345|0]<<8;v[22692]=0;v[d+56>>2]=c&15;ha(157,d+104|0,d+32|0,d+88|0,d+72|0,d+56|0);c=v[22692];v[22692]=0;if((c|0)==1){break $b}Eb(j,d+104|0);vb(d+104|0);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j;case 13:break Hb;default:break xb}}v[22692]=0;c=Q(2,d+104|0,3177)|0;e=v[22692];v[22692]=0;if((e|0)==1){break t}Eb(j,c);vb(c)}ac:{if(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2186){break ac}v[22692]=0;c=Q(188,b|0,s|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break q}if(!c){break ac}c=w[d+344|0]|w[d+345|0]<<8;v[22692]=0;U(600,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break q}}b=v[a+480180>>2];bc:{if((b|0)==16777216){v[22692]=0;Q(2,d+104|0,11065)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break bc}a=P()|0;O()|0;break j}v[22692]=0;R(411,d+32|0,1423);c=v[22692];v[22692]=0;if((c|0)==1){break y}v[d+72>>2]=w[d+347|0];c=w[d+346|0];v[22692]=0;v[d+56>>2]=c;R(595,d+88|0,d+56|0);c=v[22692];v[22692]=0;if((c|0)==1){break x}v[22692]=0;Y(578,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22692];v[22692]=0;if((c|0)==1){break w}}Eb(a+1298304|0,d+104|0);vb(d+104|0);if((b|0)!=16777216){vb(d+88|0);Hb(d+32|0)}cc:{if(v[a+480180>>2]==16777216){v[22692]=0;Q(2,d+104|0,7348)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break cc}break s}v[22692]=0;Q(2,d+104|0,3181)|0;b=v[22692];v[22692]=0;if((b|0)==1){break s}}Eb(a+1298316|0,d+104|0);vb(d+104|0);Eb(a+1298328|0,j);v[a+1298364>>2]=v[a+1074308>>2]?8:5;xb(A);xb(z);e=1}di(n);di(q);di(r);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0;break v}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;gc(c);break n}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}xb(A)}xb(z);break g}a=P()|0;O()|0}di(n);di(q);di(r);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}vb(j)}gb=d+496|0;return e|0}a=P()|0;O()|0}vb(j);S(a|0);L()}function $ma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;d=gb-1712|0;gb=d;vc(b);a:{if(!Jh(b,d+1704|0)){break a}if(!NV(d+1704|0)){break a}if(!c){f=1;break a}e=w[d+1704|3];t[d+1703|0]=e;v[d+1696>>2]=-1;v[d+1692>>2]=1048576;if(e>>>0>=5){e=qg(b);v[d+1696>>2]=e;if(!Pb(b,e)){break a}v[d+304>>2]=134217727;N=d,V=v[Fb(d+304|0,d+1696|0)>>2]<<5,v[N+1692>>2]=V}C=mc(d+1680|0);e=d+1704|4;h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22692]=0;v[d+304>>2]=h;h=Fb(d+1692|0,d+304|0);g=v[22692];v[22692]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}h=v[h>>2];v[22692]=0;R(721,C|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break x}e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22692]=0;e=W(722,b|0,C|0,e|0)|0;h=v[22692];v[22692]=0;y:{if((h|0)==1){break y}if(!e){break t}if(w[d+1703|0]>=5){v[22692]=0;Q(188,b|0,v[d+1696>>2]+12|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break y}}v[22692]=0;R(367,a|0,0);e=v[22692];v[22692]=0;if((e|0)==1){break y}v[22692]=0;yg(a);e=v[22692];v[22692]=0;if((e|0)==1){break y}v[22692]=0;Vd(d+1648|0,C);h=v[22692];v[22692]=0;e=a;z:{A:{B:{C:{if((h|0)==1){break C}h=Ud(d+1640|0);v[22692]=0;g=v[d+1652>>2];v[d+96>>2]=v[d+1648>>2];v[d+100>>2]=g;g=v[h+4>>2];v[d+88>>2]=v[h>>2];v[d+92>>2]=g;m=W(724,d+1656|0,d+96|0,d+88|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break C}v[22692]=0;W(531,m|0,a+1298268|0,-1)|0;h=v[22692];v[22692]=0;if((h|0)==1){break B}v[22692]=0;W(531,m|0,a+1298292|0,-1)|0;h=v[22692];v[22692]=0;if((h|0)==1){break B}v[22692]=0;h=Q(725,m|0,d+1216|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}if(!h|!w[d+1216|0]|t[d+1216|0]<0){break u}h=d+1225|0;if((w[h|0]|w[h+1|0]<<8)>>>0>255){break u}g=d+1227|0;if((w[g|0]|w[g+1|0]<<8)>>>0>3999){break u}u[a+480188>>1]=w[d+1216|0];i=a+484360|0;n=d+1216|3;bf(Sb(i),w[n|0]|w[n+1|0]<<8);u[a+480192>>1]=w[h|0]|w[h+1|0]<<8;u[a+480190>>1]=w[g|0]|w[g+1|0]<<8;h=d+1229|0;if(w[h|0]){break A}h=6;break z}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}h=w[h|0]}v[e+480196>>2]=h;e=a;h=d+1230|0;if(w[h|0]){h=w[h|0]}else{h=125}v[e+480204>>2]=B(h,1e4);n=d+1231|0;D:{if(t[n+1|0]&1){v[22692]=0;R(554,a|0,32);e=v[22692];v[22692]=0;if((e|0)!=1){break D}break d}if(w[n|0]&2){v[22692]=0;R(554,a|0,2);e=v[22692];v[22692]=0;if((e|0)==1){break d}break D}if(w[n|0]&128){v[22692]=0;R(554,a|0,1);e=v[22692];v[22692]=0;if((e|0)==1){break d}break D}if(w[n|0]&8){v[22692]=0;R(554,a|0,16);e=v[22692];v[22692]=0;if((e|0)==1){break d}break D}v[22692]=0;R(554,a|0,4);e=v[22692];v[22692]=0;if((e|0)==1){break d}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[n|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[n|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[n|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[n+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[n+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[n+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[n+2|0]&8){v[22692]=0;W(409,a+1074312|0,5,1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}}E:{e=v[a+480180>>2];F:{if((e|0)!=2){if((e|0)!=32){break F}t[d+304|0]=w[d+1235|0];v[22692]=0;t[d+224|0]=128;e=ac(d+304|0,d+224|0);h=v[22692];v[22692]=0;if((h|0)==1){break w}v[a+480200>>2]=w[e|0]<<1;break F}t[d+304|0]=w[d+1235|0];v[22692]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);h=v[22692];v[22692]=0;if((h|0)==1){break E}v[a+480200>>2]=w[e|0]<<2}I=a+480188|0;g=d+1237|0;h=t[g|0];e=a;if(t[g|0]<=-1){h=h+52|0}else{F=Rw(+(h|0)*.15500000000000003);G:{if(F<4294967296&F>=0){h=~~F>>>0;break G}h=0}h=h+51|0}v[e+480228>>2]=h;v[22692]=0;u[d+304>>1]=64;e=Pc(I,d+304|0);h=v[22692];v[22692]=0;if((h|0)!=1){H:{h=x[e>>1];if(h){while(1){e=v[a+480180>>2];if((e|0)==32){t[d+304|0]=w[(d+f|0)+1238|0];v[22692]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);g=v[22692];v[22692]=0;if((g|0)==1){break H}u[((f<<5)+a|0)+480286>>1]=w[e|0];e=v[a+480180>>2]}I:{if((e|0)==4){break I}e=(d+f|0)+1302|0;if(w[e|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break I}if(w[e|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break I}u[((f<<5)+a|0)+480284>>1]=w[e|0]}f=f+1|0;if((h|0)!=(f|0)){continue}break}}f=0;g=0;while(1){f=w[(d+g|0)+1366|0]!=0|f;g=g+1|0;if((g|0)!=16){continue}break}while(1){f=w[((j<<1)+d|0)+1383|0]!=0|f;j=j+1|0;if((j|0)!=128){continue}break}if(f&1){f=0;while(1){J:{e=(d+f|0)+1366|0;if(w[e|0]){v[22692]=0;_(726,d+224|0);h=v[22692];v[22692]=0;K:{L:{M:{N:{O:{if((h|0)!=1){e=w[e|0];v[22692]=0;v[d+248>>2]=e-1;R(727,d+1192|0,d+248|0);e=v[22692];v[22692]=0;if((e|0)==1){break O}v[22692]=0;U(443,d+304|0,d+224|0,d+1192|0);e=v[22692];v[22692]=0;if((e|0)==1){break N}v[22692]=0;R(444,d+1168|0,((f<<5)+a|0)+901692|0);e=v[22692];v[22692]=0;if((e|0)==1){break M}v[22692]=0;Q(401,d+1168|0,d+304|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break M}vb(d+304|0);vb(d+1192|0);Hb(d+224|0);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;break K}g=P()|0;O()|0;break L}g=P()|0;O()|0;vb(d+304|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22692]=0;e=Q(70,d+304|0,18699)|0;h=v[22692];v[22692]=0;P:{if((h|0)!=1){v[22692]=0;R(444,d+224|0,((f<<5)+a|0)+901692|0);h=v[22692];v[22692]=0;if((h|0)==1){break P}v[22692]=0;Q(401,d+224|0,e|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break P}vb(e);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){e=(d+1216|0)+(f<<1)|0;h=e;Q:{if(w[e+167|0]){v[22692]=0;_(728,d+224|0);g=v[22692];v[22692]=0;R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){h=w[h+167|0];v[22692]=0;v[d+192>>2]=h-1;R(727,d+1192|0,d+192|0);h=v[22692];v[22692]=0;if((h|0)==1){break X}e=w[e+166|0];v[22692]=0;t[d+168|0]=e;R(729,d+1168|0,d+168|0);e=v[22692];v[22692]=0;if((e|0)==1){break W}v[22692]=0;Y(730,d+304|0,d+224|0,d+1192|0,d+1168|0);e=v[22692];v[22692]=0;if((e|0)==1){break V}v[22692]=0;R(444,d+248|0,((f<<5)+a|0)+902204|0);e=v[22692];v[22692]=0;if((e|0)==1){break U}v[22692]=0;Q(401,d+248|0,d+304|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break U}vb(d+304|0);vb(d+1168|0);vb(d+1192|0);Hb(d+224|0);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;break R}g=P()|0;O()|0;break S}g=P()|0;O()|0;break T}g=P()|0;O()|0;vb(d+304|0)}vb(d+1168|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22692]=0;e=Q(70,d+304|0,18699)|0;h=v[22692];v[22692]=0;Y:{if((h|0)!=1){v[22692]=0;R(444,d+224|0,((f<<5)+a|0)+902204|0);h=v[22692];v[22692]=0;if((h|0)==1){break Y}v[22692]=0;Q(401,d+224|0,e|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Y}vb(e);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=128){continue}break}}e=Sb(i);f=d+1216|1;f=w[f|0]|w[f+1|0]<<8;v[22692]=0;fa(519,e|0,m|0,f|0,255,254)|0;e=v[22692];v[22692]=0;Z:{_:{$:{aa:{ba:{ca:{if((e|0)!=1){i=d+1216|5;e=w[i|0]|w[i+1|0]<<8;f=w[d+1216|0];v[22692]=0;U(288,d+304|0,m|0,B(e,f)<<1);e=v[22692];v[22692]=0;if((e|0)==1){break ca}G=jc(d+1192|0,d+304|0);xb(d+304|0);e=w[i|0]|w[i+1|0]<<8;v[22692]=0;U(288,d+304|0,m|0,e<<1);e=v[22692];v[22692]=0;if((e|0)==1){break ba}H=jc(d+1168|0,d+304|0);xb(d+304|0);e=d+1216|7;e=w[e|0]|w[e+1|0]<<8;v[22692]=0;A=Q(328,d+1152|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break aa}N=d,V=Vb(A),v[N+248>>2]=V;N=d,V=Zb(A),v[N+192>>2]=V;if(Gb(d+248|0,d+192|0)){while(1){e=v[d+248>>2];v[22692]=0;f=T(190,m|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break $}v[22692]=0;U(288,d+224|0,m|0,f|0);f=v[22692];v[22692]=0;if((f|0)==1){break _}qd(e,jc(d+304|0,d+224|0));xb(d+304|0);xb(d+224|0);Bh(d+248|0);if(Gb(d+248|0,d+192|0)){continue}break}}e=v[a+480180>>2];r=1;s=c&1;if(!s){break Z}f=w[i|0]|w[i+1|0]<<8;v[22692]=0;R(330,a+484344|0,f|0);f=v[22692];v[22692]=0;if((f|0)!=1){break Z}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}D=a+484344|0;da:{ea:{fa:{ga:{ha:{ia:{if(w[i|0]|w[i+1|0]<<8){p=(e|0)==16?14:(e|0)==32?1:13;while(1){v[22692]=0;e=T(287,H|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break da}v[d+224>>2]=e;ja:{if(!s){break ja}v[22692]=0;e=W(331,D|0,l&65535,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break da}if(!e){break ja}k=0;if(!w[d+1216|0]){break ja}while(1){v[22692]=0;e=T(287,G|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ea}ka:{if($e(A)>>>0<=e>>>0){break ka}o=Jg(A,e);vc(o);e=_b(D,l);v[22692]=0;f=Wc(e,0,k&65535);e=v[22692];v[22692]=0;if((e|0)==1){break h}h=0;if(!v[d+224>>2]){break ka}while(1){v[22692]=0;z=T(374,o|0)|0;e=v[22692];v[22692]=0;la:{ma:{if((e|0)!=1){if(!z){break ka}Eh(d+304|0);j=0;q=z&15;if(q){break ma}break la}g=P()|0;O()|0;break g}while(1){na:{v[22692]=0;R(731,o|0,d+248|0);e=v[22692];v[22692]=0;if((e|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{e=w[d+248|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(e-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}e=w[d+249|0];Ja:{if(e>>>0<=119){t[d+304|0]=e+p;break Ja}Ka:{switch(e-254|0){case 1:t[d+304|0]=255;break Ja;case 0:t[d+304|0]=254;break Ja;default:break Ka}}t[d+304|0]=253}v[22692]=0;e=tv(d+304|0);g=v[22692];v[22692]=0;if((g|0)==1){break na}r=e&r;break oa}t[d+305|0]=w[d+249|0]+1;break oa}La:{if(w[d+306|0]){break La}e=v[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break La}e=w[d+249|0];if(e&15){break La}t[d+306|0]=11;t[d+308|0]=e>>>4;break oa}g=0;e=w[d+249|0];while(1){if((e|0)==w[g+39088|0]){t[d+308|0]=g;t[d+306|0]=11;break oa}g=g+1|0;if((g|0)!=10){continue}break}}t[d+307|0]=4;t[d+309|0]=w[d+249|0];break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>9|v[a+480180>>2]!=32)){t[d+308|0]=e;t[d+306|0]=8;break oa}t[d+309|0]=e;t[d+307|0]=5;break oa}Ma:{if(w[d+306|0]){break Ma}Na:{e=v[a+480180>>2];if((e|0)!=4){if((e|0)!=32){break Ma}g=w[d+249|0];if((g|0)!=255){break Na}t[d+308|0]=64;t[d+306|0]=2;break oa}g=w[d+249|0];if(g&15){break Ma}break pa}if(!(g&3)){break pa}}t[d+307|0]=9;t[d+309|0]=w[d+249|0];break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>64|v[a+480180>>2]==1)){t[d+308|0]=e;t[d+306|0]=1;break oa}t[d+309|0]=e;t[d+307|0]=13;break oa}t[d+307|0]=14;e=w[d+249|0];t[d+309|0]=e;if(v[a+480180>>2]==32){break oa}t[d+309|0]=B((e&240)>>>4|0,10)+(e&15);break oa}e=w[d+249|0];t[d+309|0]=e;if(e>>>0<=31){t[d+307|0]=16;break oa}t[d+307|0]=17;break oa}g=w[d+249|0];if(g>>>0>=16){t[d+308|0]=g>>>4;t[d+306|0]=(e|0)==20?3:5;break oa}t[d+308|0]=g;t[d+306|0]=(e|0)==20?4:6;break oa}e=w[d+249|0];if(e>>>0>=16){t[d+306|0]=10;t[d+308|0]=e>>>4;break oa}t[d+308|0]=e;t[d+306|0]=9;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|16;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|32;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33120|0];break oa}t[d+309|0]=w[d+249|0];e=w[d+307|0];t[d+307|0]=(e|0)==4?6:(e|0)==5?7:11;break oa}e=w[d+249|0];t[d+308|0]=(e>>>0)%10;if(e>>>0<=9){t[d+306|0]=5;break oa}if(e>>>0<=19){t[d+306|0]=6;break oa}if(e>>>0<=29){t[d+306|0]=3;break oa}if(e>>>0>39){break oa}t[d+306|0]=4;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33120|0];break oa}e=w[d+249|0]+33|0;if((e&255)>>>0>9){break oa}t[d+308|0]=e;t[d+306|0]=15;break oa}if(e>>>0>=56){break oa}t[d+309|0]=w[d+249|0];t[d+307|0]=w[w[d+248|0]+33120|0];break oa}t[d+306|0]=2;t[d+308|0]=g>>>2}j=j+1|0;if(q>>>0>(j&255)>>>0){continue}break la}break}g=P()|0;O()|0;break g}v[22692]=0;v[d+248>>2]=(z>>>4|0)+h;e=Fb(d+248|0,d+224|0);g=v[22692];v[22692]=0;if((g|0)==1){break ia}e=v[e>>2];if(e>>>0>h>>>0){while(1){g=v[d+304>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=x[d+308>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;f=B(w[d+1216|0],6)+f|0;h=h+1|0;if((e|0)!=(h|0)){continue}break}h=e}if(y[d+224>>2]>h>>>0){continue}break}}k=k+1|0;if(w[d+1216|0]>(k&65535)>>>0){continue}break}}l=l+1|0;if(l>>>0<(w[i|0]|w[i+1|0]<<8)>>>0){continue}break}}if(!((r^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ha}i=0;break ga}g=P()|0;O()|0;break g}i=!((w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24))&512);e=0;if(v[a+480180>>2]!=4){break fa}}e=x[a+480192>>1]}v[22692]=0;r=Q(732,d+1136|0,e|0)|0;e=v[22692];v[22692]=0;h=1;if((e|0)!=1){Oa:{Pa:{Qa:{if(x[a+480192>>1]){g=1;while(1){Ra:{Sa:{Ta:{if(!i){v[22692]=0;f=W(376,a|0,g&65535,0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Ta}if(f){break Sa}}while(1){v[22692]=0;e=T(374,m|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break j}if(e){continue}break}if(w[d+1703|0]>=5){while(1){v[22692]=0;e=T(374,m|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){g=P()|0;O()|0;break i}if(e){continue}break}}v[22692]=0;Q(318,m|0,826)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break Ra}}g=P()|0;O()|0;break i}e=Kb(d+224|0);v[22692]=0;W(531,m|0,e|0,-1)|0;j=v[22692];v[22692]=0;if((j|0)==1){break Qa}v[22692]=0;Q(301,f+492|0,e|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break Qa}Ua:{if(w[d+1703|0]<5){break Ua}v[22692]=0;W(531,m|0,e|0,-1)|0;j=v[22692];v[22692]=0;if((j|0)==1){break Qa}v[22692]=0;Q(301,f+524|0,e|0)|0;j=v[22692];v[22692]=0;if((j|0)!=1){break Ua}break Qa}v[22692]=0;j=Q(733,m|0,d+304|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break Qa}if(!j){break Pa}j=v[a+480180>>2];v[22692]=0;U(734,d+304|0,f|0,j|0);f=v[22692];v[22692]=0;if((f|0)==1){break Qa}if(v[a+480180>>2]==4){f=Lb(r,h-1|0);h=x[d+1106>>1]|x[d+1108>>1]<<16;t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24}vb(e)}g=g+1|0;h=g&65535;if(h>>>0<=x[a+480192>>1]){continue}break}}if(!i){break Oa}u[a+480192>>1]=0;break Oa}g=P()|0;O()|0;vb(e);break i}vb(e)}e=x[a+480190>>1];v[22692]=0;z=Q(735,d+288|0,e|0)|0;e=v[22692];v[22692]=0;q=1;if((e|0)!=1){q=w[d+1703|0]<=4?!(t[n|0]&1):q;J=c&2;e=0;Va:{if(!x[a+480190>>1]){break Va}j=1;h=1;while(1){c=e;l=Kb(d+272|0);v[22692]=0;W(531,m|0,l|0,-1)|0;e=v[22692];v[22692]=0;Wa:{Xa:{Ya:{Za:{_a:{if((e|0)==1){break _a}v[22692]=0;Q(301,((j<<5)+a|0)+946304|0,l|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break _a}g=B(j,104)+a|0;if(w[d+1703|0]<5){break Za}v[22692]=0;W(531,m|0,l|0,-1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break _a}v[22692]=0;Q(303,g+484423|0,l|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break Za}}g=P()|0;O()|0;break Ya}v[22692]=0;e=Q(736,m|0,d+304|0)|0;f=v[22692];v[22692]=0;$a:{ab:{bb:{cb:{db:{eb:{fb:{if((f|0)==1){break fb}if(!e){break eb}e=v[a+480180>>2];v[22692]=0;f=g+484380|0;Y(737,d+304|0,f|0,e|0,q|0);e=v[22692];v[22692]=0;if((e|0)==1){break fb}i=0;gb:{if(((w[d+324|0]|w[d+325|0]<<8)&61440)!=28672|w[d+1703|0]<5){break gb}v[22692]=0;i=T(738,m|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break gb}g=P()|0;O()|0;break Ya}if(!J){break Xa}K=w[d+324|0]|w[d+325|0]<<8;o=K&61440;if(!(o|(w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24)))){e=Rc(d+224|0,(w[d+324|0]|w[d+325|0]<<8)&1?16:8,(w[d+324|0]|w[d+325|0]<<8)&1024?3:1,0,0);v[22692]=0;W(329,e|0,f|0,b|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break Xa}g=P()|0;O()|0;break Ya}if(!(((w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24))+j|0)<1|(w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24))>-1)){e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22692]=0;Q(739,f|0,(B(e+j|0,104)+a|0)+484380|0)|0;f=v[22692];v[22692]=0;e=c;if((f|0)!=1){break Wa}g=P()|0;O()|0;break Ya}if((w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24))<1){break Xa}if(t[d+324|0]&1){e=g+484414|0;u[e>>1]=x[e>>1]|1}if(w[d+325|0]&4){e=g+484414|0;u[e>>1]=x[e>>1]|64}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22692]=0;U(288,d+224|0,b|0,e|0);k=v[22692];v[22692]=0;hb:{ib:{M=d;jb:{kb:{if((k|0)!=1){k=jc(d+248|0,d+224|0);xb(d+224|0);s=dd(f);e=(o|0)==16384;if(!((o|0)!=8192?e:1)){break ib}v[22692]=0;p=T(193,d+248|0)|0;E=v[22692];v[22692]=0;if((E|0)==1){break hb}v[d+224>>2]=p;E=v[d+224>>2];p=4/(s>>>0)|0;if(E>>>0>4294967295/(p>>>0)>>>0){break kb}p=B(p,E);break jb}g=P()|0;O()|0;break Ya}p=-1}v[M+224>>2]=p;tc(f,p);if(!e){if((o|0)!=8192){break ib}v[22692]=0;e=T(386,f|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break ab}if(!e){break cb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22692]=0;Y(740,k|0,e|0,f|0,s|0);f=v[22692];v[22692]=0;e=c;if((f|0)!=1){break bb}break ab}e=v[g+484400>>2];f=v[f>>2];v[22692]=0;Y(741,k|0,e|0,f|0,s|0);f=v[22692];v[22692]=0;e=c;if((f|0)==1){break ab}break bb}v[22692]=0;e=T(386,f|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break ab}if(!e){break cb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22692]=0;Y(742,k|0,e|0,f|0,s|0);f=v[22692];v[22692]=0;e=c;if((f|0)==1){break ab}break bb}e=v[g+484400>>2];f=v[f>>2];v[22692]=0;Y(743,k|0,e|0,f|0,s|0);f=v[22692];v[22692]=0;e=c;if((f|0)==1){break ab}break bb}if((K&45056)==12288){e=MV(d+224|0,k,w[d+343|0]|w[d+344|0]<<8,i);f=Ol(z,j-1|0);qd(f,e);v[f+20>>2]=v[e+20>>2];xb(e);break cb}if((o|0)!=32768){e=1;if((o|0)!=4096){break bb}e=Pe(d+224|0,k);v[22692]=0;Q(744,d+216|0,k|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){lb:{if(!w[d+221|0]){break lb}i=x[d+218>>1]<<1;if((i&65535)>>>0>(w[d+343|0]|w[d+344|0]<<8)>>>0){break lb}i=(w[d+343|0]|w[d+344|0]<<8)-i|0;t[d+343|0]=i;t[d+344|0]=i>>>8;v[22692]=0;Q(188,d+248|0,x[d+216>>1])|0;i=v[22692];v[22692]=0;if((i|0)==1){break db}v[22692]=0;i=T(465,d+248|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break db}v[22692]=0;U(288,d+168|0,d+248|0,i|0);i=v[22692];v[22692]=0;if((i|0)==1){break db}qd(e,jc(d+192|0,d+168|0));xb(d+192|0);xb(d+168|0)}v[22692]=0;e=fa(745,a|0,h&65535,e|0,1,1)|0;i=v[22692];v[22692]=0;if((i|0)==1){break db}mb:{if(!e){v[22692]=0;c=v[22692];v[22692]=0;if((c|0)==1){break db}c=1;break mb}nb:{if(!(w[d+343|0]|w[d+344|0]<<8)){break nb}e=w[d+343|0]|w[d+344|0]<<8;if(Zi(f)>>>0<=e>>>0){break nb}e=w[d+343|0]|w[d+344|0]<<8;i=gj(f);g=g+484400|0;vh(zb(v[g>>2]),zb(v[g>>2])+(w[d+343|0]|w[d+344|0]<<8)|0,Zi(f)-(w[d+343|0]|w[d+344|0]<<8)|0);v[f>>2]=v[f>>2]-((e>>>0)/(i>>>0)|0)}e=v[d+312>>2];v[d+164>>2]=e;v[d+68>>2]=e;if(y[f>>2]>(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))>>>0){v[f>>2]=w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24)}}e=c;xb(d+224|0);break bb}break db}v[22692]=0;e=Q(572,k|0,d+224|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){if(!e){break cb}v[d+80>>2]=v[d+232>>2];v[22692]=0;e=v[d+228>>2];v[d+72>>2]=v[d+224>>2];v[d+76>>2]=e;U(573,f|0,1,d+72|0);e=v[22692];v[22692]=0;if((e|0)!=1){break cb}}g=P()|0;O()|0;break $a}g=P()|0;O()|0;break $a}g=P()|0;O()|0;break Ya}vb(l);e=c;break Va}g=P()|0;O()|0;xb(d+224|0);break $a}e=c}xb(d+248|0);break Wa}g=P()|0;O()|0}xb(d+248|0)}vb(l);break k}e=c}vb(l);h=h+1|0;j=h&65535;if(j>>>0<=x[a+480190>>1]){continue}break}}if(!(!J|!x[a+480190>>1])){f=1;k=1;while(1){c=Ol(z,f-1|0);v[22692]=0;b=T(275,c|0)|0;h=v[22692];v[22692]=0;ob:{pb:{qb:{if((h|0)!=1){if(!b){break ob}h=x[c+22>>1];b=h+k&65535;rb:{sb:{j=(h|0)!=0&(b|0)!=0&b>>>0<=x[a+480190>>1];if(!j){v[22692]=0;T(193,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break sb}break l}g=x[c+20>>1];h=Ol(z,b-1|0);vc(h);b=x[c+20>>1];v[22692]=0;b=Q(189,h|0,b|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break l}if(!b){break ob}v[d+224>>2]=0;v[d+248>>2]=0;v[22692]=0;U(747,d+304|0,h|0,g|0);b=v[22692];v[22692]=0;tb:{if((b|0)!=1){v[22692]=0;b=Td(d+304|0);g=v[22692];v[22692]=0;if((g|0)==1){break tb}b=zb(b);g=Ti(v[d+304>>2]);v[22692]=0;b=fa(748,b|0,g|0,d+224|0,d+248|0,0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break tb}v[22692]=0;Q(318,h|0,v[d+224>>2])|0;h=v[22692];v[22692]=0;if((h|0)==1){break tb}zc(d+304|0);break rb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}vc(c);b=0;v[d+224>>2]=0;v[d+248>>2]=0}v[22692]=0;R(749,d+304|0,c|0);h=v[22692];v[22692]=0;ub:{vb:{if((h|0)!=1){v[22692]=0;i=Td(d+304|0);h=v[22692];v[22692]=0;if((h|0)==1){break ub}g=v[d+304>>2];if(!j){b=zb(i);h=Ti(g);v[22692]=0;b=fa(748,b|0,h|0,d+224|0,d+248|0,0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break qb}v[22692]=0;Q(318,c|0,v[d+224>>2])|0;h=v[22692];v[22692]=0;if((h|0)==1){break qb}h=v[d+224>>2];g=g-h|0;i=h+i|0}if(b){break vb}e=1;break pb}g=P()|0;O()|0;break k}v[22692]=0;f=B(f,104)+a|0;j=f+484380|0;T(386,j|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break qb}o=f+484400|0;p=f+484414|0;f=0;h=v[d+248>>2];while(1){wb:{if(y[j>>2]<=f>>>0|(!g|(h|0)!=1?h:0)){break wb}if(!Nd(j)){break wb}v[d+192>>2]=0;v[d+168>>2]=0;h=zb(i);l=Ti(g);v[22692]=0;h=la(750,b|0,h|0,l|0,d+192|0,d+272|0,d+168|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break qb}v[22692]=0;v[d+224>>2]=h;Q(318,c|0,h|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break qb}s=v[d+224>>2];Zj(d+168|0,Ti(v[j>>2]-f|0));xb:{if(v[d+168>>2]<1){break xb}if(v[d+192>>2]!=(dd(j)|0)){break xb}if(t[p|0]&1){h=kg(d+152|0,v[o>>2]+(B(dd(j),f)<<1)|0,dd(j),v[d+168>>2]);l=kg(d+136|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22692]=0;v[d- -64>>2]=v[h+8>>2];q=v[h+4>>2];v[d+56>>2]=v[h>>2];v[d+60>>2]=q;v[d+48>>2]=v[l+8>>2];h=v[l+4>>2];v[d+40>>2]=v[l>>2];v[d+44>>2]=h;R(751,d+56|0,d+40|0);h=v[22692];v[22692]=0;if((h|0)!=1){break xb}break qb}h=kg(d+120|0,v[o>>2]+B(dd(j),f)|0,dd(j),v[d+168>>2]);l=kg(d+104|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22692]=0;v[d+32>>2]=v[h+8>>2];q=v[h+4>>2];v[d+24>>2]=v[h>>2];v[d+28>>2]=q;v[d+16>>2]=v[l+8>>2];h=v[l+4>>2];v[d+8>>2]=v[l>>2];v[d+12>>2]=h;R(752,d+24|0,d+8|0);h=v[22692];v[22692]=0;if((h|0)==1){break qb}}v[22692]=0;l=v[d+168>>2];h=by(b);q=v[22692];v[22692]=0;if((q|0)==1){break qb}g=g-s|0;i=i+s|0;v[d+248>>2]=h;f=f+l|0;continue}break}v[22692]=0;cy(b);b=v[22692];v[22692]=0;if((b|0)!=1){break pb}break qb}break qb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}zc(d+304|0)}k=k+1|0;f=k&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}yb:{if(v[a+480180>>2]!=4){break yb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break yb}b=w[Lb(r,f)|0];c=w[Lb(r,f)+1|0];h=w[Lb(r,f)+2|0];g=w[Lb(r,f)+3|0];v[22692]=0;f=f+1|0;ka(755,a|0,f&65535,b|0,c|0,h|0,g|0);b=v[22692];v[22692]=0;if((b|0)!=1){continue}break}g=P()|0;O()|0;break k}zb:{Ab:{Bb:{Cb:{if(!(w[n+2|0]&16)){break Cb}v[22692]=0;b=Q(189,m|0,1)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}if(!b){break Cb}f=0;v[22692]=0;b=T(374,m|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break n}if(!(!(b&1)|!x[I>>1])){while(1){v[22692]=0;b=T(190,m|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Bb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[22692]=0;b=Q(189,m|0,1)|0;c=v[22692];v[22692]=0;Db:{if((c|0)!=1){if(!b){break Cb}v[22692]=0;b=T(374,m|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Ab}if(!b){break Cb}v[22692]=0;c=T(190,m|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break zb}v[22692]=0;U(288,d+224|0,m|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break zb}c=jc(d+304|0,d+224|0);xb(d+224|0);if(b>>>0>250){break Db}v[22692]=0;R(601,c|0,(B(b,160)+a|0)+906140|0);b=v[22692];v[22692]=0;if((b|0)!=1){break Db}g=P()|0;O()|0;xb(d+304|0);break k}g=P()|0;O()|0;break k}xb(d+304|0);continue}}i=a+901404|0;j=a+1074308|0;h=Kb(d+192|0);g=0;c=0;Eb:{Fb:{while(1){v[22692]=0;b=Q(189,m|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Eb}if(!b){break Fb}v[22692]=0;f=T(190,m|0)|0;b=v[22692];v[22692]=0;Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{if((b|0)!=1){v[22692]=0;b=T(190,m|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break Wb}v[22692]=0;U(288,d+304|0,m|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break Vb}b=jc(d+224|0,d+304|0);xb(d+304|0);if((f|0)<=1397900629){if((f|0)==1229211981){break Tb}if((f|0)!=1229476432){break Hb}v[22692]=0;f=T(374,b|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break q}v[a+480216>>2]=f;v[22692]=0;b=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break q}v[a+480220>>2]=b;break Hb}if((f|0)==1397900630){break Ub}if((f|0)!=1414548815){break Hb}v[22692]=0;f=Q(551,b|0,11103)|0;k=v[22692];v[22692]=0;if((k|0)==1){break q}if(!f){break Rb}v[22692]=0;f=T(190,b|0)|0;k=v[22692];v[22692]=0;if((k|0)!=1){v[22692]=0;U(288,d+304|0,d+224|0,f|0);f=v[22692];v[22692]=0;if((f|0)!=1){break Sb}}g=P()|0;O()|0;break p}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}Xb:{Yb:{Zb:{f=v[a+480180>>2];switch(f-2|0){case 1:break Hb;case 0:break Ib;case 2:break Yb;default:break Zb}}if((f|0)==16){break Xb}if((f|0)!=32){break Hb}v[22692]=0;g=T(287,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}v[22692]=0;c=T(287,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break Hb}break q}v[d+304>>2]=32;v[22692]=0;f=T(193,d+224|0)|0;k=v[22692];v[22692]=0;_b:{if((k|0)==1){break _b}v[22692]=0;v[d+248>>2]=f;f=Fb(d+304|0,d+248|0);k=v[22692];v[22692]=0;if((k|0)==1){break _b}f=v[f>>2];v[22692]=0;U(756,b|0,h|0,f|0);b=v[22692];v[22692]=0;if((b|0)!=1){break Hb}}g=P()|0;O()|0;break p}v[22692]=0;b=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Gb}v[22692]=0;R(757,d+248|0,1320);f=v[22692];v[22692]=0;$b:{if((f|0)!=1){v[d+168>>2]=b>>>4;v[22692]=0;v[d+272>>2]=b&15;Y(458,d+304|0,d+248|0,d+168|0,d+272|0);b=v[22692];v[22692]=0;if((b|0)==1){break $b}Eb(h,d+304|0);vb(d+304|0);Hb(d+248|0);break Hb}g=P()|0;O()|0;break p}g=P()|0;O()|0;Hb(d+248|0);break p}v[22692]=0;Q(564,b|0,i|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break q}v[22692]=0;Du(i);b=v[22692];v[22692]=0;if((b|0)==1){break q}break Hb}k=jc(d+248|0,d+304|0);xb(d+304|0);v[22692]=0;f=T(193,d+248|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break Qb}u[d+304>>1]=f>>>5;f=Re(D);v[22692]=0;u[d+168>>1]=f;f=Pc(d+304|0,d+168|0);l=v[22692];v[22692]=0;if((l|0)==1){break Qb}l=x[f>>1];if(l){f=0;while(1){v[22692]=0;W(758,k|0,d+304|0,32)|0;o=v[22692];v[22692]=0;if((o|0)==1){break Qb}o=_b(D,f);v[22692]=0;Q(759,o|0,d+304|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break Qb}f=f+1|0;if((l|0)!=(f|0)){continue}break}}xb(d+248|0)}v[22692]=0;f=Q(551,b|0,11108)|0;k=v[22692];v[22692]=0;if((k|0)==1){break q}if(!f){break Ob}v[22692]=0;f=T(190,b|0)|0;k=v[22692];v[22692]=0;if((k|0)!=1){v[22692]=0;U(288,d+248|0,d+224|0,f|0);f=v[22692];v[22692]=0;if((f|0)!=1){break Pb}}g=P()|0;O()|0;break p}g=P()|0;O()|0;xb(d+248|0);break p}k=jc(d+304|0,d+248|0);xb(d+248|0);v[22692]=0;f=T(193,d+304|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break Nb}u[d+248>>1]=(f>>>0)/20;f=x[a+480188>>1];v[22692]=0;u[d+168>>1]=f;f=Pc(d+248|0,d+168|0);l=v[22692];v[22692]=0;if((l|0)==1){break Nb}l=x[f>>1];if(l){f=0;while(1){v[22692]=0;W(567,k|0,((f<<5)+a|0)+480289|0,20)|0;o=v[22692];v[22692]=0;if((o|0)==1){break Nb}f=f+1|0;if((l|0)!=(f|0)){continue}break}}xb(d+304|0)}v[22692]=0;Q(584,a|0,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break q}v[22692]=0;Y(585,a|0,b|0,1,0);f=v[22692];v[22692]=0;if((f|0)==1){break q}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[22692]=0;U(600,a|0,b|0,g&65535);b=v[22692];v[22692]=0;if((b|0)==1){break q}}if(!v[j>>2]){break Hb}v[22692]=0;b=Q(2,d+248|0,14692)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Mb}v[22692]=0;R(160,d+168|0,j|0);f=v[22692];v[22692]=0;if((f|0)==1){break Lb}v[22692]=0;U(3,d+304|0,b|0,d+168|0);f=v[22692];v[22692]=0;if((f|0)==1){break Kb}Eb(h,d+304|0);vb(d+304|0);vb(d+168|0);vb(b);break Hb}g=P()|0;O()|0;xb(d+304|0);break p}g=P()|0;O()|0;break p}g=P()|0;O()|0;break Jb}g=P()|0;O()|0;vb(d+168|0)}vb(b);break p}v[22692]=0;g=T(287,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break q}}xb(d+224|0);continue}break}g=P()|0;O()|0;break p}ac:{bc:{cc:{dc:{ec:{fc:{gc:{if(v[a+480180>>2]!=32){break gc}b=g&65535;if(b>>>0<256){break gc}if(b>>>0<532){break fc}}hc:{if(v[a+480180>>2]!=2){break hc}b=g&65535;if(b>>>0<12544){break hc}if(b>>>0<12820){break fc}}if(v[a+480180>>2]!=2){break ec}b=g&65535;if(b>>>0<4864|b>>>0>4895){break ec}}v[22692]=0;Oo(i);b=v[22692];v[22692]=0;if((b|0)==1){break dc}}if(!(t[n+2|0]&1)){break ac}f=v[a+1074308>>2];if(!f){if(x[a+480192>>1]){f=1;while(1){b=v[(((f&65535)<<2)+a|0)+900380>>2];if(b){v[22692]=0;g=hi(b,2);n=v[22692];v[22692]=0;if((n|0)==1){break cc}n=v[a+480180>>2];v[22692]=0;U(760,g|0,4,n|0);g=v[22692];v[22692]=0;if((g|0)==1){break bc}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[22692]=0;b=a+1074312|0;Q(410,b|0,27)|0;f=v[22692];v[22692]=0;if((f|0)==1){break dc}v[22692]=0;Q(410,b|0,57)|0;b=v[22692];v[22692]=0;if((b|0)==1){break dc}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[22692]=0;Q(410,a+1074312|0,73)|0;b=v[22692];v[22692]=0;if((b|0)==1){break dc}f=v[a+1074308>>2]}if(f>>>0>19267583){break ac}v[22692]=0;Q(410,a+1074312|0,50)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break ac}}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}ic:{jc:{kc:{lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{if(ed(h)){v[22692]=0;_(761,d+224|0);b=v[22692];v[22692]=0;wc:{if((b|0)!=1){v[22692]=0;U(718,d+304|0,d+224|0,d+1703|0);b=v[22692];v[22692]=0;if((b|0)==1){break wc}break vc}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}v[22692]=0;_(762,d+224|0);b=v[22692];v[22692]=0;if((b|0)==1){break uc}v[22692]=0;Y(763,d+304|0,d+224|0,d+1703|0,h|0);b=v[22692];v[22692]=0;if((b|0)==1){break tc}}Eb(h,d+304|0);vb(d+304|0);Hb(d+224|0);v[22692]=0;R(717,d+224|0,1108);b=v[22692];v[22692]=0;if((b|0)==1){break rc}v[22692]=0;U(718,d+304|0,d+224|0,d+1703|0);b=v[22692];v[22692]=0;if((b|0)==1){break qc}Eb(a+1298304|0,d+304|0);vb(d+304|0);Hb(d+224|0);v[22692]=0;b=Q(2,d+304|0,12135)|0;f=v[22692];v[22692]=0;if((f|0)==1){break pc}Eb(a+1298316|0,b);vb(b);b=v[a+480180>>2];if((b|0)>15){break sc}switch(b-1|0){case 1:break lc;case 3:break mc;case 0:break nc;default:break v}}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}if((b|0)==16){break oc}if((b|0)==32){break kc}if((b|0)!=16777216){break v}v[22692]=0;b=Q(2,d+304|0,7348)|0;c=v[22692];v[22692]=0;if((c|0)==1){break jc}Eb(a+1298352|0,b);vb(b);v[22692]=0;b=Q(2,d+304|0,11065)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ic}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}g=P()|0;O()|0;break o}v[22692]=0;b=Q(2,d+304|0,7353)|0;c=v[22692];v[22692]=0;xc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22692]=0;b=Q(2,d+304|0,5497)|0;c=v[22692];v[22692]=0;if((c|0)==1){break xc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22692]=0;b=Q(2,d+304|0,9510)|0;c=v[22692];v[22692]=0;yc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22692]=0;b=Q(2,d+304|0,11429)|0;c=v[22692];v[22692]=0;if((c|0)==1){break yc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22692]=0;b=Q(2,d+304|0,7326)|0;c=v[22692];v[22692]=0;zc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22692]=0;b=Q(2,d+304|0,12378)|0;c=v[22692];v[22692]=0;if((c|0)==1){break zc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22692]=0;b=Q(2,d+304|0,7698)|0;c=v[22692];v[22692]=0;Ac:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22692]=0;b=Q(2,d+304|0,12178)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Ac}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22692]=0;b=Q(2,d+304|0,3181)|0;f=v[22692];v[22692]=0;Bc:{Cc:{Dc:{Ec:{Fc:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);if(!(c&65535)){break Bc}v[22692]=0;R(411,d+224|0,1423);b=v[22692];v[22692]=0;if((b|0)==1){break Fc}v[d+168>>2]=(c&65280)>>>8;v[22692]=0;v[d+272>>2]=c&255;R(595,d+248|0,d+272|0);b=v[22692];v[22692]=0;if((b|0)==1){break Ec}v[22692]=0;Y(578,d+304|0,d+224|0,d+168|0,d+248|0);b=v[22692];v[22692]=0;if((b|0)==1){break Dc}Eb(a+1298340|0,d+304|0);vb(d+304|0);vb(d+248|0);Hb(d+224|0);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break Cc}g=P()|0;O()|0;vb(d+248|0)}Hb(d+224|0);break o}v[22692]=0;b=Q(2,d+304|0,5673)|0;c=v[22692];v[22692]=0;if((c|0)!=1){Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break i}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}Eb(a+1298328|0,h);Gc:{if(v[a+1074308>>2]){v[a+1298364>>2]=8;break Gc}if(v[a+480180>>2]==1){v[a+1298364>>2]=2;break Gc}v[a+1298364>>2]=5}f=1;if(e&1){v[22692]=0;b=Q(2,d+304|0,13699)|0;c=v[22692];v[22692]=0;if((c|0)==1){break s}v[22692]=0;U(556,a|0,2,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break r}vb(b)}vb(h);_B(z);ci(r);hd(A);xb(H);xb(G)}xb(m)}gc(C);break a}g=P()|0;O()|0;break o}g=P()|0;O()|0;vb(b);break o}g=P()|0;O()|0}xb(d+224|0)}vb(h);break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0}_B(z);break i}g=P()|0;O()|0}ci(r);break g}g=P()|0;O()|0}hd(A)}xb(H)}xb(G);break c}g=P()|0;O()|0}xb(m)}gc(C);S(g|0);L()}gb=d+1712|0;return f|0}function Oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,ga=0,ha=0,ia=C(0),ja=0,ka=0,la=0,ma=C(0);e=gb-480|0;gb=e;vc(b);a:{b:{c:{if(!Jh(b,e+472|0)){break c}if(!ST(e+472|0)){break c}if((NT(b)|0)>-1){break c}if(!c){f=1;break c}Id(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;bA(e+208|0,32);f=v[e+220>>2];d=a+1074320|0;v[d>>2]=v[e+216>>2];v[d+4>>2]=f;d=v[e+212>>2];v[a+1074312>>2]=v[e+208>>2];v[a+1074316>>2]=d;Pf(a+1074312|0,38);D=cd(e+456|0);F=cd(e+440|0);E=cd(e+424|0);m=cd(e+408|0);ng(b,4);n=a+480190|0;H=c&1;h=a+1298292|0;y=2500;k=!(c&2);d:{e:{f:{g:{h:{i:{while(1){v[22692]=0;c=Q(189,b|0,4)|0;d=v[22692];v[22692]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){t:{if(c){v[22692]=0;j=T(895,b|0)|0;c=v[22692];v[22692]=0;u:{if((c|0)==1){break u}f=0;v:{switch(j+21|0){case 20:v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){if(x[a+480188>>1]){continue}d=c&65535;if(!d|d>>>0>127){continue}u[a+480188>>1]=c;ka=a,la=Mb(512/(d>>>0)|0,16,128),v[ka+480228>>2]=la;continue}a=P()|0;O()|0;break a;case 19:v[22692]=0;K=T(426,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break u}if(K>>>0<=1024){continue}break q;case 16:v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){if((c&65535)==4){continue}break q}a=P()|0;O()|0;break a;case 15:v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;w:{if((d|0)!=1){v[e+208>>2]=c;v[22692]=0;v[e+104>>2]=800;c=Fb(e+208|0,e+104|0);d=v[22692];v[22692]=0;if((d|0)==1){break w}v[a+480204>>2]=B(v[c>>2],12400);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a;case 17:case 18:v[22692]=0;Q(318,b|0,4)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break u;case 31:v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}Z=1;y=Gd(c,0,1e4);continue;case 32:case 33:v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;x:{y:{if((d|0)!=1){Z=1;if(!c){continue}v[22692]=0;c=Q(2,e+208|0,9770)|0;d=v[22692];v[22692]=0;if((d|0)==1){break y}v[22692]=0;U(556,a|0,2,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break x}vb(c);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a;case 14:v[22692]=0;Q(318,b|0,4)|0;c=v[22692];v[22692]=0;if((c|0)==1){break u}o=!x[n>>1]|o;continue;case 11:z:{if(!H){break z}if(!bd(D)){break z}v[22692]=0;R(896,e+208|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=D;d=c;if(v[c>>2]){Pd(d);wB(v[d>>2],bi(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+208|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Mu(e+208|0);continue}a=P()|0;O()|0;break a}v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break u;case 3:case 4:case 10:if(ah(m)>>>0<=x[n>>1]){continue}A:{if((k|o)&1){break A}if(!fi(a)){break A}q=x[n>>1]+1|0;u[n>>1]=q;d=mc(e+392|0);v[22692]=0;c=T(214,e+208|0)|0;f=v[22692];v[22692]=0;B:{C:{D:{if((f|0)!=1){if((j|0)==-17){break D}if((j|0)!=-11){break C}v[22692]=0;f=T(426,b|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break B}v[22692]=0;U(288,e+368|0,b|0,f|0);f=v[22692];v[22692]=0;if((f|0)==1){break B}qd(c,jc(e+104|0,e+368|0));xb(e+104|0);xb(e+368|0);break j}a=P()|0;O()|0;break d}v[22692]=0;R(897,e+104|0,b|0);f=v[22692];v[22692]=0;E:{if((f|0)!=1){gp(d,e+104|0);gc(e+104|0);v[22692]=0;Vd(e+360|0,d);f=v[22692];v[22692]=0;if((f|0)==1){break E}f=Ud(e+352|0);v[22692]=0;j=v[e+364>>2];v[e+32>>2]=v[e+360>>2];v[e+36>>2]=j;j=v[f+4>>2];v[e+24>>2]=v[f>>2];v[e+28>>2]=j;f=W(505,e+104|0,e+32|0,e+24|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break E}qd(c,f);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22692]=0;R(898,e+104|0,b|0);f=v[22692];v[22692]=0;F:{if((f|0)!=1){gp(d,e+104|0);gc(e+104|0);v[22692]=0;Vd(e+344|0,d);f=v[22692];v[22692]=0;if((f|0)==1){break F}f=Ud(e+336|0);v[22692]=0;j=v[e+348>>2];v[e+16>>2]=v[e+344>>2];v[e+20>>2]=j;j=v[f+4>>2];v[e+8>>2]=v[f>>2];v[e+12>>2]=j;f=W(505,e+104|0,e+16|0,e+8|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break F}qd(c,f);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break u;case 9:if(!fi(a)){continue}u[n>>1]=x[n>>1]+1;continue;case 8:G:{if(!H){break G}if(!bd(E)){break G}v[22692]=0;R(899,e+208|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=E;d=c;if(v[c>>2]){Pd(d);jC(v[d>>2],ye(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+208|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;ci(e+208|0);continue}a=P()|0;O()|0;break a}v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break u;case 7:if(bd(m)){v[22692]=0;R(900,e+208|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=m;d=c;if(v[c>>2]){Pd(d);tB(v[d>>2],uB(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+208|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Ku(e+208|0);continue}a=P()|0;O()|0;break a}v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break u;case 6:H:{if(!H){break H}if(!bd(F)){break H}v[22692]=0;R(901,e+208|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=F;d=c;if(v[c>>2]){Pd(d);vB(v[d>>2],vi(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+208|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Ju(e+208|0);continue}a=P()|0;O()|0;break a}v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break u;case 5:v[22692]=0;R(902,e+208|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break t}I:{if(bd(e+208|0)){break I}c=v[e+208>>2];d=pc(e+208|0);v[22692]=0;ca(903,h|0,c|0,d|0,1)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break I}a=P()|0;O()|0;gc(e+208|0);break a}gc(e+208|0);continue;case 0:case 1:case 2:break v;default:break q}}v[22692]=0;c=T(426,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break u}v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}}a=P()|0;O()|0;break a}f=0;if(!x[a+480188>>1]|!K){break q}if(bd(m)){break q}if(H){if(bd(D)){break q}if(bd(E)){break q}if(bd(F)){break q}}if(ah(m)>>>0>=256){v[22692]=0;R(904,m|0,255);b=v[22692];v[22692]=0;if((b|0)==1){break b}}ka=a,la=ah(m),u[ka+480192>>1]=la;v[22692]=0;k=a+480192|0;b=Je(n,k);c=v[22692];v[22692]=0;if((c|0)==1){break b}u[n>>1]=x[b>>1];if(o&1){v[22692]=0;b=Q(2,e+208|0,13529)|0;c=v[22692];v[22692]=0;if((c|0)==1){break k}v[22692]=0;U(556,a|0,2,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break l}vb(b)}f=x[k>>1];o=1;while(1){d=f;f=0;c=1;b=1;J:{if(!d){break J}while(1){K:{h=Kl(m,c-1|0);d=h;if(w[d|0]){d=t[d+128|0]<0}else{d=1}L:{if(d){break L}if((Iu(h)|0)==(o&1)){break L}j=0;d=h;M:{if(!Iu(d)){break M}if(Ib(w[d+6|0]|w[d+7|0]<<8)){break M}if(Ib(w[d+14|0]|w[d+15|0]<<8)>>>0>20){break M}j=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==4}N:{O:{if(j){f=w[h+23|0];d=w[h+140|0];v[22692]=0;d=fa(905,h|0,a|0,(d&2)>>>1|0,(B(c,104)+a|0)+484380|0,y&65535)|0;j=v[22692];v[22692]=0;P:{Q:{R:{if((j|0)!=1){if(!d){break P}v[22692]=0;d=Q(70,e+208|0,7967)|0;j=v[22692];v[22692]=0;if((j|0)==1){break R}v[22692]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Q}vb(d);d=b;if(ah(m)>>>0<=f>>>0){break N}ka=h,la=w[Kl(m,f)+143|0]+w[h+143|0]|0,t[ka+143|0]=la;break O}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=f+1|0;break N}j=0;S:{if(!Iu(h)){break S}if((Ib(w[d+6|0]|w[d+7|0]<<8)|0)!=1){break S}if((Ib(w[d+14|0]|w[d+15|0]<<8)|0)!=2){break S}j=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==10}d=b;if(!j){break N}hc(e+208|0,h,128);if(Ib(w[e+228|0]|w[e+229|0]<<8)>>>0>=x[n>>1]){break O}v[22692]=0;f=Q(890,e+104|0,0)|0;d=v[22692];v[22692]=0;T:{U:{V:{if((d|0)!=1){d=(B(Ib(w[e+228|0]|w[e+229|0]<<8),104)+a|0)+484484|0;if(Ib(w[e+244|0]|w[e+245|0]<<8)>>>0<x[a+480190>>1]){f=(B(Ib(w[e+244|0]|w[e+245|0]<<8),104)+a|0)+484484|0}v[22692]=0;d=ca(906,e+208|0,d|0,f|0,(B(c,104)+a|0)+484380|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break V}if(!d){break O}v[22692]=0;d=Q(70,e+368|0,8497)|0;f=v[22692];v[22692]=0;if((f|0)==1){break U}v[22692]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break T}vb(d);t[h+139|0]=w[h+139|0]+12;break O}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=b}v[22692]=0;c=d&65535;d=W(376,a|0,b&65535,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break K}if(!d|c>>>0>x[n>>1]){break L}v[22692]=0;Y(907,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22692];v[22692]=0;if((c|0)==1){break K}}b=b+1|0;c=b&65535;f=x[k>>1];if(c>>>0<=f>>>0){continue}break J}break}a=P()|0;O()|0;break a}b=o&1;o=0;if(b){continue}break}I=Bk(e+104|0);n=Bk(e+368|0);b=Nb(E);$=B(x[a+480188>>1],K);aa=Fv((b>>>0)/($>>>0)|0);v[22692]=0;M=a+484344|0;R(330,M|0,aa|0);b=v[22692];v[22692]=0;if((b|0)==1){a=P()|0;O()|0;break m}ba=a+484360|0;Vl(Sb(ba));b=x[a+480188>>1];v[22692]=0;r=Q(908,e+392|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){ka=e,la=Vb(F),v[ka+96>>2]=la;ka=e,la=Zb(F),v[ka+88>>2]=la;if(!Gb(e+96|0,e+88|0)){break s}W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{while(1){da:{p=v[e+96>>2];b=p;ea:{if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==1){break ea}if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==65535){break da}b=Ib(w[p|0]|w[p+1|0]<<8);if(ze(D)>>>0<=b>>>0){break ea}b=Ib(w[p+2|0]|w[p+3|0]<<8);if(ze(D)>>>0<b>>>0){break ea}if(!Ib(w[p+2|0]|w[p+3|0]<<8)){break ea}if(ze(D)-Ib(w[p+2|0]|w[p+3|0]<<8)>>>0<Ib(w[p|0]|w[p+1|0]<<8)>>>0){break ea}b=v[D>>2];sd(e+208|0,b,b+(ze(D)<<5)|0);c=Ib(w[p|0]|w[p+1|0]<<8);b=Ib(w[p+2|0]|w[p+3|0]<<8);d=v[e+208>>2]+(c<<5)|0;b=(b|0)==-1?(v[e+212>>2]-v[e+208>>2]>>5)-c|0:b;v[e+80>>2]=d;v[e+84>>2]=d+(b<<5);fa:{N=Sb(ba);if(bd(N)){break fa}v[22692]=0;R(704,N|0,65534);b=v[22692];v[22692]=0;if((b|0)!=1){break fa}a=P()|0;O()|0;break n}b=v[e+80>>2];da=v[e+84>>2];if((b|0)==(da|0)){break ea}while(1){q=b;c=Ib(Ib(w[p+8|0]|w[p+9|0]<<8)+Ib(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;ga:{ha:{ia:{d=b;f=I;c=Yd(f);ja:{if(c){wb(f);while(1){j=c+14|0;if(!Gu(d,j)){f=1;if(!Gu(j,d)){break ja}c=c+4|0}c=v[c>>2];if(c){continue}break}}f=0}if(f){v[22692]=0;c=Q(909,I|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break ia}G=x[c>>1];break ha}G=0;if(!H){break ha}c=Ib(w[b+12|0]|w[b+13|0]<<8);v[22692]=0;G=W(540,M|0,c|0,0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ia}if((G|0)==65535){break ea}v[22692]=0;c=Q(909,I|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break ia}u[c>>1]=G;c=b;if(Ib(w[c+8|0]|w[c+9|0]<<8)>>>0>=aa>>>0){break ga}d=b;if(Ib(w[d+10|0]|w[d+11|0]<<8)>>>0>=K>>>0){break ga}ea=b;j=Ib(w[b+14|0]|w[b+15|0]<<8);ka=e,la=Vb(E),v[ka+56>>2]=la;ka=e,la=So(e+56|0,B(Ib(w[c+8|0]|w[c+9|0]<<8),$)),v[ka+208>>2]=la;ka=e,la=So(e+208|0,B(Ib(w[d+10|0]|w[d+11|0]<<8),x[a+480188>>1])),v[ka+72>>2]=la;v[e+68>>2]=0;_i(e+56|0);ga=b;if(Ib(w[b+12|0]|w[b+13|0]<<8)){V=0;while(1){c=_b(M,G);v[22692]=0;X=Wc(c,V,0);c=v[22692];v[22692]=0;ka:{la:{if((c|0)!=1){s=0;o=0;if(x[a+480188>>1]){break la}break ka}a=P()|0;O()|0;break n}while(1){ka=e,la=Zb(E),v[ka+208>>2]=la;c=e+68|0;if(Gb(e+72|0,e+208|0)){c=v[e+72>>2]}ka=e,la=Zb(E),v[ka+208>>2]=la;if(Gb(e+72|0,e+208|0)){Oe(e+72|0)}d=B(s,6);h=c;if(t[c+1|0]<0|t[c+1|0]>84){f=255}else{f=w[h+1|0]+25|0}d=d+X|0;y=0;l=ah(m);k=c;J=w[c+3|0];ma:{if(l>>>0<=J>>>0){break ma}y=J+1|0;if(t[Kl(m,J)+142|0]&1|f<<24>>24<0){break ma}f=hn(Ib(w[q+16|0]|w[q+17|0]<<8)+f<<24>>24)}na:{if(!w[d|0]){break na}if(!(w[k+3|0]|(w[c|0]|w[h+1|0]!=255))){if(!w[c+2|0]){break na}}l=w[d+1|0];if(!l){break na}if(ah(m)>>>0<l>>>0){break na}if(w[Kl(m,l-1|0)+132|0]!=2){break na}To(d)}g=Lj(r,s);oa:{if(o&1){l=v[e+56>>2];t[d|0]=l;t[d+1|0]=l>>>8;t[d+2|0]=l>>>16;t[d+3|0]=l>>>24;l=x[e+60>>1];t[d+4|0]=l;t[d+5|0]=l>>>8;pa:{if(w[d+3|0]){break pa}l=s-1|0;if(w[g+21|0]==w[Lj(r,l)+21|0]){break pa}t[d+3|0]=21;l=w[Lj(r,l)+21|0];t[g+21|0]=l;t[d+5|0]=l}o=0;l=1;qa:{if(w[c|0]==9){break qa}if(w[c|0]==24|w[c|0]==25|!(w[c+2|0]==249|w[c+2|0]==250?w[c|0]:1)){break qa}l=0}if(!l){break oa}}l=d;ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{switch(w[c|0]){case 5:h=w[g+17|0];break xa;case 0:za:{if(w[c+2|0]>=201){o=0;Aa:{switch(w[c+2|0]-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[g+16|0]=0;break sa;case 9:t[d+4|0]=1;t[d+2|0]=15;break sa;case 8:if((j&255)>>>0<2){break sa}j=j-1|0;break ta;case 7:if((j&255)==255){j=255;break sa}j=j+1|0;break ta;case 6:t[g+17|0]=f;if(w[g+18|0]!=(y&255)){break sa}t[d|0]=f;t[d+5|0]=255;t[d+3|0]=4;u[g+32>>1]=0;v[g+8>>2]=0;break sa;case 5:t[d+5|0]=242;t[d+3|0]=2;break sa;case 4:t[d+5|0]=242;t[d+3|0]=3;break sa;case 3:t[d+5|0]=244;t[d+3|0]=2;break sa;case 2:t[d+5|0]=244;t[d+3|0]=3;break sa;case 1:t[d+5|0]=248;t[d+3|0]=2;break sa;case 12:break za;case 0:break Aa;default:break sa}}t[d+5|0]=248;t[d+3|0]=3;break sa}if(t[h+1|0]<=-1){o=0;if(w[c+2|0]>99){break sa}}if(t[h+1|0]>=0){t[g+17|0]=f;t[d|0]=f;t[g+18|0]=y;t[d+1|0]=y;u[g+32>>1]=0;v[g+8>>2]=0}if(!w[c+2|0]){o=0;break sa}c=w[c+2|0];v[22692]=0;c=bn(+(c>>>0)*.64);f=v[22692];v[22692]=0;if((f|0)==1){break ua}t[g+19|0]=c;i=z[g>>2];v[g>>2]=0;o=i!=C(0);break sa}t[d+4|0]=0;t[d+2|0]=14;t[g+16|0]=1;break sa;case 1:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(.0333000011742115);break ra;case 2:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(-.0333000011742115);break ra;case 12:t[e+208|0]=15;f=w[k+3|0];v[22692]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;Ba:{if((h|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22692]=0;t[e+52|0]=c>>>3;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)==1){break Ba}t[g+24|0]=w[c|0]|f<<4;break ra}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 3:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(.0333000011742115);break ra;case 4:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(-.0333000011742115);break ra;case 15:h=f<<24>>24;if(!w[c+2|0]|(h|0)<0){break ra}k=h-w[g+17|0]|0;h=k>>31;h=h^h+(k<<5);v[e+208>>2]=h;t[g+17|0]=f;v[g+8>>2]=0;t[d|0]=f;t[d+3|0]=4;c=ei((h>>>0)/(w[c+2|0]<<1>>>0)|0);t[d+5|0]=c;t[g+27|0]=c;v[22692]=0;f=v[e+208>>2];v[e+52>>2]=B(c,(j&255)-1|0);c=nd(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){u[g+32>>1]=f-v[c>>2];break ra}a=P()|0;O()|0;break n;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break ra;case 13:t[e+208|0]=15;f=w[k+3|0];v[22692]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;Ca:{if((h|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22692]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)==1){break Ca}t[g+23|0]=w[c|0]|f<<4;break ra}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 23:case 24:case 25:k=n;f=Yd(k);Da:{if(f){wb(k);while(1){l=f+13|0;if(!Fu(h,l)){k=1;if(!Fu(l,h)){break Da}f=f+4|0}f=v[f>>2];if(f){continue}break}}k=0}if(k){t[d+3|0]=31;v[22692]=0;c=Q(910,n|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ua}t[d+5|0]=w[c|0];break ra}if(OT(n)>>>0>127){break ra}f=OT(n);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22692]=0;v[e+48>>2]=h;v[e+40>>2]=h;h=W(911,e+40|0,(((f&255)<<5)+a|0)+902204|0,a|0)|0;k=v[22692];v[22692]=0;Ea:{if((k|0)==1){break Ea}if(!h){break ra}t[d+3|0]=31;v[22692]=0;h=Q(910,n|0,c|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break Ea}f=f|-128;t[h|0]=f;t[d+5|0]=f;if(w[c|0]!=25?w[c|0]!=24:0){break ra}ja=1;break ra}a=P()|0;O()|0;break n;case 16:if(!w[c+2|0]){break ra}t[d+3|0]=15;v[e+208>>2]=15;f=w[k+3|0];v[22692]=0;v[e+52>>2]=f+1;f=nd(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){t[d+5|0]=v[f>>2];u[g+30>>1]=B(w[c+2|0],w[k+3|0]+1|0);break ra}a=P()|0;O()|0;break n;case 9:t[d+3|0]=16;j=w[c+2|0]?w[c+2|0]:4;t[d+5|0]=j;break ra;case 19:if(w[h+1|0]!=4?w[h+1|0]:0){break ra}t[e+47|0]=w[h+1|0]==4?w[k+3|0]:128;t[e+208|0]=w[c+2|0];v[22692]=0;t[e+52|0]=100;c=ac(e+208|0,e+52|0);f=v[22692];v[22692]=0;Fa:{Ga:{if((f|0)!=1){c=w[c|0];v[e+208>>2]=128;v[22692]=0;v[e+52>>2]=256-w[e+47|0];f=nd(e+208|0,e+52|0);k=v[22692];v[22692]=0;if((k|0)==1){break Ga}f=v[f>>2];v[22692]=0;t[e+208|0]=128;k=ac(e+208|0,e+47|0);l=v[22692];v[22692]=0;if((l|0)==1){break Fa}k=w[k|0];f=(B(c,f)|0)/128|0;l=f&255;if((l|0)!=w[g+20|0]){t[g+20|0]=f;t[d+3|0]=21;f=Qc(((B(l,w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[d+5|0]=f}if(w[h+1|0]!=4|(x[a+480188>>1]-1|0)<=(s|0)){break ra}f=s+1|0;h=Lj(r,f);c=B(c,k)>>>7|0;if(w[h+20|0]==(c&255)){break ra}t[h+20|0]=c;c=B(f,6)+X|0;t[c+3|0]=21;f=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[c+5|0]=f;break ra}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 17:case 20:t[d+3|0]=0;break ra;case 7:c=w[c+2|0];t[g+25|0]=0;t[g+26|0]=0;t[g+22|0]=c;break ra;case 8:t[g+22|0]=w[g+22|0]+w[c+2|0];break ra;case 14:t[g+25|0]=w[k+3|0];t[g+26|0]=w[c+2|0];break ra;case 18:break wa;case 6:break ya;default:break ra}}t[g+18|0]=y;t[g+17|0]=f;t[d+1|0]=y;h=f}t[l|0]=h;if(f<<24>>24>=0){t[g+18|0]=y;t[d+1|0]=y}if(w[c|0]==5){t[d+4|0]=1;t[d+2|0]=11}if(!(w[g+26|0]?1:w[c+2|0]|w[g+22|0])){break va}f=w[g+26|0];if(f){ha=+(f>>>0)*.25*(qi(+x[g+28>>1]*.006135923151542565+4.71238898038469)+-1)}else{ha=0}t[d+3|0]=44;f=w[g+22|0];c=w[c+2|0];v[22692]=0;c=bn(ha+ +(c+f|0));f=v[22692];v[22692]=0;if((f|0)!=1){t[d+5|0]=c;break va}a=P()|0;O()|0;break n}c=w[g+17|0]+w[c+2|0]&255;c=c?c>>>0<120?c:120:1;t[g+17|0]=c;t[d|0]=c;t[d+5|0]=255;t[d+3|0]=4}u[g+32>>1]=0;break ra}a=P()|0;O()|0;break n}t[d+5|0]=j;t[d+3|0]=16}c=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);if(w[g+21|0]==(c&255)?o:1){t[g+21|0]=c;t[d+5|0]=c;t[d+3|0]=21}if(s&1|t[h+1|0]<1|(x[a+480188>>1]-1|0)<=(s|0)){break ra}if(ah(m)>>>0<=J>>>0){break ra}if(w[Kl(m,J)+132|0]!=1){break ra}f=s+1|0;c=B(f,6)+X|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=h;t[c+1|0]=h>>>8;t[c+2|0]=h>>>16;t[c+3|0]=h>>>24;h=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;t[c+1|0]=w[c+1|0]+1;ka=Lj(r,f),la=w[g+19|0],t[ka+19|0]=la;ka=Lj(r,f),ma=z[g>>2],z[ka>>2]=ma;ka=Lj(r,f),ma=z[g+4>>2],z[ka+4>>2]=ma;ka=Lj(r,f),ma=z[g+8>>2],z[ka+8>>2]=ma;ka=Lj(r,f),ma=z[g+12>>2],z[ka+12>>2]=ma;ka=Lj(r,f),la=x[g+30>>1],u[ka+30>>1]=la}Ha:{if(w[d|0]){t[g+16|0]=0;break Ha}o=0;if(w[g+16|0]){break oa}}Ia:{Ja:{Ka:{La:{Ma:{Na:{if(!x[g+30>>1]){break Na}v[22692]=0;c=j&255;u[e+208>>1]=c;f=Je(g+30|0,e+208|0);h=v[22692];v[22692]=0;if((h|0)==1){break Ma}u[g+30>>1]=x[f>>1]-c;if(w[d+3|0]){break Na}t[d+3|0]=15;t[d+5|0]=0}i=z[g>>2];if(i==C(0)){break Ia}c=j&255;i=C(z[g+4>>2]+C(i*C(c>>>0)));z[g+4>>2]=i;if(w[d+3|0]){break Ia}Oa:{Pa:{if(c>>>0>=2){f=c-1|0;A=C(f|0);if(A>i){break Pa}t[e+208|0]=15;v[22692]=0;c=e;i=C(i/A);Qa:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Qa}h=0}t[c+52|0]=h;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(B(c,f)|0);t[d+3|0]=22;c=c<<4;break Ja}a=P()|0;O()|0;break n}if(i<C(1)){break Oa}break Ka}if(!(i<C(1))){break Ka}if(i>C(1-c|0)){break Oa}t[e+208|0]=15;v[22692]=0;c=e;i=C(C(-i)/A);Ra:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Ra}h=0}t[c+52|0]=h;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(B(f,c)|0);t[d+3|0]=22;break Ja}a=P()|0;O()|0;break n}if(i>C(-1)){break Ia}t[e+208|0]=14;v[22692]=0;c=e;i=C(-i);Sa:{if(i<C(4294967296)&i>=C(0)){f=~~i>>>0;break Sa}f=0}t[c+52|0]=f;c=ac(e+208|0,e+52|0);f=v[22692];v[22692]=0;if((f|0)==1){break La}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(c>>>0);t[d+3|0]=22;c=c|-16;break Ja}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22692]=0;c=e;if(i<C(4294967296)&i>=C(0)){f=~~i>>>0}else{f=0}t[c+52|0]=f;c=ac(e+208|0,e+52|0);f=v[22692];v[22692]=0;if((f|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(c>>>0);t[d+3|0]=22;c=c<<4|15;break Ja}a=P()|0;O()|0;break n}t[d+5|0]=c}Ta:{i=z[g+8>>2];if(i==C(0)){break Ta}c=j&255;i=C(z[g+12>>2]+C(i*C(c>>>0)));z[g+12>>2]=i;Ua:{if(!w[d+3|0]){Va:{Wa:{if(c>>>0>=2){f=c-1|0;A=C(f|0);if(A>i){break Wa}t[e+208|0]=223;v[22692]=0;c=e;i=C(i/A);Xa:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Xa}h=0}t[c+52|0]=h;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)|0);t[d+3|0]=2;t[d+5|0]=c;break Ta}a=P()|0;O()|0;break n}if(i<C(1)){break Va}break Ua}if(!(i<C(1))){break Ua}if(i>C(1-c|0)){break Va}t[e+208|0]=223;v[22692]=0;c=e;i=C(C(-i)/A);Ya:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Ya}h=0}t[c+52|0]=h;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)|0);t[d+3|0]=3;t[d+5|0]=c;break Ta}a=P()|0;O()|0;break n}if(i>C(-1)){break Ta}t[e+208|0]=14;v[22692]=0;c=e;i=C(-i);Za:{if(i<C(4294967296)&i>=C(0)){f=~~i>>>0;break Za}f=0}t[c+52|0]=f;c=ac(e+208|0,e+52|0);f=v[22692];v[22692]=0;if((f|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(c>>>0);t[d+3|0]=3;t[d+5|0]=c|240;break Ta}a=P()|0;O()|0;break n}if(w[d+2|0]|c>>>0<2){break Ta}ia=C(i*C(.25));f=c-1|0;A=C(f|0);if(!(ia<A)){t[e+208|0]=9;v[22692]=0;c=e;i=C(i/A);_a:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break _a}h=0}t[c+52|0]=h>>>2;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)<<2);t[d+2|0]=12;t[d+4|0]=c;break Ta}a=P()|0;O()|0;break n}if(C(1-c|0)<ia){break Ta}t[e+208|0]=9;v[22692]=0;c=e;i=C(C(-i)/A);$a:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break $a}h=0}t[c+52|0]=h>>>2;c=ac(e+208|0,e+52|0);h=v[22692];v[22692]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)<<2);t[d+2|0]=13;t[d+4|0]=c;break Ta}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22692]=0;c=e;if(i<C(4294967296)&i>=C(0)){f=~~i>>>0}else{f=0}t[c+52|0]=f;c=ac(e+208|0,e+52|0);f=v[22692];v[22692]=0;if((f|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(c>>>0);t[d+3|0]=2;t[d+5|0]=c|240;break Ta}a=P()|0;O()|0;break n}ab:{bb:{cb:{db:{eb:{fb:{gb:{h=w[d+3|0];switch(h|0){case 4:break ab;case 0:break gb;default:break fb}}hb:{c=w[g+23|0];if(!c){c=w[g+24|0];if(c){break hb}if(!x[g+32>>1]){break ab}c=g+32|0;break eb}t[d+3|0]=5;t[d+5|0]=c;if(!x[g+32>>1]){break ab}break db}t[d+3|0]=8;t[d+5|0]=c;if(x[g+32>>1]){break db}break ab}if(!x[g+32>>1]){break ab}c=g+32|0;f=c;if(h){break cb}}t[d+3|0]=4;break bb}f=g+32|0}c=f;t[d+2|0]=11}f=w[g+27|0];v[22692]=0;u[e+208>>1]=B(f,(j&255)-1|0);f=Pc(c,e+208|0);h=v[22692];v[22692]=0;if((h|0)!=1){u[c>>1]=x[c>>1]-x[f>>1];break ab}a=P()|0;O()|0;break n}u[g+28>>1]=x[g+28>>1]+B(w[g+25|0],j&255)&1023;o=0;if(s&1){break oa}c=w[g+18|0];if(!c){break oa}if(ah(m)>>>0<c>>>0){break oa}if(!(w[Kl(m,c-1|0)+142|0]&4)){break oa}v[e+56>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+60>>1]=w[d+4|0]|w[d+5|0]<<8;if(!w[e+57|0]){o=1;break oa}o=1;if(w[Kl(m,w[g+18|0]-1|0)+132|0]!=1){break oa}t[e+57|0]=w[e+57|0]+1}s=s+1|0;if(s>>>0<x[a+480188>>1]){continue}break}}V=V+1|0;if(Ib(w[ga+12|0]|w[ga+13|0]<<8)>>>0>V>>>0){continue}break}}c=_b(M,G);d=Ib(w[ea+14|0]|w[ea+15|0]<<8);v[22692]=0;d=Be(e+208|0,16,d&255);f=v[22692];v[22692]=0;if((f|0)!=1){d=Gh(Se(d,0));v[22692]=0;Q(431,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break ha}}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}c=Tl(N);ka=e,la=Ib(w[b+4|0]|w[b+5|0]<<8),u[ka+208>>1]=la;v[22692]=0;u[e+56>>1]=1;d=Je(e+208|0,e+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break ca}d=x[d>>1];v[22692]=0;ca(912,N|0,c|0,d|0,G&65535)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ca}c=Ib(w[p+8|0]|w[p+9|0]<<8);c=Ib(Ib(w[q+16|0]|w[q+17|0]<<8)-c&65535);t[q+16|0]=c;t[q+17|0]=c>>>8}b=b+32|0;if((da|0)!=(b|0)){continue}break}}Ro(e+96|0);if(Gb(e+96|0,e+88|0)){continue}}break}c=0;if(!ja){break r}v[22692]=0;_(436,a+906300|0);b=v[22692];v[22692]=0;if((b|0)==1){break ba}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22692]=0;v[e+208>>2]=0;b=a+906332|0;uD(b,b+16|0,e+208|0);b=v[22692];v[22692]=0;if((b|0)==1){break aa}v[22692]=0;b=Q(70,e+208|0,6667)|0;c=v[22692];v[22692]=0;if((c|0)==1){break $}v[22692]=0;Hv(a+906348|0,b);c=v[22692];v[22692]=0;if((c|0)==1){break _}vb(b);v[22692]=0;b=Q(70,e+208|0,6660)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Z}v[22692]=0;Fr(a+906380|0,b);c=v[22692];v[22692]=0;if((c|0)==1){break Y}vb(b);v[22692]=0;b=Q(70,e+208|0,6652)|0;c=v[22692];v[22692]=0;if((c|0)==1){break X}v[22692]=0;Hv(a+906508|0,b);d=v[22692];v[22692]=0;c=1;if((d|0)==1){break W}vb(b);break r}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break m}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}c=0}if(x[a+480188>>1]){b=0;while(1){v[22692]=0;_t(a,b&65535);d=v[22692];v[22692]=0;if((d|0)==1){break p}d=(b<<5)+a|0;u[d+480284>>1]=b<<8&256;if(c){t[d+480288|0]=1}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[22692]=0;b=Q(2,e+208|0,9305)|0;c=v[22692];v[22692]=0;ib:{jb:{kb:{lb:{if((c|0)!=1){Eb(a+1298304|0,b);vb(b);v[22692]=0;b=Q(2,e+208|0,9507)|0;c=v[22692];v[22692]=0;if((c|0)==1){break lb}Eb(a+1298316|0,b);vb(b);if(Z){break jb}v[22692]=0;b=Q(2,e+208|0,9305)|0;c=v[22692];v[22692]=0;if((c|0)==1){break kb}break ib}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}if(ah(m)>>>0<=128){v[22692]=0;b=Q(2,e+208|0,6409)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break ib}a=P()|0;O()|0;break n}v[22692]=0;b=Q(2,e+208|0,11945)|0;c=v[22692];v[22692]=0;if((c|0)==1){break o}}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;AB(r);GT(n);FT(I);f=1}Ku(m);ci(E);Ju(F);Mu(D);break c}a=P()|0;O()|0;break n}a=P()|0;O()|0}AB(r)}GT(n);FT(I);break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}v[22692]=0;f=q&65535;j=W(914,a|0,f|0,c|0)|0;q=v[22692];v[22692]=0;mb:{nb:{ob:{pb:{if((q|0)==1){break pb}if(j){break mb}v[22692]=0;j=fa(915,a|0,f|0,c|0,0,0)|0;q=v[22692];v[22692]=0;if((q|0)==1){break pb}if(j){break mb}v[22692]=0;j=ca(916,a|0,f|0,c|0,0)|0;q=v[22692];v[22692]=0;if((q|0)==1){break pb}if(j){break mb}v[22692]=0;c=Q(917,(B(f,104)+a|0)+484380|0,c|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break pb}if(c){break mb}v[22692]=0;c=Q(2,e+104|0,13240)|0;j=v[22692];v[22692]=0;if((j|0)==1){break ob}v[22692]=0;U(556,a|0,2,c|0);j=v[22692];v[22692]=0;if((j|0)==1){break nb}vb(c);break mb}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}qb:{rb:{sb:{j=B(f,104)+a|0;if(w[j+484414|0]&64){if(fi(a)){break sb}}if(ah(m)>>>0<=f>>>0){break rb}if(w[Kl(m,f)+132|0]!=2){break rb}if(!fi(a)){break rb}u[n>>1]=x[n>>1]+1;break rb}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22692]=0;f=j+484380|0;q=B(c&65535,104)+a|0;ca(918,f|0,q+484380|0,f|0,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break qb}v[22692]=0;c=Q(70,e+104|0,3374)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}v[22692]=0;Q(303,q+484423|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break h}vb(c);v[22692]=0;c=Q(70,e+104|0,3277)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}v[22692]=0;Q(303,j+484423|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}vb(c)}xb(e+208|0);gc(d);o=0;continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c)}xb(e+208|0)}gc(d);break a}gb=e+480|0;return f|0}a=P()|0;O()|0}Ku(m);ci(E);Ju(F);Mu(D);S(a|0);L()}function pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0;d=gb-928|0;gb=d;vc(b);a:{if(!gW(b,d+872|0)){break a}if(!iW(d+872|0)){break a}if(!Pb(b,Qc(hW(d+872|0),jb))){break a}if(!c){e=1;break a}Id(a,8);yg(a);j=w[d+872|3]-48|0;t[d+871|0]=j;Yc(b,Yb(w[d+880|0]|w[d+881|0]<<8|(w[d+882|0]<<16|w[d+883|0]<<24)));ud(d+560|0,b,504);N=jc(d+848|0,d+560|0);xb(d+560|0);v[22692]=0;R(683,b|0,d+560|0);g=v[22692];v[22692]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((g|0)!=1){if(w[d+843|0]>63){break b}if(Ib(w[d+560|0]|w[d+561|0]<<8)<<16>>16<0){break b}Qb(d+480|0,0,80);o:{if(!Yb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24))){break o}g=Yb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24));v[22692]=0;g=Q(188,b|0,g|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){if(!g){break o}v[22692]=0;R(684,b|0,d+480|0);g=v[22692];v[22692]=0;if((g|0)!=1){break o}}f=P()|0;O()|0;break e}v[22692]=0;U(685,d+472|0,b|0,j&255);g=v[22692];v[22692]=0;if((g|0)!=1){V=Te(d+472|0);g=x[d+472>>1];if((g-1&65535)>>>0>126){break b}u[a+480188>>1]=g;I=cd(d+456|0);p:{if(Yb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24))){g=Yb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24));v[22692]=0;Q(188,b|0,g|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){g=w[d+843|0];v[22692]=0;U(686,b|0,I|0,g|0);g=v[22692];v[22692]=0;if((g|0)!=1){break p}}f=P()|0;O()|0;break f}e=0;if(w[d+843|0]){break c}}g=w[d+843|0];u[a+480192>>1]=g;u[a+480190>>1]=g;e=1;X=1;if((j&255)>>>0>=2){X=t[d+824|0]>-1;g=x[a+480192>>1]}if(g&65535){G=c&2;H=!X;l=d+72|2;J=d+72|7;K=d+72|6;q=d+72|5;r=d+72|4;h=d+40|4;o=1;p=1;while(1){v[22692]=0;s=p&65535;g=W(376,a|0,o&65535,s|0)|0;j=v[22692];v[22692]=0;q:{r:{if((j|0)!=1){if(!g){break d}i=v[((e<<2)+a|0)+900380>>2];u[d+44>>1]=0;v[d+40>>2]=0;v[22692]=0;D=T(214,d+144|0)|0;g=v[22692];v[22692]=0;s:{t:{u:{v:{if((g|0)!=1){j=e-1|0;g=Lb(I,j);w:{if(!Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break w}g=Lb(I,j);g=Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[22692]=0;g=Q(188,b|0,g|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break g}if(!g){break w}v[22692]=0;R(687,b|0,d+40|0);g=v[22692];v[22692]=0;if((g|0)==1){break g}g=Yb(w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24));v[22692]=0;U(288,d+432|0,b|0,g|0);g=v[22692];v[22692]=0;if((g|0)==1){break g}qd(D,jc(d+72|0,d+432|0));xb(d+72|0);xb(d+432|0)}j=Ib(w[h|0]|w[h+1|0]<<8);g=Ib(w[h|0]|w[h+1|0]<<8)&15;n=j<<16>>16;if((n|0)>-1){break v}v[22692]=0;mr(i,0);j=v[22692];v[22692]=0;da=1;if((j|0)!=1){break u}break g}f=P()|0;O()|0;break f}if(g>>>0>6){break u}j=w[g+28902|0];if(!g){g=j;break r}u[a+480190>>1]=(x[a+480190>>1]+j|0)-1;g=i+108|0;m=i+236|0;C=j-2|0;f=4;while(1){k=B(f,12);e=(C<<3)+f|0;E=e+28956|0;z=w[e+28908|0]+p|0;e=0;while(1){A=e+k|0;la=wd(m,A),ma=z,u[la>>1]=ma;A=lc(g,A);t[A|0]=w[A|0]+w[E|0];e=e+1|0;if((e|0)!=12){continue}break}k=1;f=f+1|0;if((f|0)!=10){continue}break}g=j;break t}j=1;if((g|0)!=7){g=1;break r}k=0;v[22692]=0;yS(i,-24);j=v[22692];v[22692]=0;g=1;if((j|0)==1){break s}j=1}C=1;break q}break g}f=P()|0;O()|0;break f}k=0;if(H|(n|0)<0){break q}m=i+108|0;f=7;while(1){E=B(f,12);z=B(f,-12)+72|0;e=0;while(1){A=lc(m,e+E|0);t[A|0]=z+w[A|0];e=e+1|0;if((e|0)!=12){continue}break}f=f+1|0;if((f|0)!=10){continue}break}}v[22692]=0;R(690,N|0,d+72|0);e=v[22692];v[22692]=0;x:{if((e|0)!=1){if(!(!w[r|0]|w[r|0]>16)){t[i+31|0]=w[r|0];C=1}if(!(!w[q|0]|w[q|0]>128)){t[i+30|0]=w[q|0]}e=0;f=0;if(!g){break x}y:{while(1){z:{v[22692]=0;e=B(e+s|0,104)+a|0;R(424,e+484380|0,8);i=v[22692];v[22692]=0;if((i|0)==1){break z}t[d+432|0]=w[K|0];v[22692]=0;t[d+400|0]=64;i=ac(d+432|0,d+400|0);m=v[22692];v[22692]=0;if((m|0)==1){break y}u[e+484410>>1]=w[i|0]<<2;t[e+484416|0]=w[J|0];f=f+1|0;e=f&65535;if(g>>>0>e>>>0){continue}break x}break}break g}break g}break g}A:{if(!G|(n|0)<0){break A}n=Rc(d+432|0,8,1,1,0);E=Ib(w[l|0]|w[l+1|0]<<8);f=Ib(w[d+72|0]|w[d+73|0]<<8);i=Ib(w[l|0]|w[l+1|0]<<8);v[22692]=0;e=T(193,d+144|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break g}if(Ib(w[h|0]|w[h+1|0]<<8)&16){Xi(n,16);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&32){vp(n,3);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&64){zf(n,2)}e=k?(e>>>0)/((-1<<g^-1)>>>0)|0:e;if(!g){break A}i=f+i|0;k=0;m=0;while(1){k=B(k+s|0,104)+a|0;z=k+484380|0;v[z>>2]=e;v[22692]=0;W(329,n|0,z|0,D|0)|0;z=v[22692];v[22692]=0;if((z|0)==1){break g}f=f<<1;i=i<<1;if(E>>>0>=2){v[k+484388>>2]=i;v[k+484384>>2]=f;k=k+484414|0;u[k>>1]=x[k>>1]|2}e=e<<1;m=m+1|0;k=m&65535;if(k>>>0<g>>>0){continue}break}}p=j+p|0;xb(d+144|0);o=o+1|0;e=o&65535;if(e>>>0<=x[a+480192>>1]){continue}break}}g=d+480|4;B:{if(!Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break B}if(!Ib(w[d+488|0]|w[d+489|0]<<8)){break B}g=Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[22692]=0;g=Q(188,b|0,g|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break h}if(!g){break B}la=d,ma=Ib(w[d+488|0]|w[d+489|0]<<8),u[la+144>>1]=ma;g=w[d+843|0];v[22692]=0;u[d+72>>1]=g;g=Pc(d+144|0,d+72|0);j=v[22692];v[22692]=0;if((j|0)==1){break i}l=x[g>>1];h=Ib(w[d+490|0]|w[d+491|0]<<8);if(!l){break B}i=d+144|5;m=d+144|3;k=d+144|1;j=d+80|0;o=d+72|4;p=h>>>0<19;q=h>>>0<21;r=h>>>0<15;f=0;while(1){v[22692]=0;U(691,b|0,d+144|0,h|0);g=v[22692];v[22692]=0;C:{D:{E:{if((g|0)!=1){f=f+1|0;g=v[((f<<2)+a|0)+900380>>2];if(!w[d+144|0]){break C}s=nr(d+72|0,0,64);nr(o,w[d+144|0]-1&65535,64);C=w[d+144|0];nr(j,C+(w[k|0]?64/w[k|0]|0:0)|0,0);v[d+428>>2]=3;v[d+424>>2]=s;v[22692]=0;e=v[d+428>>2];v[d+8>>2]=v[d+424>>2];v[d+12>>2]=e;e=g+48|0;R(692,e|0,d+8|0);n=v[22692];v[22692]=0;if((n|0)==1){break E}if(w[d+144|0]!=1){break D}la=d,ma=Vb(e),v[la+72>>2]=ma;Hd(d+416|0,d+72|0);v[22692]=0;R(693,e|0,v[d+416>>2]);e=v[22692];v[22692]=0;if((e|0)!=1){break D}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}v[g>>2]=w[k|0]?w[k|0]<<9:32767;C=1;t[g+60|0]=w[g+60|0]|1}F:{if(p){break F}v[g+4>>2]=w[d+162|0]+1>>>1;if(q){break F}u[g+28>>1]=w[d+164|0]|w[d+165|0]<<8}g=B(x[wd(g+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[m|0]<<4;G:{H:{if(!r){la=g+484384|0,ma=Yb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24)),v[la>>2]=ma;la=g+484388|0,ma=Yb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24))+Yb(w[d+158|0]|w[d+159|0]<<8|(w[d+160|0]<<16|w[d+161|0]<<24))|0,v[la>>2]=ma;break H}if(h>>>0<6){break G}}if(t[i|0]&1){e=g+484414|0;u[e>>1]=x[e>>1]|2}if(w[i|0]&8){e=g+484414|0;u[e>>1]=x[e>>1]|6}if(!(w[i|0]&4)){break G}u[g+484412>>1]=0}if((f|0)!=(l|0)){continue}break}}if(!Yb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24))){break j}if(!Ib(w[d+504|0]|w[d+505|0]<<8)){break j}g=Yb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24));v[22692]=0;g=Q(188,b|0,g|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break h}if(!g){break j}la=d,ma=Ib(w[d+504|0]|w[d+505|0]<<8),u[la+144>>1]=ma;g=w[d+843|0];v[22692]=0;u[d+72>>1]=g;g=Pc(d+144|0,d+72|0);j=v[22692];v[22692]=0;if((j|0)!=1){e=x[g>>1];f=Ib(w[d+506|0]|w[d+507|0]<<8);if(!e){break j}k=0;I:while(1){J:{v[22692]=0;U(694,b|0,d+144|0,f|0);g=v[22692];v[22692]=0;if((g|0)==1){break k}v[22692]=0;TC(d+432|0,2,d+144|0);g=v[22692];v[22692]=0;if((g|0)==1){break l}v[22692]=0;R(324,d+72|0,d+432|0);g=v[22692];v[22692]=0;if((g|0)==1){break l}k=k+1|0;h=((k<<2)+a|0)+900380|0;g=v[h>>2];v[22692]=0;Q(301,g+492|0,d+72|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break m}vb(d+72|0);g=v[h>>2];v[22692]=0;R(696,d+72|0,g|0);g=v[22692];v[22692]=0;if((g|0)==1){break n}la=d,ma=lr(d+72|0),v[la+432>>2]=ma;la=d,ma=Ah(d+72|0),v[la+40>>2]=ma;while(1){v[22692]=0;g=Rl(d+432|0,d+40|0);j=v[22692];v[22692]=0;K:{if((j|0)!=1){if(g){break K}kr(d+72|0);if((e|0)!=(k|0)){continue I}break j}break J}v[22692]=0;g=Pl(d+432|0);j=v[22692];v[22692]=0;if((j|0)!=1){j=(x[g>>1]<<5)+a|0;i=j+946328|0;g=v[h>>2];l=v[g+520>>2];v[i>>2]=v[g+516>>2];v[i+4>>2]=l;l=v[g+512>>2];i=j+946320|0;v[i>>2]=v[g+508>>2];v[i+4>>2]=l;l=v[g+504>>2];i=j+946312|0;v[i>>2]=v[g+500>>2];v[i+4>>2]=l;i=v[g+496>>2];j=j+946304|0;v[j>>2]=v[g+492>>2];v[j+4>>2]=i;Oj(d+432|0);continue}break}}break}f=P()|0;O()|0;kr(d+72|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+72|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}g=0;v[22692]=0;Oo(a+901404|0);j=v[22692];v[22692]=0;if((j|0)==1){break h}t[a+901696|0]=w[2040];j=a+901692|0;e=w[2036]|w[2037]<<8|(w[2038]<<16|w[2039]<<24);t[j|0]=e;t[j+1|0]=e>>>8;t[j+2|0]=e>>>16;t[j+3|0]=e>>>24;vc(b);J=a+484360|0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{if(!w[V|0]){break T}ea=c&1;s=a+484344|0;D=a+1298292|0;E=a+1298268|0;fa=d+144|1;l=d+144|4;j=d+16|4;z=d+16|2;A=d- -64|2;ga=d- -64|3;q=d+560|2;while(1){U:{v[22692]=0;Y(699,b|0,d+872|0,d+480|0,d+560|0);c=v[22692];v[22692]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((c|0)==1){break fa}c=Z&255;if(c){v[22692]=0;e=T(417,J|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break fa}if((e|0)==255){break d}}n=Nj(J,c);r=Bk(d+400|0);Vl(n);m=w[d+871|0];if(m>>>0>1){break da}if(Ib(w[q|0]|w[q+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break ca}eW(d+144|0,d+560|0);c=Ib(w[q|0]|w[q+1|0]<<8);v[22692]=0;U(700,n|0,d+144|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break ba}la=d,ma=Vb(n),v[la+144>>2]=ma;la=d,ma=Zb(n),v[la+72>>2]=ma;if(Gb(d+144|0,d+72|0)){break ea}break X}f=P()|0;O()|0;break f}while(1){c=v[d+144>>2];u[c>>1]=x[c>>1]+g;nf(d+144|0);if(Gb(d+144|0,d+72|0)){continue}break}break X}eW(d+144|0,d+560|0);if(!Ib(w[d+156|0]|w[d+157|0]<<8)){break ca}if(Ib(w[d+156|0]|w[d+157|0]<<8)>>>0>64|x[a+480188>>1]>64){break ca}k=Yb(w[d+164|0]|w[d+165|0]<<8|(w[d+166|0]<<16|w[d+167|0]<<24));ga:{if(Ib(w[d+168|0]|w[d+169|0]<<8)){la=d,ma=Ib(w[d+168|0]|w[d+169|0]<<8),u[la+72>>1]=ma;v[22692]=0;u[d+432>>1]=800;c=Pc(d+72|0,d+432|0);e=v[22692];v[22692]=0;if((e|0)==1){break ga}c=Qc(((x[c>>1]<<5)+50>>>0)/100|0,0)}else{c=32}e=Yb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22692]=0;h=Q(188,b|0,e|0)|0;e=v[22692];v[22692]=0;ha:{if((e|0)==1){break ha}e=0;ia:{ja:{ka:{la:{ma:{if(h&x[a+480188>>1]!=0){while(1){v[22692]=0;h=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ma}t[d+72|0]=h;v[22692]=0;t[d+432|0]=64;h=ac(d+72|0,d+432|0);f=v[22692];v[22692]=0;if((f|0)==1){break la}u[((e<<5)+a|0)+480286>>1]=w[h|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}if(!Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break ja}e=Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22692]=0;e=Q(188,b|0,e|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break ha}if(!e){break ja}e=0;if(!x[a+480188>>1]){break ia}while(1){v[22692]=0;h=T(701,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ka}la=((e<<5)+a|0)+480284|0,ma=(Mb(h,-16,16)<<3)+128|0,u[la>>1]=ma;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break ia}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}v[22692]=0;uh(a,1);e=v[22692];v[22692]=0;if((e|0)==1){break ha}}h=cd(d+128|0);e=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[22692]=0;f=Q(188,b|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break aa}i=1;e=0;if(!f){break Y}f=Ib(w[q|0]|w[q+1|0]<<8);v[22692]=0;f=Q(189,b|0,f<<1)|0;o=v[22692];v[22692]=0;if((o|0)==1){break aa}if(!f){break Y}f=Ib(w[q|0]|w[q+1|0]<<8);v[22692]=0;f=W(702,b|0,h|0,f|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break aa}if(!f){break Y}la=d,ma=Vb(h),v[la+16>>2]=ma;la=d,ma=Zb(h),v[la+120>>2]=ma;if(!Gb(d+16|0,d+120|0)){break Z}while(1){e=v[d+16>>2];e=Ib(w[e|0]|w[e+1|0]<<8);na:{if(Ib(w[d+158|0]|w[d+159|0]<<8)>>>0<e>>>0){break na}f=Yb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[22692]=0;Q(188,b|0,f+(e<<2)|0)|0;e=v[22692];v[22692]=0;oa:{pa:{qa:{ra:{sa:{if((e|0)==1){break sa}v[22692]=0;e=T(426,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break sa}v[22692]=0;e=Q(188,b|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break sa}if(!e){break na}v[22692]=0;e=Q(189,b|0,42)|0;f=v[22692];v[22692]=0;if((f|0)==1){break sa}if(!e){break na}v[22692]=0;R(703,b|0,d+72|0);e=v[22692];v[22692]=0;ta:{if((e|0)!=1){if(bd(n)){break ta}v[22692]=0;R(704,n|0,65534);e=v[22692];v[22692]=0;if((e|0)!=1){break ta}}f=P()|0;O()|0;break _}e=Ib(w[d+112|0]|w[d+113|0]<<8);v[22692]=0;v[d+68>>2]=e;e=Q(189,b|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ra}if(!e){v[22692]=0;e=T(465,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ra}tc(d+68|0,e)}tc(d+68|0,65534);f=sc(n);v[22692]=0;R(705,n|0,f+v[d+68>>2]|0);e=v[22692];v[22692]=0;if((e|0)==1){break pa}e=0;if(!v[d+68>>2]){break qa}while(1){ua:{v[22692]=0;i=T(416,b|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break ua}i=i<<16>>16;if((i|0)>=0){v[22692]=0;R(704,n|0,g+i&65535);i=v[22692];v[22692]=0;if((i|0)==1){break ua}}e=e+1|0;if(e>>>0<y[d+68>>2]){continue}break qa}break}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}va:{if(!w[d+72|0]){break va}v[22692]=0;U(6,d+432|0,2,d+72|0);e=v[22692];v[22692]=0;wa:{if((e|0)!=1){v[22692]=0;R(418,n|0,d+432|0);e=v[22692];v[22692]=0;if((e|0)==1){break wa}vb(d+432|0);break va}f=P()|0;O()|0;break _}f=P()|0;O()|0;vb(d+432|0);break _}if(!Yb(w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))){break na}e=Yb(w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24));v[22692]=0;e=Q(188,b|0,e|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break oa}}f=P()|0;O()|0;break _}if(!e){break na}while(1){xa:{v[22692]=0;e=Q(706,b|0,d- -64|0)|0;i=v[22692];v[22692]=0;ya:{za:{if((i|0)!=1){if(!e){break na}e=w[ga|0];v[22692]=0;U(288,d+40|0,b|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break za}e=jc(d+432|0,d+40|0);xb(d+40|0);i=d- -64|0;la=d,ma=Fv(Ib(w[i|0]|w[i+1|0]<<8)+f|0),u[la+40>>1]=ma;i=d- -64|0;if((Ib(w[i|0]|w[i+1|0]<<8)|0)==65535){break xa}i=x[d+40>>1];if(sc(n)>>>0>i>>>0){break ya}xb(d+432|0);break na}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}Aa:{if(w[A|0]==1){e=65535}else{if(w[A|0]!=2){break Aa}v[22692]=0;e=T(416,e|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break $}v[22692]=0;i=Q(707,r|0,d+40|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break $}u[i>>1]=e;e=65534}la=rc(n,x[d+40>>1]),ma=e,u[la>>1]=ma}xb(d+432|0);continue}break}xb(d+432|0)}Jv(d+16|0);if(Gb(d+16|0,d+120|0)){continue}break}break Z}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}jr(r);break d}f=P()|0;O()|0;break L}f=P()|0;O()|0;break _}f=P()|0;O()|0;xb(d+432|0)}Gv(h);break L}i=0;e=1}Gv(h);if(e){k=c>>>(k>>>1&1)|0;break W}jr(r);if(!i){break d}break V}v[22692]=0;uh(a,1);c=v[22692];v[22692]=0;Ba:{if((c|0)!=1){e=0;k=32;if(!x[a+480188>>1]){break W}while(1){t[d+144|0]=w[(d+e|0)+826|0];v[22692]=0;t[d+72|0]=64;c=ac(d+144|0,d+72|0);h=v[22692];v[22692]=0;if((h|0)==1){break Ba}u[((e<<5)+a|0)+480286>>1]=w[c|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break W}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}e=w[d+823|0];$=w[d+823|0]&64;K=w[d+824|0]&32;G=(w[d+824|0]&31)+1|0;la=a,ma=bW(Ib(w[d+820|0]|w[d+821|0]<<8),$>>>6|0,K>>>5|0,G),v[la+480204>>2]=ma;la=a,ma=Gd(w[d+825|0],1,32),v[la+480196>>2]=ma;if(K){v[a+480216>>2]=G;v[a+480220>>2]=G<<2}Ca:{Da:{if(w[d+842|0]){t[d+144|0]=w[d+842|0];v[22692]=0;t[d+72|0]=64;c=ac(d+144|0,d+72|0);h=v[22692];v[22692]=0;if((h|0)==1){break Da}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=k;v[a+480232>>2]=k;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+823|0]>>>4^-1)&2;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{if(!Yb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24))){break Pa}c=Yb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24));v[22692]=0;c=Q(188,b|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Oa}if(!c){break Pa}c=Yb(w[d+528|0]|w[d+529|0]<<8|(w[d+530|0]<<16|w[d+531|0]<<24));v[22692]=0;W(413,b|0,E|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Oa}if(w[V|0]<2){break Pa}v[22692]=0;U(13,d+144|0,2,E|0);c=v[22692];v[22692]=0;if((c|0)==1){break Na}v[22692]=0;R(418,n|0,d+144|0);c=v[22692];v[22692]=0;if((c|0)==1){break Ma}vb(d+144|0)}Qa:{if(Yb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))>>>0<2){break Qa}c=Yb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24));v[22692]=0;c=Q(188,b|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Oa}if(!c){break Qa}c=Yb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24));v[22692]=0;ca(507,D|0,b|0,c-1|0,4)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Oa}}if(!Yb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24))){break Ca}c=Yb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24));v[22692]=0;c=Q(188,b|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Oa}if(!c){break Ca}v[22692]=0;c=Q(189,b|0,12)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Oa}if(!c){break Ca}v[22692]=0;Q(318,b|0,6)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Oa}v[22692]=0;c=T(416,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Oa}if((c|0)!=1){break Ca}v[22692]=0;c=T(426,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Ka}if(!c){break Ca}v[22692]=0;h=Q(189,b|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Ka}if(h){break La}break Ca}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;vb(d+144|0);break L}Dc(d+144|0,D);v[22692]=0;ca(507,D|0,b|0,c|0,4)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Fa}if(!ed(d+144|0)){v[22692]=0;c=W(708,d+432|0,2,13)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Ja}v[22692]=0;U(709,d+72|0,d+144|0,c|0);h=v[22692];v[22692]=0;if((h|0)==1){break Ia}v[22692]=0;U(710,d+24|0,d+72|0,D|0);h=v[22692];v[22692]=0;if((h|0)==1){break Ha}Eb(D,d+24|0);vb(d+24|0);vb(d+72|0);vb(c)}vb(d+144|0);break Ca}f=P()|0;O()|0;break L}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;break Ga}f=P()|0;O()|0;vb(d+72|0)}vb(c);break Ea}f=P()|0;O()|0}vb(d+144|0);break L}f=P()|0;O()|0;break L}Ra:{if(m>>>0<2){break Ra}if(!Yb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24))){break Ra}i=0;if(!x[a+480188>>1]){break Ra}while(1){c=Yb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24));v[22692]=0;c=Q(188,b|0,c+(i<<2)|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break M}Sa:{if(!c){break Sa}v[22692]=0;c=T(426,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break M}v[22692]=0;c=Q(188,b|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break M}k=0;m=0;if(!c){break Sa}while(1){Ta:{v[22692]=0;c=Q(189,b|0,8)|0;h=v[22692];v[22692]=0;Ua:{Va:{Wa:{if((h|0)!=1){if(!c){break Ta}v[22692]=0;R(711,b|0,d+144|0);c=v[22692];v[22692]=0;if((c|0)==1){break Wa}if(!Yb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))){break Ta}switch((Yb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))&536870911)-1|0){case 1:break Ua;case 0:break Va;default:continue}}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}k=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}m=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}break}if(!k|!m){break Sa}v[22692]=0;c=Q(188,b|0,k|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break N}if(!c){break Sa}v[22692]=0;W(567,b|0,((i<<5)+a|0)+480289|0,m|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break N}}i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}m=Ib(w[d+560|0]|w[d+561|0]<<8);v[22692]=0;c=g+m|0;R(330,s|0,c&65535);h=v[22692];v[22692]=0;if((h|0)==1){break S}if(m){ia=e&16;ja=g&65535;k=0;while(1){Xa:{if(!ea){break Xa}e=Yb(w[d+888|0]|w[d+889|0]<<8|(w[d+890|0]<<16|w[d+891|0]<<24));v[22692]=0;e=Q(188,b|0,e+(k<<2)|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Q}if(!e){break Xa}v[22692]=0;e=T(426,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Q}v[22692]=0;e=Q(188,b|0,e|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break Q}if(!e){break Xa}H=Kb(d+128|0);v[22692]=0;aa=T(214,d+72|0)|0;e=v[22692];v[22692]=0;Ya:{Za:{if((e|0)!=1){h=w[d+871|0];if(h){break Za}v[22692]=0;R(712,b|0,d+144|0);e=v[22692];v[22692]=0;if((e|0)==1){break P}u[d+120>>1]=w[d+144|0];o=w[fa|0]+1|0;e=48;break Ya}f=P()|0;O()|0;break O}f=t[d+822|0];v[22692]=0;R(713,b|0,d+16|0);e=v[22692];v[22692]=0;_a:{$a:{if((e|0)!=1){la=d,ma=Ib(w[d+16|0]|w[d+17|0]<<8),u[la+120>>1]=ma;o=Ib(w[z|0]|w[z+1|0]<<8)+1|0;e=j;if(!Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break _a}i=v[b+8>>2];e=Yb(w[j|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22692]=0;Q(188,b|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break P}v[22692]=0;R(714,b|0,d+144|0);e=v[22692];v[22692]=0;if((e|0)==1){break P}e=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[22692]=0;e=Q(188,b|0,e|0)|0;p=v[22692];v[22692]=0;if((p|0)==1){break P}if(!e){break $a}e=Yb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22692]=0;W(413,b|0,H|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break $a}break P}break P}ab:{if(!Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break ab}e=Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22692]=0;e=Q(188,b|0,e|0)|0;p=v[22692];v[22692]=0;if((p|0)==1){break P}if(!e){break ab}v[22692]=0;e=T(426,b|0)|0;p=v[22692];v[22692]=0;if((p|0)==1){break P}v[22692]=0;e=Q(188,b|0,e|0)|0;p=v[22692];v[22692]=0;if((p|0)==1){break P}if(!e){break ab}v[22692]=0;U(288,d+40|0,b|0,B(x[d+120>>1],o)|0);e=v[22692];v[22692]=0;if((e|0)==1){break P}qd(aa,jc(d+432|0,d+40|0));xb(d+432|0);xb(d+40|0)}v[22692]=0;Q(188,b|0,i|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break P}}e=f+(h>>>0<3?48:24)|0}v[22692]=0;f=k+ja|0;i=W(331,s|0,f&65535,o|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break P}h=e;if(i){ba=_b(s,f);v[22692]=0;Q(428,ba|0,H|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break P}wg(d+120|0,x[a+480188>>1]);p=0;while(1){v[22692]=0;e=Wc(ba,p,0);f=v[22692];v[22692]=0;bb:{cb:{if((f|0)!=1){i=0;if(x[d+120>>1]){break cb}break bb}break P}while(1){db:{if(!w[d+871|0]){v[22692]=0;R(715,d+144|0,b|0);f=v[22692];v[22692]=0;if((f|0)!=1){f=od(d+144|0);_=Te(d+144|0);F=w[d+144|0];t[e+1|0]=F>>>3&16|w[f|0]>>>4|F>>>1&32;t[e+3|0]=w[f|0]&15;t[e+5|0]=w[_|0];f=F&63;f=f?f+h|0:0;break db}break P}v[22692]=0;R(529,d+144|0,b|0);f=v[22692];v[22692]=0;eb:{fb:{if((f|0)!=1){F=od(d+144|0);_=Te(d+144|0);ka=bj(d+144|0);v[22692]=0;f=T(374,aa|0)|0;M=v[22692];v[22692]=0;if((M|0)==1){break P}t[e+4|0]=f;M=w[d+144|0];f=M&127;if(!f){break fb}f=f+h|0;break eb}break P}f=0;if((M|0)!=128){break eb}t[e|0]=254}t[e+1|0]=w[F|0]&63;t[e+3|0]=w[_|0];t[e+5|0]=w[ka|0]}if(f-1>>>0<=119){t[e|0]=f}v[22692]=0;ha(716,e|0,($|0)!=0|0,(K|0)!=0|0,G|0,(ia|0)!=0|0);F=v[22692];v[22692]=0;if((F|0)!=1){C=(f|0)>84&X|C;e=e+6|0;i=i+1|0;if(x[d+120>>1]<=(i&65535)>>>0){break bb}continue}break}break P}p=p+1|0;if((o|0)!=(p|0)){continue}break}}xb(d+72|0);vb(H)}k=k+1|0;if((m|0)!=(k|0)){continue}break}}la=d,ma=lr(r),v[la+72>>2]=ma;la=d,ma=Ah(r),v[la+432>>2]=ma;gb:{hb:{if(mg(d+72|0,d+432|0)){while(1){e=Pl(d+72|0);c=e;h=Te(e);ib:{jb:{kb:{e=x[e>>1];if(!e){e=0;break kb}v[22692]=0;f=Q(470,n|0,e-1&65535)|0;e=v[22692];v[22692]=0;if((e|0)==1){break hb}e=x[c>>1];if(!f){break kb}v[22692]=0;e=Q(541,n|0,e-1&65535)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break jb}break hb}if(x[h>>1]==((e&65535)+1|0)){break ib}v[22692]=0;e=W(540,s|0,1,0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break hb}if((e|0)==65535){break ib}la=rc(n,x[c>>1]),ma=e,u[la>>1]=ma}c=_b(s,e);h=xv(x[h>>1]);v[22692]=0;h=Be(d+144|0,12,h);f=v[22692];v[22692]=0;if((f|0)==1){break gb}h=jp(Se(h,v[_b(s,e)+12>>2]-1|0));v[22692]=0;Q(431,c|0,h|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break gb}m=(m&65535)>>>0>e>>>0?m:e+1|0}Oj(d+72|0);if(mg(d+72|0,d+432|0)){continue}break}c=g+m|0}if(!Yb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))){break U}g=Yb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24));v[22692]=0;g=Q(188,b|0,g|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break S}if(!g){break U}jr(r);g=c;break V}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}Z=Z+1|0;if(w[V|0]>(Z&255)>>>0){continue}break T}break}jr(r)}v[22692]=0;Pi(J,0);b=v[22692];v[22692]=0;if((b|0)==1){break R}if(!(C&1)){i=x[a+480192>>1];if(i){e=1;while(1){b=(((e&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Xb(jv(c));i=x[a+480192>>1]}v[b>>2]=0;e=e+1|0;if((e&65535)>>>0<=(i&65535)>>>0){continue}break}}u[a+480192>>1]=0}lb:{mb:{nb:{ob:{pb:{qb:{rb:{if(da){v[22692]=0;b=Q(2,d+144|0,13440)|0;c=v[22692];v[22692]=0;if((c|0)==1){break rb}v[22692]=0;U(556,a|0,2,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break qb}vb(b)}f=18699;switch(w[d+871|0]){case 3:break mb;case 2:break nb;case 1:break ob;case 0:break pb;default:break lb}}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(b);break f}f=x[a+480188>>1]>4?14312:14298;break lb}f=14280;break lb}f=14262;break lb}f=14235}v[22692]=0;R(717,d+72|0,13850);b=v[22692];v[22692]=0;sb:{tb:{ub:{if((b|0)!=1){v[22692]=0;U(718,d+144|0,d+72|0,d+871|0);b=v[22692];v[22692]=0;if((b|0)==1){break ub}Eb(a+1298304|0,d+144|0);vb(d+144|0);Hb(d+72|0);v[22692]=0;b=Q(2,d+144|0,9901)|0;c=v[22692];v[22692]=0;if((c|0)==1){break tb}Eb(a+1298316|0,b);vb(b);v[22692]=0;Q(155,a+1298328|0,f|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break sb}v[a+1298364>>2]=2;e=1;break c}f=P()|0;O()|0;break f}f=P()|0;O()|0;Hb(d+72|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break L}f=P()|0;O()|0;break f}f=P()|0;O()|0;break L}f=P()|0;O()|0;xb(d+72|0)}vb(H);break L}f=P()|0;O()|0;break L}f=P()|0;O()|0}jr(r);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;xb(d+144|0)}ci(I)}xb(N);S(f|0);L()}e=0}ci(I)}xb(N)}gb=d+928|0;return e|0}function oma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;e=gb-1728|0;gb=e;vc(b);h=gb-32|0;gb=h;l=e+1600|0;dV(h+24|0,l);i=yb(h+24|0);f=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=f;v[h>>2]=j;v[h+4>>2]=f;f=b;cc(h+16|0,f,h);j=yb(h+16|0);if((j|0)==(i|0)){Rb(f,yb(h+24|0))}gb=h+32|0;f=(i|0)==(j|0);if(!f){cV(l)}a:{if(!f){break a}if(!gV(e+1600|0)){break a}if(!Pb(b,Qc(256,0))){break a}b:{if(!c){break b}Id(a,1048576);yg(a);d=gb-16|0;gb=d;f=Tb(d,1339);Dc(e+1344|0,f);vb(f);gb=d+16|0;q=e+1608|0;v[e+160>>2]=w[q+1|0];d=w[q|0];v[22692]=0;v[e+16>>2]=d;R(595,e+88|0,e+16|0);d=v[22692];v[22692]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){v[22692]=0;Y(578,e+240|0,e+1344|0,e+160|0,e+88|0);d=v[22692];v[22692]=0;if((d|0)==1){break o}Eb(a+1298304|0,e+240|0);vb(e+240|0);vb(e+88|0);Hb(e+1344|0);d=Tb(e+240|0,12266);Eb(a+1298316|0,d);vb(d);Ie(e+88|0,2,e+1610|0);Bc(e+1344|0,e+88|0);v[22692]=0;U(13,e+240|0,8,e+1344|0);d=v[22692];v[22692]=0;if((d|0)==1){break j}Eb(a+1298328|0,e+240|0);vb(e+240|0);vb(e+1344|0);v[a+1298364>>2]=8;Dr(e+1344|0,2,e+1642|0);Bc(e+240|0,e+1344|0);Eb(a+1298268|0,e+240|0);vb(e+240|0);d=e+1712|0;u[a+480188>>1]=w[d|0]|w[d+1|0]<<8;d=Gd(w[e+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=d;A=e+1722|0;u[a+480192>>1]=w[A|0]|w[A+1|0]<<8;C=e+1724|0;u[a+480190>>1]=w[C|0]|w[C+1|0]<<8;d=Gd(w[e+1717|0],1,32);v[a+480216>>2]=d;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=d<<2;dw(b,e+1344|0);D=a+484360|0;m=e+1706|0;Qr(Sb(D),e+1344|0,w[m|0]|w[m+1|0]<<8,65535,65535);d=e+1708|0;bf(Sb(D),w[d|0]|w[d+1|0]<<8);ud(e+240|0,b,Mg(b));I=jc(e+1320|0,e+240|0);xb(e+240|0);v[22692]=0;d=T(190,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break m}v[22692]=0;U(288,e+240|0,b|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break m}G=jc(e+1296|0,e+240|0);xb(e+240|0);F=x[a+480188>>1];v[22692]=0;E=Q(189,I|0,274)|0;d=v[22692];v[22692]=0;if((d|0)==1){break l}if(E){u[a+480188>>1]=x[a+480188>>1]+8}H=c&1;if(!H){break k}d=e+1710|0;d=w[d|0]|w[d+1|0]<<8;v[22692]=0;R(330,a+484344|0,d|0);d=v[22692];v[22692]=0;if((d|0)!=1){break k}g=P()|0;O()|0;break e}g=P()|0;O()|0;break n}g=P()|0;O()|0;vb(e+88|0)}Hb(e+1344|0);break c}g=P()|0;O()|0;break d}g=P()|0;O()|0;break e}o=a+484344|0;n=e+1718|0;l=e+1710|0;if(!(w[l|0]|w[l+1|0]<<8)){break f}while(1){v[22692]=0;d=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}v[e+160>>2]=d;v[22692]=0;d=T(190,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break h}v[22692]=0;U(288,e+88|0,b|0,d+1&-2);d=v[22692];v[22692]=0;if((d|0)==1){break h}p=jc(e+240|0,e+88|0);xb(e+88|0);tc(e+160|0,1024);d=v[e+160>>2];p:{if(!d|!H){break p}v[22692]=0;d=W(331,o|0,r&65535,d|0)|0;f=v[22692];v[22692]=0;q:{if((f|0)!=1){if(!d){break p}j=0;if(t[n|0]&1){i=0;while(1){v[22692]=0;d=Q(189,e+240|0,1)|0;f=v[22692];v[22692]=0;r:{if((f|0)!=1){if(!d){break p}v[22692]=0;d=T(374,p|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}s=0;if((d|0)!=255){break r}v[22692]=0;s=T(374,p|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;d=T(374,p|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break r}}break i}break i}s:{if(!(d&127)){break s}f=_b(o,r);v[22692]=0;h=Wc(f,i,j&65535);f=v[22692];v[22692]=0;if((f|0)==1){break i}Nv(e+88|0);if(d&1){v[22692]=0;f=T(374,p|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}t[e+88|0]=f}if(d&2){v[22692]=0;f=T(374,p|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}t[e+89|0]=f}if(d&4){v[22692]=0;f=T(374,p|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}t[e+90|0]=f}if(d&8){v[22692]=0;f=T(374,p|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}t[e+91|0]=f}if(d&16){v[22692]=0;f=T(374,p|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}t[e+92|0]=f}if(d&32){v[22692]=0;f=T(374,p|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}t[e+93|0]=f}if(d&64){v[22692]=0;d=T(374,p|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}t[e+94|0]=d}v[22692]=0;d=Q(782,h|0,e+88|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}v[e+16>>2]=s;v[22692]=0;v[e+64>>2]=v[e+160>>2]+(i^-1);k=Fb(e+16|0,e- -64|0);f=v[22692];v[22692]=0;if((f|0)==1){break i}g=d|g;f=0;d=h;J=v[k>>2];if(!J){break s}while(1){d=B(x[a+480188>>1],6)+d|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;k=w[h+4|0]|w[h+5|0]<<8;t[d+4|0]=k;t[d+5|0]=k>>>8;f=f+1|0;if((J|0)!=(f|0)){continue}break}}i=(i+s|0)+1|0;d=v[e+160>>2];if(i>>>0>=d>>>0){while(1){j=j+1|0;i=i-d|0;if(d>>>0<=i>>>0){continue}break}}if(F>>>0>(j&65535)>>>0){continue}break}break p}f=0;if(v[e+160>>2]){break q}break p}break i}while(1){d=_b(o,r);v[22692]=0;h=Rf(d,f);d=v[22692];v[22692]=0;t:{u:{if((d|0)!=1){d=0;if(F){break u}break t}break i}while(1){v:{v[22692]=0;R(783,p|0,e+88|0);i=v[22692];v[22692]=0;if((i|0)==1){break v}v[22692]=0;i=Q(782,h+B(d,6)|0,e+88|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break v}g=g|i;d=d+1|0;if((F|0)!=(d|0)){continue}break t}break}break i}f=f+1|0;if(f>>>0<y[e+160>>2]){continue}break}}xb(e+240|0);r=r+1|0;if(r>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break f}g=P()|0;O()|0;vb(e+1344|0);break c}g=P()|0;O()|0;xb(e+240|0);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}d=e+1714|0;if(!((w[d|0]|w[d+1|0]<<8)>>>0<=1|(w[d|0]|w[d+1|0]<<8)>>>0>4999)){w:{if(g&1){i=0;d=w[d|0]|w[d+1|0]<<8;d=Ac(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break w}i=2;z=2646e7/+(B(B(v[a+480216>>2],v[a+480196>>2]),w[d|0]|w[d+1|0]<<8)>>>0);x:{if(z<4294967296&z>=0){d=~~z>>>0;break x}d=0}}t[a+480224|0]=i;v[a+480204>>2]=d}d=x[a+480188>>1];v[22692]=0;t[e+240|0]=0;p=W(784,e+1280|0,d|0,e+240|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){i=a+1298280|0;r=a+1298292|0;k=e+240|3;s=0;y:{z:{A:{B:{C:{while(1){v[22692]=0;d=Q(189,G|0,8)|0;f=v[22692];v[22692]=0;D:{if((f|0)!=1){if(d){break D}if(x[a+480188>>1]){d=0;while(1){f=t[kc(p,d)|0];E:{if((f|0)<=(d|0)|(f|0)>=x[a+480188>>1]){break E}h=((f<<5)+a|0)+480288|0;f=w[h|0];if(!f){break E}g=((d<<5)+a|0)+480288|0;i=w[g|0];if(!i){t[g|0]=f;break E}g=(B(i-1&255,160)+a|0)+906300|0;if((Ok(g)|0)!=255){while(1){g=(B(Ok(g),160)+a|0)+906300|0;if((Ok(g)|0)!=255){continue}break}}f=g+28|0;h=w[h|0]-1&255;h=h>>>0<250?h+128|0:0;t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[e+232>>2]=0;v[e+236>>2]=0;v[e+224>>2]=0;v[e+228>>2]=0;v[e+216>>2]=0;v[e+220>>2]=0;v[e+208>>2]=0;v[e+212>>2]=0;F:{G:{H:{I:{J:{K:{if(E){v[22692]=0;R(785,I|0,e+240|0);d=v[22692];v[22692]=0;L:{if((d|0)!=1){g=0;while(1){d=x[a+480192>>1];v[22692]=0;d=DO(a,d+1&65535);f=v[22692];v[22692]=0;M:{N:{O:{P:{Q:{R:{S:{if((f|0)!=1){f=g<<1;h=f+(e+224|0)|0;u[h>>1]=d;j=f+(e+208|0)|0;f=e+f|0;i=f+242|0;u[j>>1]=w[i|0]|w[i+1|0]<<8;if((d|0)==65535){break N}f=w[f+242|0]|w[f+243|0]<<8;v[22692]=0;d=W(376,a|0,d|0,f+1&65535)|0;f=v[22692];v[22692]=0;if((f|0)==1){break S}if(!d){break M}v[22692]=0;R(441,e+160|0,1571);f=v[22692];v[22692]=0;if((f|0)==1){break R}v[22692]=0;v[e+16>>2]=g+1;U(787,e+88|0,e+160|0,e+16|0);f=v[22692];v[22692]=0;if((f|0)==1){break Q}v[22692]=0;Q(301,d+492|0,e+88|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break P}vb(e+88|0);Hb(e+160|0);break M}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break O}g=P()|0;O()|0;vb(e+88|0)}Hb(e+160|0);break y}u[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break L}g=P()|0;O()|0;break y}f=w[e+240|0]|w[e+241|0]<<8;d=0;v[22692]=0;r=Q(328,e+16|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break F}if(w[e+240|0]|w[e+241|0]<<8){while(1){v[22692]=0;f=T(287,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break H}v[22692]=0;U(288,e+160|0,b|0,f<<5);f=v[22692];v[22692]=0;if((f|0)==1){break I}f=jc(e+88|0,e+160|0);qd(Jg(r,d),f);xb(e+88|0);xb(e+160|0);d=d+1|0;if(d>>>0<(w[e+240|0]|w[e+241|0]<<8)>>>0){continue}break}}d=w[l|0]|w[l+1|0]<<8;h=0;v[22692]=0;j=W(788,e+88|0,d|0,33220)|0;d=v[22692];v[22692]=0;if((d|0)==1){break J}if(w[m|0]|w[m+1|0]<<8){while(1){g=e+h|0;T:{if(w[g+258|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break T}if(x[rc(Sb(D),h)>>1]>=(w[l|0]|w[l+1|0]<<8)>>>0){break T}f=x[rc(Sb(D),h)>>1];U:{if(x[rc(j,f)>>1]==65535){d=w[g+258|0];K=rc(j,f),M=d,u[K>>1]=M;break U}if(x[rc(j,f)>>1]==w[g+258|0]){break U}v[22692]=0;d=W(789,o|0,f|0,0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break K}if((d|0)==65535){break U}K=rc(Sb(D),h),M=d,u[K>>1]=M;f=d}v[22692]=0;d=le(o,f);i=v[22692];v[22692]=0;if((i|0)==1){break K}if(!d){break T}E=Jg(r,w[g+258|0]);vc(E);v[22692]=0;d=T(193,E|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break K}if(!v[_b(o,f)+12>>2]){break T}H=d>>>5|0;i=0;while(1){d=_b(o,f);g=x[a+480188>>1];v[22692]=0;d=Wc(d,i,g-8&65535);g=v[22692];v[22692]=0;if((g|0)==1){break K}g=0;while(1){Eh(e+160|0);k=x[e+164>>1];t[d+4|0]=k;t[d+5|0]=k>>>8;k=v[e+160>>2];t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;V:{if(i>>>0>=H>>>0){break V}v[22692]=0;Q(790,E|0,e+160|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break K}if(t[e+160|0]>-1){break V}t[d|0]=61;t[d+1|0]=w[(e+224|0)+(g<<1)|0];k=w[e+160|0]&31;t[e+64|0]=k;if(k){xf(e- -64|0,15);t[d+3|0]=20;t[d+5|0]=w[e+64|0]|208}t[d+2|0]=1;t[d+4|0]=w[e+161|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}i=i+1|0;if(i>>>0<y[_b(o,f)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}}We(j);hd(r)}if(!(!(w[n|0]&2)|!(w[l|0]|w[l+1|0]<<8))){i=0;f=((((w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24))&8?x[a+480188>>1]:F)&65535)+((w[q|0]|w[q+1|0]<<8)>>>0>591?s:0)|0)+((w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24))>>>4&1)|0;while(1){d=0;W:{if(!f){break W}while(1){X:{v[22692]=0;h=Q(189,b|0,4)|0;g=v[22692];v[22692]=0;if((g|0)==1){break X}if(!h){break W}h=w[q|0]|w[q+1|0]<<8;v[22692]=0;R(791,h|0,b|0);h=v[22692];v[22692]=0;if((h|0)==1){break X}d=d+1|0;if((f|0)!=(d|0)){continue}break W}break}g=P()|0;O()|0;break y}i=i+1|0;if(i>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}}v[22692]=0;l=Q(328,e+192|0,255)|0;d=v[22692];v[22692]=0;Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){r=e+88|7;D=e+88|1;F=e+88|4;s=e+88|2;k=e+88|3;h=0;while(1){d=h;v[22692]=0;R(792,b|0,e+160|0);f=v[22692];v[22692]=0;ca:{da:{ea:{fa:{if((f|0)!=1){v[22692]=0;f=T(190,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break fa}h=w[q|0]|w[q+1|0]<<8;v[22692]=0;f=(f|0)==32?428:f;f=h>>>0>513?f?f+4|0:f:f;U(288,e+88|0,b|0,f|0);h=v[22692];v[22692]=0;if((h|0)==1){break ea}h=d+1|0;g=jc(e+240|0,e+88|0);j=Pe(e+16|0,qd(Jg(l,d),g));xb(e+240|0);xb(e+88|0);if(d>>>0>=(w[A|0]|w[A+1|0]<<8)>>>0){break ca}v[22692]=0;d=h&65535;g=W(376,a|0,d|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break da}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}if(!g){break ca}v[22692]=0;Ie(e+88|0,2,e+160|0);d=v[22692];v[22692]=0;ga:{ha:{ia:{if((d|0)==1){break ia}v[22692]=0;R(324,e+240|0,e+88|0);d=v[22692];v[22692]=0;if((d|0)==1){break ia}v[22692]=0;Q(301,g+492|0,e+240|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break ha}vb(e+240|0);if(!f){break ca}v[22692]=0;R(793,j|0,e+240|0);d=v[22692];v[22692]=0;if((d|0)==1){break $}o=0;if((w[q|0]|w[q+1|0]<<8)>>>0<513){break ga}v[22692]=0;o=T(287,j|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break ga}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;vb(e+240|0);break Z}i=3;ja:{if((w[q|0]|w[q+1|0]<<8)>>>0<514){break ja}v[22692]=0;i=T(190,j|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break ja}g=P()|0;O()|0;break Z}v[g>>2]=w[e+342|0]|w[e+343|0]<<8;t[g+16|0]=w[((w[e+344|0]|w[e+345|0]<<8)&3)+33222|0];t[g+17|0]=w[(w[e+345|0]&3)+33222|0];t[g+18|0]=w[((w[e+344|0]|w[e+345|0]<<8)>>>12&3)+33226|0];n=0;ka:{la:{ma:{na:{while(1){oa:{if(!(i&1)){break oa}v[22692]=0;R(794,j|0,e+88|0);d=v[22692];v[22692]=0;if((d|0)==1){break na}v[22692]=0;f=hi(g,w[n+33230|0]);d=v[22692];v[22692]=0;if((d|0)==1){break ma}d=f;if((n|0)!=3){m=w[f+12|0]&-17}else{m=w[f+12|0]&-17|w[e+88|0]<<4&16}t[d+12|0]=m;t[f+12|0]=w[f+12|0]&254|t[e+88|0]&1;t[f+12|0]=w[f+12|0]&251|w[e+88|0]<<1&4;t[f+12|0]=w[f+12|0]&253|w[e+88|0]>>>1&2;t[e+64|0]=w[D|0];v[22692]=0;t[e+48|0]=16;d=ac(e- -64|0,e+48|0);m=v[22692];v[22692]=0;if((m|0)==1){break la}d=w[d|0];v[22692]=0;R(448,f|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break la}d=w[s|0];t[f+15|0]=d;t[f+16|0]=d;t[f+13|0]=w[k|0];t[f+14|0]=w[F|0];d=0;if(!Nb(f)){break oa}while(1){m=(e+88|0)+(d<<2)|0;E=w[m+8|0]|w[m+9|0]<<8;K=Lb(f,d),M=E,u[K>>1]=M;m=Gd(w[m+10|0]|w[m+11|0]<<8,0,64);K=Lb(f,d),M=m,t[K+2|0]=M;d=d+1|0;if(Nb(f)>>>0>d>>>0){continue}break}}i=i>>>1|0;n=n+1|0;if((n|0)!=4){continue}break}if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}v[22692]=0;am(g,127,1);d=v[22692];v[22692]=0;if((d|0)==1){break ba}v[22692]=0;$l(g,0,1);d=v[22692];v[22692]=0;if((d|0)==1){break ba}if(!o){break ca}v[22692]=0;R(797,j|0,e+88|0);d=v[22692];v[22692]=0;if((d|0)==1){break _}if(!(o&2)){break ka}d=w[s|0]|w[s+1|0]<<8;v[22692]=0;d=tA(a,+(d>>>0));f=v[22692];v[22692]=0;if((f|0)==1){break _}v[22692]=0;am(g,d,1);d=v[22692];v[22692]=0;if((d|0)==1){break _}d=w[F|0];v[22692]=0;$l(g,d,1);d=v[22692];v[22692]=0;if((d|0)!=1){break ka}break _}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}t[g+25|0]=w[D|0]==1;if(!(o&4)){break ca}t[g+31|0]=w[r|0]+1;t[g+34|0]=w[e+96|0]+1;if(t[e+96|0]<=-1){t[g+30|0]=w[e+103|0]+1}if(w[e+100|0]){d=0;i=g+108|0;while(1){f=d+1|0;v[e+64>>2]=f+t[e+100|0];eV(e- -64|0);j=v[e+64>>2];K=lc(i,d),M=j,t[K|0]=M;d=f;if(d>>>0<128){continue}break}}v[22692]=0;mr(g,0);d=v[22692];v[22692]=0;if((d|0)==1){break _}}xb(e+16|0);if((h|0)!=255){continue}break}q=PB(e+88|0);h=e+16|4;o=PB(e+160|0);g=0;pa:{qa:{while(1){v[22692]=0;R(792,b|0,e+240|0);d=v[22692];v[22692]=0;if((d|0)==1){break pa}v[22692]=0;d=T(190,b|0)|0;f=v[22692];v[22692]=0;ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{if((f|0)!=1){v[22692]=0;U(288,e+16|0,b|0,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break ya}i=jc(e- -64|0,e+16|0);xb(e+16|0);if((w[C|0]|w[C+1|0]<<8)>>>0>g>>>0){v[22692]=0;Ie(e+48|0,2,e+240|0);f=v[22692];v[22692]=0;if((f|0)==1){break ra}v[22692]=0;R(324,e+16|0,e+48|0);f=v[22692];v[22692]=0;if((f|0)==1){break ra}v[22692]=0;Q(301,((g<<5)+a|0)+946336|0,e+16|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break xa}vb(e+16|0)}if(!d|(w[C|0]|w[C+1|0]<<8)>>>0<=g>>>0){break sa}v[22692]=0;d=B(g+1|0,104)+a|0;f=d+484380|0;R(424,f|0,32);j=v[22692];v[22692]=0;if((j|0)==1){break wa}v[22692]=0;R(799,i|0,e+16|0);i=v[22692];v[22692]=0;if((i|0)==1){break va}v[f>>2]=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[d+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[e+24|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[e+25|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|64;v[f>>2]=v[f>>2]>>>1}i=2;za:{if(w[e+27|0]!=1){i=6;if(w[e+27|0]!=2){break za}}f=d+484414|0;u[f>>1]=x[f>>1]|i}v[d+484384>>2]=w[e+28|0]|w[e+29|0]<<8|(w[e+30|0]<<16|w[e+31|0]<<24);v[d+484388>>2]=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);u[d+484410>>1]=(w[e+36|0]|w[e+37|0]<<8)>>>7;if(w[e+38|0]!=128){break ua}f=d+484414|0;j=x[f>>1]|256;u[f>>1]=j;break ta}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;vb(e+16|0);break qa}g=P()|0;O()|0;break qa}g=P()|0;O()|0;break qa}u[d+484408>>1]=t[e+38|0]+128;j=x[d+484414>>1]}f=d+484414|0;u[f>>1]=j|32;t[d+484416|0]=w[e+39|0];if(w[e+26|0]&2){Db(e+48|0,o,g);ar(e+48|0)}if(w[e+26|0]&5){u[f>>1]=x[f>>1]|16384}if(!(w[e+26|0]&8)){break sa}Db(e+48|0,q,g);ar(e+48|0);d=0;while(1){f=d<<1;Aa:{if(x[f+(e+208|0)>>1]!=(g|0)){break Aa}f=v[((x[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Aa}t[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}xb(e- -64|0);g=g+1|0;if((g|0)==256){break aa}continue}break}g=P()|0;O()|0}xb(e- -64|0);break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break Z}Ba:{if(!(w[A|0]|w[A+1|0]<<8)){break Ba}i=0;Ca:{Da:{while(1){Ea:{d=Jg(l,i);v[22692]=0;d=T(193,d|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Ea}Fa:{if(!d){i=i+1|0;break Fa}d=Jg(l,i);vc(d);v[22692]=0;R(793,d|0,e+240|0);d=v[22692];v[22692]=0;if((d|0)==1){break Da}j=cd(e+16|0);d=w[e+240|0]|w[e+241|0]<<8;v[22692]=0;U(800,b|0,j|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break Ca}i=i+1|0;f=v[((i<<2)+a|0)+900380>>2];if(!(!f|w[f+34|0])){v[f+4>>2]=32;v[22692]=0;mr(f,0);d=v[22692];v[22692]=0;if((d|0)==1){break Ca}s=f+108|0;C=f+236|0;d=0;while(1){h=d+e|0;Ga:{if(w[h+242|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break Ga}n=xe(j,w[h+242|0]);h=w[n|0];g=h+1|0;m=d+12|0;K=wd(C,m),M=g,u[K>>1]=M;if(h>>>0>=x[a+480190>>1]){break Ga}h=B(g,104)+a|0;t[h+484418|0]=w[e+338|0]&3;t[h+484419|0]=w[e+339|0];t[h+484420|0]=w[e+340|0];t[h+484421|0]=w[e+341|0];u[h+484412>>1]=w[n+1|0]<<1;t[h+484417|0]=w[n+2|0];h=g-1|0;Db(e- -64|0,q,h);if(Cb(e- -64|0)){t[f+14|0]=0}Db(e- -64|0,o,h);if(!Cb(e- -64|0)){break Ga}K=lc(s,m),M=61,t[K|0]=M}d=d+1|0;if((d|0)!=96){continue}break}}js(j)}if((w[A|0]|w[A+1|0]<<8)>>>0>i>>>0){continue}break Ba}break}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;js(j);break Y}Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(!(c&2)|!x[a+480190>>1])){g=0;while(1){g=g+1|0;d=B(g,104)+a|0;c=d+484416|0;f=t[c|0];h=d+484417|0;i=t[h|0];v[22692]=0;j=d+484380|0;Ho(j,(+(i|0)*.0078125-+(f-49|0))*.08333333333333333);f=v[22692];v[22692]=0;if((f|0)==1){break Ha}t[h|0]=0;t[c|0]=0;c=x[d+484414>>1];Ra:{if(!(c&16384)){c=Rc(e+240|0,c&1?16:8,c&64?3:1,0,12);v[22692]=0;W(329,c|0,j|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break Ra}g=P()|0;O()|0;break Y}v[22692]=0;f=T(190,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Qa}v[22692]=0;Q(318,b|0,12)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Qa}c=Kb(e+240|0);v[22692]=0;W(413,b|0,c|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Pa}v[22692]=0;Q(303,d+484423|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break Pa}v[22692]=0;R(577,e- -64|0,13487);d=v[22692];v[22692]=0;if((d|0)==1){break Oa}v[e+12>>2]=g;d=Ck(a);v[22692]=0;U(13,e+48|0,d|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break Na}v[22692]=0;Y(578,e+16|0,e- -64|0,e+12|0,e+48|0);d=v[22692];v[22692]=0;if((d|0)==1){break Ma}v[22692]=0;U(556,a|0,2,e+16|0);d=v[22692];v[22692]=0;if((d|0)==1){break La}vb(e+16|0);vb(e+48|0);Hb(e- -64|0);vb(c)}if(x[a+480190>>1]>g>>>0){continue}break}}hd(l);gc(p);xb(G);xb(I);break b}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ja}g=P()|0;O()|0;break Ka}g=P()|0;O()|0;vb(e+16|0)}vb(e+48|0)}Hb(e- -64|0)}vb(c);break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Z}g=P()|0;O()|0}xb(e+16|0)}hd(l);break y}g=P()|0;O()|0;We(j);break G}g=P()|0;O()|0;break G}g=P()|0;O()|0;break G}g=P()|0;O()|0}hd(r);break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}v[22692]=0;f=T(190,G|0)|0;h=v[22692];v[22692]=0;d=a;Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{if((h|0)!=1){v[22692]=0;h=T(190,G|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break eb}v[22692]=0;U(288,e+240|0,G|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break eb}h=jc(e+88|0,e+240|0);xb(e+240|0);if((f|0)<=844387157){if((f|0)==4674381){break Wa}if((f|0)==5068115){break Va}if(g&1|(f|0)!=726487106){break Ta}t[a+480224|0]=2;v[22692]=0;z=+pa(802,h|0);f=v[22692];v[22692]=0;if((f|0)==1){break Sa}if(z==0){break Ta}z=2646e7/(z*+(B(v[a+480216>>2],v[a+480196>>2])>>>0));if(!(z<4294967296&z>=0)){break db}f=~~z>>>0;break cb}if((f|0)<=1314144591){if((f|0)==844387158){break Ua}if((f|0)!=1280004692){break Ta}j=0;if(!x[a+480188>>1]){break Ta}while(1){v[22692]=0;d=Q(189,e+88|0,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break B}if(!d){break Ta}d=Kb(e+240|0);v[22692]=0;W(531,h|0,d|0,-1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ab}f=Jb(d);H=Ab(d);v[22692]=0;Ve(e+16|0,3,f,H);f=v[22692];v[22692]=0;if((f|0)==1){break $a}v[22692]=0;R(324,e+160|0,e+16|0);f=v[22692];v[22692]=0;if((f|0)==1){break $a}v[22692]=0;Q(399,((j<<5)+a|0)+480289|0,e+160|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break _a}vb(e+160|0);vb(d);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break Ta}if((f|0)==1397445204){break bb}if((f|0)!=1314144592){break Ta}d=0;if(!(w[l|0]|w[l+1|0]<<8)){break Ta}while(1){v[22692]=0;f=Q(189,e+88|0,1)|0;j=v[22692];v[22692]=0;if((j|0)==1){break Ya}if(!f){break Ta}v[22692]=0;f=Wl(o,d&65535);j=v[22692];v[22692]=0;if((j|0)==1){break Ya}if(!f){break Ta}f=Kb(e+240|0);v[22692]=0;W(531,h|0,f|0,-1)|0;j=v[22692];v[22692]=0;if((j|0)==1){break Xa}j=_b(o,d);v[22692]=0;Q(428,j|0,f|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break Xa}vb(f);d=d+1|0;if(d>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break Ta}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}f=0}v[d+480204>>2]=f;break Ta}v[22692]=0;d=T(287,h|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break A}v[a+480232>>2]=d>>>9;v[a+480228>>2]=d>>>8;d=0;if(!x[a+480188>>1]){break Ta}while(1){v[22692]=0;f=Q(804,h|0,e+240|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break C}if(f){u[((d<<5)+a|0)+480286>>1]=(w[e+240|0]|w[e+241|0]<<8)>>>10;f=w[k|0];K=kc(p,d),M=f,t[K|0]=M}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break Ta}g=P()|0;O()|0;break Za}g=P()|0;O()|0;break Za}g=P()|0;O()|0;vb(e+160|0)}vb(d);break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;vb(f);break z}v[22692]=0;Q(318,e+88|0,1)|0;d=v[22692];v[22692]=0;if((d|0)==1){break A}v[22692]=0;d=T(465,e+88|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break A}v[22692]=0;ca(507,r|0,h|0,d|0,2)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break Ta}break A}v[22692]=0;Q(805,h|0,e+16|0)|0;d=v[22692];v[22692]=0;fb:{if((d|0)!=1){d=Kb(e+240|0);v[22692]=0;W(531,h|0,d|0,-1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break fb}if(ur(d,9837)){v[22692]=0;U(13,e+160|0,8,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break fb}Eb(i,e+160|0);vb(e+160|0)}vb(d);break Ta}g=P()|0;O()|0;break z}g=P()|0;O()|0;vb(d);break z}v[22692]=0;s=T(190,h|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break A}}xb(e+88|0);continue}break}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0}xb(e+88|0)}gc(p);break e}g=P()|0;O()|0}xb(G)}xb(I)}S(g|0);L()}d=1}gb=e+1728|0;return d|0}function Ag(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,D=0,E=0,F=0;e=gb-2736|0;gb=e;a:{b:{c:{d:{e:{f:{if(bs(c)){tc(b,268435456);D=v[c+8>>2];p=e+2712|0;d=p;v[d>>2]=0;v[d+4>>2]=0;mc(d+8|0);v[e+2708>>2]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{f=e;q:{r:{s:{t:{if(w[a+3|0]-4>>>0<=4){v[22692]=0;d=T(465,c|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break n}v[e+2708>>2]=d;break t}d=w[a+3|0];if(d>>>0>18){break t}d=1<<d;u:{if(!(d&126991)){if(d&396800){break u}break t}if(!w[a|0]){break t}}d=v[b>>2];v[22692]=0;d=rv(a,d);i=v[22692];v[22692]=0;if((i|0)==1){break s}v[22692]=0;U(747,e+544|0,c|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break s}d=e+544|0;i=v[d+4>>2];v[p>>2]=v[d>>2];v[p+4>>2]=i;gp(p+8|0,d+8|0);zc(e+544|0);v[22692]=0;g=Td(p);d=v[22692];v[22692]=0;if((d|0)==1){break n}v[e+2708>>2]=v[p>>2]}d=w[a+3|0];if(d>>>0>18){break p}i=1<<d;v:{if(!(i&126991)){h=0;if(i&396800){break v}break p}h=!w[a|0]}if(h|y[b>>2]<262145){break p}d=v[e+2708>>2];i=w[a+3|0];v[22692]=0;v[e+520>>2]=((i|0)==11)<<4;i=Fb(e+520|0,e+2708|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[e+544>>2]=d-v[i>>2];d=w[a+3|0];if(d>>>0>16){break r}w:{if(!(1<<d&126991)){if((d|0)==11){break w}break r}if(!(w[a|0]&7)){break r}}d=v[e+544>>2];if(d>>>0<=2147483647){d=d<<1;break q}d=-1;break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=0;v[22692]=0;i=$o(a);h=v[22692];v[22692]=0;x:{y:{if((h|0)!=1){z:{A:{switch(w[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:d=w[a|0];break z;case 9:d=16;break z;case 11:d=4;break z;case 10:case 17:case 18:break A;default:break z}}d=8}i=B(d,i)>>>3|0;d=i-1|0;h=v[e+544>>2];if(d>>>0>-1-h>>>0){break y}h=d+h|0;break x}a=P()|0;O()|0;break a}h=-1}d=(h>>>0)/(i>>>0)|0}v[f+544>>2]=d;tc(b,d);break o}f=e;B:{C:{D:{E:{if(!(w[a+3|0]==4|w[a+3|0]==5|(w[a+3|0]==8|w[a+3|0]==7))){if(w[a+3|0]!=6){break o}d=0;if(y[e+2708>>2]<10){break g}v[22692]=0;Q(318,c|0,4)|0;d=v[22692];v[22692]=0;if((d|0)==1){break n}v[22692]=0;d=T(190,c|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break E}v[e+520>>2]=d;d=v[e+2708>>2];v[22692]=0;v[e+2704>>2]=d;d=Fb(e+520|0,e+2704|0);i=v[22692];v[22692]=0;if((i|0)==1){break D}v[e+544>>2]=v[d>>2];ng(c,8);d=v[e+544>>2];if(d>>>0>50529027){break C}d=B(d,85);break B}v[e+544>>2]=v[e+2708>>2];v[22692]=0;f=$o(a);i=v[22692];v[22692]=0;h=e;F:{G:{if((i|0)!=1){i=v[e+544>>2];f=8/(f>>>0)|0;if(i>>>0>4294967295/(f>>>0)>>>0){break G}f=B(f,i);break F}a=P()|0;O()|0;break a}f=-1}v[h+544>>2]=f;tc(b,f);break o}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=-1}v[f+544>>2]=d;tc(b,(d>>>0)/(w[a|0]>>>3>>>0)|0)}if(!v[b>>2]){d=0;break g}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[22692]=0;d=T(386,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}if(!d){d=0;v[b>>2]=0;break g}if(ke(a,Rc(e+544|0,8,1,0,11))){v[22692]=0;a=Q(1170,c|0,e+544|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){d=0;if(!a){break h}a=v[b>>2];v[22692]=0;v[e+520>>2]=a+1>>>1;a=T(465,c|0)|0;d=v[22692];v[22692]=0;H:{if((d|0)!=1){tc(e+520|0,a);a=zb(g);d=v[e+520>>2];if(d){break H}d=16;break h}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];g=0;while(1){f=w[e+544|w[a|0]&15]+g|0;t[b|0]=f;g=w[e+544|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=g;a=a+1|0;b=b+2|0;d=d-1|0;if(d){continue}break}d=v[e+520>>2]+16|0;break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=5?w[a+3|0]!=4:0)){a=w[a+3|0];v[22692]=0;a=ca(1171,e+1616|0,c|0,b|0,(a|0)==5|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}xb(a);d=v[c+8>>2]-D|0;break h}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[22692]=0;Q(318,c|0,4)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}v[22692]=0;a=T(190,c|0)|0;d=v[22692];v[22692]=0;I:{J:{K:{if((d|0)!=1){v[22692]=0;v[e+520>>2]=a;d=T(374,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break K}v[22692]=0;U(1172,e+544|0,c|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break I}tc(e+520|0,v[e+544>>2]);v[22692]=0;a=v[e+520>>2];f=Td(e+544|0);i=v[22692];v[22692]=0;if((i|0)!=1){i=v[e+544>>2];h=v[b+20>>2];b=Zi(b);v[22692]=0;ha(1173,f|0,i|0,h|0,b|0,d<<24>>24);b=v[22692];v[22692]=0;if((b|0)!=1){break J}}a=P()|0;O()|0;zc(e+544|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=a+9|0;zc(e+544|0);break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[e+2708>>2];d=x[Km(e+1608|0)>>1];v[22692]=0;d=HQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16){break m}d=0;v[22692]=0;f=Q(189,c|0,8)|0;i=v[22692];v[22692]=0;if((i|0)==1){break f}if(!f){break h}v[22692]=0;f=T(190,c|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break f}v[e+2708>>2]=f;if(f>>>0<4){break h}v[22692]=0;U(288,e+520|0,c|0,f|0);f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;f=Gp(e+544|0,e+520|0);i=v[22692];v[22692]=0;if((i|0)==1){break c}xb(e+520|0);v[22692]=0;i=T(1175,f|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break e}if(!v[b>>2]){break j}h=w[a|0];n=(h|0)!=16;while(1){L:{if(n){break L}v[22692]=0;o=Q(198,f|0,8)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break L}a=V(27348)|0;break k}v[22692]=0;l=Q(198,f|0,1)|0;a=v[22692];v[22692]=0;if((a|0)==1){break l}v[22692]=0;a=Q(198,f|0,1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break l}M:{N:{O:{if(!a){g=8;while(1){v[22692]=0;a=Q(198,f|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break M}if(a){break O}g=g+16|0;continue}}v[22692]=0;a=Q(198,f|0,3)|0;g=v[22692];v[22692]=0;if((g|0)!=1){break N}break l}v[22692]=0;a=Q(198,f|0,4)|0;k=v[22692];v[22692]=0;if((k|0)==1){break l}a=a+g|0}j=(j&255)+(((l?-1:0)^a)&255)|0;P:{if((h|0)!=16){t[v[b+20>>2]+d|0]=j;break P}u[v[b+20>>2]+(d<<1)>>1]=o&255|j<<8}d=d+1|0;if(d>>>0<y[b>>2]){continue}break j}break}a=V(27348)|0;break k}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){d=0;if(y[e+2708>>2]<5){break h}a=zb(zb(v[b+20>>2]));b=Zi(b);v[22692]=0;d=W(1176,c|0,a|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|(w[a+3|0]!=18?w[a+3|0]!=17:0)|(w[a+1|0]!=2?w[a+1|0]!=1:0))){d=v[b>>2];v[22692]=0;f=$o(a);i=v[22692];v[22692]=0;if((i|0)!=1){v[e+544>>2]=B(d,f);tc(e+544|0,v[e+2708>>2]);b=v[b+20>>2];d=v[e+544>>2];f=w[a+3|0];a=v[e+544>>2];v[e+544>>2]=a-1;if((f|0)!=17){if(!a){break h}while(1){E=b,F=x[wd(37252,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}if(!a){break h}while(1){E=b,F=x[wd(36740,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}a=P()|0;O()|0;break a}if(!(w[a|0]!=8|w[a+1|0]!=1)){Q:{R:{S:{T:{U:{a=w[a+3|0];switch(a|0){case 2:break R;case 1:break S;case 0:break T;default:break U}}d=0;switch(a-10|0){case 0:break Q;case 2:break R;default:break h}}v[22692]=0;d=GQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=FQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}a=v[e+2708>>2];d=w[yA(e+512|0)|0];v[22692]=0;d=EQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=DQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=8|w[a+1|0]!=3)){V:{W:{X:{Y:{f=w[a+3|0];switch(f|0){case 2:break V;case 1:break X;case 0:break Y;default:break W}}v[22692]=0;d=CQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=BQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=12){break h}}d=v[e+2708>>2];f=w[yA(e+504|0)|0];v[22692]=0;d=AQ(b,g,d,f);f=v[22692];v[22692]=0;if((f|0)==1){break f}if(w[a+3|0]!=12){break h}f=v[b>>2]<<1;if((f|0)<1){break h}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=8|w[a+1|0]!=2)){d=0;Z:{switch(w[a+3|0]){case 0:v[22692]=0;d=zQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 1:v[22692]=0;d=yQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 2:break Z;default:break h}}a=v[e+2708>>2];d=w[yA(e+496|0)|0];v[22692]=0;d=xQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){_:{$:{aa:{ba:{a=w[a+3|0];switch(a|0){case 0:break ba;case 2:break _;case 1:break aa;default:break $}}v[22692]=0;d=wQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=vQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}d=0;if((a|0)!=12){break h}}a=v[e+2708>>2];d=x[Km(e+488|0)>>1];v[22692]=0;d=uQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){d=0;ca:{switch(w[a+3|0]){case 0:v[22692]=0;d=tQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 1:v[22692]=0;d=rQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 2:break ca;default:break h}}a=v[e+2708>>2];d=x[Km(e+480|0)>>1];v[22692]=0;d=qQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){da:{ea:{fa:{ga:{f=w[a+3|0];switch(f|0){case 2:break da;case 1:break fa;case 0:break ga;default:break ea}}v[22692]=0;d=pQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=oQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=12){break h}}d=v[e+2708>>2];f=x[Km(e+472|0)>>1];v[22692]=0;d=nQ(b,g,d,f);f=v[22692];v[22692]=0;if((f|0)==1){break f}if(w[a+3|0]!=12){break h}f=v[b>>2];if(f<<1<1){break h}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){d=0;ha:{switch(w[a+3|0]){case 0:v[22692]=0;d=mQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 1:v[22692]=0;d=lQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 2:break ha;default:break h}}a=v[e+2708>>2];d=x[Km(e+464|0)>>1];v[22692]=0;d=kQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){d=0;ia:{switch(w[a+3|0]){case 0:v[22692]=0;d=jQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 1:v[22692]=0;d=iQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 2:break ia;default:break h}}a=v[e+2708>>2];d=x[Km(e+456|0)>>1];v[22692]=0;d=hQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){d=0;ja:{switch(w[a+3|0]){case 0:v[22692]=0;d=gQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 1:v[22692]=0;d=fQ(b,g,v[e+2708>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h;case 2:break ja;default:break h}}a=v[e+2708>>2];d=x[Km(e+448|0)>>1];v[22692]=0;d=eQ(b,g,a,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=dQ(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=cQ(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=bQ(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=aQ(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=$P(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=_P(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=ZP(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=YP(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=XP(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=WP(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=VP(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=UP(b,g,d);a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=W(1217,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=W(1218,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=W(1219,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=W(1220,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=W(1221,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=W(1222,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22692]=0;d=W(1223,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[22692]=0;d=W(1224,b|0,g|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=24|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ka:{if(!w[a+2|0]){v[e+8>>2]=v[e+440>>2];v[e+436>>2]=0;a=v[e+436>>2];v[e>>2]=v[e+432>>2];v[e+4>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],dd(b)),v[E+12>>2]=F;tc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+4>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d+2|0])<<24;la:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break la}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;ma:{if(!a){break ma}j=v[k+12>>2];if(!j){break ma}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g+2|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;na:{if((f|0)>0?1:(f|0)>=0){f=mqa(h,f,i,0);h=jb;break na}l=n;h=mqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=gd(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3);break ka}v[e+24>>2]=v[e+424>>2];v[e+420>>2]=0;a=v[e+420>>2];v[e+16>>2]=v[e+416>>2];v[e+20>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],dd(b)),v[E+12>>2]=F;tc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+20>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+2|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d|0])<<24;oa:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break oa}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;pa:{if(!a){break pa}j=v[k+12>>2];if(!j){break pa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+2|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;qa:{if((f|0)>0?1:(f|0)>=0){f=mqa(h,f,i,0);h=jb;break qa}l=n;h=mqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=gd(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3)}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}f=jqa(x[b+32>>1],0,a,0)+1073741824|0;a=jb;a=f>>>0<1073741824?a+1|0:a;E=b,F=Gd(Qc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ra:{if(!w[a+2|0]){v[e+40>>2]=v[e+408>>2];v[e+404>>2]=0;a=v[e+404>>2];v[e+32>>2]=v[e+400>>2];v[e+36>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],dd(b)),v[E+12>>2]=F;tc(k+12|0,d>>>2|0);d=zb(g);a=v[e+36>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=f|zb(w[d+1|0])<<8|zb(w[d+2|0])<<16|zb(w[d+3|0])<<24;sa:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break sa}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;ta:{if(!a){break ta}j=v[k+12>>2];if(!j){break ta}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=f|zb(w[g+1|0])<<8|zb(w[g+2|0])<<16|zb(w[g+3|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ua:{if((f|0)>0?1:(f|0)>=0){f=mqa(h,f,i,0);h=jb;break ua}l=n;h=mqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=gd(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2;break ra}v[e+56>>2]=v[e+392>>2];v[e+388>>2]=0;a=v[e+388>>2];v[e+48>>2]=v[e+384>>2];v[e+52>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],dd(b)),v[E+12>>2]=F;tc(k+12|0,d>>>2|0);d=zb(g);a=v[e+52>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+3|0]);j=f|zb(w[d+2|0])<<8|zb(w[d+1|0])<<16|zb(w[d|0])<<24;va:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break va}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;wa:{if(!a){break wa}j=v[k+12>>2];if(!j){break wa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+3|0]);o=d;f=f|zb(w[g+2|0])<<8|zb(w[g+1|0])<<16|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;xa:{if((f|0)>0?1:(f|0)>=0){f=mqa(h,f,i,0);h=jb;break xa}l=n;h=mqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=gd(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}a=jqa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;E=b,F=Gd(Qc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}ya:{if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[e+544>>2]=1065353216;d=v[e+2708>>2];za:{if(!w[a+2|0]){v[e+372>>2]=0;v[e+376>>2]=1065353216;a=v[e+380>>2];v[e+72>>2]=v[e+376>>2];v[e+76>>2]=a;v[22692]=0;a=v[e+372>>2];v[e+64>>2]=v[e+368>>2];v[e+68>>2]=a;d=fa(1225,b|0,g|0,d|0,e+544|0,e- -64|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break za}break ya}v[e+356>>2]=0;v[e+360>>2]=1065353216;a=v[e+364>>2];v[e+88>>2]=v[e+360>>2];v[e+92>>2]=a;v[22692]=0;a=v[e+356>>2];v[e+80>>2]=v[e+352>>2];v[e+84>>2]=a;d=fa(1226,b|0,g|0,d|0,e+544|0,e+80|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break ya}}if(!d){break h}q=z[e+544>>2];if(q==C(1)){break h}a=b;h=a;q=ge(zo(C(q*C(x[a+32>>1])),C(1),C(64)));a=65535;Aa:{if(!(q<C(65535))){break Aa}a=0;if(!(q>C(0))){break Aa}a=~~q>>>0;if(q<C(4294967296)&q>=C(0)){break Aa}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}Ba:{if(!(w[a|0]!=64|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[e+544>>2]=0;v[e+548>>2]=1072693248;d=v[e+2708>>2];Ca:{if(!w[a+2|0]){v[e+336>>2]=0;v[e+340>>2]=1072693248;v[e+328>>2]=0;v[e+332>>2]=0;v[e+104>>2]=0;v[e+108>>2]=0;v[e+112>>2]=0;v[e+116>>2]=1072693248;a=v[e+348>>2];v[e+120>>2]=v[e+344>>2];v[e+124>>2]=a;v[22692]=0;a=v[e+324>>2];v[e+96>>2]=v[e+320>>2];v[e+100>>2]=a;d=fa(1227,b|0,g|0,d|0,e+544|0,e+96|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break Ca}break Ba}v[e+304>>2]=0;v[e+308>>2]=1072693248;v[e+296>>2]=0;v[e+300>>2]=0;v[e+136>>2]=0;v[e+140>>2]=0;v[e+144>>2]=0;v[e+148>>2]=1072693248;a=v[e+316>>2];v[e+152>>2]=v[e+312>>2];v[e+156>>2]=a;v[22692]=0;a=v[e+292>>2];v[e+128>>2]=v[e+288>>2];v[e+132>>2]=a;d=fa(1228,b|0,g|0,d|0,e+544|0,e+128|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break Ba}}if(!d){break h}r=A[e+544>>3];if(r==1){break h}a=b;h=a;r=fe(uA(r*+x[a+32>>1],1,64));a=65535;Da:{if(!(r<65535)){break Da}a=0;if(!(r>0)){break Da}a=~~r>>>0;if(r<4294967296&r>=0){break Da}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+280>>2]=939524096;v[22692]=0;a=v[e+284>>2];v[e+160>>2]=v[e+280>>2];v[e+164>>2]=a;d=ca(1229,b|0,g|0,d|0,e+160|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[e+272>>2]=939524096;v[22692]=0;a=v[e+276>>2];v[e+168>>2]=v[e+272>>2];v[e+172>>2]=a;d=ca(1230,b|0,g|0,d|0,e+168|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+264>>2]=939524096;v[22692]=0;a=v[e+268>>2];v[e+176>>2]=v[e+264>>2];v[e+180>>2]=a;d=ca(1231,b|0,g|0,d|0,e+176|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[e+256>>2]=939524096;v[22692]=0;a=v[e+260>>2];v[e+184>>2]=v[e+256>>2];v[e+188>>2]=a;d=ca(1232,b|0,g|0,d|0,e+184|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+248>>2]=872415232;v[22692]=0;a=v[e+252>>2];v[e+192>>2]=v[e+248>>2];v[e+196>>2]=a;d=ca(1229,b|0,g|0,d|0,e+192|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}v[e+240>>2]=872415232;v[22692]=0;a=v[e+244>>2];v[e+200>>2]=v[e+240>>2];v[e+204>>2]=a;d=ca(1230,b|0,g|0,d|0,e+200|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}d=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break h}d=v[e+2708>>2];if(!w[a+2|0]){v[e+232>>2]=872415232;v[22692]=0;a=v[e+236>>2];v[e+208>>2]=v[e+232>>2];v[e+212>>2]=a;d=ca(1231,b|0,g|0,d|0,e+208|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break h}break f}v[e+224>>2]=872415232;v[22692]=0;a=v[e+228>>2];v[e+216>>2]=v[e+224>>2];v[e+220>>2]=a;d=ca(1232,b|0,g|0,d|0,e+216|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(27348)|0}if((O()|0)!=(ea(27348)|0)){break d}Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break i}}d=i+4|0;xb(f);break h}a=P()|0;O()|0;break d}v[22692]=0;Q(188,c|0,d+D|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}}zc(p)}gb=e+2736|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);break a}a=P()|0;O()|0;xb(e+520|0);break a}a=P()|0;O()|0}zc(p);S(a|0);L()}function nu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,ga=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;l=gb-192|0;gb=l;Z=cd(a);o=l+160|0;t[o+26|0]=0;u[o+24>>1]=0;v[o+16>>2]=0;v[o+20>>2]=-1;v[o+8>>2]=-1;v[o+12>>2]=-1;v[o>>2]=0;v[o+4>>2]=0;G=v[d+16>>2];X=w[d+6|0];$=b+484360|0;if(X>>>0>=Oi($)>>>0){X=w[$+16|0]}z=Nj($,X);v[22692]=0;q=Q(1233,l+120|0,b|0)|0;a=v[22692];v[22692]=0;a:{if((a|0)!=1){f=v[q+4>>2];v[22692]=0;H=W(1234,l+80|0,b|0,X|0)|0;a=v[22692];v[22692]=0;b:{if((a|0)!=1){g=x[d+4>>1];c:{d:{if(g>>>0>=sc(z)>>>0){break d}while(1){v[22692]=0;a=Q(470,z|0,g&65535)|0;k=v[22692];v[22692]=0;if((k|0)==1){break c}if(a){break d}v[d>>2]=0;g=g+1|0;u[d+4>>1]=g;if(sc(z)>>>0>(g&65535)>>>0){continue}break}}a=v[d>>2];v[f+52>>2]=a;v[f+48>>2]=a;v[o+16>>2]=a;u[f+74>>1]=g;u[f+72>>1]=g;u[o+24>>1]=g;I=l+72|0;Ud(I);ga=tr(l- -64|0);ia=c&7;la=(ia|0)!=7;e:{if(la){break e}Bl(I,1);Bl(I,2);Bl(I,3);Bl(I,28);Bl(I,38);Bl(I,40);Bl(I,39);Bl(I,41);PP(ga,12);PP(ga,13);if((G|0)!=2){break e}a=x[d+12>>1];if(sc(z)>>>0<=a>>>0){break e}a=x[rc(z,a)>>1];v[22692]=0;k=b+484344|0;g=le(k,a);e=v[22692];v[22692]=0;if((e|0)==1){break c}if(!g){break e}e=_b(k,a);g=v[d+8>>2];v[22692]=0;e=OP(e,g);i=v[22692];v[22692]=0;if((i|0)==1){break c}if(!e){break e}e=0;a=_b(k,a);v[22692]=0;g=Wc(a,g,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}if(!x[b+480188>>1]){break e}a=q+20|0;while(1){f:{g:{h:{switch(w[g|0]-253|0){case 0:if(x[b+480192>>1]){break g}break;case 1:case 2:break g;default:break h}}v[22692]=0;k=de(g);i=v[22692];v[22692]=0;if((i|0)==1){break c}if(!k){break f}if(ou(g)){break f}}sa=xe(a,e),ta=-1,v[sa>>2]=ta}g=g+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}T=f+74|0;K=f+48|0;M=f+80|0;oa=f+44|0;F=q+20|0;ka=q+8|0;aa=c&1;ba=f+20|0;D=b+1074312|0;ma=f+616|0;J=b+484344|0;da=32768;pa=(G|0)!=3;na=(G|0)!=2;e=0;g=0;i:{j:{while(1){N=g;k:{l:{while(1){i=x[d+12>>1];qa=A[d+8>>3];while(1){v[22692]=0;Jz(l+32|0,b,f,e&1);a=v[22692];v[22692]=0;if((a|0)==1){break c}k=w[l+32|0];if(!(A[q+32>>3]<qa?1:pa)){break l}g=x[f+72>>1];a=f;m:{if(sc(z)>>>0>g>>>0){g=x[rc(z,x[f+72>>1])>>1];break m}g=65535}u[a+70>>1]=g;v[22692]=0;a=le(J,g&65535);g=v[22692];v[22692]=0;if((g|0)==1){break i}if(!((i|0)==x[f+72>>1]?x[f+70>>1]==65535|na|a:1)){break l}n:{if(x[f+70>>1]<Re(J)>>>0){break n}while(1){a=f;h=a;o:{p:{if(x[a+70>>1]!=65535){g=x[f+72>>1];if(sc(z)>>>0>g>>>0){break p}}if(x[z+28>>1]==x[f+72>>1]){break n}g=x[z+28>>1];break o}g=x[f+72>>1]+1|0}u[h+72>>1]=g;a=f;q:{if(sc(z)>>>0>(g&65535)>>>0){g=x[rc(z,x[f+72>>1])>>1];break q}g=65535}u[a+70>>1]=g;u[f+74>>1]=x[f+72>>1];v[22692]=0;a=le(J,g&65535);g=v[22692];v[22692]=0;if((g|0)==1){break i}r:{if(a){break r}a=x[f+72>>1];g=Dq(l+32|0,ma);v[22692]=0;a=fa(1237,H|0,a|0,0,g|0,(k|0)!=0|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!a){break r}if(G>>>0<2){a=x[f+72>>1];v[o+8>>2]=0;u[o+20>>1]=a;if(!G){break n}}v[22692]=0;a=ca(1238,H|0,T|0,K|0,1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break i}if(!a){break n}A[o>>3]=A[q+32>>3];v[22692]=0;R(1239,Z|0,o|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}v[o+16>>2]=v[K>>2];u[o+24>>1]=x[T>>1];v[22692]=0;_(1240,q|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}a=x[f+74>>1];u[f+72>>1]=a;sa=f,ta=x[rc(z,a)>>1],u[sa+70>>1]=ta;v[f+52>>2]=v[f+48>>2];break n}if(x[f+70>>1]>=Re(J)>>>0){continue}break}}if(x[T>>1]==65535){break j}a=x[f+70>>1];v[22692]=0;a=le(J,a);g=v[22692];v[22692]=0;if((g|0)==1){break i}if(!a){if(x[z+28>>1]==x[f+72>>1]){if(!G){break j}v[22692]=0;a=ca(1238,H|0,T|0,K|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break i}if(!a){break j}A[o>>3]=A[q+32>>3];v[22692]=0;R(1239,Z|0,o|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}v[o+16>>2]=v[K>>2];u[o+24>>1]=x[T>>1];v[22692]=0;_(1240,q|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}v[f+52>>2]=v[f+48>>2];continue}u[f+74>>1]=x[f+72>>1]+1;continue}break}if(y[f+48>>2]>=y[_b(J,x[f+70>>1])+12>>2]){v[K>>2]=0}if(!(v[K>>2]==v[d+8>>2]?x[f+72>>1]!=x[d+12>>1]|na:1)){break l}g=0;if(!((G|0)==3|y[H+28>>2]<da>>>0)){v[q+32>>2]=0;v[q+36>>2]=2146435072;v[H+28>>2]=0;da=da>>>(da>>>0>256)|0;g=1}a=v[f+48>>2];i=x[f+72>>1];h=Dq(l+32|0,ma);v[22692]=0;a=fa(1237,H|0,i|0,a|0,h|0,(k|0)!=0|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}if((a|g)==1){if(G>>>0<2){u[o+20>>1]=x[f+72>>1];v[o+8>>2]=v[f+48>>2];if(!G){break j}}v[22692]=0;a=ca(1238,H|0,T|0,K|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break c}if(!a){break j}A[o>>3]=A[q+32>>3];v[22692]=0;R(1239,Z|0,o|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[o+16>>2]=v[K>>2];u[o+24>>1]=x[T>>1];v[22692]=0;_(1240,q|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[f+52>>2]=v[f+48>>2];continue}u[o+22>>1]=x[f+72>>1];v[o+12>>2]=v[f+48>>2];v[22692]=0;Iz(b,f,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}if(y[f+48>>2]>=y[_b(J,x[f+70>>1])+12>>2]){v[K>>2]=0}if(k){continue}break}a=_b(J,x[f+70>>1]);k=v[f+48>>2];v[22692]=0;g=Wc(a,k,0);a=v[22692];v[22692]=0;s:{if((a|0)!=1){Db(l+32|0,D,77);e=Cb(l+32|0);h=0;if(x[b+480188>>1]){break s}break k}break c}while(1){t:{if(sa=sA(g),ta=1,ua=!e|!(w[((h<<5)+b|0)+480281|0]&4),ua?sa:ta){To((B(h,872)+f|0)+1404|0);break t}v[22692]=0;a=zg(g);k=v[22692];v[22692]=0;if((k|0)==1){break c}if(a){u:{if(!aa){break u}a=w[g+1|0];if(a-251>>>0<5|!a){break u}v[22692]=0;a=yo(g);k=v[22692];v[22692]=0;if((k|0)==1){break c}v[22692]=0;k=Cq(g);i=v[22692];v[22692]=0;if((i|0)==1){break c}u[l+8>>1]=k;t[l+32|0]=w[g+1|0];u[l+34>>1]=x[l+8>>1];v[22692]=0;k=Q(1245,ka|0,l+32|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}u[k>>1]=a}To((B(h,872)+f|0)+1404|0);break t}a=B(h,872)+f|0;k=a+1408|0;i=w[g+4|0]|w[g+5|0]<<8;t[k|0]=i;t[k+1|0]=i>>>8;a=a+1404|0;k=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[a|0]=k;t[a+1|0]=k>>>8;t[a+2|0]=k>>>16;t[a+3|0]=k>>>24;v:{switch(w[g+3|0]-16|0){case 0:a=w[g+5|0];v[22692]=0;U(1246,b|0,f|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}break t;case 1:Db(l+32|0,D,5);if(!Cb(l+32|0)){break t}a=w[g+5|0];if(!a){break t}v[22692]=0;U(1246,b|0,f|0,a|0);a=v[22692];v[22692]=0;if((a|0)!=1){break t}break c;case 4:a=w[g+5|0];k=a&240;if((k|0)!=224){if((k|0)!=96){break t}v[f+24>>2]=v[f+24>>2]+(a&15);break t}if(v[ba>>2]){break t}a=w[g+5|0]&15;if(a?0:v[b+480180>>2]&2){break t}v[ba>>2]=a+1;break t;case 3:break v;default:break t}}a=w[g+5|0];if((a&240)!=224){break t}v[ba>>2]=(a&15)+1}g=g+6|0;h=h+1|0;if(h>>>0<x[b+480188>>1]){continue}break}break k}t[o+26|0]=1;break j}k=ok(f);v[22692]=0;v[l+32>>2]=1;a=Mc(ba,l+32|0);g=v[22692];v[22692]=0;w:{if((g|0)!=1){a=v[a>>2];u[f+68>>1]=65535;v[f+60>>2]=-1;v[f+64>>2]=-1;if(!x[b+480188>>1]){break w}V=k-1|0;g=k-a|0;r=B(g,1e4);h=0;while(1){x:{i=B(h,872)+f|0;a=i+1404|0;y:{if(sA(a)){break y}n=i+616|0;e=w[i+1409|0];ea=i+1407|0;m=w[ea|0];z:{A:{if(!aa){break A}j=w[a|0];s=i+1405|0;p=w[s|0];if(p){t[i+1415|0]=0;t[i+1419|0]=p;sa=xe(F,h),ta=255,t[sa+5|0]=ta}v[22692]=0;p=de(a);E=v[22692];v[22692]=0;if((E|0)==1){break x}if(p){t[i+1415|0]=j}v[22692]=0;p=de(a);E=v[22692];v[22692]=0;if((E|0)==1){break x}B:{if(!(w[s|0]?1:p)){break B}C:{s=i+1419|0;p=w[s|0];if(!p|p>>>0>x[b+480192>>1]){break C}p=v[((w[s|0]<<2)+b|0)+900380>>2];if(!p|!(t[p+15|0]&1)){break C}p=v[p+8>>2];v[22692]=0;Lo(n,p,b);p=v[22692];v[22692]=0;if((p|0)!=1){break C}break c}j=Vz(b,j,w[s|0]);if(!j){break B}j=B(j,104)+b|0;if(!(w[j+484414|0]&32)){break B}j=x[j+484408>>1];v[22692]=0;Lo(n,j,b);j=v[22692];v[22692]=0;if((j|0)!=1){break B}break c}D:{E:{F:{j=w[i+1406|0];switch(j-1|0){case 1:break A;case 2:case 3:break E;case 0:break F;default:break D}}sa=xe(F,h),ta=w[i+1408|0],t[sa+5|0]=ta;break A}a=w[i+1408|0];if(!a){break A}t[i+1450|0]=a;break A}if(!w[i+1408|0]|(j|0)!=11){break A}rA(l+32|0,b,a,0);a=Te(l+32|0);u[i+1384>>1]=x[l+32>>1];if(w[a|0]){break z}}G:{H:{switch(m-12|0){case 0:v[22692]=0;qA(b,f,h&65535);a=v[22692];v[22692]=0;if((a|0)!=1){break G}break x;case 2:v[22692]=0;a=pA(b,f,h&65535,e);j=v[22692];v[22692]=0;if((j|0)!=1){if((a|0)==-1){break G}v[f+60>>2]=a;break G}break c;case 5:Db(l+32|0,D,5);if(Cb(l+32|0)){break G}a=v[f+48>>2];j=x[f+70>>1];v[22692]=0;a=Jm(b,j,a,h&65535,0);j=v[22692];v[22692]=0;I:{J:{if((j|0)!=1){a=B(a,1e4);if(!aa|!(v[b+480180>>2]&16777250)){break I}if(a>>>0<1e4){break J}t[i+1451|0]=(a>>>0)/1e4;break I}break c}a=B(w[i+1451|0],1e4)}j=(a>>>0)/1e4|0;K:{if(a>>>0>319999){break K}s=B(r,j&15);a=v[f+44>>2];if((j&240)==16){a=a+s|0;break K}j=a-s|0;a=a>>>0<j>>>0?0:j}v[f+44>>2]=a;a=v[v[b+8>>2]+20>>2];j=v[v[b+8>>2]+24>>2];Db(l+32|0,D,8);Ap(oa,B(a,1e4),Cb(l+32|0)?255e4:B(j,1e4));break G;case 8:L:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break G}v[i+704>>2]=v[i+704>>2]&-257|((e|0)==145)<<8;break G;case 1:t[i+1452|0]=e&15;break G;case 2:mu(b,f,n,e&15);break G;case 6:break L;default:break G}}t[i+1460|0]=e&15;break G;case 7:a=e&240;if((a|0)!=240){if((a|0)!=96){break G}mu(b,f,n,e&15);break G}t[i+1460|0]=e&15;break G;case 1:case 3:case 4:case 6:break G;default:break H}}if((m|0)!=28|(e&240)!=160){break G}Db(l+32|0,D,58);if(Cb(l+32|0)){break G}t[i+1452|0]=e&15}if(!aa){break y}M:{N:{O:{P:{Q:{R:{S:{switch(m-2|0){case 0:if(!e){break z}Db(l+32|0,D,90);if(!Cb(l+32|0)){t[i+1428|0]=e}t[i+1427|0]=e;break z;case 1:if(!e){break z}Db(l+32|0,D,90);if(!Cb(l+32|0)){t[i+1427|0]=e}t[i+1428|0]=e;break z;case 2:if(!e){break z}u[i+1384>>1]=e;break z;case 8:if(!e){break z}v[i+1280>>2]=e<<8;break z;case 4:case 9:if(!e){break z}t[i+1425|0]=e;break z;case 11:sa=xe(F,h),ta=e,t[sa+5|0]=ta;break z;case 21:a=e<<(!(v[b+480180>>2]&59593760)&e<<24>>24>-1)&255;if(a>>>0<=128){v[M>>2]=a<<1;break z}if(v[b+480180>>2]&16777250){break z}v[M>>2]=256;break z;case 22:Db(l+32|0,D,9);T:{if(Cb(l+32|0)){a=i+1433|0;if(e){t[a|0]=e;break T}e=w[a|0];break T}if(e){t[f+1433|0]=e;break T}e=w[f+1433|0]}a=M;m=e&240;j=e&15;U:{if(!(!m|(j|0)!=15)){p=v[M>>2]+(m>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break U}p=v[M>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(m|0)!=240)){break U}p=v[M>>2]+B(g,(e>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(m){break U}p=v[M>>2]-B(g,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=p;Sd(M,0,256);break z;case 19:if(e>>>0>64){break z}v[i+1364>>2]=e;break z;case 20:a=i+1432|0;V:{if(e){t[a|0]=e;break V}e=w[a|0]}m=e&255;j=i+1364|0;a=v[j>>2];s=e&240;e=e&15;W:{if(!(!s|(e|0)!=15)){v[l+32>>2]=a+(m>>>4|0);break W}if(!(!e|(s|0)!=240)){v[l+32>>2]=a-e;break W}if(e){v[l+32>>2]=a-B(e,g);break W}v[l+32>>2]=a+B(g,m>>>4|0)}Sd(l+32|0,0,64);v[j>>2]=v[l+32>>2];break z;case 7:Im(b,n,e,8);break z;case 25:break M;case 6:break N;case 24:break O;case 3:break P;case 5:break Q;case 18:break R;case 17:break S;default:break z}}if(!x[b+480188>>1]|e>>>0>15){break R}m=(e&1)<<14;a=0;while(1){j=B(a,872)+f|0;v[j+704>>2]=(m|v[j+704>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((e&240)!=128){break z}Im(b,n,e&15,4);break z}if(e){t[i+1425|0]=e}e=0}Al(n,e);break z}LP(b,n,e);break z}KP(n,e);break z}JP(n,e)}X:{Y:{switch(w[i+1406|0]-2|0){case 0:Im(b,n,w[i+1408|0],6);break X;case 5:Db(l+32|0,D,53);e=Cb(l+32|0);a=w[i+1408|0];if(e){t[i+1439|0]=a&15;break X}Al(n,a<<4);break X;case 6:break Y;default:break X}}Al(n,w[i+1408|0])}Z:{_:{$:{aa:{a=w[ea|0];switch(a-5|0){case 3:break _;case 0:case 2:break $;case 1:break y;default:break aa}}switch(a-26|0){case 1:break Z;case 0:break $;default:break y}}ba:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ba}}a=g}e=w[i+1439|0];Db(l+32|0,D,21);n=Cb(l+32|0);i=i+1435|0;a=B(a,e);t[i|0]=w[i|0]+(n?a<<2:a);break y}ca:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ca}}a=g}e=w[i+1442|0];Db(l+32|0,D,21);n=Cb(l+32|0);i=i+1436|0;a=B(a,e);t[i|0]=w[i|0]+(n?a<<2:a);break y}a=i+1437|0;t[a|0]=w[a|0]+B(V,w[i+1445|0]);v[22692]=0;Lz(b,n);a=v[22692];v[22692]=0;if((a|0)==1){break x}}h=h+1|0;if(h>>>0<x[b+480188>>1]){continue}break w}break}break c}break c}if(v[f+40>>2]==65535?v[b+480180>>2]==4:0){break j}v[f+32>>2]=v[b+480216>>2];if(IP(_b(J,x[f+70>>1]))){sa=f,ta=v[_b(J,x[f+70>>1])+16>>2],v[sa+32>>2]=ta}v[22692]=0;g=Q(1252,b|0,f|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){a=B(g,k);A[q+32>>3]=+(a>>>0)/+y[b+24620>>2]+A[q+32>>3];v[f>>2]=a+v[f>>2];if(!(!x[b+480188>>1]|la)){a=0;ea=(N|0)!=0&(g|0)!=(N|0);while(1){da:{if(v[xe(F,a)>>2]==-1){break da}m=B(a,872)+f|0;V=m+1404|0;r=m+1316|0;if(!v[r>>2]){if(sA(V)){break da}}s=1;ea:{fa:{p=m+1407|0;switch(w[p|0]-4|0){case 0:case 2:break ea;default:break fa}}s=w[m+1406|0]==11}if(w[m+1405|0]){v[m+1276>>2]=0}n=m+1409|0;j=w[n|0];v[22692]=0;E=de(V);e=v[22692];v[22692]=0;ga:{if((e|0)==1){break ga}i=m+616|0;h=j&15;e=0;ha:{ia:{if(!E){break ia}ja:{if(!s){break ja}if(!w[xe(F,a)+4|0]){break ja}e=v[r>>2];v[22692]=0;ha(1253,l+32|0,b|0,i|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)==1){break c}e=v[l+36>>2];v[m+624>>2]=v[l+32>>2];v[m+628>>2]=e}t[m+1418|0]=w[m+1415|0];E=m+1308|0;ra=v[E>>2];e=w[m+1419|0];if(e){v[22692]=0;xo(b,i,e,s,1,1);e=v[22692];v[22692]=0;if((e|0)==1){break i}}e=w[V|0];v[22692]=0;ja(1255,b|0,i|0,e|0,s|0,1,0,65535);e=v[22692];v[22692]=0;if((e|0)==1){break i}j=j>>>4|0;sa=xe(F,a),ta=1,t[sa+4|0]=ta;r=w[p|0];ka:{if(!((w[n|0]&240)!=208|(r-19&255)>>>0>1)){e=h;if(k>>>0>e>>>0){break ka}}e=(r|0)==33?k>>>0>j>>>0?j:0:0}e=!(v[b+480180>>2]&16777250)|(!e|y[ba>>2]<2)?e:B(v[f+20>>2]-1|0,v[f+24>>2]+v[f+40>>2]|0)+e|0;if(!s){sa=xe(F,a),ta=0,v[sa>>2]=ta}r=w[p|0];la:{ma:{if((r|0)==9){break ma}na:{if((r|0)!=19){if((r|0)!=20|(j|0)!=8){break na}break ma}if((j|0)==8){break ma}}if(w[m+1406|0]!=2){break la}}v[E>>2]=ra}oa:{pa:{qa:{switch(r-42|0){default:if((r|0)!=10){break pa}v[22692]=0;Y(1256,b|0,i|0,a&65535,f|0);j=v[22692];v[22692]=0;if((j|0)==1){break i}break ia;case 2:break oa;case 1:break pa;case 0:break qa}}if(!v[m+720>>2]){break pa}v[22692]=0;Y(1257,q|0,a&65535,N|0,-1);e=v[22692];v[22692]=0;if((e|0)==1){break i}e=w[n|0];v[22692]=0;nA(i,e);e=v[22692];v[22692]=0;if((e|0)==1){break i}e=v[f+40>>2]-1|0;break ia}if(w[m+1406|0]!=15){break ia}j=m+1408|0;if(w[j|0]>9){break ia}r=v[m+720>>2];if(!r){break ia}j=w[j|0];ra:{if(!j){j=v[m+1280>>2];break ra}j=v[(r+(j<<2)|0)- -64>>2];v[m+1280>>2]=j}v[22692]=0;Hm(b,i,j);j=v[22692];v[22692]=0;if((j|0)!=1){break ia}break c}r=jqa(w[n|0],0,v[m+692>>2],0);j=jb;E=j>>>8|0;j=Qc((j&255)<<24|r>>>8,E);v[22692]=0;Hm(b,i,j);j=v[22692];v[22692]=0;if((j|0)==1){break i}}sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{switch(w[V|0]-253|0){case 0:if(x[b+480192>>1]){break za}break;case 1:case 2:break za;default:break Aa}}j=w[p|0];if((j-19&255)>>>0<=1){r=0;if((w[n|0]&240)!=192){break xa}if(h>>>0<k>>>0){break za}break xa}r=0;E=j&255;if((E|0)==33&(h|0)!=0&e+h>>>0<k>>>0){break za}if((E|0)!=25){break ya}}j=w[p|0];r=1}if((j&255)==13){break wa}}if(w[m+1406|0]==1){v[m+1304>>2]=w[m+1408|0]<<2}if(!v[m+720>>2]|r){break va}h=0;if((j&255)>>>0>44){break ta}break ua}v[m+1304>>2]=w[n|0]<<2;j=13;if(!(!v[m+720>>2]|r)){break ua}}if(!r){break sa}break ha}Db(l+32|0,I,j&255);h=1;if(Cb(l+32|0)){break ta}h=0;if(w[p|0]!=19){break ta}h=w[n|0]&240;h=(h|0)==16|(h|0)==32}j=w[m+1406|0];if(j>>>0<=15){tl(l+32|0,ga,j);if(Cb(l+32|0)|h){break ha}break sa}if(h){break ha}}if(ea){v[22692]=0;Y(1257,q|0,a&65535,N|0,-1);h=v[22692];v[22692]=0;if((h|0)==1){break ga}}h=w[p|0];Ba:{if(h>>>0<=18){if(!k|(!(v[b+480180>>2]==1?w[n|0]:1)|((h|0)!=11?h-6>>>0>=2:0))){break Ba}j=m+1467|0;h=0;while(1){t[j|0]=!h|w[j|0]&254;wo(b,i,w[n|0]);h=h+1|0;if((k|0)!=(h|0)){continue}break}break Ba}Ca:{switch(h-19|0){case 0:h=w[n|0];if(!(h&15)){if(!(v[b+480180>>2]&1048580)){break Ba}h=w[n|0]}n=m+1467|0;t[n|0]=w[n|0]|1;n=h&240;if((n|0)!=176){if((n|0)!=160){break Ba}Bq(b,i,h&15,0);break Ba}Aq(b,i,h&15,0);break Ba;case 1:Da:{Ea:{Fa:{h=w[n|0];switch(h-158|0){case 1:break Ea;case 0:break Fa;default:break Da}}v[22692]=0;Y(1257,q|0,a&65535,N|0,-1);h=v[22692];v[22692]=0;if((h|0)==1){break ga}v[m+704>>2]=v[m+704>>2]&-129;break Ba}v[22692]=0;Y(1257,q|0,a&65535,N|0,-1);h=v[22692];v[22692]=0;if((h|0)==1){break ga}v[m+704>>2]=v[m+704>>2]|128;if(!v[m+692>>2]|v[i+4>>2]){break Ba}v[22692]=0;h=de(V);n=v[22692];v[22692]=0;if((n|0)==1){break ga}if(!(w[m+704|0]&2?h:1)){break Ba}n=v[m+692>>2]-1|0;v[i>>2]=-1;v[i+4>>2]=n;break Ba}if((h&240)!=112|h>>>0<115){break Ba}v[22692]=0;cB(i,h,b);h=v[22692];v[22692]=0;if((h|0)!=1){break Ba}break ga;default:break Ca}}if(h-35>>>0>=2){break Ba}v[22692]=0;h=a&65535;Y(1257,q|0,h|0,N|0,-1);n=v[22692];v[22692]=0;if((n|0)==1){break ga}v[22692]=0;Y(1261,b|0,h|0,f|0,0);h=v[22692];v[22692]=0;if((h|0)==1){break ga}}n=m+1467|0;h=w[n|0]|1;t[n|0]=h;Ga:{Ha:{Ia:{Ja:{Ka:{j=m+1406|0;switch(w[j|0]-3|0){case 11:break Ha;case 0:case 1:break Ia;case 3:break Ja;case 2:break Ka;default:break Ga}}h=w[m+1408|0];Db(l+32|0,D,41);Bq(b,i,h,Cb(l+32|0));break Ga}h=w[m+1408|0];Db(l+32|0,D,41);Aq(b,i,h,Cb(l+32|0));break Ga}h=w[m+1408|0];La:{if(h){break La}Db(l+32|0,D,41);h=0;if(!Cb(l+32|0)){break La}h=w[m+1450|0];if(!h){break Ga}}if(!k){break Ga}m=w[j|0]==3?h<<4:h;h=0;while(1){t[n|0]=!h|w[n|0]&254;wo(b,i,m&255);h=h+1|0;if((k|0)!=(h|0)){continue}break}break Ga}i=w[m+1408|0];if(i>>>0>1){break Ga}t[n|0]=h&251|!i<<2}if(w[n|0]&4){break da}if(s){h=xe(F,a);i=v[h>>2];v[h>>2]=i+k;v[22692]=0;Y(1257,q|0,a&65535,g|0,(e+i|0)+1|0);e=v[22692];v[22692]=0;if((e|0)!=1){break da}break c}i=xe(F,a);v[i>>2]=v[i>>2]+(k-e|0);break da}v[22692]=0;dB(i);e=v[22692];v[22692]=0;if((e|0)==1){break ga}sa=xe(F,a),ta=0,v[sa>>2]=ta;break da}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}e=EP(b,f,0);continue}break}break c}if(!(!x[b+480188>>1]|(ia|0)!=7)){a=0;while(1){Ma:{if(v[xe(F,a)>>2]==-1){break Ma}v[22692]=0;Y(1257,q|0,a&65535,N|0,-1);d=v[22692];v[22692]=0;if((d|0)!=1){break Ma}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[o+26|0]){u[o+20>>1]=x[f+72>>1];v[o+8>>2]=v[f+48>>2]}A[o>>3]=A[q+32>>3];v[22692]=0;R(1239,Z|0,o|0);a=v[22692];v[22692]=0;Na:{if((a|0)==1){break Na}Oa:{Pa:{if(!aa){break Pa}Qa:{Ra:{if(G?w[o+26|0]:1){g=b+1074376|0;e=hc(g,f,614);a=0;while(1){k=B(a,872);d=(k+f|0)+616|0;k=hc((e+k|0)+616|0,d,88);v[k+88>>2]=v[d+88>>2];hc(k+92|0,d+92|0,576);v[k+668>>2]=v[d+668>>2];hc(k+672|0,d+672|0,52);ro(k+724|0,d+724|0);ro(k+732|0,d+732|0);ro(k+740|0,d+740|0);hc(k+748|0,d+748|0,123);a=a+1|0;if((a|0)!=256){continue}break}mA(g);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1298260|0;if(Dd(d)){f=v[d>>2];v[22692]=0;SA(f);f=v[22692];v[22692]=0;if((f|0)==1){break Na}}if(x[b+480188>>1]){k=(ia|0)==7;while(1){f=B(a,872)+b|0;g=w[f+1075791|0];if(g){t[f+1075794|0]=g}g=xe(F,a);if(!(k|w[g+5|0]==255)){v[22692]=0;t[l+32|0]=64;g=ac(g+5|0,l+32|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[f+1075680>>2]=w[g|0]<<2}Sa:{g=f+1075096|0;e=v[g>>2];if(!e|!(w[e+35|0]&2)){break Sa}if(!Dd(d)){break Sa}e=v[d>>2];g=v[g>>2];v[22692]=0;h=e;e=a&65535;xu(h,e,g+68|0);g=v[22692];v[22692]=0;if((g|0)!=1){g=v[d>>2];v[22692]=0;Ni(g,e,1);g=v[22692];v[22692]=0;if((g|0)!=1){break Sa}}break c}v[f+1075008>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=PB(l+32|0);sa=l,ta=lr(ka),v[sa+24>>2]=ta;sa=l,ta=Ah(ka),v[sa+16>>2]=ta;if(!mg(l+24|0,l+16|0)){break Ra}while(1){f=Pl(l+24|0);k=w[f|0]-1&255;a=v[(B(k,160)+b|0)+906300>>2];if(a){Db(l+8|0,d,k);if(!Cb(l+8|0)){v[22692]=0;R(1266,d|0,k|0);k=v[22692];v[22692]=0;if((k|0)==1){break Oa}k=v[v[a>>2]+172>>2];v[22692]=0;R(k|0,a|0,-1);k=v[22692];v[22692]=0;if((k|0)==1){break Oa}}k=x[f+2>>1];g=v[v[a>>2]+44>>2];f=x[f+4>>1];v[22692]=0;Aa(g|0,a|0,k|0,C(C(C(f>>>0)*C(.0010010009864345193))));a=v[22692];v[22692]=0;if((a|0)==1){break Oa}}Oj(l+24|0);if(mg(l+24|0,l+16|0)){continue}break}break Ra}if((c|0)==3){break Qa}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2];break Qa}g=250;a=d;e=a;Ta:{while(1){f=1;if(v[e>>2]){break Ta}e=e+4|0;g=g-32|0;if(g>>>0>31){continue}break}f=(v[a+28>>2]&67108863)!=0}if(!f){break Qa}a=0;while(1){Db(l+8|0,d,a);Ua:{if(!Cb(l+8|0)){break Ua}f=v[(B(a,160)+b|0)+906300>>2];k=v[v[f>>2]+176>>2];v[22692]=0;_(k|0,f|0);f=v[22692];v[22692]=0;if((f|0)!=1){break Ua}break c}a=a+1|0;if((a|0)!=250){continue}break}}if(w[$+16|0]==(X|0)){break Pa}v[22692]=0;Pi($,X);a=v[22692];v[22692]=0;if((a|0)==1){break Na}}if(c&9){c=H;b=b+1298224|0;d=b;a=b;if(v[a>>2]){Ec(a);kR(a);gR(a);fm(wb(a),v[a>>2],sg(a));sa=wb(a),ta=0,v[sa>>2]=ta;v[a>>2]=0;v[a+4>>2]=0}dp(d,c);v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];a=wb(c);sa=wb(d),ta=v[a>>2],v[sa>>2]=ta;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;a=b+12|0;Gq(a,v[fc(a)>>2]);b=c+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];fc(b);fc(a);v[a+8>>2]=v[b+8>>2];d=v[wb(a)>>2];c=fc(a);Va:{if(!d){v[a>>2]=c;break Va}sa=v[fc(a)>>2],ta=c,v[sa+8>>2]=ta;sa=b,ta=fc(b),v[sa>>2]=ta;sa=fc(b),ta=0,v[sa>>2]=ta;sa=wb(b),ta=0,v[sa>>2]=ta}}zq(H);DP(q);gb=l+192|0;return}}}}a=P()|0;O()|0;zq(H);break b}a=P()|0;O()|0}DP(q);break a}a=P()|0;O()|0}$m(Z);S(a|0);L()}function q6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=C(0),s=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=0,M=C(0),N=0,O=C(0),P=0,Q=0,R=C(0),S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=C(0),$=0,ba=0,ca=0,da=0,ea=C(0),fa=C(0),ga=C(0),ha=C(0),ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;ba=gb-16|0;gb=ba;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{l=b+e|0;if(w[l|0]!=79|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))!=(w[90056]|w[90057]<<8|(w[90058]<<16|w[90059]<<24))){break f}h=b+26|0;if((h|0)>=(a|0)){break e}j=b+27|0;k=e+h|0;c=w[k|0];if((a|0)<=(j+c|0)){break e}i=c+27|0;f=0;if(c){while(1){i=w[e+(f+j|0)|0]+i|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){o=22;f=ay(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){f=ay(f,0);o=o+1|0;if((o|0)!=26){continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=i-26;v[c+1424>>2]=w[l+22|0]|w[l+23|0]<<8|(w[l+24|0]<<16|w[l+25|0]<<24);f=w[e+(h+w[k|0]|0)|0]==255?-1:w[l+6|0]|w[l+7|0]<<8|(w[l+8|0]<<16|w[l+9|0]<<24);v[c+1436>>2]=h;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){l=d+B(a,20)|0;o=l+1432|0;c=v[o>>2];f=0;j=v[l+1436>>2];h=b-j|0;k=l+1428|0;i=v[k>>2];h=(h|0)<(i|0)?h:i;if((h|0)>=1){while(1){c=ay(c,w[e+(f+j|0)|0]);n=f+1|0;f=n;if((h|0)!=(n|0)){continue}break}}f=i-h|0;v[k>>2]=f;v[o>>2]=c;g:{if(!f){f=c;c=l+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+j|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;l=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=l;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!cJ(a)){v[f>>2]=0;b=0;break a}ia=gb-16|0;gb=ia;h=ba+4|0;j=h;l=a;c=l;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}o=Le(g);if(v[g+96>>2]){break i}if((o|0)!=79){break j}if((Le(g)|0)!=103){break j}if((Le(g)|0)!=103){break j}if((Le(g)|0)!=83){break j}if(!ZI(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;ec(g,32);break i}k=Zx(g);break i}ec(g,30)}if(!k){break h}if(oc(c,1)){ec(c,35);break h}o=ia;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=oc(c,wm(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ia+12>>2]=g;k=c+B(g,6)|0;if(!w[k+412|0]){i=v[c+112>>2];g=i>>1;break m}i=v[c+116>>2];g=i>>1;n=oc(c,1);H=oc(c,1);if(n|!w[k+412|0]){break m}v[j>>2]=i-v[c+112>>2]>>2;j=v[c+112>>2]+i>>2;break l}aa(3379,10482,3137,7975);L()}v[j>>2]=0;j=g}v[o+8>>2]=j;n:{if(!(!w[k+412|0]|H)){g=B(i,3);v[ba+8>>2]=g-v[c+112>>2]>>2;i=g+v[c+112>>2]>>2;break n}v[ba+8>>2]=g}v[ia+4>>2]=i;i=1}if(i){o:{Z=v[h>>2];oa=v[ba+8>>2];na=v[ia+4>>2];qa=h;i=0;Q=gb-2368|0;gb=Q;q=v[l+404>>2];pa=l+B(v[ia+12>>2],6)|0;E=w[pa+413|0];W=q+B(E,40)|0;ca=W;X=v[(l+(w[pa+412|0]<<2)|0)+104>>2];p:{o=v[l+4>>2];q:{if((o|0)>0){while(1){c=w[(v[ca+4>>2]+B(i,3)|0)+2|0];S=(Q+1344|0)+(i<<2)|0;v[S>>2]=0;g=w[(c+W|0)+9|0];if(!x[(l+(g<<1)|0)+132>>1]){ec(l,21);c=0;break q}h=v[l+260>>2];r:{s:{if(oc(l,1)){c=2;k=v[(l+(i<<2)|0)+996>>2];o=h+B(g,1596)|0;F=v[(w[o+1588|0]<<2)+69692>>2];g=wm(F)-1|0;za=k,Aa=oc(l,g),u[za>>1]=Aa;za=k,Aa=oc(l,g),u[za+2>>1]=Aa;j=0;if(w[o|0]){while(1){T=w[(j+o|0)+1|0];h=T+o|0;n=w[h+33|0];g=0;s=w[h+49|0];t:{if(!s){break t}h=v[l+124>>2]+B(w[h+65|0],2096)|0;if(v[l+1396>>2]<=9){jl(l)}m=v[l+1392>>2];g=u[(h+((m&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){D=m;m=w[g+v[h+8>>2]|0];v[l+1392>>2]=D>>>m;P=v[l+1396>>2]-m|0;m=(P|0)<0;v[l+1396>>2]=m?0:P;g=m?-1:g;break u}g=vm(l,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(n){K=-1<<s^-1;h=c+n|0;while(1){m=0;n=u[((o+(T<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((n|0)<0){break v}n=v[l+124>>2]+B(n&65535,2096)|0;if(v[l+1396>>2]<=9){jl(l)}P=v[l+1392>>2];m=u[(n+((P&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){D=P;P=w[m+v[n+8>>2]|0];v[l+1392>>2]=D>>>P;H=v[l+1396>>2]-P|0;P=(H|0)<0;v[l+1396>>2]=P?0:H;m=P?-1:m;break w}m=vm(l,n)}if(!w[n+23|0]){break v}m=v[v[n+2088>>2]+(m<<2)>>2]}g=g>>s;u[k+(c<<1)>>1]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}j=j+1|0;if(j>>>0<w[o|0]){continue}break}}if(v[l+1396>>2]!=-1){break s}}v[S>>2]=1;break r}u[Q+320>>1]=257;j=o+1592|0;c=v[o+1592>>2];if((c|0)>=3){g=2;while(1){h=o+338|0;n=g<<1;s=n+o|0;S=w[s+1088|0];P=S<<1;m=x[h+P>>1];T=w[s+1089|0];K=T<<1;H=u[k+P>>1];s=u[K+k>>1]-H|0;P=s>>31;h=(B(x[h+n>>1]-m|0,P^s+P)|0)/(x[h+K>>1]-m|0)|0;m=H+((s|0)<0?0-h|0:h)|0;P=k+n|0;n=x[P>>1];x:{y:{if(n){t[T+(Q+320|0)|0]=1;t[S+(Q+320|0)|0]=1;t[(Q+320|0)+g|0]=1;h=n<<16>>16;s=F-m|0;if((h|0)>=((m|0)>(s|0)?s:m)<<1){if((m|0)<(s|0)){break x}m=F+(n^-1)|0;break y}if(h&1){m=m-(h+1>>>1|0)|0;break y}m=(h>>1)+m|0;break y}t[(Q+320|0)+g|0]=0}u[P>>1]=m;c=v[j>>2]}g=g+1|0;if((g|0)<(c|0)){continue}break}}m=0;if((c|0)<=0){break r}while(1){if(!w[(Q+320|0)+m|0]){u[k+(m<<1)>>1]=65535;c=v[j>>2]}m=m+1|0;if((m|0)<(c|0)){continue}break}}i=i+1|0;o=v[l+4>>2];if((i|0)<(o|0)){continue}break}}z:{A:{c=v[l+80>>2];if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){hc(Q+320|0,Q+1344|0,o<<2);h=x[W>>1];if(h){j=v[ca+4>>2];m=0;while(1){i=j+B(m,3)|0;g=w[i+1|0];i=(Q+1344|0)+(w[i|0]<<2)|0;if(!(v[(Q+1344|0)+(g<<2)>>2]?v[i>>2]:0)){v[(Q+1344|0)+(g<<2)>>2]=0;v[i>>2]=0}m=m+1|0;if((h|0)!=(m|0)){continue}break}}P=X>>1;la=q+B(E,40)|0;if(w[la+8|0]){c=0;while(1){B:{if((o|0)<1){g=0;break B}i=v[ca+4>>2];m=0;g=0;while(1){if(w[(i+B(m,3)|0)+2|0]==(c|0)){k=g+Q|0;h=m<<2;C:{if(v[h+(Q+1344|0)>>2]){j=1;h=0;break C}j=0;h=v[(h+l|0)+800>>2]}t[k|0]=j;v[(Q+256|0)+(g<<2)>>2]=h;g=g+1|0}m=m+1|0;if((m|0)!=(o|0)){continue}break}}da=Q+256|0;E=Q;J=gb-16|0;gb=J;h=l;H=v[h+4>>2];m=v[h+396>>2];i=w[(c+la|0)+24|0];U=m+B(i,24)|0;k=v[U+4>>2];o=P;ma=x[(h+(i<<1)|0)+268>>1];j=o<<((ma|0)==2);n=j>>>0>k>>>0?k:j;k=v[U>>2];D=(n-(j>>>0>k>>>0?k:j)>>>0)/y[U+8>>2]|0;F=D<<2;j=B(H,F+4|0);V=v[v[h+124>>2]+B(w[U+13|0],2096)>>2];va=v[h+92>>2];D:{if(v[h+80>>2]){j=Xn(h,j);H=v[h+4>>2];break D}j=Cd(j)}k=0;if((H|0)>=1){n=(H<<2)+j|0;while(1){v[(k<<2)+j>>2]=n;n=n+F|0;k=k+1|0;if((H|0)!=(k|0)){continue}break}}F=j;E:{F:{G:{if((g|0)>=1){j=o<<2;k=0;while(1){if(!w[k+E|0]){Qb(v[da+(k<<2)>>2],0,j)}k=k+1|0;if((k|0)!=(g|0)){continue}break}if((g|0)==1|(ma|0)!=2){break G}k=0;while(1){if(!w[k+E|0]){break F}k=k+1|0;if((k|0)!=(g|0)){continue}break}break E}k=0;if((ma|0)==2){break F}}ra=m+B(i,24)|0;wa=ra;xa=(D|0)<1;H=0;while(1){if(!xa){j=0;sa=(g|0)<1;ya=sa|(H|0)!=0;o=0;while(1){k=0;if(!ya){while(1){if(!w[k+E|0]){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){jl(h)}m=v[h+1392>>2];n=u[(i+((m&1023)<<1)|0)+36>>1];H:{if((n|0)>=0){q=m;m=w[n+v[i+8>>2]|0];v[h+1392>>2]=q>>>m;s=v[h+1396>>2]-m|0;m=(s|0)<0;v[h+1396>>2]=m?0:s;n=m?-1:n;break H}n=vm(h,i)}n=w[i+23|0]?v[v[i+2088>>2]+(n<<2)>>2]:n;if((n|0)==-1){break E}v[v[F+(k<<2)>>2]+(j<<2)>>2]=v[v[ra+16>>2]+(n<<2)>>2]}k=k+1|0;if((k|0)!=(g|0)){continue}break}}I:{if((V|0)<1){break I}n=0;if((o|0)>=(D|0)){break I}while(1){k=0;if(!sa){while(1){J:{if(w[k+E|0]){break J}m=k<<2;i=u[(v[wa+20>>2]+(w[v[v[m+F>>2]+(j<<2)>>2]+n|0]<<4)|0)+(H<<1)>>1];if((i|0)<0){break J}S=h;i=v[h+124>>2]+B(i&65535,2096)|0;$=v[m+da>>2];Y=v[U+8>>2];m=v[U>>2]+B(Y,o)|0;K:{L:{M:{if(ma){N=0;T=1;if((Y|0)<=0){break K}while(1){ja=$+(m<<2)|0;K=Y-N|0;s=0;p=C(0);G=WI(S,i);N:{if((G|0)<0){break N}q=i;s=v[i>>2];K=(s|0)<(K|0)?s:K;ka=B(s,G);O:{P:{if(w[i+22|0]){G=0;if((K|0)>0){break P}break O}G=0;if((K|0)<=0){break O}while(1){s=ja+(G<<2)|0;z[s>>2]=z[s>>2]+z[v[q+28>>2]+(G+ka<<2)>>2];s=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}while(1){s=ja+(G<<2)|0;p=C(z[v[q+28>>2]+(G+ka<<2)>>2]+p);z[s>>2]=z[s>>2]+p;p=C(z[q+12>>2]+p);s=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}s=1}if(!s){break M}s=v[i>>2];m=s+m|0;N=s+N|0;if((Y|0)>(N|0)){continue}break}break K}N=0;q=(Y|0)/v[i>>2]|0;if((q|0)<=0){break L}ja=$+(m<<2)|0;while(1){ka=ja+(N<<2)|0;G=Y-(m+N|0)|0;K=q;s=0;p=C(0);ta=WI(S,i);Q:{if((ta|0)<0){break Q}s=1;T=i;$=v[i>>2];ua=(G|0)>($|0)?$:G;if((ua|0)<1){break Q}$=B($,ta);G=0;while(1){s=ka+(B(G,K)<<2)|0;A=C(z[v[T+28>>2]+(G+$<<2)>>2]+p);z[s>>2]=z[s>>2]+A;p=w[T+22|0]?A:p;s=1;G=G+1|0;if((ua|0)!=(G|0)){continue}break}}if(!s){break M}N=N+1|0;if((q|0)!=(N|0)){continue}break}break L}T=0;break K}T=1}if(!T){break E}}k=k+1|0;if((k|0)!=(g|0)){continue}break}}o=o+1|0;n=n+1|0;if((V|0)<=(n|0)){break I}if((o|0)<(D|0)){continue}break}}j=j+1|0;if((o|0)<(D|0)){continue}break}}H=H+1|0;if((H|0)!=8){continue}break}break E}if((g|0)==(k|0)){break E}m=m+B(i,24)|0;s=m;S=(g|0)!=2;E=(D|0)<1;T=(g|0)<3;n=0;while(1){R:{if(!S){k=0;H=0;if(E){break R}while(1){j=v[U>>2]+B(v[U+8>>2],k)|0;v[J+12>>2]=j&1;v[J+8>>2]=j>>1;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){jl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];S:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break S}j=vm(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}T:{if((V|0)<1){break T}i=0;if((k|0)>=(D|0)){break T}while(1){j=v[U+8>>2];q=u[(v[s+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];U:{if((q|0)>=0){if(YI(h,v[h+124>>2]+B(q&65535,2096)|0,da,2,J+12|0,J+8|0,o,j)){break U}break E}j=v[U>>2]+(j+B(j,k)|0)|0;v[J+8>>2]=j>>1;v[J+12>>2]=j&1}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break T}if((k|0)<(D|0)){continue}break}}H=H+1|0;if((k|0)<(D|0)){continue}break}break R}if(T){break R}k=0;H=0;if(E){break R}while(1){i=v[U>>2]+B(v[U+8>>2],k)|0;j=(i|0)/(g|0)|0;v[J+12>>2]=i-B(g,j);v[J+8>>2]=j;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){jl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];V:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break V}j=vm(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}W:{if((V|0)<1){break W}i=0;if((k|0)>=(D|0)){break W}while(1){j=v[U+8>>2];q=u[(v[s+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];X:{if((q|0)>=0){if(YI(h,v[h+124>>2]+B(q&65535,2096)|0,da,g,J+12|0,J+8|0,o,j)){break X}break E}j=v[U>>2]+(j+B(j,k)|0)|0;q=(j|0)/(g|0)|0;v[J+8>>2]=q;v[J+12>>2]=j-B(g,q)}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break W}if((k|0)<(D|0)){continue}break}}H=H+1|0;if((k|0)<(D|0)){continue}break}}n=n+1|0;if((n|0)!=8){continue}break}}if(!v[h+80>>2]){Xb(F)}v[h+92>>2]=va;gb=J+16|0;c=c+1|0;if(c>>>0<w[la+8|0]){o=v[l+4>>2];continue}break}c=v[l+80>>2]}if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){i=x[W>>1];if(i){h=(P|0)>1?P:1;g=l+800|0;while(1){c=i;i=c-1|0;if((X|0)>=2){j=v[ca+4>>2]+B(i,3)|0;o=v[g+(w[j+1|0]<<2)>>2];j=v[g+(w[j|0]<<2)>>2];m=0;while(1){k=m<<2;n=k+o|0;r=z[n>>2];k=j+k|0;p=z[k>>2];Y:{if(!(p<=C(0))){if(!(r<=C(0))){A=C(p-r);break Y}A=p;p=C(r+p);break Y}if(!(r<=C(0))){A=C(r+p);break Y}A=p;p=C(p-r)}z[k>>2]=p;z[n>>2]=A;m=m+1|0;if((h|0)!=(m|0)){continue}break}}if((c|0)>1){continue}break}}m=0;if(v[l+4>>2]<=0){break z}U=P<<2;while(1){g=m<<2;h=g+l|0;c=h;Z:{if(v[g+(Q+320|0)>>2]){Qb(v[c+800>>2],0,U);break Z}g=X;j=v[c+800>>2];T=v[h+996>>2];k=1;c=l;h=w[(W+w[(v[W+4>>2]+B(m,3)|0)+2|0]|0)+9|0];_:{if(!x[(c+(h<<1)|0)+132>>1]){ec(c,21);break _}s=g>>1;F=v[c+260>>2]+B(h,1596)|0;g=B(w[F+1588|0],u[T>>1]);c=0;n=v[F+1592>>2];if((n|0)>=2){G=F+1592|0;J=F+1588|0;while(1){h=w[(k+F|0)+838|0]<<1;i=u[h+T>>1];if((i|0)>=0){i=B(w[J|0],i&65535);h=x[(h+F|0)+338>>1];if((h|0)!=(c|0)){o=j;n=c;E=i-g|0;q=h-c|0;S=(E|0)/(q|0)|0;K=(h|0)>(s|0)?s:h;$:{if((K|0)<=(c|0)){break $}c=o+(n<<2)|0;z[c>>2]=z[c>>2]*z[((g&255)<<2)+69712>>2];c=n+1|0;if((K|0)<=(c|0)){break $}n=E>>31;D=n+E^n;n=S>>31;n=D-B(q,n+S^n)|0;E=(E|0)>-1?1:-1;H=0;while(1){D=o+(c<<2)|0;N=D;p=z[D>>2];H=n+H|0;D=(H|0)<(q|0);g=(g+S|0)+(D?0:E)|0;z[N>>2]=p*z[((g&255)<<2)+69712>>2];H=H-(D?0:q)|0;c=c+1|0;if((K|0)!=(c|0)){continue}break}}n=v[G>>2];c=h}g=i}k=k+1|0;if((n|0)>(k|0)){continue}break}}if((c|0)<(s|0)){p=z[(g<<2)+69712>>2];while(1){g=j+(c<<2)|0;z[g>>2]=z[g>>2]*p;c=c+1|0;if((s|0)!=(c|0)){continue}break}}}}m=m+1|0;c=v[l+4>>2];if((m|0)<(c|0)){continue}break}break A}aa(3379,10482,3319,2726);L()}aa(3379,10482,3286,2726);L()}m=0;if((c|0)<=0){break z}while(1){ca=w[pa+412|0];F=X;V=F>>1;g=V<<2;s=l;ma=v[l+92>>2];o=v[(l+(m<<2)|0)+800>>2];c=V<<2;W=o+c|0;aa:{if(v[l+80>>2]){n=Xn(s,g);break aa}n=Cd(g)}h=(n+c|0)-8|0;i=v[(s+(ca<<2)|0)+1068>>2];ba:{if(F>>>0<2){c=i;break ba}g=o;c=i;while(1){z[h+4>>2]=C(z[c>>2]*z[g>>2])-C(z[c+4>>2]*z[g+8>>2]);z[h>>2]=C(z[c>>2]*z[g+8>>2])+C(z[c+4>>2]*z[g>>2]);c=c+8|0;h=h-8|0;g=g+16|0;if((W|0)!=(g|0)){continue}break}}if(h>>>0>=n>>>0){g=((V<<2)+o|0)-12|0;while(1){z[h+4>>2]=C(z[c+4>>2]*z[g>>2])-C(z[c>>2]*z[g+8>>2]);z[h>>2]=C(z[c>>2]*C(-z[g>>2]))-C(z[c+4>>2]*z[g+8>>2]);g=g-16|0;c=c+8|0;h=h-8|0;if(n>>>0<=h>>>0){continue}break}}da=F>>2;if((F|0)>=16){c=da<<2;h=c+n|0;k=c+o|0;c=(i+(V<<2)|0)-32|0;j=o;g=n;while(1){p=z[g>>2];A=z[h>>2];r=z[g+4>>2];I=z[h+4>>2];z[k+4>>2]=r+I;z[k>>2]=z[g>>2]+z[h>>2];r=C(I-r);p=C(A-p);z[j+4>>2]=C(z[c+16>>2]*r)-C(z[c+20>>2]*p);z[j>>2]=C(z[c+20>>2]*r)+C(z[c+16>>2]*p);p=z[g+8>>2];A=z[h+8>>2];r=z[g+12>>2];I=z[h+12>>2];z[k+12>>2]=r+I;z[k+8>>2]=z[g+8>>2]+z[h+8>>2];r=C(I-r);p=C(A-p);z[j+12>>2]=C(z[c>>2]*r)-C(z[c+4>>2]*p);z[j+8>>2]=C(z[c+4>>2]*r)+C(z[c>>2]*p);g=g+16|0;h=h+16|0;j=j+16|0;k=k+16|0;c=c-32|0;if(i>>>0<=c>>>0){continue}break}}E=wm(F);g=F>>4;k=V-1|0;c=F>>3;h=0-c|0;XI(g,o,k,h,i);XI(g,o,k-da|0,h,i);Y=F>>5;g=0-g|0;_p(Y,o,k,g,i,16);_p(Y,o,k-c|0,g,i,16);_p(Y,o,k-(c<<1)|0,g,i,16);_p(Y,o,k+B(c,-3)|0,g,i,16);j=2;if((E|0)>=10){j=E-4>>>1|0;h=2;while(1){g=h;h=g+1|0;q=2<<g;if((q|0)>=1){S=8<<g;T=F>>g+4;c=0;g=F>>g+2;K=0-(g>>1)|0;while(1){_p(T,o,k-B(c,g)|0,K,i,S);c=c+1|0;if((q|0)!=(c|0)){continue}break}}if((h|0)!=(j|0)){continue}break}}la=E-7|0;if((la|0)>(j|0)){while(1){g=j;j=g+1|0;c=F>>g+6;if((c|0)>=1){T=2<<g;K=8<<g;$=K<<2;H=F>>g+2;U=0-(H>>1)|0;h=i;g=k;while(1){G=o;J=g;D=U;E=h;q=K;N=H;S=T;if((S|0)>=1){ja=E+B(q,12)|0;p=z[ja>>2];ka=q<<3;A=z[ka+E>>2];q=E+(q<<2)|0;r=z[q>>2];I=z[ja+4>>2];M=z[E+(ka|4)>>2];ea=z[q+4>>2];fa=z[E+4>>2];ga=z[E>>2];E=G+(J<<2)|0;G=E+(D<<2)|0;q=0-N<<2;while(1){J=G-4|0;R=z[J>>2];ha=z[G>>2];_=z[E>>2];z[E>>2]=ha+_;D=E-4|0;O=z[D>>2];z[D>>2]=z[J>>2]+O;O=C(O-R);R=C(_-ha);z[J>>2]=C(O*ga)+C(R*fa);z[G>>2]=C(R*ga)-C(O*fa);J=G-12|0;ha=z[J>>2];D=E-8|0;O=z[D>>2];N=D;D=G-8|0;_=z[D>>2];z[N>>2]=_+O;N=E-12|0;R=z[N>>2];z[N>>2]=z[J>>2]+R;R=C(R-ha);O=C(O-_);z[J>>2]=C(R*r)+C(O*ea);z[D>>2]=C(O*r)-C(R*ea);J=G-20|0;ha=z[J>>2];D=E-16|0;O=z[D>>2];N=D;D=G-16|0;_=z[D>>2];z[N>>2]=_+O;N=E-20|0;R=z[N>>2];z[N>>2]=z[J>>2]+R;R=C(R-ha);O=C(O-_);z[J>>2]=C(R*A)+C(O*M);z[D>>2]=C(O*A)-C(R*M);J=G-28|0;ha=z[J>>2];D=E-24|0;O=z[D>>2];N=D;D=G-24|0;_=z[D>>2];z[N>>2]=_+O;N=E-28|0;R=z[N>>2];z[N>>2]=z[J>>2]+R;R=C(R-ha);O=C(O-_);z[J>>2]=C(R*p)+C(O*I);z[D>>2]=C(O*p)-C(R*I);G=q+G|0;E=q+E|0;J=(S|0)>1;S=S-1|0;if(J){continue}break}}g=g-8|0;h=($<<2)+h|0;E=(c|0)>1;c=c-1|0;if(E){continue}break}}if((j|0)!=(la|0)){continue}break}}c=o;g=F;if((0-(Y<<4)|0)<=-1){c=c+(k<<2)|0;h=c-(Y<<6)|0;p=z[i+(g>>3<<2)>>2];while(1){g=c-32|0;r=z[g>>2];I=z[c>>2];z[c>>2]=r+I;j=c-4|0;A=z[j>>2];i=j;j=c-36|0;M=z[j>>2];z[i>>2]=M+A;z[g>>2]=I-r;z[j>>2]=A-M;j=c-8|0;A=z[j>>2];i=j;j=c-40|0;I=z[j>>2];z[i>>2]=I+A;i=c-12|0;r=z[i>>2];k=i;i=c-44|0;M=z[i>>2];z[k>>2]=M+r;r=C(r-M);A=C(A-I);z[j>>2]=C(r+A)*p;z[i>>2]=C(r-A)*p;j=c-20|0;A=z[j>>2];i=c-52|0;r=z[i>>2];k=c-16|0;I=z[k>>2];q=k;k=c-48|0;M=z[k>>2];z[q>>2]=I+M;z[j>>2]=r+A;z[k>>2]=A-r;z[i>>2]=M-I;j=c-60|0;A=z[j>>2];i=c-28|0;r=z[i>>2];k=c-24|0;I=z[k>>2];q=k;k=c-56|0;M=z[k>>2];z[q>>2]=I+M;z[i>>2]=A+r;A=C(r-A);r=C(M-I);z[k>>2]=C(A+r)*p;z[j>>2]=C(r-A)*p;VI(c);VI(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}E=V-4|0;c=(n+(da<<2)|0)-16|0;if(n>>>0<=c>>>0){h=n+(E<<2)|0;g=v[(s+(ca<<2)|0)+1100>>2];while(1){j=(x[g>>1]<<2)+o|0;z[h+12>>2]=z[j>>2];z[h+8>>2]=z[j+4>>2];z[c+12>>2]=z[j+8>>2];z[c+8>>2]=z[j+12>>2];j=(x[g+2>>1]<<2)+o|0;z[h+4>>2]=z[j>>2];z[h>>2]=z[j+4>>2];z[c+4>>2]=z[j+8>>2];z[c>>2]=z[j+12>>2];g=g+4|0;h=h-16|0;c=c-16|0;if(n>>>0<=c>>>0){continue}break}}h=n+(V<<2)|0;i=h-16|0;if(n>>>0<i>>>0){g=v[(s+(ca<<2)|0)+1084>>2];k=h;c=n;while(1){p=z[g+4>>2];j=k-4|0;A=z[j>>2];r=z[c+4>>2];I=C(A+r);M=z[g>>2];ea=z[c>>2];q=k-8|0;fa=z[q>>2];ga=C(ea-fa);O=C(C(p*I)-C(M*ga));A=C(r-A);z[c+4>>2]=O+A;p=C(C(M*I)+C(p*ga));r=C(fa+ea);z[c>>2]=p+r;z[j>>2]=O-A;z[q>>2]=r-p;p=z[g+12>>2];j=k-12|0;A=z[j>>2];r=z[c+12>>2];I=C(A+r);M=z[g+8>>2];ea=z[c+8>>2];fa=z[i>>2];ga=C(ea-fa);O=C(C(p*I)-C(M*ga));A=C(r-A);z[c+12>>2]=O+A;p=C(C(M*I)+C(p*ga));r=C(fa+ea);z[c+8>>2]=p+r;z[i>>2]=r-p;z[j>>2]=O-A;g=g+16|0;c=c+16|0;k=i;i=i-16|0;if(c>>>0<i>>>0){continue}break}}i=h-32|0;if(n>>>0<=i>>>0){c=v[(s+(ca<<2)|0)+1076>>2]+(V<<2)|0;g=(E<<2)+o|0;k=((F<<2)+o|0)-16|0;while(1){p=z[c-4>>2];A=z[h-8>>2];r=z[c-8>>2];I=z[h-4>>2];M=C(C(p*A)-C(r*I));z[o>>2]=M;z[g+12>>2]=-M;p=C(C(r*C(-A))-C(I*p));z[W>>2]=p;z[k+12>>2]=p;p=z[c-12>>2];A=z[h-16>>2];r=z[c-16>>2];I=z[h-12>>2];M=C(C(p*A)-C(r*I));z[o+4>>2]=M;z[g+8>>2]=-M;p=C(C(r*C(-A))-C(I*p));z[W+4>>2]=p;z[k+8>>2]=p;p=z[c-20>>2];A=z[h-24>>2];r=z[c-24>>2];I=z[h-20>>2];M=C(C(p*A)-C(r*I));z[o+8>>2]=M;z[g+4>>2]=-M;p=C(C(r*C(-A))-C(I*p));z[W+8>>2]=p;z[k+4>>2]=p;p=z[c-28>>2];A=z[i>>2];c=c-32|0;r=z[c>>2];I=z[h-28>>2];M=C(C(p*A)-C(r*I));z[o+12>>2]=M;z[g>>2]=-M;p=C(C(r*C(-A))-C(I*p));z[W+12>>2]=p;z[k>>2]=p;k=k-16|0;g=g-16|0;W=W+16|0;o=o+16|0;h=i;i=h-32|0;if(n>>>0<=i>>>0){continue}break}}if(!v[s+80>>2]){Xb(n)}v[s+92>>2]=ma;m=m+1|0;if((m|0)<v[l+4>>2]){continue}break}}$I(l);ca:{if(w[l+1377|0]){v[l+1060>>2]=0-P;t[l+1377|0]=0;v[l+1064>>2]=1;v[l+1412>>2]=X-na;break ca}c=v[l+1412>>2];if(!c){break ca}g=oa-Z|0;if((g|0)<=(c|0)){v[l+1412>>2]=c-g;v[qa>>2]=oa;Z=oa;break ca}Z=c+Z|0;v[qa>>2]=Z;v[l+1412>>2]=0}g=v[l+1064>>2];c=l;da:{ea:{fa:{if(v[c+1388>>2]==v[c+1404>>2]){ga:{if(!g|!(w[l+1375|0]&4)){break ga}g=v[l+1408>>2];h=v[l+1060>>2];if(g>>>0>=h+(na-Z|0)>>>0){break ga}c=g-h|0;c=(c>>>0>g>>>0?0:c)+Z|0;c=(c|0)>(na|0)?na:c;v[ba+12>>2]=c;v[l+1060>>2]=c+v[l+1060>>2];break da}v[l+1064>>2]=1;g=v[l+1408>>2]+(Z-P|0)|0;break fa}if(!g){break ea}g=v[l+1060>>2]}v[c+1060>>2]=(oa-Z|0)+g}if(v[l+84>>2]!=v[l+92>>2]?v[l+80>>2]:0){break p}v[ba+12>>2]=na}c=1}gb=Q+2368|0;break o}aa(3379,10482,3435,2726);L()}}else{c=0}gb=ia+16|0;if(!c){ha:{ia:{ja:{c=v[a+100>>2];switch(c-32|0){case 0:break ia;case 3:break ja;default:break ha}}v[a+100>>2]=0;while(1){if(za=0,Aa=(mh(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ha}v[a+100>>2]=0;while(1){if(za=0,Aa=(mh(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}j=ba;k=v[j+12>>2];F=v[j+4>>2];n=F;g=v[j+8>>2];i=0;ka:{la:{ma:{na:{c=a;o=v[c+992>>2];oa:{if(!o){h=v[c+4>>2];o=0;break oa}X=o<<1;pa:{if((X|0)==v[c+112>>2]){h=l+1092|0}else{h=0;if((X|0)!=v[l+116>>2]){break pa}h=l+1096|0}h=v[h>>2]}l=h;if(!l){break la}h=v[c+4>>2];if((h|0)<=0){break na}X=(o|0)<1;while(1){if(!X){m=c+(i<<2)|0;Q=m;h=0;while(1){Z=v[m+800>>2]+(h+n<<2)|0;s=h<<2;z[Z>>2]=C(z[l+(o+(h^-1)<<2)>>2]*z[s+v[Q+928>>2]>>2])+C(z[l+s>>2]*z[Z>>2]);h=h+1|0;if((o|0)!=(h|0)){continue}break}h=v[c+4>>2]}i=i+1|0;if((i|0)<(h|0)){continue}break}o=v[c+992>>2]}X=k-g|0;v[c+992>>2]=X;if((h|0)>=1){i=0;while(1){if((g|0)<(k|0)){m=c+(i<<2)|0;Q=m;h=0;l=g;while(1){z[v[Q+928>>2]+(h<<2)>>2]=z[v[m+800>>2]+(l<<2)>>2];h=h+1|0;l=g+h|0;if((h|0)!=(X|0)){continue}break}h=v[c+4>>2]}i=i+1|0;if((i|0)<(h|0)){continue}break}}if(!o){break la}break ma}v[c+992>>2]=k-g}h=c;i=v[c+1416>>2];c=((g|0)>(k|0)?k:g)-n|0;v[h+1416>>2]=i+c;break ka}c=0}g=c;v[j+12>>2]=c;l=v[a+4>>2];if((l|0)>=1){c=0;while(1){h=(c<<2)+a|0;v[h+864>>2]=v[h+800>>2]+(F<<2);c=c+1|0;if((l|0)!=(c|0)){continue}break}}if(d){v[d>>2]=l}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}gb=ba+16|0;return b|0}function p6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=0,K=C(0),M=0,N=0,O=0,P=0,Q=0,R=C(0);r=gb-1520|0;gb=r;g=Qb(r+8|0,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;b=0;o=gb-1024|0;gb=o;f=r+8|0;t[f+1377|0]=1;a:{if(!kt(f)){break a}e=w[f+1375|0];if(!(e&2)){ec(f,34);break a}if(e&4){ec(f,34);break a}if(e&1){ec(f,34);break a}if(v[f+1116>>2]!=1){ec(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!$x(f,o+1018|0,6)|w[o+1018|0]!=102|(w[o+1019|0]!=105|w[o+1020|0]!=115)){break b}if(w[o+1021|0]!=104|w[o+1022|0]!=101|w[o+1023|0]!=97){break b}if((Le(f)|0)!=100){break b}if(Le(f)){break b}ec(f,38);break a}ec(f,34);break a}if((Le(f)|0)!=1){ec(f,34);break a}if(!$x(f,o+1018|0,6)){ec(f,10);break a}if(!_x(o+1018|0)){ec(f,34);break a}if(uj(f)){ec(f,34);break a}e=Le(f);v[f+4>>2]=e;if(!e){ec(f,34);break a}if(e>>>0>=17){ec(f,5);break a}e=uj(f);v[f>>2]=e;if(!e){ec(f,34);break a}uj(f);uj(f);uj(f);e=Le(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){ec(f,20);break a}if((e<<24)-1610612736>>24<=-1){ec(f,20);break a}if(g>>>0>h>>>0){ec(f,20);break a}if(!(Le(f)&1)){ec(f,34);break a}if(!kt(f)){break a}if(!Zx(f)){break a}if(!Yx(f)){break a}c:{d:{if((mh(f)|0)==3){while(1){P=(o+1018|0)+b|0,Q=mh(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!_x(o+1018|0)){ec(f,20);break c}g=Xx(f);e=$d(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=mh(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=Xx(f);v[f+24>>2]=b;b=$d(f,b<<2);v[f+28>>2]=b;e=v[f+24>>2];if(!(b?0:(e|0)>=1)){e:{if((e|0)>0){while(1){g=Xx(f);b=$d(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=mh(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(mh(f)&1)){ec(f,20);break c}bJ(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=Yx(f);bJ(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!Zx(f)){break a}if(!cJ(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){g=e<<24;h=0;while(1){g=g>>31&79764919^g<<1;h=h+1|0;if((h|0)!=8){continue}break}v[(e<<2)+459648>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((mh(f)|0)==5){while(1){P=(o+1018|0)+b|0,Q=mh(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!_x(o+1018|0)){ec(f,20);break c}b=oc(f,8)+1|0;v[f+120>>2]=b;b=$d(f,B(b,2096));v[f+124>>2]=b;if(!b){ec(f,3);break c}Qb(b,0,B(v[f+120>>2],2096));f:{g:{h:{i:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((oc(f,8)&255)!=66){ec(f,20);break c}if((oc(f,8)&255)!=67){ec(f,20);break c}if((oc(f,8)&255)!=86){ec(f,20);break c}g=b+B(F,2096)|0;P=g,Q=oc(f,8)&255|oc(f,8)<<8,v[P>>2]=Q;P=g,Q=oc(f,8)&255|(oc(f,8)<<8&65280|oc(f,8)<<16),v[P+4>>2]=Q;b=0;k=oc(f,1);if(!k){b=oc(f,1)}t[g+23|0]=b;q=g+4|0;e=v[q>>2];j:{if(v[g>>2]){h=e;break j}h=0;if(!e){break j}ec(f,20);break c}k:{if(b&255){h=Xn(f,h);break k}h=$d(f,h);v[g+8>>2]=h}if(!h){ec(f,3);break c}l:{if(!k){b=0;j=0;e=v[q>>2];if((e|0)<=0){break l}while(1){m:{n:{if(w[g+23|0]){if(!oc(f,1)){break n}}e=oc(f,5)+1|0;t[b+h|0]=e;if((e&255)!=32){j=j+1|0;break m}ec(f,20);break c}t[b+h|0]=255}b=b+1|0;e=v[q>>2];if((b|0)<(e|0)){continue}break}break l}i=oc(f,5);j=0;b=0;e=v[q>>2];if((e|0)<1){break l}while(1){k=oc(f,wm(e-b|0));i=i+1|0;if((i|0)>=32){ec(f,20);break c}e=b+k|0;if((e|0)>v[q>>2]){ec(f,20);break c}Qb(b+h|0,i,k);b=e;e=v[q>>2];if((b|0)<(e|0)){continue}break}}o:{p:{if(w[g+23|0]){if(e>>2>(j|0)){break p}b=g;k=f;if(v[f+16>>2]<(e|0)){v[f+16>>2]=e;e=v[q>>2]}j=b;b=$d(k,e);v[j+8>>2]=b;if(!b){ec(f,3);break c}hc(b,h,v[q>>2]);tj(f,h,v[q>>2]);h=v[g+8>>2];t[g+23|0]=0;e=v[q>>2]}k=0;b=0;i=0;if((e|0)>=1){while(1){i=((w[b+h|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}}v[g+2092>>2]=i;b=$d(f,e<<2);v[g+32>>2]=b;if(b){l=g+2092|0;break o}ec(f,3);break c}v[g+2092>>2]=j;l=g+2092|0;q:{if(!j){k=0;b=0;break q}b=$d(f,j);v[g+8>>2]=b;if(!b){ec(f,3);break c}b=Xn(f,v[l>>2]<<2);v[g+32>>2]=b;if(!b){ec(f,3);break c}k=Xn(f,v[l>>2]<<2);if(!k){break i}e=v[q>>2];b=v[l>>2]}b=(b<<3)+e|0;if(b>>>0<=y[f+16>>2]){break o}v[f+16>>2]=b}e=g;j=h;m=v[q>>2];p=k;i=0;b=gb-128|0;gb=b;A=Qb(b,0,128);r:{s:{t:{u:{if((m|0)<1){break u}while(1){if(w[i+j|0]!=255){break u}i=i+1|0;if((m|0)!=(i|0)){continue}break}break t}if((i|0)!=(m|0)){break s}}b=1;if(!v[e+2092>>2]){break r}aa(12808,10482,1088,4617);L()}b=i+j|0;UI(e,0,i,0,w[b|0],p);n=w[b|0];if(n){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;s=(b|0)==(n|0);b=b+1|0;if(!s){continue}break}}J=1;s=i+1|0;if((m|0)<=(s|0)){b=1;break r}v:{w:{x:{while(1){y:{i=j+s|0;n=w[i|0];z:{if((n|0)==255){break z}b=n;if(!b){break v}while(1){M=A+(b<<2)|0;G=v[M>>2];if(!G){G=(b|0)>1;b=b-1|0;if(G){continue}break v}break}if(b>>>0>=32){break y}v[M>>2]=0;UI(e,um(G),s,J,n,p);J=J+1|0;i=w[i|0];if((i|0)==(b|0)){break z}if(i>>>0>31){break x}if((b|0)>=(i|0)){break z}while(1){n=A+(i<<2)|0;if(v[n>>2]){break w}v[n>>2]=G+(1<<32-i);i=i-1|0;if((i|0)>(b|0)){continue}break}}b=1;s=s+1|0;if((m|0)!=(s|0)){continue}break r}break}aa(12298,10482,1111,4617);L()}aa(12315,10482,1116,4617);L()}aa(12852,10482,1118,4617);L()}b=0}gb=A+128|0;if(!b){if(w[g+23|0]){tj(f,k,0)}ec(f,20);break c}b=v[l>>2];if(b){b=$d(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){ec(f,3);break c}b=$d(f,(v[l>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){ec(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;p=h;n=k;i=0;m=0;A:{b=g;if(w[b+23|0]){m=v[b+2092>>2];if((m|0)<=0){break A}while(1){e=i<<2;P=e+v[b+2084>>2]|0,Q=um(v[e+v[b+32>>2]>>2]),v[P>>2]=Q;i=i+1|0;m=v[b+2092>>2];if((i|0)<(m|0)){continue}break}break A}if(v[b+4>>2]>=1){while(1){if(TI(b,w[i+p|0])){P=v[b+2084>>2]+(m<<2)|0,Q=um(v[v[b+32>>2]+(i<<2)>>2]),v[P>>2]=Q;m=m+1|0}i=i+1|0;if((i|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(m|0)){break A}aa(4558,10482,1185,7206);L()}FI(v[b+2084>>2],m,2268);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;B:{m=w[b+23|0];G=v[b+(m?2092:4)>>2];if((G|0)<1){break B}e=0;while(1){C:{j=e;i=b;if(m&255){j=v[n+(e<<2)>>2]}M=w[j+p|0];D:{if(!TI(i,M)){break D}O=e<<2;j=um(v[O+v[b+32>>2]>>2]);A=v[b+2084>>2];i=0;m=v[b+2092>>2];if((m|0)>=2){while(1){s=m>>>1|0;N=s+i|0;J=j>>>0<y[A+(N<<2)>>2];i=J?i:N;m=J?s:m-s|0;if((m|0)>1){continue}break}}m=i<<2;if((j|0)!=v[m+A>>2]){break C}if(w[b+23|0]){v[m+v[b+2088>>2]>>2]=v[n+O>>2];t[v[b+8>>2]+i|0]=M;break D}v[m+v[b+2088>>2]>>2]=e}e=e+1|0;if((G|0)==(e|0)){break B}m=w[b+23|0];continue}break}aa(9439,10482,1215,7206);L()}}if(w[g+23|0]){tj(f,k,v[l>>2]<<2);tj(f,v[g+32>>2],v[l>>2]<<2);tj(f,h,v[q>>2]);v[g+32>>2]=0}b=g;Qb(b+36|0,255,2048);e=v[b+(w[b+23|0]?2092:4)>>2];if((e|0)>=1){j=(e|0)<32767?e:32767;k=v[b+8>>2];e=0;while(1){E:{if(w[e+k|0]>10){break E}F:{if(w[b+23|0]){h=um(v[v[b+2084>>2]+(e<<2)>>2]);break F}h=v[v[b+32>>2]+(e<<2)>>2]}if(h>>>0>1023){break E}while(1){u[(b+(h<<1)|0)+36>>1]=e;k=v[b+8>>2];h=(1<<w[k+e|0])+h|0;if(h>>>0<1024){continue}break}}e=e+1|0;if((j|0)!=(e|0)){continue}break}}b=oc(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){ec(f,20);break c}if(b){P=g,R=aJ(oc(f,32)),z[P+12>>2]=R;P=g,R=aJ(oc(f,32)),z[P+16>>2]=R;P=g,Q=oc(f,4)+1|0,t[P+20|0]=Q;P=g,Q=oc(f,1),t[P+22|0]=Q;h=v[g>>2];k=v[q>>2];G:{if(w[g+21|0]==1){I=H(Rw(+C(C(Op(+C(k|0)))/C(h|0))));H:{if(D(I)<2147483648){b=~~I;break H}b=-2147483648}e=b;I=H(dy(+C(C(b|0)+C(1)),h));I:{if(D(I)<2147483648){b=~~I;break I}b=-2147483648}b=e+((b|0)<=(k|0))|0;E=C(b|0);if(dy(+C(E+C(1)),h)<=+(k|0)){b=-1}else{I=H(dy(+E,h));J:{if(D(I)<2147483648){e=~~I;break J}e=-2147483648}b=(e|0)>(k|0)?-1:b}if((b|0)>-1){break G}ec(f,20);break c}b=B(h,k)}v[g+24>>2]=b;if(!b){ec(f,20);break c}e=Xn(f,b<<1);if(!e){break h}b=0;i=v[g+24>>2];if((i|0)>0){while(1){h=oc(f,w[g+20|0]);if((h|0)==-1){tj(f,e,v[g+24>>2]<<1);ec(f,20);break c}u[e+(b<<1)>>1]=h;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}K:{if(w[g+21|0]==1){h=w[g+23|0];L:{if(h){b=v[l>>2];if(b){break L}break K}b=v[q>>2]}b=$d(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){tj(f,e,v[g+24>>2]<<1);ec(f,3);break c}n=v[(h?l:q)>>2];if((n|0)>=1){m=g+2088|0;E=C(0);p=0;while(1){l=p;l=h?v[v[m>>2]+(l<<2)>>2]:l;M:{k=v[g>>2];if((k|0)<1){break M}j=v[g+24>>2];b=1;i=0;while(1){K=C(C(z[g+12>>2]+E)+C(z[g+16>>2]*C(x[e+(((l>>>0)/(b>>>0)>>>0)%(j>>>0)<<1)>>1])));z[v[g+28>>2]+(B(k,p)+i<<2)>>2]=K;E=w[g+22|0]?K:E;i=i+1|0;k=v[g>>2];if((i|0)>=(k|0)){break M}j=v[g+24>>2];jqa(j,0,b,0);if(!jb){b=B(b,j);continue}else{tj(f,e,j<<1);ec(f,20);break c}}}p=p+1|0;if((n|0)!=(p|0)){continue}break}}t[g+21|0]=2;i=v[g+24>>2];break K}b=$d(f,i<<2);v[g+28>>2]=b;i=v[g+24>>2];if(!b){break g}if((i|0)<1){break K}E=C(z[g+12>>2]+C(z[g+16>>2]*C(x[e>>1])));z[b>>2]=E;b=1;i=v[g+24>>2];if((i|0)<=1){break K}K=C(0);while(1){K=w[g+22|0]?E:K;E=C(C(z[g+12>>2]+K)+C(z[g+16>>2]*C(x[e+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=E;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}tj(f,e,i<<1)}F=F+1|0;if((F|0)<v[f+120>>2]){continue}break}}N:{e=oc(f,6)+1&255;if(!e){break N}b=0;while(1){if(!oc(f,16)){b=b+1|0;if((e|0)!=(b|0)){continue}break N}break}ec(f,20);break c}b=oc(f,6)+1|0;v[f+128>>2]=b;b=$d(f,B(b,1596));v[f+260>>2]=b;if(!b){break f}p=0;if(v[f+128>>2]<=0){break d}F=0;O:while(1){b=oc(f,16);u[((p<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(f,20);break c}if(!b){e=v[f+260>>2]+B(p,1596)|0;P=e,Q=oc(f,8),t[P|0]=Q;P=e,Q=oc(f,16),u[P+2>>1]=Q;P=e,Q=oc(f,16),u[P+4>>1]=Q;P=e,Q=oc(f,6),t[P+6|0]=Q;P=e,Q=oc(f,8),t[P+7|0]=Q;b=(oc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){P=b+g|0,Q=oc(f,8),t[P|0]=Q;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}ec(f,4);break c}l=v[f+260>>2]+B(p,1596)|0;g=oc(f,5);t[l|0]=g;b=-1;i=0;e=0;if(g&255){while(1){g=oc(f,4);t[(e+l|0)+1|0]=g;g=g&255;b=(b|0)<(g|0)?g:b;e=e+1|0;if(e>>>0<w[l|0]){continue}break}while(1){g=i+l|0;P=g,Q=oc(f,3)+1|0,t[P+33|0]=Q;e=oc(f,2);t[g+49|0]=e;P:{if(e&255){e=oc(f,8);t[g+65|0]=e;if(v[f+120>>2]<=(e&255)){ec(f,20);break c}if(w[g+49|0]==31){break P}}e=0;while(1){Q:{h=oc(f,8)-1|0;u[((l+(i<<4)|0)+(e<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break Q}e=e+1|0;if((e|0)<1<<w[g+49|0]){continue}break P}break}ec(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}h=2;P=l,Q=oc(f,2)+1|0,t[P+1588|0]=Q;b=oc(f,4);v[l+1592>>2]=2;k=0;u[l+338>>1]=0;t[l+1589|0]=b;u[l+340>>1]=1<<b;n=l+1592|0;j=w[l|0];R:{if(j){b=l+1589|0;while(1){e=0;g=l+w[(k+l|0)+1|0]|0;if(w[g+33|0]){while(1){h=oc(f,w[b|0]);u[(l+(v[n>>2]<<1)|0)+338>>1]=h;h=v[n>>2]+1|0;v[n>>2]=h;e=e+1|0;if(e>>>0<w[g+33|0]){continue}break}j=w[l|0]}k=k+1|0;if(k>>>0<(j&255)>>>0){continue}break}if((h|0)<=0){break R}}e=0;while(1){b=x[(l+(e<<1)|0)+338>>1];g=(o+16|0)+(e<<2)|0;u[g+2>>1]=e;u[g>>1]=b;e=e+1|0;h=v[n>>2];if((e|0)<(h|0)){continue}break}}k=l+338|0;FI(o+16|0,h,2267);e=0;h=v[n>>2];b=h-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(e|0)){e=0;S:{if((h|0)<=0){break S}while(1){t[(e+l|0)+838|0]=w[((o+16|0)+(e<<2)|0)+2|0];e=e+1|0;h=v[n>>2];if((e|0)<(h|0)){continue}break}e=2;if((h|0)<=2){break S}while(1){v[o+12>>2]=0;v[o+8>>2]=0;b=k;h=0;g=e;if((e|0)>=1){i=b+(g<<1)|0;m=-1;q=65536;while(1){A=b+(h<<1)|0;j=x[A>>1];if(!((m|0)>=(j|0)|x[i>>1]<=j>>>0)){v[o+12>>2]=h;j=x[A>>1];m=j}if(!((j|0)>=(q|0)|x[i>>1]>=j>>>0)){v[o+8>>2]=h;q=x[A>>1]}h=h+1|0;if((g|0)!=(h|0)){continue}break}}b=l+(e<<1)|0;t[b+1088|0]=v[o+12>>2];t[b+1089|0]=v[o+8>>2];e=e+1|0;h=v[n>>2];if((e|0)<(h|0)){continue}break}}F=(h|0)>(F|0)?h:F;p=p+1|0;if((p|0)<v[f+128>>2]){continue O}p=F<<1;break d}g=x[(o+16|0)+(e<<2)>>1];e=e+1|0;if((g|0)!=x[(o+16|0)+(e<<2)>>1]){continue}break}break}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}tj(f,e,i<<1);ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}b=oc(f,6)+1|0;v[f+264>>2]=b;b=$d(f,B(b,24));v[f+396>>2]=b;if(!b){ec(f,3);break c}l=0;Qb(b,0,B(v[f+264>>2],24));T:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=oc(f,16);u[((l<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){ec(f,20);break c}h=b+B(l,24)|0;P=h,Q=oc(f,24),v[P>>2]=Q;b=oc(f,24);v[h+4>>2]=b;if(b>>>0<y[h>>2]){ec(f,20);break c}P=h,Q=oc(f,24)+1|0,v[P+8>>2]=Q;P=h,Q=oc(f,6)+1|0,t[P+12|0]=Q;b=oc(f,8);t[h+13|0]=b;U:{V:{if(v[f+120>>2]>(b&255)){b=0;if(w[h+12|0]){break V}e=0;break U}ec(f,20);break c}while(1){g=(o+16|0)+b|0;e=oc(f,3);if(oc(f,1)){j=oc(f,5)}else{j=0}t[g|0]=e+(j<<3);b=b+1|0;e=w[h+12|0];if(b>>>0<e>>>0){continue}break}}b=$d(f,e<<4);v[h+20>>2]=b;if(!b){break T}if(w[h+12|0]){k=0;while(1){e=w[(o+16|0)+k|0];b=0;while(1){W:{if(e>>>b&1){g=oc(f,8);n=b<<1;j=k<<4;u[n+(j+v[h+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[n+(j+v[h+20>>2]|0)>>1]){break W}ec(f,20);break c}u[(v[h+20>>2]+(k<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if(k>>>0<w[h+12|0]){continue}break}}b=$d(f,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);v[h+16>>2]=b;if(!b){ec(f,3);break c}j=0;Qb(b,0,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];e=w[h+13|0];if(v[(b+B(e,2096)|0)+4>>2]>0){while(1){g=v[B(e,2096)+b>>2];b=$d(f,g);k=j<<2;v[k+v[h+16>>2]>>2]=b;X:{e=v[k+v[h+16>>2]>>2];if(e){if((g|0)<1){break X}b=g-1|0;t[e+b|0]=(j>>>0)%w[h+12|0];e=j;if((g|0)==1){break X}while(1){g=b-1|0;n=w[h+12|0];e=(e|0)/(n|0)|0;t[g+v[k+v[h+16>>2]>>2]|0]=(e|0)%(n|0);n=(b|0)>1;b=g;if(n){continue}break}break X}ec(f,3);break c}j=j+1|0;b=v[f+124>>2];e=w[h+13|0];if((j|0)<v[(b+B(e,2096)|0)+4>>2]){continue}break}}l=l+1|0;if((l|0)<v[f+264>>2]){continue}break}}b=oc(f,6)+1|0;v[f+400>>2]=b;b=$d(f,B(b,40));v[f+404>>2]=b;if(!b){ec(f,3);break c}k=0;Qb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(oc(f,16)){ec(f,20);break c}g=b+B(k,40)|0;b=$d(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){ec(f,3);break c}b=g;if(oc(f,1)){e=oc(f,4)+1|0}else{e=1}t[b+8|0]=e;Y:{if(oc(f,1)){b=oc(f,8)+1|0;u[g>>1]=b;Z:{e=v[f+4>>2];b=b&65535;if((e|0)>=(b|0)){j=0;if(b){break Z}break Y}ec(f,20);break c}while(1){e=oc(f,wm(e-1|0));b=B(j,3);t[b+v[g+4>>2]|0]=e;e=oc(f,wm(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=e;e=v[f+4>>2];b=b+v[g+4>>2]|0;h=w[b|0];if((e|0)<=(h|0)){ec(f,20);break c}b=w[b+1|0];if((b|0)>=(e|0)){ec(f,20);break c}if((b|0)!=(h|0)){j=j+1|0;if(j>>>0>=x[g>>1]){break Y}continue}break}ec(f,20);break c}u[g>>1]=0}if(oc(f,2)){ec(f,20);break c}h=v[f+4>>2];_:{$:{b=w[g+8|0];if(b>>>0<=1){e=0;if((h|0)>0){while(1){t[(v[g+4>>2]+B(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break _}break $}e=0;if((h|0)<=0){break $}while(1){aa:{b=oc(f,4);h=B(e,3);t[(h+v[g+4>>2]|0)+2|0]=b;if(w[(h+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break aa}e=e+1|0;if((e|0)<v[f+4>>2]){continue}break $}break}ec(f,20);break c}b=0;while(1){oc(f,8);h=b+g|0;e=h;P=e,Q=oc(f,8),t[P+9|0]=Q;h=oc(f,8);t[e+24|0]=h;if(v[f+128>>2]<=w[e+9|0]){ec(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break _}continue}break}ec(f,20);break c}k=k+1|0;if((k|0)<v[f+400>>2]){continue}break}}b=oc(f,6)+1|0;v[f+408>>2]=b;e=0;ba:{if((b|0)<=0){break ba}while(1){b=B(e,6)+f|0;P=b,Q=oc(f,1),t[P+412|0]=Q;P=b,Q=oc(f,16),u[P+414>>1]=Q;P=b,Q=oc(f,16),u[P+416>>1]=Q;g=oc(f,8);t[b+413|0]=g;if(x[b+414>>1]){ec(f,20);break c}if(x[b+416>>1]){ec(f,20);break c}if(v[f+400>>2]>(g&255)){e=e+1|0;if((e|0)>=v[f+408>>2]){break ba}continue}break}ec(f,20);break c}$I(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;P=e,Q=$d(f,v[f+116>>2]<<2),v[P+800>>2]=Q;P=e,Q=$d(f,v[f+116>>2]<<1&2147483646),v[P+928>>2]=Q;g=$d(f,p);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){ec(f,3);break c}Qb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!_I(f,0,v[f+112>>2])){break a}if(!_I(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;N=f;l=h<<1&2147483646;p=l;n=v[f+264>>2];if((n|0)<1){e=4}else{i=v[f+396>>2];h=0;j=0;while(1){k=i+B(j,24)|0;m=v[k+4>>2];e=g>>>0>m>>>0?m:g;m=v[k>>2];k=(e-(g>>>0>m>>>0?m:g)>>>0)/y[k+8>>2]|0;h=(h|0)<(k|0)?k:h;j=j+1|0;if((n|0)!=(j|0)){continue}break}e=(h<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<l>>>0?p:e;v[N+12>>2]=e;ca:{da:{if(!v[f+80>>2]){break da}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break ca}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break da}ec(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}aa(4385,10482,4182,5945);L()}ec(f,3)}b=0}gb=o+1024|0;ea:{fa:{if(!b){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break fa}b=$d(r+8|0,1512);if(b){P=c,Q=v[hc(b,r+8|0,1512)+32>>2]-a|0,v[P>>2]=Q;v[d>>2]=0;break ea}dJ(r+8|0)}b=0}gb=r+1520|0;return b|0}function cZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-400|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Jh(b,d+392|0)){break D}if(!xD(d+392|0)){break D}if(!c){p=1;break D}q=Fh(d+368|0,b);v[22692]=0;R(404,d+352|0,q|0);b=v[22692];v[22692]=0;E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[22692]=0;U(405,d+208|0,d+352|0,1229866575);b=v[22692];v[22692]=0;if((b|0)==1){break J}v[22692]=0;p=Q(406,d+208|0,d+336|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break L}xb(d+208|0);if(!p){break E}v[22692]=0;R(367,a|0,524288);b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;yg(a);b=v[22692];v[22692]=0;if((b|0)!=1){break K}break c}e=P()|0;O()|0;break a}e=P()|0;O()|0;xb(d+208|0);break b}v[a+480208>>2]=12;H=a,I=Gd(Ib(w[d+344|0]|w[d+345|0]<<8),1,127),u[H+480188>>1]=I;H=d,I=Ib(w[d+336|0]|w[d+337|0]<<8),u[H+208>>1]=I;v[22692]=0;u[d+312>>1]=255;b=Pc(d+208|0,d+312|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+336|2;H=d,I=Ib(w[b|0]|w[b+1|0]<<8),u[H+208>>1]=I;v[22692]=0;u[d+312>>1]=3999;b=Pc(d+208|0,d+312|0);f=v[22692];v[22692]=0;if((f|0)==1){break e}u[a+480190>>1]=x[b>>1];v[22692]=0;b=a+1074312|0;W(409,b|0,6,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}v[22692]=0;Q(410,b|0,21)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}v[22692]=0;Q(410,b|0,13)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;b=Q(2,d+208|0,6393)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}Eb(a+1298304|0,b);vb(b);v[22692]=0;b=Q(2,d+208|0,7541)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}Eb(a+1298316|0,b);vb(b);v[22692]=0;R(411,d+312|0,1445);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;R(412,d+288|0,d+392|4);b=v[22692];v[22692]=0;if((b|0)==1){break j}v[22692]=0;R(412,d+264|0,d+392|5);b=v[22692];v[22692]=0;if((b|0)==1){break l}v[22692]=0;Y(134,d+208|0,d+312|0,d+288|0,d+264|0);b=v[22692];v[22692]=0;if((b|0)==1){break m}Eb(a+1298328|0,d+208|0);vb(d+208|0);vb(d+264|0);vb(d+288|0);Hb(d+312|0);v[a+1298364>>2]=2;v[22692]=0;U(405,d+312|0,d+352|0,1312902469);b=v[22692];v[22692]=0;if((b|0)==1){break n}v[22692]=0;b=T(193,d+312|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break p}v[22692]=0;f=a+1298268|0;W(413,d+312|0,f|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break p}v[22692]=0;U(405,d+288|0,d+352|0,1397706311);b=v[22692];v[22692]=0;if((b|0)==1){break q}b=a+484360|0;Vl(Sb(b));M:{g=d+336|4;g=Ib(w[g|0]|w[g+1|0]<<8);N:{if(!g){break N}while(1){v[22692]=0;i=Q(189,d+288|0,46)|0;k=v[22692];v[22692]=0;O:{if((k|0)!=1){if(!i){break N}v[22692]=0;R(414,d+288|0,d+208|0);i=v[22692];v[22692]=0;if((i|0)!=1){if(!ed(f)){break O}v[22692]=0;Q(415,f|0,d+208|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break O}}e=P()|0;O()|0;break r}e=P()|0;O()|0;break r}v[22692]=0;i=T(416,d+288|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break M}if(!bd(Sb(b))){v[22692]=0;k=T(417,b|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break M}if((k|0)==255){break N}}k=Sb(b);v[22692]=0;U(6,d+264|0,2,d+208|0);j=v[22692];v[22692]=0;if((j|0)==1){break s}v[22692]=0;R(418,k|0,d+264|0);k=v[22692];v[22692]=0;if((k|0)==1){break t}vb(d+264|0);k=Sb(b);v[22692]=0;U(419,k|0,d+288|0,i|0);i=v[22692];v[22692]=0;if((i|0)==1){break M}e=e+1|0;if(g>>>0>(e&65535)>>>0){continue}break}}v[22692]=0;Pi(b,0);b=v[22692];v[22692]=0;if((b|0)==1){break u}v[22692]=0;U(405,d+264|0,d+352|0,1229869908);b=v[22692];v[22692]=0;if((b|0)==1){break v}v[22692]=0;b=T(421,d+264|0)|0;e=v[22692];v[22692]=0;P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)==1){break W}X:{Y:{Z:{_:{$:{aa:{if(!b){break aa}if(x[a+480192>>1]){e=1;while(1){v[22692]=0;R(422,d+264|0,d+208|0);b=v[22692];v[22692]=0;ba:{ca:{da:{if((b|0)!=1){b=Ib(w[d+238|0]|w[d+239|0]<<8);v[22692]=0;b=W(376,a|0,e&65535,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break da}if(!b){break ba}if(Ib(w[d+238|0]|w[d+239|0]<<8)>>>0>3999){break ba}v[22692]=0;Hr(d+96|0,2,d+208|0);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;R(324,d+120|0,d+96|0);f=v[22692];v[22692]=0;if((f|0)!=1){break ca}}e=P()|0;O()|0;break V}e=P()|0;O()|0;break V}e=P()|0;O()|0;break V}v[22692]=0;Q(301,b+492|0,d+120|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break $}vb(d+120|0);v[22692]=0;Hr(d+96|0,2,d+208|0);f=v[22692];v[22692]=0;if((f|0)==1){break _}v[22692]=0;R(324,d+120|0,d+96|0);f=v[22692];v[22692]=0;if((f|0)==1){break _}f=Ib(w[d+238|0]|w[d+239|0]<<8);v[22692]=0;Q(301,((f<<5)+a|0)+946304|0,d+120|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Z}vb(d+120|0);v[b>>2]=0;H=b,I=Ib(w[d+254|0]|w[d+255|0]<<8)+128&65535,v[H+8>>2]=I;tc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=Ib(w[d+238|0]|w[d+239|0]<<8);v[22692]=0;b=B(b,104)+a|0;R(424,b+484380|0,0);f=v[22692];v[22692]=0;if((f|0)==1){break Y}H=d,I=Ib(w[d+240|0]|w[d+241|0]<<8),u[H+120>>1]=I;v[22692]=0;u[d+96>>1]=64;f=Pc(d+120|0,d+96|0);g=v[22692];v[22692]=0;if((g|0)==1){break X}u[b+484410>>1]=x[f>>1]<<2;H=b+484404|0,I=Yb(w[d+242|0]|w[d+243|0]<<8|(w[d+244|0]<<16|w[d+245|0]<<24)),v[H>>2]=I;if(!Yb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))){break ba}if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&3)){break ba}f=Yb(w[d+246|0]|w[d+247|0]<<8|(w[d+248|0]<<16|w[d+249|0]<<24));v[b+484384>>2]=f;H=b+484388|0,I=Yb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))+f|0,v[H>>2]=I;b=b+484414|0;u[b>>1]=x[b>>1]|2;if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&2)){break ba}u[b>>1]=x[b>>1]|4}e=e+1|0;if(x[a+480192>>1]>=(e&65535)>>>0){continue}break}}v[22692]=0;U(405,d+184|0,d+352|0,1447382614);b=v[22692];v[22692]=0;if((b|0)==1){break W}b=v[d+196>>2];v[d+40>>2]=v[d+192>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+200>>2];v[22692]=0;b=v[d+188>>2];v[d+32>>2]=v[d+184>>2];v[d+36>>2]=b;Y(425,d+32|0,0,a|0,0);b=v[22692];v[22692]=0;if((b|0)==1){break W}v[22692]=0;U(405,d+160|0,d+352|0,1346719318);b=v[22692];v[22692]=0;if((b|0)==1){break W}b=v[d+172>>2];v[d+16>>2]=v[d+168>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+176>>2];v[22692]=0;b=v[d+164>>2];v[d+8>>2]=v[d+160>>2];v[d+12>>2]=b;Y(425,d+8|0,1,a|0,w[d+396|0]>2|0);b=v[22692];v[22692]=0;if((b|0)==1){break W}if(!x[a+480192>>1]){break aa}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}xb(d+264|0);v[22692]=0;U(405,d+208|0,d+352|0,1346458708);b=v[22692];v[22692]=0;if((b|0)==1){break U}v[22692]=0;b=T(275,d+208|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break T}if(!b|!(c&1)){break I}v[22692]=0;U(405,d+264|0,d+352|0,1347305805);b=v[22692];v[22692]=0;if((b|0)==1){break S}v[22692]=0;Q(318,d+264|0,1)|0;b=v[22692];v[22692]=0;if((b|0)==1){break R}i=d+336|6;b=Ib(w[i|0]|w[i+1|0]<<8);v[22692]=0;k=a+484344|0;R(330,k|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break R}b=cd(d+144|0);if(Ib(w[i|0]|w[i+1|0]<<8)){break Q}break P}e=P()|0;O()|0;vb(d+120|0);break V}e=P()|0;O()|0;break V}e=P()|0;O()|0;vb(d+120|0);break V}e=P()|0;O()|0;break V}e=P()|0;O()|0;break V}e=P()|0;O()|0}xb(d+264|0);break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break x}z=d+96|5;A=d+96|3;C=d+96|4;D=d+96|2;E=d+96|1;while(1){v[22692]=0;y=T(416,d+208|0)|0;e=v[22692];v[22692]=0;ea:{fa:{ga:{ha:{ia:{if((e|0)!=1){v[22692]=0;e=T(426,d+208|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ia}v[22692]=0;U(288,d+96|0,d+208|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break ha}f=jc(d+120|0,d+96|0);xb(d+96|0);v[22692]=0;e=W(331,k|0,m&65535,y|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ga}if(!e){break ea}o=Kb(d+80|0);v[22692]=0;U(427,d+264|0,o|0,-1);e=v[22692];v[22692]=0;if((e|0)!=1){e=_b(k,m);v[22692]=0;Q(428,e|0,o|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break fa}}break A}e=P()|0;O()|0;break y}e=P()|0;O()|0;break y}e=P()|0;O()|0;break y}e=P()|0;O()|0;break z}e=_b(k,m);v[22692]=0;e=Rf(e,0);g=v[22692];v[22692]=0;if((g|0)==1){break A}Pd(b);n=0;ja:{while(1){v[22692]=0;g=Q(189,d+120|0,1)|0;j=v[22692];v[22692]=0;ka:{la:{ma:{if((j|0)!=1){if(!g){break ja}v[22692]=0;j=T(374,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break A}if(j){break la}H=d,I=Vb(b),v[H+72>>2]=I;H=d,I=Zb(b),v[H+64>>2]=I;if(Gb(d+72|0,d- -64|0)){break ma}break ka}break A}while(1){na:{e=v[d+72>>2];g=_b(k,m);j=w[e+1|0];e=w[e|0];v[22692]=0;e=Be(d+96|0,e,j);j=v[22692];v[22692]=0;if((j|0)==1){break na}e=Se(e,n);v[22692]=0;Q(431,g|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break na}Jv(d+72|0);if(Gb(d+72|0,d- -64|0)){continue}break ka}break}break A}Eh(d+96|0);r=x[a+480188>>1];v[22692]=0;g=T(374,f|0)|0;h=v[22692];v[22692]=0;oa:{pa:{if((h|0)!=1){s=j-1|0;qa:{if(!(g&1)){break qa}v[22692]=0;h=T(374,f|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break A}if(!h){break qa}l=j>>>0>r>>>0?d+96|0:B(s,6)+e|0;if((h|0)!=31){if(h>>>0>253){break qa}h=(B(h>>>4|0,12)+(h&15)|0)+13|0}else{h=255}t[l|0]=h}if(!(g&2)){break oa}v[22692]=0;h=T(374,f|0)|0;l=v[22692];v[22692]=0;if((l|0)!=1){break pa}}break A}t[(j>>>0>r>>>0?E:(B(s,6)+e|0)+1|0)|0]=h}if(!(g&60)){continue}t[d+63|0]=0;t[d+62|0]=0;t[d+61|0]=0;t[d+60|0]=0;if(g&4){v[22692]=0;h=T(374,f|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break A}t[d+62|0]=h}if(g&8){v[22692]=0;h=T(374,f|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break A}t[d+60|0]=h}if(g&16){v[22692]=0;h=T(374,f|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break A}t[d+63|0]=h}if(g&32){v[22692]=0;g=T(374,f|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break A}t[d+61|0]=g}vD(d+63|0,d+61|0);vD(d+62|0,d+60|0);g=w[d+62|0];if(!(w[d+63|0]==13|g?(g|0)!=13:0)){Dh(d+63|0,d+62|0);Dh(d+61|0,d+60|0)}v[22692]=0;mo(d- -64|0,d+63|0,d+61|0,d+62|0,d+60|0);g=v[22692];v[22692]=0;ra:{if((g|0)==1){break ra}v[22692]=0;g=jz(w[d+64|0],w[d+65|0]);h=v[22692];v[22692]=0;if((h|0)==1){break ra}sa:{if(!g){break sa}H=d,I=Vb(b),v[H+72>>2]=I;Hd(d+56|0,d+72|0);v[22692]=0;U(434,b|0,v[d+56>>2],d- -64|0);g=v[22692];v[22692]=0;if((g|0)!=1){break sa}break A}g=B(s,6)+e|0;j=j>>>0>r>>>0;t[(j?D:g+2|0)|0]=w[d+63|0];t[(j?C:g+4|0)|0]=w[d+61|0];h=w[d+62|0];t[(j?A:g+3|0)|0]=h;t[(j?z:g+5|0)|0]=w[d+60|0];if((h|0)==43){F=1;continue}if((h|0)!=31){continue}G=1;continue}break A}Pd(b);n=n+1|0;if(y>>>0<=n>>>0){break ja}e=_b(k,m);v[22692]=0;e=Rf(e,n);g=v[22692];v[22692]=0;if((g|0)!=1){continue}break}break A}vb(o)}xb(d+120|0);m=m+1|0;if(Ib(w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break}}Gv(b);xb(d+264|0);if(!(c&4)){break G}f=0;if(!F){break H}e=x[a+480188>>1];if(!e){f=1;break H}b=0;while(1){f=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((e|0)!=(b|0)){continue}break}break H}e=P()|0;O()|0;break r}e=P()|0;O()|0;break b}f=0;if(!(c&4)){break F}}v[d+120>>2]=-1778364416;v[d+124>>2]=-16756736;v[22692]=0;U(405,d+264|0,d+352|0,1146310725);b=v[22692];v[22692]=0;ta:{ua:{va:{wa:{xa:{ya:{if((b|0)!=1){v[22692]=0;b=T(421,d+264|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break va}if(!b){break xa}v[22692]=0;g=T(416,d+264|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break va}if(g){break ya}e=f;break wa}e=P()|0;O()|0;break w}b=0;e=f;while(1){v[22692]=0;m=T(374,d+264|0)|0;i=v[22692];v[22692]=0;za:{Aa:{if((i|0)!=1){if(x[a+480188>>1]<=b>>>0){break za}if(!f){break Aa}i=((b<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-67108865|((m|0)!=0)<<26;break za}break va}if(m){break za}e=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break wa}xb(d+264|0);if(!f){break G}break ta}v[22692]=0;Q(435,d+264|0,d+120|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break ua}}e=P()|0;O()|0;xb(d+264|0);break w}xb(d+264|0);if(!(e&1)){break G}}v[22692]=0;_(436,a+906300|0);b=v[22692];v[22692]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((b|0)==1){break Ga}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22692]=0;v[d+264>>2]=0;b=a+906332|0;uD(b,b+16|0,d+264|0);b=v[22692];v[22692]=0;if((b|0)==1){break Fa}v[22692]=0;b=Q(70,d+264|0,6667)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Ea}v[22692]=0;Hv(a+906348|0,b);e=v[22692];v[22692]=0;if((e|0)==1){break Da}vb(b);v[22692]=0;b=Q(70,d+264|0,6631)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Ca}v[22692]=0;Fr(a+906380|0,b);e=v[22692];v[22692]=0;if((e|0)==1){break Ba}vb(b);v[22692]=0;b=a+906304|0;R(440,b|0,8);e=v[22692];v[22692]=0;if((e|0)==1){break Ga}PY(d+264|0,w[d+121|0],w[d+123|0],w[d+125|0],w[d+127|0]);e=v[d+268>>2];b=v[b>>2];f=v[d+264>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break G}e=P()|0;O()|0;break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;vb(b);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;vb(b);break w}if(!G){break F}b=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{while(1){cb:{v[d+80>>2]=B(b,127)>>>5;v[22692]=0;R(441,d+120|0,1202);e=v[22692];v[22692]=0;if((e|0)==1){break cb}v[22692]=0;R(442,d+96|0,d+80|0);e=v[22692];v[22692]=0;if((e|0)==1){break bb}v[22692]=0;U(443,d+264|0,d+120|0,d+96|0);e=v[22692];v[22692]=0;if((e|0)==1){break ab}v[22692]=0;e=(b<<5)+a|0;R(444,d+144|0,e+902204|0);f=v[22692];v[22692]=0;if((f|0)==1){break $a}v[22692]=0;Q(401,d+144|0,d+264|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break $a}vb(d+264|0);vb(d+96|0);Hb(d+120|0);v[22692]=0;R(441,d+120|0,1184);f=v[22692];v[22692]=0;if((f|0)==1){break Ya}v[22692]=0;R(442,d+96|0,d+80|0);f=v[22692];v[22692]=0;if((f|0)==1){break Xa}v[22692]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22692];v[22692]=0;if((f|0)==1){break Wa}v[22692]=0;R(444,d+144|0,e+903228|0);f=v[22692];v[22692]=0;if((f|0)==1){break Va}v[22692]=0;Q(401,d+144|0,d+264|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Va}vb(d+264|0);vb(d+96|0);Hb(d+120|0);v[22692]=0;R(441,d+120|0,1175);f=v[22692];v[22692]=0;if((f|0)==1){break Sa}v[22692]=0;R(442,d+96|0,d+80|0);f=v[22692];v[22692]=0;if((f|0)==1){break Ra}v[22692]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22692];v[22692]=0;if((f|0)==1){break Qa}v[22692]=0;R(444,d+144|0,e+904252|0);f=v[22692];v[22692]=0;if((f|0)==1){break Pa}v[22692]=0;Q(401,d+144|0,d+264|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Pa}vb(d+264|0);vb(d+96|0);Hb(d+120|0);v[22692]=0;R(441,d+120|0,1148);f=v[22692];v[22692]=0;if((f|0)==1){break Ma}v[22692]=0;R(442,d+96|0,d+80|0);f=v[22692];v[22692]=0;if((f|0)==1){break La}v[22692]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22692];v[22692]=0;if((f|0)==1){break Ka}v[22692]=0;R(444,d+144|0,e+905276|0);e=v[22692];v[22692]=0;if((e|0)==1){break Ja}v[22692]=0;Q(401,d+144|0,d+264|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Ja}vb(d+264|0);vb(d+96|0);Hb(d+120|0);b=b+1|0;if((b|0)!=32){continue}break F}break}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Za}e=P()|0;O()|0;break _a}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Ta}e=P()|0;O()|0;break Ua}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Na}e=P()|0;O()|0;break Oa}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Ha}e=P()|0;O()|0;break Ia}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}v[22692]=0;U(405,d+264|0,d+352|0,1397575756);b=v[22692];v[22692]=0;if((b|0)==1){break B}v[22692]=0;b=T(275,d+264|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break C}if(!(!x[a+480190>>1]|(!b|!(c&2)))){f=1;e=1;while(1){v[22692]=0;b=T(426,d+264|0)|0;c=v[22692];v[22692]=0;db:{if((c|0)!=1){v[22692]=0;c=T(426,d+264|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break C}if(!(b&7)){break db}f=(B(f,104)+a|0)+484380|0;v[f>>2]=c;b=Rc(d+120|0,b&4?32:b&2?16:8,1,1,0);v[22692]=0;W(329,b|0,f|0,d+264|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break db}break C}break C}e=e+1|0;f=e&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}xb(d+264|0);xb(d+208|0);xb(d+288|0);xb(d+312|0)}Ed(d+352|0);xb(q)}gb=d+400|0;return p|0}e=P()|0;O()|0;xb(d+264|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;vb(o)}xb(d+120|0)}Gv(b)}xb(d+264|0)}xb(d+208|0);break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;vb(d+264|0);break r}e=P()|0;O()|0}xb(d+288|0);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0}xb(d+312|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+264|0);break k}e=P()|0;O()|0}vb(d+288|0);break i}e=P()|0;O()|0}Hb(d+312|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Ed(d+352|0)}xb(q);S(e|0);L()}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=gb-352|0;gb=d;vc(b);a:{if(!xr(b,d+336|0)){break a}if(!MU(d+336|0)){break a}q=Fh(d+312|0,b);o=eh(d+296|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!c){v[22692]=0;R(840,d|0,q|0);b=v[22692];v[22692]=0;if((b|0)==1){break q}break s}v[22692]=0;R(841,d|0,q|0);b=v[22692];v[22692]=0;if((b|0)==1){break r}}LU(o,d);Ed(d);v[22692]=0;U(842,d|0,o|0,1413891155);b=v[22692];v[22692]=0;t:{u:{if((b|0)!=1){v[22692]=0;e=Q(843,d|0,11342)|0;b=v[22692];v[22692]=0;if((b|0)==1){break u}xb(d);if(!e){break b}if(c){break t}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;xb(d);break c}v[22692]=0;R(367,a|0,4194304);b=v[22692];v[22692]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22692]=0;U(842,d+272|0,o|0,1280592212);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;b=T(193,d+272|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}v[22692]=0;W(612,d+272|0,a+1298268|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}m=a+484360|0;Vl(Sb(m));k=cd(d+256|0);t[d+255|0]=0;v[22692]=0;U(844,d+240|0,o|0,1196314451);b=v[22692];v[22692]=0;if((b|0)==1){break i}y=d,z=Vb(d+240|0),v[y+232>>2]=z;y=d,z=Zb(d+240|0),v[y+224>>2]=z;v:{w:{x:{y:{z:{A:{B:{if(!Gb(d+232|0,d+224|0)){break B}n=d+12|0;g=d+24|0;p=d+44|0;while(1){b=v[d+232>>2];v[22692]=0;e=Fh(d+200|0,b);b=v[22692];v[22692]=0;C:{D:{E:{F:{G:{H:{if((b|0)!=1){v[22692]=0;f=Q(846,d+200|0,d+184|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){b=1;if(!(f&w[d+193|0]==1)){break C}y=a,z=Gd(w[d+194|0],x[a+480188>>1],127),u[y+480188>>1]=z;v[22692]=0;h=T(847,d|0)|0;b=v[22692];v[22692]=0;I:{J:{K:{L:{if((b|0)!=1){of(d+168|0,d+184|0,9,1);v[22692]=0;R(324,d+120|0,d+168|0);b=v[22692];v[22692]=0;if((b|0)==1){break L}v[22692]=0;R(848,d+160|0,p|0);b=v[22692];v[22692]=0;if((b|0)==1){break K}v[22692]=0;Q(401,d+160|0,d+120|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break K}vb(d+120|0);if(bd(Sb(m))){break I}v[22692]=0;b=T(417,m|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break J}if((b|0)!=255){break I}b=2;break D}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}b=Sb(m);v[22692]=0;U(6,d+120|0,5,p|0);f=v[22692];v[22692]=0;M:{N:{O:{if((f|0)!=1){v[22692]=0;R(418,b|0,d+120|0);b=v[22692];v[22692]=0;if((b|0)==1){break O}vb(d+120|0);v[22692]=0;R(841,d+168|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break N}y=d,z=Vb(d+168|0),v[y+152>>2]=z;y=d,z=Zb(d+168|0),v[y+144>>2]=z;if(Gb(d+152|0,d+144|0)){break M}break G}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}P:{Q:{while(1){R:{b=v[d+152>>2];i=Pe(d+120|0,wb(b));e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+160>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+164>>2]=e;e=1;S:{b=w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24);if((b|0)!=1212960847){if((b|0)!=1312903248){break S}b=0;if(!x[a+480188>>1]){break S}T:{while(1){v[22692]=0;f=Q(189,d+120|0,2)|0;j=v[22692];v[22692]=0;if((j|0)==1){break T}if(!f){break S}v[22692]=0;R(403,d+96|0,i|0);f=v[22692];v[22692]=0;U:{V:{W:{X:{if((f|0)!=1){f=od(d+96|0);switch(w[d+96|0]){case 4:break V;case 2:break W;case 0:break X;default:break U}}break H}f=w[f|0];y=kc(d,b),z=f^128,t[y|0]=z;pe(d+104|0,g,b);Af(d+104|0,0);break U}y=kc(d,b),z=128,t[y|0]=z;pe(d+104|0,g,b);Af(d+104|0,1);break U}y=kc(d,b),z=128,t[y|0]=z;pe(d+104|0,g,b);Af(d+104|0,0)}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break S}break H}if(Zm(d+160|0)>>>0<9){break S}b=0;v[22692]=0;Q(318,d+120|0,2)|0;e=v[22692];v[22692]=0;j=65535;if((e|0)==1){break R}while(1){v[22692]=0;e=Q(189,d+120|0,1)|0;f=v[22692];v[22692]=0;Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((f|0)!=1){f=1;if(!e){break $}v[22692]=0;l=T(374,i|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break H}e=0;switch(l|0){case 14:break Z;case 13:break _;case 0:break $;case 12:break aa;case 8:break ba;case 7:break ca;case 4:break da;case 1:break ea;default:break S}}break H}if(x[d+36>>1]==65535){y=d,z=Tl(Sb(m)),u[y+36>>1]=z}e=Tl(Sb(m));v[22692]=0;u[d+38>>1]=e;e=Q(849,i|0,d+255|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break H}fa:{ga:{switch(e-254|0){case 1:v[22692]=0;e=65535;f=v[22692];v[22692]=0;if((f|0)!=1){break fa}break H;case 0:break ga;default:break fa}}v[22692]=0;e=65534;f=v[22692];v[22692]=0;if((f|0)==1){break H}}f=Sb(m);v[22692]=0;R(704,f|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break H}j=(j&65535)==65535?b:j;break Y}v[22692]=0;e=T(287,i|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break H}if(e>>>0>=(j&65535)>>>0){u[d+40>>1]=e-j}bf(Sb(m),x[d+40>>1]);break Y}v[22692]=0;e=T(374,i|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break H}t[d+43|0]=e;break Y}v[22692]=0;e=T(374,i|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break H}t[d+42|0]=e;break Y}v[22692]=0;e=Q(805,i|0,d+104|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break H}f=0;if(!(e&!w[d+104|0])|w[d+105|0]!=255|(w[d+106|0]|w[d+107|0])){break $}if(w[d+108|0]!=1){break $}if(!w[d+109|0]){break Y}}e=f;break S}v[22692]=0;R(715,d+112|0,i|0);e=v[22692];v[22692]=0;ha:{ia:{ja:{ka:{if((e|0)!=1){f=od(d+112|0);l=Te(d+112|0);e=d+112|0;r=w[e|0];if(pc(d)>>>0<=r>>>0){break Y}switch(w[l|0]){case 4:break ia;case 2:break ja;case 0:break ka;default:break ha}}break H}f=w[f|0];y=kc(d,w[e|0]),z=f^128,t[y|0]=z;pe(d+104|0,g,w[e|0]);Af(d+104|0,0);break ha}y=kc(d,w[e|0]),z=128,t[y|0]=z;pe(d+104|0,g,w[e|0]);Af(d+104|0,1);break ha}y=kc(d,w[e|0]),z=128,t[y|0]=z;pe(d+104|0,g,w[e|0]);Af(d+104|0,0)}la:{if(s){break la}s=0;if(!$q(k)){break Y}if(w[kc(KU(k),w[e|0])|0]!=w[kc(d,w[e|0])|0]){break la}pe(d+104|0,KU(k)+24|0,w[e|0]);f=Cb(d+104|0);pe(d+96|0,g,w[e|0]);if((Cb(d+96|0)|0)==(f|0)){break Y}}s=1;break Y}v[22692]=0;R(403,d+104|0,i|0);e=v[22692];v[22692]=0;if((e|0)==1){break P}e=od(d+104|0);f=d+104|0;l=w[f|0];if(pc(n)>>>0<=l>>>0){break Y}e=w[e|0];y=kc(n,w[f|0]),z=(e>>>2|0)+1|0,t[y|0]=z}b=b+1|0;continue}}xb(d+120|0);if(!e){break Q}kp(d+152|0);if(Gb(d+152|0,d+144|0)){continue}break G}break}break H}b=1;break E}break H}b=P()|0;O()|0;break k}b=P()|0;O()|0;break j}b=P()|0;O()|0;xb(d+120|0);break F}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break E}b=Sb(m);v[22692]=0;_(852,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){b=0;v[22692]=0;R(853,k|0,h|0);e=v[22692];v[22692]=0;if((e|0)!=1){break E}}b=P()|0;O()|0}Ed(d+168|0);break l}Ed(d+168|0)}Tu(h)}xb(d+200|0);if(!b){Bh(d+232|0);if(Gb(d+232|0,d+224|0)){continue}break B}break}e=0;if((b|0)!=2){break A}}e=0;v[22692]=0;Pi(m,0);b=v[22692];v[22692]=0;if((b|0)==1){break v}if(bd(k)){break A}if(c&2){v[22692]=0;U(844,d+200|0,o|0,1347244868);b=v[22692];v[22692]=0;if((b|0)==1){break w}y=d,z=Vb(d+200|0),v[y+184>>2]=z;y=d,z=Zb(d+200|0),v[y+160>>2]=z;f=w[d+255|0];if(Gb(d+184|0,d+160|0)){e=a+480190|0;j=d+13|0;i=d+17|0;while(1){b=v[d+184>>2];ma:{na:{oa:{pa:{qa:{if(!f){v[22692]=0;g=Q(854,b|0,d|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break qa}if(!g){break ma}g=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[22692]=0;g=Je(e,d+104|0);h=v[22692];v[22692]=0;if((h|0)==1){break qa}u[a+480190>>1]=x[g>>1];v[22692]=0;R(855,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[22692];v[22692]=0;if((g|0)==1){break qa}IU(d+168|0,j);v[22692]=0;R(324,d+120|0,d+168|0);g=v[22692];v[22692]=0;ra:{if((g|0)!=1){v[22692]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ra}vb(d+120|0);break oa}b=P()|0;O()|0;break na}b=P()|0;O()|0;vb(d+120|0);break na}v[22692]=0;g=Q(856,b|0,d|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break pa}if(!g){break ma}g=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[22692]=0;g=Je(e,d+104|0);h=v[22692];v[22692]=0;if((h|0)==1){break pa}u[a+480190>>1]=x[g>>1];v[22692]=0;R(857,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[22692];v[22692]=0;if((g|0)==1){break pa}IU(d+168|0,i);v[22692]=0;R(324,d+120|0,d+168|0);g=v[22692];v[22692]=0;sa:{if((g|0)!=1){v[22692]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break sa}vb(d+120|0);break oa}b=P()|0;O()|0;break na}b=P()|0;O()|0;vb(d+120|0);break na}b=P()|0;O()|0;break na}b=P()|0;O()|0;break na}if((x[d+104>>1]-1&65535)>>>0>3998){break ma}g=Rc(d,8,1,0,2);v[22692]=0;W(329,g|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break ma}b=P()|0;O()|0}hd(d+200|0);break j}Bh(d+184|0);if(Gb(d+184|0,d+160|0)){continue}break}}hd(d+200|0)}b=0;y=a,z=w[Ym(k,0)+43|0],v[y+480196>>2]=z;y=a,z=B(w[Ym(k,0)+42|0],1e4),v[y+480204>>2]=z;bf(Sb(m),x[Ym(k,0)+40>>1]);if(x[a+480188>>1]){while(1){v[22692]=0;e=(b<<5)+a|0;f=e+480280|0;Ue(f);j=v[22692];v[22692]=0;if((j|0)==1){break x}y=e+480286|0,z=w[kc(Ym(k,0)+12|0,b)|0],u[y>>1]=z;y=e+480284|0,z=w[kc(Ym(k,0),b)|0],u[y>>1]=z;pe(d,Ym(k,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ta:{if(w[d+255|0]){v[22692]=0;Q(2,d|0,14178)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break ta}break m}v[22692]=0;Q(2,d|0,14051)|0;b=v[22692];v[22692]=0;if((b|0)==1){break m}}Eb(a+1298304|0,d);vb(d);v[22692]=0;b=Q(2,d|0,7361)|0;f=v[22692];v[22692]=0;e=1;if((f|0)==1){break y}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;if(!(c&1)|!x[a+480188>>1]){break A}v[22692]=0;U(844,d+120|0,o|0,1146045008);b=v[22692];v[22692]=0;if((b|0)==1){break n}b=$e(d+120|0);v[22692]=0;g=a+484344|0;R(330,g|0,b&65535);b=v[22692];v[22692]=0;if((b|0)==1){break p}y=d,z=Vb(d+120|0),v[y+168>>2]=z;y=d,z=Zb(d+120|0),v[y+184>>2]=z;if(Gb(d+168|0,d+184|0)){while(1){i=v[d+168>>2];v[22692]=0;b=T(193,i|0)|0;c=v[22692];v[22692]=0;ua:{va:{wa:{if((c|0)==1){break wa}v[22692]=0;c=T(190,i|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break ua}v[22692]=0;b=Q(858,i|0,8)|0;c=v[22692];v[22692]=0;if((c|0)==1){break wa}if(b){break va}break ua}b=P()|0;O()|0;break o}v[22692]=0;p=Q(849,i|0,d+255|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;n=T(287,i|0)|0;b=v[22692];v[22692]=0;xa:{if((b|0)==1){break xa}v[22692]=0;b=W(331,g|0,p|0,n|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break xa}j=0;if(!(b&(n|0)!=0)){break ua}ya:{za:{Aa:{while(1){Ba:{b=_b(g,p);v[22692]=0;c=Rf(b,j);b=v[22692];v[22692]=0;if((b|0)==1){break ya}v[22692]=0;b=T(287,i|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break za}Ca:{if(b>>>0>=3){v[22692]=0;U(288,d+200|0,i|0,b-2|0);b=v[22692];v[22692]=0;if((b|0)==1){break Aa}h=jc(d,d+200|0);xb(d+200|0);while(1){v[22692]=0;b=Q(189,d|0,3)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Ca}if(b){v[22692]=0;R(403,d+200|0,h|0);b=v[22692];v[22692]=0;Da:{Ea:{Fa:{Ga:{if((b|0)!=1){f=d+200|0;b=od(d+200|0);u[d+160>>1]=x[a+480188>>1]-1;b=w[b|0];v[22692]=0;u[d+104>>1]=b;b=Pc(d+160|0,d+104|0);e=v[22692];v[22692]=0;if((e|0)==1){break Ba}e=x[b>>1];b=t[f|0];if((b|0)>-1){break Da}v[22692]=0;b=T(374,h|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break Ba}if(w[d+255|0]){break Fa}if((b|0)!=255){break Ga}b=254;break Ea}break Ba}if(b>>>0>128){break Ea}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ea}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[f|0]}if(b&64){v[22692]=0;b=T(374,h|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break Ba}t[(c+B(e,6)|0)+1|0]=b+1;b=w[f|0]}if(b&32){v[22692]=0;b=T(374,h|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break Ba}t[d+160|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;v[22692]=0;t[d+104|0]=127;l=ac(d+160|0,d+104|0);r=v[22692];v[22692]=0;if((r|0)==1){break Ba}t[b+4|0]=w[l|0]+1>>>1;b=w[f|0]}if(!(b&16)){continue}v[22692]=0;R(403,d+160|0,h|0);b=v[22692];v[22692]=0;if((b|0)==1){break Ba}b=c+B(e,6)|0;f=w[od(d+160|0)|0];t[b+5|0]=f;Ha:{switch(w[d+160|0]-1|0){case 0:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f<<4|15;continue}t[b+5|0]=f<<3|15;continue;case 1:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue;case 2:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue;case 3:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue;case 10:t[(c+B(e,6)|0)+3|0]=2;y=b,z=Su(f,w[d+255|0])|240,t[y+5|0]=z;continue;case 11:t[(c+B(e,6)|0)+3|0]=2;y=b,z=Su(f,w[d+255|0]),t[y+5|0]=z;continue;case 12:t[(c+B(e,6)|0)+3|0]=3;y=b,z=Su(f,w[d+255|0])|240,t[y+5|0]=z;continue;case 13:t[(c+B(e,6)|0)+3|0]=3;y=b,z=Su(f,w[d+255|0]),t[y+5|0]=z;continue;case 14:t[(c+B(e,6)|0)+3|0]=4;if(w[d+255|0]){continue}t[b+5|0]=(f&252)>>>2;continue;case 16:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue;case 15:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue;case 17:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue;case 18:t[(c+B(e,6)|0)+3|0]=20;continue;case 20:t[(c+B(e,6)|0)+3|0]=5;continue;case 21:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue;case 22:t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue;case 23:t[(c+B(e,6)|0)+3|0]=7;continue;case 30:t[(c+B(e,6)|0)+3|0]=8;continue;case 31:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue;case 40:t[(c+B(e,6)|0)+3|0]=10;v[22692]=0;e=T(374,h|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Ba}t[b+5|0]=e;v[22692]=0;Q(318,d|0,1)|0;b=v[22692];v[22692]=0;if((b|0)!=1){continue}break Ba;case 41:t[(c+B(e,6)|0)+3|0]=15;continue;case 42:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue;case 43:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue;case 50:t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[22692]=0;Q(318,d|0,1)|0;b=v[22692];v[22692]=0;if((b|0)!=1){continue}break Ba;case 51:t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue;case 53:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue;case 60:t[(c+B(e,6)|0)+3|0]=16;continue;case 61:t[(c+B(e,6)|0)+3|0]=17;continue;case 70:t[(c+B(e,6)|0)+3|0]=1;continue;case 71:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue;case 72:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue;default:break Ha}}t[(c+B(e,6)|0)+3|0]=0;continue}break}xb(d)}j=j+1|0;if((n|0)==(j|0)){break ua}continue}}break}b=P()|0;O()|0;xb(d);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}Bh(d+168|0);if(Gb(d+168|0,d+184|0)){continue}break}}if($q(k)>>>0>=2){j=0;while(1){b=Nj(m,j&255);c=Ym(k,j);e=x[rc(b,x[c+36>>1])>>1];v[22692]=0;e=le(g,e);f=v[22692];v[22692]=0;Ia:{Ja:{if((f|0)!=1){if(!e){break Ia}e=x[c+36>>1];v[22692]=0;e=Q(541,b|0,e|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break Ja}}b=P()|0;O()|0;break o}if(!(!s|!x[a+480188>>1])){i=c+24|0;b=0;while(1){pe(d,i,b);h=Cb(d);f=_b(g,e);Ka:{if(h){v[22692]=0;h=Be(d,20,145);n=v[22692];v[22692]=0;if((n|0)!=1){h=Gh(ip(Se(h,0),b&65535));v[22692]=0;Q(431,f|0,h|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break Ka}}b=P()|0;O()|0;break o}h=w[kc(c,b)|0];v[22692]=0;h=Be(d,9,h);n=v[22692];v[22692]=0;if((n|0)!=1){h=Gh(ip(Se(h,0),b&65535));v[22692]=0;Q(431,f|0,h|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break Ka}}b=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(g,e);f=w[c+43|0];v[22692]=0;f=Be(d,16,f);i=v[22692];v[22692]=0;if((i|0)==1){break z}f=Gh(Se(f,0));v[22692]=0;Q(431,b|0,f|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break z}b=_b(g,e);c=w[c+42|0];v[22692]=0;c=Be(d,17,c);e=v[22692];v[22692]=0;if((e|0)!=1){c=Gh(Se(c,0));v[22692]=0;Q(431,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break Ia}}b=P()|0;O()|0;break o}j=j+1|0;if($q(k)>>>0>j>>>0){continue}break}}hd(d+120|0);e=1}hd(d+240|0);FU(k);xb(d+272|0);break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}hd(d+120|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}Tu(h)}xb(d+200|0)}hd(d+240|0);break h}b=P()|0;O()|0}FU(k);break f}b=P()|0;O()|0}xb(d+272|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Ed(o);xb(q);S(b|0);L()}Ed(o);xb(q)}gb=d+352|0;return e|0}function ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;m=d+248|0;vv(f+24|0,m);g=yb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;cc(f+16|0,b,f);i=yb(f+16|0);if((i|0)==(g|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){LX(m)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!e){break u}if(!OX(d+248|0)){break u}if(!c){j=1;break u}Id(a,1024);yg(a);v[a+480208>>2]=v[a+480208>>2]|12;Pf(a+1074312|0,21);if(Ib(w[d+264|0]|w[d+265|0]<<8)){F=a,G=B(Ib(w[d+264|0]|w[d+265|0]<<8),1e4),v[F+480204>>2]=G}if(Ib(w[d+262|0]|w[d+263|0]<<8)){F=a,G=Ib(w[d+262|0]|w[d+263|0]<<8),v[F+480196>>2]=G}if(!w[d+258|0]){uh(a,1)}e=d+248|4;Kv(b,a+1298268|0,Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=Fh(d+144|0,b);v[22692]=0;R(517,d+232|0,b|0);e=v[22692];v[22692]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){xb(b);v[22692]=0;U(518,d+144|0,d+232|0,1395544366);b=v[22692];v[22692]=0;if((b|0)==1){break E}v[22692]=0;b=T(421,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break L}if(!b){break F}v[22692]=0;b=T(416,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break L}v[22692]=0;e=T(416,d+144|0)|0;f=v[22692];v[22692]=0;N:{if((f|0)==1){break N}v[22692]=0;Q(318,d+144|0,4)|0;f=v[22692];v[22692]=0;if((f|0)==1){break N}f=a+484360|0;g=Sb(f);v[22692]=0;fa(519,g|0,d+144|0,b|0,65535,65535)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break M}}break L}a=P()|0;O()|0;xb(b);break a}bf(Sb(f),e);xb(d+144|0);v[22692]=0;U(518,d+144|0,d+232|0,1346458708);b=v[22692];v[22692]=0;if((b|0)==1){break K}v[22692]=0;b=T(421,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break J}if(!b){break H}v[22692]=0;b=T(416,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[22692]=0;b=T(416,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break J}v[22692]=0;q=a+484344|0;R(330,q|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break J}v[22692]=0;m=T(426,d+144|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break J}switch(m-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}if(!m){break G}}xb(d+144|0);break A}xb(d+144|0);v[22692]=0;U(518,d+208|0,d+232|0,1398157625);b=v[22692];v[22692]=0;if((b|0)==1){break D}v[22692]=0;b=T(421,d+208|0)|0;e=v[22692];v[22692]=0;O:{if((e|0)==1){break O}if(!b){break B}v[22692]=0;Q(318,d+208|0,2)|0;b=v[22692];v[22692]=0;if((b|0)==1){break O}v[22692]=0;e=T(426,d+208|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[22692]=0;Q(520,d+208|0,d+144|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+80>>2]=G;v[22692]=0;v[d+64>>2]=180;e=nd(d+80|0,d- -64|0);f=v[22692];v[22692]=0;if((f|0)!=1){e=v[e>>2]-90|0;f=e>>31;F=((b<<5)+a|0)+480284|0,G=Ac(kqa(e<<7|45,f<<7|e>>>25,90,0),jb)+128|0,u[F>>1]=G;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}xb(d+144|0);break A}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[22692]=0;Q(318,d+208|0,16)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;b=Q(189,d+208|0,2)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}if(b){v[22692]=0;b=T(416,d+208|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}u[d+80>>1]=b;v[22692]=0;u[d+64>>1]=256;b=Pc(d+80|0,d- -64|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[22692]=0;Q(318,d+208|0,128)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;b=Q(520,d+208|0,d+80|0)|0;e=v[22692];v[22692]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+64>>2]=G;v[22692]=0;v[d+40>>2]=128;e=nd(d- -64|0,d+40|0);f=v[22692];v[22692]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}xb(d+208|0);v[22692]=0;U(518,d+144|0,d+232|0,1413830740);b=v[22692];v[22692]=0;R:{S:{if((b|0)!=1){v[22692]=0;b=T(421,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(!b){break R}v[22692]=0;R(521,d+144|0,d+80|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}if((Ib(w[d+90|0]|w[d+91|0]<<8)|0)!=65535){break S}v[22692]=0;Q(318,d+144|0,1)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break S}break d}a=P()|0;O()|0;break b}v[22692]=0;b=T(465,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;ca(507,a+1298292|0,d+144|0,b|0,2)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}}xb(d+144|0);v[22692]=0;U(518,d+80|0,d+232|0,1229869908);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;b=T(421,d+80|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){if(b){v[22692]=0;b=T(416,d+80|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}T:{e=b<<16>>16;g=e&32767;if(g>>>0>3999){break T}v[22692]=0;b=Q(189,d+80|0,B(g,(e>>>14&2)+50|0)|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break y}if(!b){break T}u[a+480190>>1]=g;j=a+480190|0;if(!g){break z}i=d+162|0;b=1;k=(e|0)>-1;U:{V:{while(1){W:{e=b;f=d;X:{Y:{Z:{if(!k){v[22692]=0;e=T(416,d+80|0)|0;n=v[22692];v[22692]=0;if((n|0)==1){break Z}e=e+1|0}u[f+40>>1]=e;v[22692]=0;R(522,d+80|0,d+144|0);e=v[22692];v[22692]=0;if((e|0)!=1){if((x[d+40>>1]-1&65535)>>>0>3998){break X}v[22692]=0;e=Je(j,d+40|0);f=v[22692];v[22692]=0;if((f|0)!=1){break Y}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];e=x[d+40>>1];f=Yb(w[d+266|0]|w[d+267|0]<<8|(w[d+268|0]<<16|w[d+269|0]<<24));v[22692]=0;Y(523,d+144|0,(B(e,104)+a|0)+484380|0,f|0,m|0);e=v[22692];v[22692]=0;if((e|0)==1){break W}v[22692]=0;Jk(d- -64|0,2,i);e=v[22692];v[22692]=0;if((e|0)==1){break V}v[22692]=0;R(324,d+208|0,d- -64|0);e=v[22692];v[22692]=0;if((e|0)==1){break V}v[22692]=0;Q(301,((x[d+40>>1]<<5)+a|0)+946304|0,d+208|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break U}vb(d+208|0)}e=b&65535;b=b+1|0;if(e>>>0<g>>>0){continue}break z}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+208|0);break f}xb(d+80|0);break A}break w}a=P()|0;O()|0;break f}break v}v[22692]=0;b=T(416,d+80|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break x}}a=P()|0;O()|0;break f}if((b|0)==4){u[d+144>>1]=x[j>>1];v[22692]=0;u[d+208>>1]=255;b=Pc(d+144|0,d+208|0);e=v[22692];v[22692]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[22692]=0;U(518,d+208|0,d+232|0,1229278806);b=v[22692];v[22692]=0;if((b|0)==1){break i}g=d- -64|4;j=d- -64|3;i=d- -64|5;k=d- -64|7;while(1){v[22692]=0;b=Q(189,d+80|0,15)|0;e=v[22692];v[22692]=0;_:{if((e|0)!=1){$:{if(b){v[22692]=0;R(525,d+80|0,d- -64|0);b=v[22692];v[22692]=0;aa:{if((b|0)!=1){b=d- -64|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>=x[a+480192>>1]){continue}b=d- -64|0;b=B(Ib(w[b|0]|w[b+1|0]<<8),104)+a|0;t[b+484524|0]=w[d+72|0];e=w[k|0];t[b+484523|0]=255;t[b+484525|0]=e;b=d- -64|0;b=Ib(w[b|0]|w[b+1|0]<<8);e=d- -64|0;e=Ib(w[e|0]|w[e+1|0]<<8);v[22692]=0;e=W(376,a|0,b+1&65535,e+1&65535)|0;b=v[22692];v[22692]=0;if((b|0)==1){break $}if(!e){continue}F=d,G=Ib(w[i|0]|w[i+1|0]<<8),u[F+144>>1]=G;v[22692]=0;u[d+40>>1]=4095;b=Pc(d+144|0,d+40|0);f=v[22692];v[22692]=0;if((f|0)==1){break $}v[e>>2]=x[b>>1];if(w[j|0]==255){continue}b=w[j|0];v[22692]=0;b=Q(188,d+208|0,B(b,34)+2|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break $}if(!b){continue}v[22692]=0;R(526,d+208|0,d+144|0);b=v[22692];v[22692]=0;if((b|0)==1){break $}t[e+60|0]=w[e+60|0]|1;b=Ib(w[d+144|0]|w[d+145|0]<<8);v[d+60>>2]=3;v[d+44>>2]=16;v[d+48>>2]=240;v[d+40>>2]=b;v[d+56>>2]=d+40;b=v[d+60>>2];v[d+8>>2]=v[d+56>>2];v[d+12>>2]=b;b=MX(d+8|0);v[22692]=0;f=e+48|0;R(448,f|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break $}b=0;if(Nb(f)){break aa}break _}break $}while(1){ba:{t[d+40|0]=64;n=(d+144|0)+(b<<1)|0;o=w[n+2|0];v[22692]=0;t[d+32|0]=o;o=ac(d+40|0,d+32|0);h=v[22692];v[22692]=0;if((h|0)==1){break ba}o=w[o|0];F=Lb(f,b),G=o,t[F+2|0]=G;n=w[n+3|0];F=Lb(f,b),G=n,u[F>>1]=G;b=b+1|0;if(Nb(f)>>>0>b>>>0){continue}break _}break}break $}xb(d+208|0);break w}}a=P()|0;O()|0;xb(d+208|0);break f}if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(bd(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Nb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}xb(d+80|0);v[22692]=0;U(527,d+208|0,d+232|0,1145131092);b=v[22692];v[22692]=0;if((b|0)==1){break j}F=d,G=Vb(d+208|0),v[F+32>>2]=G;F=d,G=Zb(d+208|0),v[F+24>>2]=G;if(Gb(d+32|0,d+24|0)){z=c&1;n=d+80|4;o=(m|0)!=841887798;A=(m|0)!=841887796;while(1){g=v[d+32>>2];v[22692]=0;Q(318,g|0,4)|0;b=v[22692];v[22692]=0;ca:{da:{ea:{if((b|0)!=1){v[22692]=0;e=T(416,g|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break l}v[22692]=0;i=T(416,g|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break m}i=o?i:(i>>>0)/y[a+480196>>2]|0;if(!z|e>>>0>255){break ca}v[22692]=0;b=W(331,q|0,e|0,i|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break m}if(!b){break ca}if(o){break da}v[22692]=0;Q(318,g|0,4)|0;b=v[22692];v[22692]=0;if((b|0)==1){break m}k=0;if(!x[a+480188>>1]){break ca}while(1){v[22692]=0;b=T(416,g|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ea}v[22692]=0;U(288,d+80|0,g|0,b+(b&1)&65535);b=v[22692];v[22692]=0;if((b|0)==1){break n}f=jc(d+144|0,d+80|0);xb(d+80|0);v[d+80>>2]=0;v[d+84>>2]=0;j=0;fa:{while(1){v[22692]=0;b=Q(189,d+144|0,6)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}if(!(b&y[d+80>>2]<i>>>0)){break fa}b=_b(q,e);v[22692]=0;b=Wc(b,v[d+80>>2],k&65535);h=v[22692];v[22692]=0;ga:{ha:{if((h|0)!=1){v[22692]=0;R(528,d+40|0,f|0);h=v[22692];v[22692]=0;if((h|0)==1){break o}h=od(d+40|0);C=Te(d+40|0);D=bj(d+40|0);p=fc(d+40|0);E=d+45|0;l=t[d+40|0];if((l-1&255)>>>0>95){break ha}t[b|0]=l+13;if(!v[d+84>>2]){break ga}t[b+3|0]=19;v[22692]=0;v[d+64>>2]=15;l=nd(n,d- -64|0);s=v[22692];v[22692]=0;if((s|0)==1){break o}t[b+5|0]=w[l|0]|208;break ga}break o}if((l|0)>-1){break ga}if(v[d+84>>2]){t[b+3|0]=19;v[22692]=0;v[d+64>>2]=15;l=nd(n,d- -64|0);s=v[22692];v[22692]=0;if((s|0)!=1){t[b+5|0]=w[l|0]|192;break ga}break o}t[b|0]=254}if(w[h|0]){t[b+2|0]=1;v[22692]=0;t[d+64|0]=64;h=ac(h,d- -64|0);l=v[22692];v[22692]=0;if((l|0)==1){break o}t[b+4|0]=w[h|0]}h=w[C|0];if(h){t[b+1|0]=h}h=w[D|0];if(h|w[p|0]){t[b+3|0]=h;t[b+5|0]=w[p|0];v[22692]=0;Nf(b);b=v[22692];v[22692]=0;if((b|0)==1){break o}}b=w[E|0];if(b&128){v[22692]=0;h=T(374,f|0)|0;p=v[22692];v[22692]=0;if((p|0)==1){break o}b=h|b<<8&32512}h=v[a+480196>>2];v[22692]=0;j=b+j|0;ht(d- -64|0,j,h);b=v[22692];v[22692]=0;if((b|0)!=1){b=v[d+68>>2];v[d+80>>2]=v[d+64>>2];v[d+84>>2]=b;continue}break}break o}xb(d+144|0);k=k+1|0;if(x[a+480188>>1]>(k&65535)>>>0){continue}break}break ca}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}b=_b(q,e);v[22692]=0;b=Wc(b,0,0);e=v[22692];v[22692]=0;if((e|0)==1){break s}k=0;if(!i){break ca}while(1){j=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[22692]=0;R(529,d+144|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break ja}ka:{if(!A){v[d+80>>2]=v[d+144>>2];h=od(d+80|0);p=Te(d+80|0);l=bj(d+80|0);e=t[d+80|0];if((e|0)>=1){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}f=b;e=w[h|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[h|0]}t[f+1|0]=e<<4&48|w[p|0]>>>4;t[b+3|0]=w[p|0]&15;t[b+5|0]=w[l|0];break ka}e=v[d+144>>2];v[d+20>>2]=e;v[22692]=0;v[d+16>>2]=e;cr(d+16|0,b);e=v[22692];v[22692]=0;if((e|0)==1){break ja}e=lc(d+144|0,0);t[b+1|0]=w[b+1|0]|w[e|0]&48}v[22692]=0;Nf(b);e=v[22692];v[22692]=0;if((e|0)==1){break ja}e=w[b+3|0];la:{if(e>>>0>11){break la}e=1<<e;ma:{if(!(e&2240)){if(!(e&12)){break la}if(!w[b+5|0]){break ma}break la}e=w[b+5|0];f=e&240;if(f){t[b+5|0]=f;break la}if(e){break la}}t[b+3|0]=0}b=b+6|0;j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break ia}break}a=P()|0;O()|0;break k}k=k+1|0;if((k|0)!=(i|0)){continue}break}}Bh(d+32|0);if(Gb(d+32|0,d+24|0)){continue}break}}hd(d+208|0);v[22692]=0;U(518,d+144|0,d+232|0,1346458702);b=v[22692];v[22692]=0;if((b|0)==1){a=P()|0;O()|0;break b}v[22692]=0;b=T(421,d+144|0)|0;e=v[22692];v[22692]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((e|0)!=1){if(b){e=Kb(d+80|0);b=0;Ba:{while(1){Ca:{v[22692]=0;f=Q(189,d+144|0,1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Ca}if(!f){break Ba}if(Re(q)>>>0<=b>>>0){break Ba}v[22692]=0;W(531,d+144|0,e|0,32)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Ca}f=_b(q,b);v[22692]=0;Q(428,f|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break Ca}b=b+1|0;continue}break}a=P()|0;O()|0;vb(e);break Aa}vb(e)}xb(d+144|0);v[22692]=0;U(518,d+144|0,d+232|0,1414679374);b=v[22692];v[22692]=0;if((b|0)==1){break za}v[22692]=0;b=T(421,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break va}if(!b){break wa}e=Kb(d+80|0);b=0;while(1){v[22692]=0;f=Q(189,d+144|0,1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ya}if(!f|x[a+480188>>1]<=b>>>0){break xa}v[22692]=0;W(531,d+144|0,e|0,32)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ya}v[22692]=0;Q(399,((b<<5)+a|0)+480289|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ya}b=b+1|0;continue}}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e);break ua}vb(e)}xb(d+144|0);v[22692]=0;U(527,d+144|0,d+232|0,1145129300);b=v[22692];v[22692]=0;if((b|0)==1){break ta}F=d,G=Vb(d+144|0),v[F+80>>2]=G;F=d,G=Zb(d+144|0),v[F+208>>2]=G;if(Gb(d+80|0,d+208|0)){e=c&2;while(1){b=v[d+80>>2];v[22692]=0;c=T(416,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Rc(d- -64|0,f&1?16:8,f&64?2:1,1,0);v[22692]=0;W(329,f|0,c+484484|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break p}}Bh(d+80|0);if(Gb(d+80|0,d+208|0)){continue}break}}hd(d+144|0);b=Kb(d+80|0);if((m|0)!=841887798){break ra}v[22692]=0;c=Q(2,d+144|0,6601)|0;e=v[22692];v[22692]=0;if((e|0)==1){break sa}Eb(b,c);vb(c);break qa}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}v[22692]=0;U(518,d+144|0,d+232|0,1447383635);c=v[22692];v[22692]=0;Da:{Ea:{Fa:{Ga:{Ha:{if((c|0)!=1){v[22692]=0;c=T(421,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break pa}if(!c){break Ea}v[22692]=0;c=T(426,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break Ha}v[22692]=0;R(411,d- -64|0,1401);e=v[22692];v[22692]=0;if((e|0)==1){break Ga}v[d+40>>2]=c>>>4;v[22692]=0;v[d+32>>2]=c&15;Y(532,d+208|0,d- -64|0,d+40|0,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break Fa}Eb(b,d+208|0);vb(d+208|0);Hb(d- -64|0);break Da}a=P()|0;O()|0;break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;Hb(d- -64|0);break r}v[22692]=0;c=Q(2,d+208|0,5641)|0;e=v[22692];v[22692]=0;if((e|0)==1){break t}Eb(b,c);vb(c)}xb(d+144|0)}v[22692]=0;c=Q(2,d+144|0,5641)|0;e=v[22692];v[22692]=0;if((e|0)==1){break oa}Eb(a+1298304|0,c);vb(c);v[22692]=0;c=Q(2,d+144|0,7357)|0;e=v[22692];v[22692]=0;if((e|0)==1){break na}Eb(a+1298316|0,c);vb(c);Eb(a+1298328|0,b);v[a+1298364>>2]=2;vb(b);j=1;break v}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}Ed(d+232|0)}gb=d+272|0;return j|0}a=P()|0;O()|0;break r}a=P()|0;O()|0;break k}xb(d+144|0)}vb(b);break b}a=P()|0;O()|0;hd(d+144|0);break b}a=P()|0;O()|0;xb(d+144|0);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0}hd(d+208|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}xb(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;xb(d+208|0)}Ed(d+232|0)}S(a|0);L()}function rI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;x=gb-48|0;gb=x;a:{if(c>>>0<=2){c=c<<2;I=v[c+74764>>2];H=v[c+74752>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=kd(b)}if(tm(c)){continue}break}m=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}m=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=kd(b)}e:{f:{while(1){if(t[f+2048|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=kd(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=x;h=gb-16|0;gb=h;g=(p(C(C(m|0)*C(N))),j(2));c=g&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;m=d<<25;d=c+1065353216|0;break h}m=g<<25;d=g>>>7|2147418112;if(c>>>0>=2139095040){break h}m=0;d=0;if(!c){break h}d=c;c=E(c);Kf(h,d,0,0,0,c+81|0);k=v[h>>2];l=v[h+4>>2];m=v[h+8>>2];d=v[h+12>>2]^65536|16265-c<<16}v[b>>2]=k;v[b+4>>2]=l;v[b+8>>2]=m;v[b+12>>2]=g&-2147483648|d;gb=h+16|0;k=v[x+8>>2];l=v[x+12>>2];h=v[x>>2];g=v[x+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+7202|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=kd(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=kd(b)}if((f&-33)==88){f=gb-432|0;gb=f;c=b;A=v[b+104>>2];b=v[b+4>>2];p:{if(A>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=kd(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){J=1;v[c+4>>2]=b+1;b=w[b|0]}else{J=1;b=kd(c)}continue}break}b=kd(c)}G=1;if((b|0)!=48){break q}while(1){b=k;k=b-1|0;l=l-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=kd(c)}if((b|0)==48){continue}break}J=1}A=1073676288;u:{while(1){v:{o=b|32;w:{x:{D=b-48|0;if(D>>>0<10){break x}if((b|0)!=46?o-97>>>0>=6:0){break u}if((b|0)!=46){break x}if(G){break v}G=1;k=h;l=g;break w}b=(b|0)>57?o-87|0:D;y:{if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){i=b+(i<<4)|0;break y}if((g|0)<0?1:(g|0)<=0?h>>>0<=28:0){Ug(f+48|0,b);Fd(f+32|0,r,z,F,A,0,0,0,1073414144);r=v[f+32>>2];z=v[f+36>>2];F=v[f+40>>2];A=v[f+44>>2];Fd(f+16|0,r,z,F,A,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);vg(f,q,e,s,u,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);s=v[f+8>>2];u=v[f+12>>2];q=v[f>>2];e=v[f+4>>2];break y}if(!b|n){break y}Fd(f+80|0,r,z,F,A,0,0,0,1073610752);vg(f- -64|0,q,e,s,u,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);s=v[f+72>>2];u=v[f+76>>2];n=1;q=v[f+64>>2];e=v[f+68>>2]}b=h+1|0;g=b>>>0<1?g+1|0:g;h=b;J=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=kd(c)}continue}break}b=46}z:{A:{B:{if(!J){if(!v[c+104>>2]){if(d){break A}break B}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break B}v[c+4>>2]=b-2;if(!G){break A}v[c+4>>2]=b-3;break A}if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){F=h;A=g;while(1){i=i<<4;n=A;A=F+1|0;n=A>>>0<1?n+1|0:n;F=A;A=n;if((F|0)!=8|n){continue}break}}C:{D:{E:{if((b&-33)==80){F=qI(c,d);b=jb;A=b;if(F|(b|0)!=-2147483648){break C}if(d){if(v[c+104>>2]){break E}break D}q=0;e=0;xi(c,0,0);c=0;b=0;break z}if(!v[c+104>>2]){break D}}v[c+4>>2]=v[c+4>>2]-1}F=0;A=0}if(!i){qj(f+112|0,+(m|0)*0);q=v[f+112>>2];e=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=G?k:h;c=(G?l:g)<<2|b>>>30;b=F+(b<<2)|0;c=c+A|0;c=b>>>0<F>>>0?c+1|0:c;h=b-32|0;g=c-(b>>>0<32)|0;b=g;if((b|0)>0?1:(b|0)>=0?h>>>0>0-I>>>0:0){v[115173]=68;Ug(f+160|0,m);Fd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Fd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];e=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=I-226|0;c=h>>>0>=b>>>0;b=b>>31;if((b|0)<(g|0)?1:(g|0)>=(b|0)?c:0){if((i|0)>-1){while(1){vg(f+416|0,q,e,s,u,0,0,0,-1073807360);c=fB(q,e,s,u,1073610752);b=(c|0)<0;vg(f+400|0,q,e,s,u,b?q:v[f+416>>2],b?e:v[f+420>>2],b?s:v[f+424>>2],b?u:v[f+428>>2]);b=h;h=b-1|0;g=g-(b>>>0<1)|0;s=v[f+408>>2];u=v[f+412>>2];q=v[f+400>>2];e=v[f+404>>2];i=i<<1|(c|0)>-1;if((i|0)>-1){continue}break}}b=h;c=I;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=((c|0)<0?1:(c|0)<=0?b>>>0<H>>>0:0)?(b|0)>0?b:0:H;F:{if((c|0)>=113){Ug(f+384|0,m);k=v[f+392>>2];l=v[f+396>>2];r=v[f+384>>2];z=v[f+388>>2];g=0;b=0;break F}qj(f+352|0,aj(1,144-c|0));Ug(f+336|0,m);r=v[f+336>>2];z=v[f+340>>2];k=v[f+344>>2];l=v[f+348>>2];uI(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],r,z,k,l);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(i&1)&((ln(q,e,s,u,0,0,0,0)|0)!=0&(c|0)<32);Un(f+320|0,c+i|0);Fd(f+304|0,r,z,k,l,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;vg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);b=c;Fd(f+288|0,b?0:q,b?0:e,b?0:s,b?0:u,r,z,k,l);vg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Lx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!ln(b,c,d,g,0,0,0,0)){v[115173]=68}tI(f+224|0,b,c,d,g,h);q=v[f+224>>2];e=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[115173]=68;Ug(f+208|0,m);Fd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Fd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];e=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break z}xi(c,0,0)}qj(f+96|0,+(m|0)*0);q=v[f+96>>2];e=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[x+16>>2]=q;v[x+20>>2]=e;v[x+24>>2]=b;v[x+28>>2]=c;gb=f+432|0;k=v[x+24>>2];l=v[x+28>>2];h=v[x+16>>2];g=v[x+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}i=b;q=m;m=0;f=0;e=gb-8976|0;gb=e;J=H+I|0;O=0-J|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}b=v[i+4>>2];if(b>>>0>=y[i+104>>2]){break I}v[i+4>>2]=b+1;c=w[b|0];break H}}else{b=v[i+4>>2];if(b>>>0<y[i+104>>2]){m=1;v[i+4>>2]=b+1;c=w[b|0]}else{m=1;c=kd(i)}continue}break}c=kd(i)}o=1;if((c|0)!=48){break G}while(1){b=k;k=b-1|0;l=l-(b>>>0<1)|0;b=v[i+4>>2];J:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;c=w[b|0];break J}c=kd(i)}if((c|0)==48){continue}break}m=1}v[e+784>>2]=0;K:{L:{b=(c|0)==46;n=c-48|0;M:{N:{O:{P:{if(n>>>0>9?b:1){while(1){Q:{if(b&1){if(!o){k=h;l=g;o=1;break Q}b=!m;break P}b=h+1|0;g=b>>>0<1?g+1|0:g;h=b;if((f|0)<=2044){G=(c|0)==48?G:h;b=(e+784|0)+(f<<2)|0;m=b;if(D){n=(B(v[b>>2],10)+c|0)-48|0}v[m>>2]=n;m=1;c=D+1|0;b=(c|0)==9;D=b?0:c;f=b+f|0;break Q}if((c|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;G=18396}b=v[i+4>>2];R:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;c=w[b|0];break R}c=kd(i)}b=(c|0)==46;n=c-48|0;if(b|n>>>0<10){continue}break}}k=o?k:h;l=o?l:g;if(!(!m|(c&-33)!=69)){r=qI(i,d);b=jb;z=b;S:{if(r|(b|0)!=-2147483648){break S}if(!d){break M}r=0;z=0;if(!v[i+104>>2]){break S}v[i+4>>2]=v[i+4>>2]-1}if(!m){break N}n=l+z|0;b=k+r|0;n=b>>>0<r>>>0?n+1|0:n;k=b;l=n;break L}b=!m;if((c|0)<0){break O}}if(!v[i+104>>2]){break O}v[i+4>>2]=v[i+4>>2]-1}if(!b){break L}}v[115173]=28}h=0;g=0;xi(i,0,0);c=0;b=0;break K}b=v[e+784>>2];if(!b){qj(e,+(q|0)*0);h=v[e>>2];g=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((h|0)!=(k|0)|(g|0)!=(l|0)|((g|0)>0?1:(g|0)>=0?h>>>0>9:0)|(b>>>H|0?(H|0)<=30:0))){Ug(e+48|0,q);Un(e+32|0,b);Fd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);h=v[e+16>>2];g=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if((l|0)>0?1:(l|0)>=0?k>>>0>(I|0)/-2>>>0:0){v[115173]=68;Ug(e+96|0,q);Fd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Fd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);h=v[e+64>>2];g=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if((b|0)>(l|0)?1:(l|0)<=(b|0)?c:0){v[115173]=68;Ug(e+144|0,q);Fd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Fd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);h=v[e+112>>2];g=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(D){if((D|0)<=8){b=(e+784|0)+(f<<2)|0;i=v[b>>2];while(1){i=B(i,10);D=D+1|0;if((D|0)!=9){continue}break}v[b>>2]=i}f=f+1|0}T:{o=k;if((G|0)>(k|0)|(G|0)>=9|(k|0)>17){break T}if((o|0)==9){Ug(e+192|0,q);Un(e+176|0,v[e+784>>2]);Fd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);h=v[e+160>>2];g=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((o|0)<=8){Ug(e+272|0,q);Un(e+256|0,v[e+784>>2]);Fd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Ug(e+224|0,v[(0-o<<2)+74752>>2]);XE(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);h=v[e+208>>2];g=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}b=(B(o,-3)+H|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break T}Ug(e+352|0,q);Un(e+336|0,c);Fd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Ug(e+304|0,v[(o<<2)+74680>>2]);Fd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);h=v[e+288>>2];g=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=f;f=f-1|0;if(!v[(e+784|0)+(f<<2)>>2]){continue}break}D=0;b=(o|0)%9|0;U:{if(!b){b=0;break U}d=(o|0)>-1?b:b+9|0;V:{if(!c){b=0;c=0;break V}g=v[(0-d<<2)+74752>>2];h=1e9/(g|0)|0;n=0;i=0;b=0;while(1){k=n;l=(e+784|0)+(i<<2)|0;n=v[l>>2];m=(n>>>0)/(g>>>0)|0;k=k+m|0;v[l>>2]=k;k=!k&(b|0)==(i|0);b=k?b+1&2047:b;o=k?o-9|0:o;n=B(h,n-B(g,m)|0);i=i+1|0;if((i|0)!=(c|0)){continue}break}if(!n){break V}v[(e+784|0)+(c<<2)>>2]=n;c=c+1|0}o=(o-d|0)+9|0}while(1){h=(e+784|0)+(b<<2)|0;W:{while(1){if((o|0)!=36|y[h>>2]>10384592?(o|0)>=36:0){break W}m=c+2047|0;n=0;while(1){l=n;g=m&2047;m=(e+784|0)+(g<<2)|0;d=v[m>>2];n=d>>>3|0;k=d<<29;d=l+k|0;n=d>>>0<k>>>0?n+1|0:n;k=d;l=n;if(!l&k>>>0<1000000001){n=0}else{n=mqa(k,l,1e9,0);k=k-jqa(n,jb,1e9,0)|0}v[m>>2]=k;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:k?c:g;m=g-1|0;if((b|0)!=(g|0)){continue}break}D=D-29|0;if(!n){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=(e+784|0)+((c+2046&2047)<<2)|0;c=c-1&2047;v[d>>2]=v[d>>2]|v[(e+784|0)+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=n;continue}break}X:{Y:while(1){d=c+1&2047;k=(e+784|0)+((c-1&2047)<<2)|0;while(1){g=(o|0)>45?9:1;Z:{while(1){m=b;i=0;_:{while(1){$:{b=i+m&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];h=v[(i<<2)+74704>>2];if(b>>>0<h>>>0){break $}if(b>>>0>h>>>0){break _}i=i+1|0;if((i|0)!=4){continue}}break}if((o|0)!=36){break _}k=0;l=0;i=0;h=0;g=0;while(1){b=i+m&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Fd(e+768|0,k,l,h,g,0,0,1342177280,1075633366);Un(e+752|0,v[(e+784|0)+(b<<2)>>2]);vg(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);h=v[e+744>>2];g=v[e+748>>2];k=v[e+736>>2];l=v[e+740>>2];i=i+1|0;if((i|0)!=4){continue}break}Ug(e+720|0,q);Fd(e+704|0,k,l,h,g,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);h=v[e+712>>2];g=v[e+716>>2];k=0;l=0;r=v[e+704>>2];z=v[e+708>>2];o=D+113|0;d=o-I|0;n=(d|0)<(H|0);b=n?(d|0)>0?d:0:H;if((b|0)<=112){break Z}break X}D=g+D|0;b=c;if((m|0)==(b|0)){continue}break}l=1e9>>>g|0;n=-1<<g^-1;i=0;b=m;while(1){h=i;f=(e+784|0)+(m<<2)|0;i=v[f>>2];h=h+(i>>>g|0)|0;v[f>>2]=h;h=!h&(b|0)==(m|0);b=h?b+1&2047:b;o=h?o-9|0:o;i=B(l,i&n);m=m+1&2047;if((m|0)!=(c|0)){continue}break}if(!i){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=i;c=d;continue Y}v[k>>2]=v[k>>2]|1;b=d;continue}break}break}qj(e+656|0,aj(1,225-b|0));uI(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],r,z,h,g);F=v[e+696>>2];A=v[e+700>>2];K=v[e+688>>2];L=v[e+692>>2];qj(e+640|0,aj(1,113-b|0));DE(e+672|0,r,z,h,g,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];l=v[e+676>>2];s=v[e+680>>2];u=v[e+684>>2];Lx(e+624|0,r,z,h,g,k,l,s,u);vg(e+608|0,K,L,F,A,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);h=v[e+616>>2];g=v[e+620>>2];r=v[e+608>>2];z=v[e+612>>2]}f=m+4&2047;aa:{if((f|0)==(c|0)){break aa}f=v[(e+784|0)+(f<<2)>>2];ba:{if(f>>>0<=499999999){if(!((m+5&2047)==(c|0)?f:1)){break ba}qj(e+496|0,+(q|0)*.25);vg(e+480|0,k,l,s,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);s=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];l=v[e+484>>2];break ba}if((f|0)!=5e8){qj(e+592|0,+(q|0)*.75);vg(e+576|0,k,l,s,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);s=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];l=v[e+580>>2];break ba}M=+(q|0);if((m+5&2047)==(c|0)){qj(e+528|0,M*.5);vg(e+512|0,k,l,s,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);s=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];l=v[e+516>>2];break ba}qj(e+560|0,M*.75);vg(e+544|0,k,l,s,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);s=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];l=v[e+548>>2]}if((b|0)>111){break aa}DE(e+464|0,k,l,s,u,0,0,0,1073676288);if(ln(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}vg(e+448|0,k,l,s,u,0,0,0,1073676288);s=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];l=v[e+452>>2]}vg(e+432|0,r,z,h,g,k,l,s,u);Lx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],K,L,F,A);h=v[e+424>>2];g=v[e+428>>2];r=v[e+416>>2];z=v[e+420>>2];ca:{if((-2-J|0)>=(o&2147483647)){break ca}v[e+408>>2]=h;v[e+412>>2]=g&2147483647;v[e+400>>2]=r;v[e+404>>2]=z;Fd(e+384|0,r,z,h,g,0,0,0,1073610752);A=v[e+400>>2];F=v[e+404>>2];f=v[e+408>>2];o=v[e+412>>2];c=fB(A,F,f,o,1081081856);m=(c|0)<0;i=m;h=i?h:v[e+392>>2];g=i?g:v[e+396>>2];r=i?r:v[e+384>>2];z=i?z:v[e+388>>2];D=((c|0)>-1)+D|0;if((D+110|0)<=(O|0)){if((((fB(A,F,f,o,1081081856)|0)<0?n:n&(b|0)!=(d|0))|0)!=1){break ca}if(!ln(k,l,s,u,0,0,0,0)){break ca}}v[115173]=68}tI(e+368|0,r,z,h,g,D);h=v[e+368>>2];g=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[x+32>>2]=h;v[x+36>>2]=g;v[x+40>>2]=b;v[x+44>>2]=c;gb=e+8976|0;k=v[x+40>>2];l=v[x+44>>2];h=v[x+32>>2];g=v[x+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=kd(b)}if((c|0)==40){f=1;break da}l=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=kd(b)}if(c-97>>>0>=26?c-48>>>0<10|c-65>>>0<26|(c|0)==95:1){f=f+1|0;continue}break}l=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[115173]=28;xi(b,0,0)}l=0}v[a>>2]=h;v[a+4>>2]=g;v[a+8>>2]=k;v[a+12>>2]=l;gb=x+48|0}function Ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-416|0;gb=d;vc(b);e=d+408|0;g=Rv(b,e);if(!g){mW(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!g){break q}if(!xW(d+408|0)){break q}if(!c){p=1;break q}A=Fh(d+384|0,b);v[22692]=0;R(662,d+368|0,A|0);b=v[22692];v[22692]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[22692]=0;U(663,d+344|0,d+368|0,20041);b=v[22692];v[22692]=0;if((b|0)==1){break F}v[22692]=0;b=T(275,d+344|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}if(!b){break r}v[22692]=0;b=Q(664,d+344|0,d+248|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}if(!b){break r}v[22692]=0;R(367,a|0,16384);b=v[22692];v[22692]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[22692]=0;b=a+1074312|0;W(409,b|0,9,1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}v[22692]=0;Q(410,b|0,21)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}v[22692]=0;Q(410,b|0,30)|0;b=v[22692];v[22692]=0;if((b|0)==1){break w}v[22692]=0;b=Q(2,d+208|0,5398)|0;e=v[22692];v[22692]=0;if((e|0)==1){break C}Eb(a+1298304|0,b);vb(b);v[22692]=0;b=Q(2,d+208|0,7963)|0;e=v[22692];v[22692]=0;if((e|0)==1){break B}Eb(a+1298316|0,b);vb(b);v[22692]=0;b=Q(2,d+96|0,14579)|0;e=v[22692];v[22692]=0;if((e|0)==1){break A}e=w[d+412|0];switch(e-16|0){case 1:break z;case 0:break E;default:break D}}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22692]=0;Q(2,d+232|0,12174)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break x}break e}if(!e){break y}v[22692]=0;Q(2,d+232|0,18699)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}break x}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22692]=0;Q(2,d+232|0,12192)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break x}break e}v[22692]=0;Q(2,d+232|0,10555)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}}v[22692]=0;U(3,d+208|0,b|0,d+232|0);e=v[22692];v[22692]=0;if((e|0)==1){break f}Eb(a+1298328|0,d+208|0);vb(d+208|0);vb(d+232|0);vb(b);v[a+1298364>>2]=5;v[22692]=0;Ie(d+96|0,3,d+248|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;R(324,d+208|0,d+96|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}Eb(a+1298268|0,d+208|0);vb(d+208|0);v[22692]=0;Uj(d+232|0,3,d+280|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;R(324,d+96|0,d+232|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;U(13,d+208|0,5,d+96|0);b=v[22692];v[22692]=0;if((b|0)==1){break i}Eb(a+1298280|0,d+208|0);vb(d+208|0);vb(d+96|0);v[a+480200>>2]=w[d+304|0]+1;H=a,I=Gd(w[d+305|0],1,255),v[H+480196>>2]=I;H=a,I=B(Gd(w[d+306|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Sb(b);g=w[d+300|0]|w[d+301|0]<<8;v[22692]=0;fa(519,e|0,d+344|0,g|0,65535,65535)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}bf(Sb(b),w[d+302|0]|w[d+303|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[22692]=0;e=(b<<5)+a|0;g=e+480280|0;Ue(g);f=v[22692];v[22692]=0;if((f|0)==1){break j}f=b+d|0;h=w[f+307|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;G:{if(t[f+307|0]<=-1){v[g>>2]=v[g>>2]|1024;break G}u[a+480188>>1]=b+1}v[22692]=0;R(665,d+344|0,e+480289|0);e=v[22692];v[22692]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[22692]=0;U(663,d+208|0,d+368|0,17741);b=v[22692];v[22692]=0;if((b|0)==1){break k}qd(d+344|0,d+208|0);xb(d+208|0);v[22692]=0;b=T(193,d+344|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}v[22692]=0;ca(507,a+1298292|0,d+344|0,b|0,0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break w}v[22692]=0;U(663,d+208|0,d+368|0,21321);b=v[22692];v[22692]=0;if((b|0)==1){break l}qd(d+344|0,d+208|0);xb(d+208|0);v[22692]=0;b=T(275,d+344|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}H:{if(b){v[22692]=0;U(663,d+208|0,d+368|0,16723);b=v[22692];v[22692]=0;if((b|0)==1){break m}v[22692]=0;l=T(374,d+344|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break n}I:{if(!l){break I}j=c&2;g=0;while(1){v[22692]=0;e=T(374,d+344|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break n}if(!e){break I}v[22692]=0;b=Q(189,d+344|0,56)|0;f=v[22692];v[22692]=0;if((f|0)==1){break n}if(!b){break I}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[22692]=0;b=B(e,104)+a|0;f=b+484380|0;R(424,f|0,0);h=v[22692];v[22692]=0;if((h|0)==1){break n}v[22692]=0;W(472,d+344|0,((e<<5)+a|0)+946304|0,32)|0;e=v[22692];v[22692]=0;if((e|0)==1){break n}v[22692]=0;W(475,d+344|0,b+484423|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break n}J:{if(w[d+412|0]<=15){v[22692]=0;e=T(287,d+344|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){break J}break n}v[22692]=0;e=T(190,d+344|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break n}}v[b+484404>>2]=e<<1;v[22692]=0;e=T(190,d+344|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break n}v[f>>2]=e;v[22692]=0;h=T(190,d+344|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=h;v[22692]=0;h=T(190,d+344|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break n}k=b+484388|0;v[k>>2]=h;if(h){i=b+484414|0;u[i>>1]=x[i>>1]|2;v[k>>2]=h+v[e>>2]}v[22692]=0;h=T(374,d+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break H}if(w[d+412|0]<=15){u[b+484410>>1]=h}v[22692]=0;h=T(374,d+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break n}m=b+484414|0;b=x[m>>1];i=8;if(h&1){b=b|1;u[m>>1]=b;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[k>>2]=v[k>>2]>>>1;i=16}u[m>>1]=b&65531|h<<1&4;b=Rc(d+96|0,i,1,0,((h&12)!=0)<<3);K:{if(!j){break K}v[22692]=0;W(329,b|0,f|0,d+208|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break K}break n}g=g+1|0;if(l>>>0>(g&255)>>>0){continue}break}}xb(d+208|0)}v[22692]=0;U(663,d+208|0,d+368|0,18761);b=v[22692];v[22692]=0;if((b|0)==1){break p}qd(d+344|0,d+208|0);xb(d+208|0);v[22692]=0;b=T(275,d+344|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}if(b){l=cd(d+96|0);i=cd(d+232|0);m=cd(d+192|0);v[22692]=0;U(663,d+168|0,d+368|0,17750);b=v[22692];v[22692]=0;if((b|0)==1){break o}e=v[d+180>>2];b=d- -64|0;v[b>>2]=v[d+176>>2];v[b+4>>2]=e;v[d+72>>2]=v[d+184>>2];v[22692]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(666,d+56|0,l|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}v[22692]=0;U(663,d+144|0,d+368|0,17744);b=v[22692];v[22692]=0;if((b|0)==1){break o}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[22692]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(666,d+32|0,i|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}v[22692]=0;U(663,d+120|0,d+368|0,17734);b=v[22692];v[22692]=0;if((b|0)==1){break o}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[22692]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(666,d+8|0,m|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}k=0;v[22692]=0;o=T(374,d+344|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break o}if(o){y=d+208|4;z=d+208|2;q=d+208|6;r=d+208|5;s=d+208|3;e=d+208|1;while(1){v[22692]=0;R(403,d+80|0,d+344|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}j=od(d+80|0);L:{M:{b=d+80|0;N:{if(!w[b|0]){break N}g=w[j|0];v[22692]=0;g=Q(189,d+344|0,B(g,14)+32|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break o}if(!g){break N}b=w[b|0];v[22692]=0;h=W(376,a|0,b|0,0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break o}if(h){break M}}b=w[j|0];v[22692]=0;Q(318,d+344|0,B(b,14)+32|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break L}break o}v[22692]=0;W(472,d+344|0,h+492|0,32)|0;b=v[22692];v[22692]=0;if((b|0)==1){break o}if(!w[j|0]){break L}C=h+88|0;D=h+68|0;E=h+48|0;F=h+236|0;f=0;b=0;while(1){v[22692]=0;R(667,d+344|0,d+208|0);g=v[22692];v[22692]=0;if((g|0)==1){break o}O:{if(!w[d+208|0]|x[a+480190>>1]<w[d+208|0]){break O}g=e;if(w[e|0]>128){t[g|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){g=w[d+208|0];H=wd(F,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}G=w[e|0];b=w[s|0];v[22692]=0;U(668,E|0,b|0,l|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}b=w[r|0];v[22692]=0;U(668,D|0,b|0,i|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}b=w[d+221|0];v[22692]=0;U(668,C|0,b|0,m|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}v[h>>2]=(w[q|0]|w[q+1|0]<<8)+1>>>1;b=w[d+208|0];P:{if(w[s|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break P}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}u[d+118>>1]=w[y|0]<<1;v[22692]=0;u[d+116>>1]=254;n=Pc(d+118|0,d+116|0);g=v[22692];v[22692]=0;Q:{R:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[n>>1];t[g+484418|0]=w[(w[d+219|0]&3)+28869|0];n=g+484419|0;t[n|0]=w[d+218|0];p=g+484420|0;t[p|0]=w[d+217|0]+3>>>2;t[g+484421|0]=w[d+216|0];b=w[n|0];if(b){break R}p=255;break Q}break o}p=_l(Qc((((w[p|0]<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0))}b=G+1|0;t[n|0]=p;if(!(w[r|0]&64)){break O}g=g+484414|0;u[g>>1]=x[g>>1]|32}f=f+1|0;if(w[j|0]>(f&255)>>>0){continue}break}}k=k+1|0;if(o>>>0>(k&255)>>>0){continue}break}}Yo(m);Yo(i);Yo(l)}p=1;l=mc(d+232|0);if(!(c&1)){break s}v[22692]=0;U(663,d+208|0,d+368|0,21076);b=v[22692];v[22692]=0;S:{T:{U:{if((b|0)!=1){b=qd(d+344|0,d+208|0);v[22692]=0;b=T(275,b|0)|0;c=v[22692];v[22692]=0;V:{W:{X:{Y:{Z:{_:{if((c|0)!=1){xb(d+208|0);$:{if(!b){break $}v[22692]=0;c=T(287,d+344|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break _}v[22692]=0;R(669,l|0,c+1|0);b=v[22692];v[22692]=0;if((b|0)==1){break _}if(!c){break $}b=1;while(1){v[22692]=0;e=T(287,d+344|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Z}v[22692]=0;U(288,d+96|0,d+344|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break Z}e=jc(d+208|0,d+96|0);qd(Jg(l,b),e);e=(b|0)==(c|0);xb(d+208|0);xb(d+96|0);b=b+1|0;if(!e){continue}break}}v[22692]=0;U(663,d+208|0,d+368|0,16720);b=v[22692];v[22692]=0;if((b|0)==1){break Y}b=qd(d+344|0,d+208|0);v[22692]=0;b=T(275,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break X}xb(d+208|0);if(!b){break V}f=0;v[22692]=0;m=T(374,d+344|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break u}if(m){while(1){j=32;aa:{if(w[d+412|0]>=16){v[22692]=0;R(670,d+344|0,d+208|0);b=v[22692];v[22692]=0;if((b|0)==1){break U}if(!(w[d+208|0]>32|x[a+480188>>1]>=w[d+208|0])){u[a+480188>>1]=w[d+208|0]}j=w[d+208|0];if(!j){break aa}}b=0;while(1){v[22692]=0;e=T(287,d+344|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break T}c=b;b=b+1|0;if(!(!e|x[a+480188>>1]>(c&65535)>>>0)){u[a+480188>>1]=b}if((b&65535)>>>0<j>>>0){continue}break}}f=f+1|0;if(m>>>0>(f&65535)>>>0){continue}break}}v[22692]=0;Q(188,d+344|0,1)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break W}break u}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}v[22692]=0;o=a+484344|0;R(330,o|0,m|0);b=v[22692];v[22692]=0;if((b|0)==1){break u}if(!m){break V}C=d+208|2;D=d+208|1;g=0;while(1){q=Kb(d+96|0);r=64;s=32;if(w[d+412|0]>=16){v[22692]=0;R(670,d+344|0,d+208|0);b=v[22692];v[22692]=0;if((b|0)==1){break v}s=w[d+208|0];b=w[D|0];v[22692]=0;wW(d+80|0,3,C);c=v[22692];v[22692]=0;if((c|0)==1){break v}v[22692]=0;R(324,d+192|0,d+80|0);c=v[22692];v[22692]=0;if((c|0)==1){break v}Eb(q,d+192|0);vb(d+192|0);r=b+1|0}v[22692]=0;b=W(331,o|0,g&65535,r|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break v}ba:{if(!b){v[22692]=0;Q(318,d+344|0,s<<1)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break ba}break v}b=_b(o,g);v[22692]=0;Q(428,b|0,q|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break v}k=0;if(!s){break ba}while(1){v[22692]=0;b=T(287,d+344|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break v}ca:{if(!b){break ca}if($e(l)>>>0<=b>>>0){break ca}n=k&65535;if(n>>>0>=x[a+480188>>1]){break ca}h=Jg(l,b);vc(h);c=0;while(1){v[22692]=0;b=Q(189,h|0,1)|0;e=v[22692];v[22692]=0;da:{ea:{fa:{ga:{ha:{ia:{if((e|0)!=1){if(!b){break ca}b=_b(o,g);v[22692]=0;b=Wc(b,c,n);e=v[22692];v[22692]=0;if((e|0)==1){break v}v[22692]=0;f=T(374,h|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break v}e=f>>>2|0;switch((f&3)-1|0){case 2:break fa;case 1:break ga;case 0:break ha;default:break ia}}break v}c=(c+e|0)+1|0;break da}if(!c){c=0;break da}f=_b(o,g);v[22692]=0;f=Wc(f,c-1|0,n);i=v[22692];v[22692]=0;if((i|0)!=1){while(1){i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;c=c+1|0;if(r>>>0<=c>>>0){break da}b=B(x[a+480188>>1],6)+b|0;i=e&255;e=e-1|0;if(i){continue}break da}}break v}if(c>>>0<=e>>>0){break ea}f=_b(o,g);v[22692]=0;e=Wc(f,e,n);f=v[22692];v[22692]=0;if((f|0)==1){break S}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break ea}if(e&1){v[22692]=0;f=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break S}t[b|0]=f>>>0>120?-1:f}if(e&2){v[22692]=0;f=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break S}t[b+1|0]=f}j=0;f=0;if(e&4){v[22692]=0;f=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break v}}y=0;if(e&8){v[22692]=0;i=T(374,h|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break v}y=i>>>4|0;j=i&15}z=0;i=0;if(e&16){v[22692]=0;i=T(374,h|0)|0;E=v[22692];v[22692]=0;if((E|0)==1){break v}}if(e&32){v[22692]=0;z=T(374,h|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break v}}v[22692]=0;vW(b,f,j,y,i,z);b=v[22692];v[22692]=0;if((b|0)==1){break v}}c=c+1|0}if(c>>>0<r>>>0){continue}break}}k=k+1|0;if((k&65535)>>>0<s>>>0){continue}break}}vb(q);g=g+1|0;if((m|0)!=(g|0)){continue}break}}v[22692]=0;U(663,d+208|0,d+368|0,20048);b=v[22692];v[22692]=0;ja:{ka:{la:{if((b|0)!=1){b=qd(d+344|0,d+208|0);v[22692]=0;b=T(275,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break la}xb(d+208|0);if(!b){break s}a=a+484344|0;if(!Re(a)){break s}while(1){v[22692]=0;b=Q(189,d+344|0,16)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ka}if(!b){break s}v[22692]=0;R(673,d+344|0,d+208|0);b=v[22692];v[22692]=0;if((b|0)==1){break ja}b=_b(a,0);v[22692]=0;R(674,b|0,d+208|0);b=v[22692];v[22692]=0;if((b|0)==1){break ja}if(Re(a)){continue}break}break s}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}break v}break n}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(q);break t}e=P()|0;O()|0}hd(l);break c}hd(l)}xb(d+344|0);Ed(d+368|0);xb(A)}gb=d+416|0;return p|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Yo(m);Yo(i);Yo(l);break c}e=P()|0;O()|0;xb(d+208|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+96|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+232|0);break d}e=P()|0;O()|0}vb(b)}xb(d+344|0)}Ed(d+368|0)}xb(A);S(e|0);L()}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-512|0;gb=d;vc(b);g=d+432|0;f=_V(b,g);if(!f){kC(g)}a:{if(!f){break a}if(!cT(d+432|0)){break a}if(!Pb(b,Qc(bT(d+432|0),jb))){break a}b:{if(!c){break b}Id(a,4);yg(a);t[a+1074368|0]=4;k=Kb(d+416|0);c:{d:{j=d+470|0;e:{if(!(rd(j,14865,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){e=48;if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break e}v[22692]=0;g=sv(d+449|0,0,20);e=v[22692];v[22692]=0;if((e|0)==1){break d}e=g?1154:34;break e}if(!rd(j,14844,20)){e=1;break e}v[22692]=0;Uj(d+16|0,3,j);g=v[22692];v[22692]=0;f:{g:{h:{if((g|0)==1){break h}v[22692]=0;R(324,d+56|0,d+16|0);g=v[22692];v[22692]=0;if((g|0)==1){break h}v[22692]=0;U(13,d+128|0,5,d+56|0);g=v[22692];v[22692]=0;if((g|0)==1){break g}Eb(k,d+128|0);vb(d+128|0);vb(d+56|0);if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))!=1852141647|(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))!=542396493){break f}e=1048;break e}c=P()|0;O()|0;break c}c=P()|0;O()|0;vb(d+56|0);break c}if(!rd(j,14592,12)){e=16;if((x[d+482>>1]|x[d+484>>1]<<16)==538976288&(x[d+486>>1]|x[d+488>>1]<<16)==538976288){break e}t[a+1074368|0]=5;break e}if(!rd(j,8865,20)){e=48;break e}if(!rd(j,33392,15)){v[22692]=0;g=a+1074312|0;Q(410,g|0,54)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;Q(410,g|0,51)|0;g=v[22692];v[22692]=0;e=16;if((g|0)==1){break d}break e}if(!rd(j,33408,14)){v[22692]=0;Q(410,a+1074312|0,57)|0;g=v[22692];v[22692]=0;e=16;if((g|0)!=1){break e}break d}e=rd(j,14680,11)?16:256}v[22692]=0;s=d+449|0;Uj(d+56|0,3,s);g=v[22692];v[22692]=0;i:{j:{k:{l:{m:{if((g|0)==1){break m}v[22692]=0;R(324,d+128|0,d+56|0);g=v[22692];v[22692]=0;if((g|0)==1){break m}Eb(a+1298268|0,d+128|0);vb(d+128|0);v[a+480260>>2]=1;v[a+480264>>2]=31999;p=a+484360|0;bf(Sb(p),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;u[d+128>>1]=w[d+504|0]|w[d+505|0]<<8;v[22692]=0;u[d+56>>1]=255;g=Pc(d+128|0,d+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break l}u[a+480192>>1]=x[g>>1];if(w[d+508|0]|w[d+509|0]<<8){v[a+480196>>2]=w[d+508|0]|w[d+509|0]<<8}if(w[d+510|0]|w[d+511|0]<<8){E=a,F=Gd(B(w[d+510|0]|w[d+511|0]<<8,1e4),32e4,1e7),v[E+480204>>2]=F}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+506|0]|w[d+507|0]<<8)<<4&16;g=(w[d+506|0]|w[d+507|0]<<8)<<3&32768;v[a+480208>>2]=g|v[a+480208>>2]&-32769;f=Sb(p);m=w[d+496|0]|w[d+497|0]<<8;v[22692]=0;fa(519,f|0,b|0,m|0,65535,65535)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}f=g>>>15|0?(e|0)==34?146:e:e;if(!(f&1024|(w[d+496|0]|w[d+497|0]<<8))){g=Sb(p);v[22692]=0;U(945,g|0,1,0);g=v[22692];v[22692]=0;if((g|0)==1){break d}}g=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[22692]=0;Q(188,b|0,g+60|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[22692]=0;U(946,b|0,d+432|0,a|0);g=v[22692];v[22692]=0;if((g|0)==1){break d}}t[d+415|0]=0;z=c&2;m=mc(d+400|0);g=-1;if(x[a+480192>>1]){break k}break j}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}C=d+74|0;D=d+161|0;e=1;n=1;while(1){n:{v[22692]=0;h=T(190,b|0)|0;i=v[22692];v[22692]=0;o:{p:{q:{r:{s:{t:{if((i|0)!=1){ng(b,4);v[22692]=0;U(947,b|0,d+128|0,(h?h:263)|0);h=v[22692];v[22692]=0;if((h|0)==1){break n}u:{if((f|0)==1){if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==245){v[a+1074308>>2]=16777381;v[22692]=0;f=Q(2,d+56|0,10642)|0;h=v[22692];v[22692]=0;if((h|0)!=1){Eb(k,f);vb(f);f=17;break u}c=P()|0;O()|0;break i}f=16;if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263){break u}v[a+1074308>>2]=16777395;v[22692]=0;f=Q(2,d+56|0,10566)|0;h=v[22692];v[22692]=0;if((h|0)!=1){Eb(k,f);vb(f);f=17;break u}c=P()|0;O()|0;break i}if(w[d+155|0]|w[d+156|0]<<8){break u}if(!(!(f&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263)){f=f|16;break u}if(!(!(f&256)|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==29)){f=f&-257;break u}if(!(f&160)){break u}f=(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==33?f:0}v[22692]=0;h=W(376,a|0,n&65535,0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break n}if(!h){break o}h=((e<<2)+a|0)+900380|0;e=v[h>>2];v[22692]=0;R(948,d+128|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break n}e=w[d+154|0];v:{if((g|0)==-1){g=e;break v}if(!(f&32)|(e|0)==(g|0)){break v}f=f&-161|128}if(!(w[d+155|0]|w[d+156|0]<<8)){break o}e=w[d+369|0];i=w[d+370|0];o=w[d+371|0]|w[d+372|0]<<8;l=w[d+375|0];q=w[d+155|0]|w[d+156|0]<<8;v[22692]=0;U(949,d+112|0,a|0,q|0);q=v[22692];v[22692]=0;if((q|0)==1){break t}f=l|(o|(e|i))?f&-4:f;e=12;while(1){i=x[wd(v[h>>2]+236|0,e)>>1];if(sc(d+112|0)>>>0>i>>>0){i=x[rc(d+112|0,x[wd(v[h>>2]+236|0,e)>>1])>>1];E=wd(v[h>>2]+236|0,e),F=i,u[E>>1]=F}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Nb(m);_q(m);gw(m)}e=w[d+155|0]|w[d+156|0]<<8;v[22692]=0;h=Q(950,d+96|0,e|0)|0;e=v[22692];v[22692]=0;w:{if((e|0)!=1){e=0;if(w[d+155|0]|w[d+156|0]<<8){break w}break s}c=P()|0;O()|0;break q}x:{y:{z:{A:{while(1){v[22692]=0;Q(951,b|0,d+56|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break x}v[22692]=0;MN(d+16|0,d+56|0);i=v[22692];v[22692]=0;B:{if((i|0)==1){break B}v[22692]=0;R(953,m|0,d+16|0);i=v[22692];v[22692]=0;if((i|0)==1){break B}i=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);E=Lb(h,e),F=i,v[E>>2]=F;o=w[d+73|0];if(sc(d+112|0)>>>0>e>>>0){i=x[rc(d+112|0,e)>>1];v[22692]=0;l=(B(i,104)+a|0)+484380|0;R(954,d+56|0,l|0);q=v[22692];v[22692]=0;if((q|0)==1){break A}v[22692]=0;NN(D,l);l=v[22692];v[22692]=0;if((l|0)==1){break A}v[22692]=0;Jk(d+40|0,3,C);l=v[22692];v[22692]=0;if((l|0)==1){break z}v[22692]=0;R(324,d+16|0,d+40|0);l=v[22692];v[22692]=0;if((l|0)==1){break z}v[22692]=0;Q(301,((i<<5)+a|0)+946304|0,d+16|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break y}vb(d+16|0);f=(w[d+70|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=o|r;e=e+1|0;if(e>>>0>=(w[d+155|0]|w[d+156|0]<<8)>>>0){break s}continue}break}c=P()|0;O()|0;break r}c=P()|0;O()|0;break r}c=P()|0;O()|0;break r}c=P()|0;O()|0;vb(d+16|0);break r}c=P()|0;O()|0;break r}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break p}e=0;if(!(w[d+155|0]|w[d+156|0]<<8)){break p}C:{while(1){D:{o=w[Lb(m,e)+3|0];i=v[Lb(h,e)>>2];v[22692]=0;U(288,d+16|0,b|0,((o|0)==11?(i+1>>>1|0)+16|0:i)|0);i=v[22692];v[22692]=0;if((i|0)==1){break D}o=jc(d+56|0,d+16|0);xb(d+16|0);if(!(!z|sc(d+112|0)>>>0<=e>>>0)){l=x[rc(d+112|0,e)>>1];i=Lb(m,e);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);v[22692]=0;v[d+12>>2]=i;v[d+8>>2]=i;i=ca(956,(B(l,104)+a|0)+484380|0,d+8|0,o|0,d+415|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break C}A=i^1|A}xb(d+56|0);e=e+1|0;if(e>>>0<(w[d+155|0]|w[d+156|0]<<8)>>>0){continue}break p}break}c=P()|0;O()|0;break r}c=P()|0;O()|0;xb(d+56|0)}Lc(h)}We(d+112|0);break i}Lc(h);We(d+112|0)}n=n+1|0;e=n&65535;if(e>>>0<=x[a+480192>>1]){continue}break j}break}c=P()|0;O()|0;break i}E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if(!(!(f&2)|r&255)){v[22692]=0;e=sv(s,0,20);h=v[22692];v[22692]=0;if((h|0)==1){break V}f=e?f|16:f}W:{if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break W}if(c&3){v[22692]=0;U(946,b|0,d+432|0,a|0);c=v[22692];v[22692]=0;if((c|0)==1){break V}}if(!z|!x[a+480190>>1]){break W}e=1;c=1;while(1){h=Lb(m,e-1|0);v[22692]=0;W(329,h|0,(B(e,104)+a|0)+484380|0,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break K}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[22692]=0;e=Q(2,d+128|0,13699)|0;c=v[22692];v[22692]=0;if((c|0)==1){break U}v[22692]=0;U(556,a|0,2,e|0);c=v[22692];v[22692]=0;if((c|0)==1){break T}vb(e)}v[22692]=0;c=Q(551,b|0,2650)|0;e=v[22692];v[22692]=0;if((e|0)==1){break V}if(c){v[22692]=0;c=T(190,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break V}v[22692]=0;ca(507,a+1298292|0,b|0,c|0,0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break V}f=f|16}v[22692]=0;c=Q(551,b|0,11322)|0;e=v[22692];v[22692]=0;if((e|0)==1){break E}if(c){v[22692]=0;e=T(190,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break E}v[22692]=0;h=a+901404|0;U(957,b|0,h|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break E}v[22692]=0;Du(h);e=v[22692];v[22692]=0;if((e|0)==1){break E}f=f|16}v[22692]=0;e=Q(551,b|0,11103)|0;h=v[22692];v[22692]=0;if((h|0)==1){break E}if(e){v[22692]=0;e=T(190,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break S}u[d+128>>1]=e>>>5;h=a+484344|0;e=Re(h);v[22692]=0;u[d+56>>1]=e;e=Pc(d+128|0,d+56|0);n=v[22692];v[22692]=0;if((n|0)==1){break R}n=x[e>>1];if(n){e=0;while(1){v[22692]=0;W(758,b|0,d+128|0,32)|0;i=v[22692];v[22692]=0;if((i|0)==1){break Q}i=_b(h,e);v[22692]=0;Q(759,i|0,d+128|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break Q}e=e+1|0;if((n|0)!=(e|0)){continue}break}}f=f|16}v[22692]=0;e=Q(551,b|0,11108)|0;h=v[22692];v[22692]=0;if((h|0)==1){break E}if(e){v[22692]=0;e=T(190,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break P}u[d+128>>1]=(e>>>0)/20;e=x[a+480188>>1];v[22692]=0;u[d+56>>1]=e;e=Pc(d+128|0,d+56|0);h=v[22692];v[22692]=0;if((h|0)==1){break O}h=x[e>>1];if(h){e=0;while(1){v[22692]=0;W(567,b|0,((e<<5)+a|0)+480289|0,20)|0;n=v[22692];v[22692]=0;if((n|0)==1){break J}e=e+1|0;if((h|0)!=(e|0)){continue}break}}f=f|16}v[22692]=0;e=Q(189,b|0,8)|0;h=v[22692];v[22692]=0;if((h|0)==1){break E}if(e){e=v[b+8>>2];v[22692]=0;Q(568,a|0,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break I}f=(e|0)==v[b+8>>2]?f:f|16}if(!(f&16)){break L}if(!(f&4)){break M}v[a+1074308>>2]=17367040;v[22692]=0;e=Q(2,d+128|0,11844)|0;h=v[22692];v[22692]=0;if((h|0)==1){break N}Eb(k,e);vb(e);break L}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;vb(e);break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[22692]=0;e=Q(2,d+128|0,12001)|0;h=v[22692];v[22692]=0;if((h|0)==1){break H}Eb(k,e);vb(e)}X:{Y:{Z:{_:{$:{aa:{ba:{if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))==1852141647&(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))==542396493){v[22692]=0;e=Q(958,d+128|0,d+478|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ba}v[22692]=0;U(13,d+56|0,1,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break aa}v[22692]=0;f=T(959,d+56|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break $}v[a+1074308>>2]=f;vb(d+56|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;vb(e);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;qv(a+1074312|0)}e=f&32;ca:{if(!e){break ca}t[a+1074368|0]=5;if(!c){v[22692]=0;Oo(a+901404|0);c=v[22692];v[22692]=0;if((c|0)==1){break E}}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break ca}v[22692]=0;W(409,a+1074312|0,4,1)|0;c=v[22692];v[22692]=0;if((c|0)==1){break E}}if(!ed(k)){break X}if(!(f&256)|r&255|g+1>>>0>1){break Y}v[22692]=0;c=Q(2,d+128|0,5410)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Z}Eb(k,c);vb(c);break X}c=P()|0;O()|0;break i}c=P()|0;O()|0;break _}c=P()|0;O()|0;vb(d+56|0)}vb(e);break i}c=P()|0;O()|0;break i}if(e){v[22692]=0;c=Q(2,d+128|0,9277)|0;g=v[22692];v[22692]=0;if((g|0)!=1){Eb(k,c);vb(c);break X}c=P()|0;O()|0;break i}v[22692]=0;c=Q(2,d+128|0,6846)|0;g=v[22692];v[22692]=0;if((g|0)==1){break G}Eb(k,c);vb(c)}t[d+40|0]=0;da:{if(x[a+480192>>1]){v[22692]=0;c=Q(584,a|0,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break da}t[d+40|0]=c}v[22692]=0;Y(585,a|0,b|0,1,d+40|0);b=v[22692];v[22692]=0;if((b|0)==1){break da}c=a+1074308|0;e=v[c>>2];ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{if(w[d+40|0]){if(e>>>0>18284543){break ra}v[a+1074308>>2]=18284544;break ra}if(e>>>0<18284544){break qa}}v[22692]=0;b=Q(2,d+56|0,14692)|0;g=v[22692];v[22692]=0;if((g|0)==1){break pa}v[22692]=0;R(960,d+16|0,c|0);g=v[22692];v[22692]=0;if((g|0)==1){break oa}v[22692]=0;U(3,d+128|0,b|0,d+16|0);g=v[22692];v[22692]=0;if((g|0)==1){break na}Eb(k,d+128|0);vb(d+128|0);vb(d+16|0);vb(b);e=v[c>>2]}sa:{if(e-1>>>0>19005952){break sa}v[22692]=0;b=a+484344|0;c=le(b,254);g=v[22692];v[22692]=0;if((g|0)==1){break da}if(!c){c=Sb(p);v[22692]=0;R(961,c|0,254);c=v[22692];v[22692]=0;if((c|0)==1){break da}}v[22692]=0;b=le(b,255);c=v[22692];v[22692]=0;if((c|0)==1){break da}if(b){break sa}b=Sb(p);v[22692]=0;c=v[22692];v[22692]=0;if((c|0)==1){break da}v[22692]=0;$u(b,255,65535);b=v[22692];v[22692]=0;if((b|0)==1){break da}}if(!w[d+415|0]){break ea}v[22692]=0;b=Q(2,d+128|0,12371)|0;c=v[22692];v[22692]=0;if((c|0)==1){break la}Eb(a+1298304|0,b);vb(b);v[22692]=0;b=Q(2,d+128|0,7325)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ka}Eb(a+1298316|0,b);vb(b);v[22692]=0;R(963,d+56|0,1211);b=v[22692];v[22692]=0;if((b|0)==1){break ja}v[d+112>>2]=w[d+491|0];b=w[d+490|0];v[22692]=0;v[d+96>>2]=b;R(595,d+16|0,d+96|0);b=v[22692];v[22692]=0;if((b|0)==1){break ia}v[22692]=0;Y(578,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22692];v[22692]=0;if((b|0)==1){break ha}Eb(a+1298340|0,d+128|0);vb(d+128|0);vb(d+16|0);Hb(d+56|0);v[22692]=0;b=Q(2,d+128|0,7326)|0;c=v[22692];v[22692]=0;if((c|0)==1){break fa}Eb(a+1298352|0,b);break F}c=P()|0;O()|0;break i}c=P()|0;O()|0;break ma}c=P()|0;O()|0;vb(d+16|0)}vb(b);break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break ga}c=P()|0;O()|0;vb(d+16|0)}Hb(d+56|0);break i}c=P()|0;O()|0;break i}v[22692]=0;R(963,d+56|0,1211);b=v[22692];v[22692]=0;ta:{ua:{va:{wa:{if((b|0)!=1){v[d+112>>2]=w[d+491|0];b=w[d+490|0];v[22692]=0;v[d+96>>2]=b;R(595,d+16|0,d+96|0);b=v[22692];v[22692]=0;if((b|0)==1){break wa}v[22692]=0;Y(578,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22692];v[22692]=0;if((b|0)==1){break va}Eb(a+1298304|0,d+128|0);vb(d+128|0);vb(d+16|0);Hb(d+56|0);v[22692]=0;b=Q(2,d+128|0,7326)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ta}Eb(a+1298316|0,b);break F}c=P()|0;O()|0;break i}c=P()|0;O()|0;break ua}c=P()|0;O()|0;vb(d+16|0)}Hb(d+56|0);break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}vb(b);Eb(a+1298328|0,k);v[a+1298364>>2]=v[a+1074308>>2]?8:5;di(m);vb(k);break b}c=P()|0;O()|0}di(m);break c}c=P()|0;O()|0}vb(k);S(c|0);L()}e=1}gb=d+512|0;return e|0}function ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-272|0;gb=d;vc(b);a:{b:{c:{if(!Vu(b,d+176|0)){break c}if(!qU(d+176|0)){break c}if(!Pb(b,Qc(pU(d+176|0),jb))){break c}if(!c){r=1;break c}Id(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=Kb(d+160|0);i=d+216|0;if((w[i|0]|w[i+1|0]<<8)==20479){g=w[d+230|0]|w[d+231|0]<<8}else{g=(w[i|0]|w[i+1|0]<<8)-16464|0}d:{e:{f:{g:{h:{i:{j:{k:{switch(((w[i|0]|w[i+1|0]<<8)&61440)-4096>>>12|0){case 0:l:{if(w[d+238|0]|w[d+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[d+228|0]|w[d+208|0]&15)){break l}if((w[d+214|0]|w[d+215|0]<<8)&65455){break l}m:{if(t[d+227|0]<=-1){v[a+1074308>>2]=18219008;v[22692]=0;f=Q(2,d+32|0,11914)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break m}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[22692]=0;f=Q(2,d+32|0,10642)|0;e=v[22692];v[22692]=0;if((e|0)==1){break j}}Eb(k,f);vb(f);v[22692]=0;l=1;W(409,a+1074312|0,81,1)|0;e=v[22692];v[22692]=0;f=1;if((e|0)!=1){break d}break b}n:{if(w[d+238|0]|w[d+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[d+228|0]|(w[d+214|0]|w[d+215|0]<<8))){break n}if(w[d+229|0]){break n}v[22692]=0;f=Q(2,d+32|0,6587)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a}v[22692]=0;e=Q(2,d+32|0,5626)|0;h=v[22692];v[22692]=0;r=1;if((h|0)!=1){Eb(k,e);vb(e);break f}b=P()|0;O()|0;break a;case 1:v[22692]=0;e=Q(2,d+32|0,3827)|0;h=v[22692];v[22692]=0;f=1;if((h|0)!=1){Eb(k,e);vb(e);break f}b=P()|0;O()|0;break a;case 2:o:{p:{q:{j=w[i|0]|w[i+1|0]<<8;r:{if(j>>>0<=12820){v[22692]=0;e=Q(2,d+32|0,5673)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Eb(k,e);vb(e);break r}b=P()|0;O()|0;break a}v[22692]=0;R(593,d+144|0,1124);e=v[22692];v[22692]=0;if((e|0)==1){break q}e=w[i|0]|w[i+1|0]<<8;v[22692]=0;v[d+128>>2]=e-12820;U(594,d+32|0,d+144|0,d+128|0);e=v[22692];v[22692]=0;if((e|0)==1){break p}Eb(k,d+32|0);vb(d+32|0);Hb(d+144|0)}if((w[i|0]|w[i+1|0]<<8)>>>0<12807){break g}if(w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24)){break o}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hb(d+144|0);break a}e=w[i|0]|w[i+1|0]<<8;f=w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24);v[22692]=0;e=kw(e,f);f=v[22692];v[22692]=0;if((f|0)==1){break i}f=Ar(d+32|0);v[f+44>>2]=e;v[22692]=0;R(597,a+1298368|0,f|0);e=v[22692];v[22692]=0;if((e|0)!=1){break g}b=P()|0;O()|0;break a;case 3:if((w[i|0]|w[i+1|0]<<8)==16640){v[22692]=0;e=Q(2,d+32|0,5458)|0;h=v[22692];v[22692]=0;f=1;if((h|0)!=1){Eb(k,e);vb(e);v[22692]=0;W(409,a+1074312|0,81,1)|0;e=v[22692];v[22692]=0;h=0;if((e|0)==1){break b}break d}b=P()|0;O()|0;break a}e=w[i|0]|w[i+1|0]<<8;f=w[d+230|0]|w[d+231|0]<<8;v[22692]=0;U(598,d+32|0,e|0,f|0);e=v[22692];v[22692]=0;s:{if((e|0)!=1){Eb(k,d+32|0);vb(d+32|0);v[a+480260>>2]=1;if((g|0)<4201){break s}v[22692]=0;W(409,a+1074312|0,7,1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}break h}b=P()|0;O()|0;break a}if((g|0)>=2386){break h}f=1;h=1;break d;case 4:j=(w[i|0]|w[i+1|0]<<8)&4095;e=j<<16;f=a;if(j>>>0>=297){e=e|(w[d+230|0]|w[d+231|0]<<8)}v[f+1074308>>2]=e;v[22692]=0;f=Q(2,d+144|0,14692)|0;e=v[22692];v[22692]=0;t:{u:{v:{if((e|0)!=1){v[22692]=0;R(160,d+128|0,a+1074308|0);e=v[22692];v[22692]=0;if((e|0)==1){break v}v[22692]=0;U(3,d+32|0,f|0,d+128|0);e=v[22692];v[22692]=0;if((e|0)==1){break u}Eb(k,d+32|0);vb(d+32|0);vb(d+128|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break t}b=P()|0;O()|0;vb(d+128|0)}vb(f);break a;case 5:v[22692]=0;e=Q(2,d+32|0,5458)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Eb(k,e);vb(e);v[22692]=0;W(409,a+1074312|0,81,1)|0;e=v[22692];v[22692]=0;f=0;if((e|0)==1){break b}break d}b=P()|0;O()|0;break a;case 6:v[22692]=0;f=Q(2,d+32|0,5484)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a;default:break k}}if((w[i|0]|w[i+1|0]<<8)!=51712){break d}v[22692]=0;f=Q(2,d+32|0,6386)|0;e=v[22692];v[22692]=0;if((e|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[22692]=0;f=1;W(409,a+1074312|0,38,1)|0;e=v[22692];v[22692]=0;h=1;if((e|0)==1){break b}break d}v[22692]=0;e=a+1074312|0;W(409,e|0,7,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;W(409,e|0,23,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;W(409,e|0,38,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;W(409,e|0,107,1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}f=1;v[a+480260>>2]=1;if(j>>>0>12820){break d}}v[22692]=0;_(872,d+144|0);e=v[22692];v[22692]=0;w:{x:{y:{if((e|0)!=1){v[d+16>>2]=w[i+1|0]&15;e=w[i|0];v[22692]=0;v[d>>2]=e;R(595,d+128|0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break y}v[22692]=0;ha(873,d+32|0,d+144|0,k|0,d+16|0,d+128|0);e=v[22692];v[22692]=0;if((e|0)==1){break x}Eb(k,d+32|0);vb(d+32|0);vb(d+128|0);Hb(d+144|0);h=0;break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+128|0)}Hb(d+144|0);break a}vb(f);f=0}v[22692]=0;e=Q(2,d+32|0,12178)|0;j=v[22692];v[22692]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((j|0)!=1){Eb(a+1298304|0,e);vb(e);v[22692]=0;e=Q(2,d+32|0,7698)|0;j=v[22692];v[22692]=0;if((j|0)==1){break M}Eb(a+1298316|0,e);vb(e);q=a+1298328|0;Eb(q,k);v[a+1298364>>2]=v[a+1074308>>2]?8:5;if(f){v[22692]=0;e=a+1074312|0;Q(410,e|0,77)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(410,e|0,78)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(410,e|0,79)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(410,e|0,80)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(410,e|0,82)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(410,e|0,96)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;Q(410,e|0,113)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}}l=((w[i|0]|w[i+1|0]<<8)&61440)>>>0<4097|((w[i|0]|w[i+1|0]<<8)>>>0<12820?((w[i|0]|w[i+1|0]<<8)&61440)==12288:0)?l:1;v[22692]=0;e=a+901404|0;_(874,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break b}if(!l){v[22692]=0;Oo(e);e=v[22692];v[22692]=0;if((e|0)==1){break b}}v[22692]=0;Fk(d+144|0,1,d+176|0);e=v[22692];v[22692]=0;if((e|0)==1){break L}v[22692]=0;R(324,d+32|0,d+144|0);e=v[22692];v[22692]=0;if((e|0)==1){break L}Eb(a+1298268|0,d+32|0);vb(d+32|0);if(w[d+214|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+214|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+214|0]&64?0:(w[i|0]|w[i+1|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}e=w[d+225|0];v[a+480196>>2]=e;if(!(!r|(e|0)!=255?e:0)){v[a+480196>>2]=6}v[a+480204>>2]=B(w[d+226|0],1e4);if(w[d+226|0]<=32){v[a+480204>>2]=r?125e4:32e4}t[d+32|0]=w[d+224|0];v[22692]=0;t[d+144|0]=64;e=ac(d+32|0,d+144|0);f=v[22692];v[22692]=0;if((f|0)==1){break H}e=w[e|0];v[a+480200>>2]=e<<2;if(!((w[i|0]|w[i+1|0]<<8)>>>0>4895|e)){v[a+480200>>2]=256}if((w[d+218|0]|w[d+219|0]<<8)!=1|w[d+227|0]>7){break J}v[d+32>>2]=(w[d+227|0]<<4)+16;v[22692]=0;v[d+144>>2]=127;e=nd(d+32|0,d+144|0);f=v[22692];v[22692]=0;if((f|0)==1){break K}v[a+480228>>2]=v[e>>2];break I}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}if(!(w[d+227|0]!=18?w[d+227|0]!=2:0)){v[a+480228>>2]=32;break I}if(!(w[d+227|0]&127)){v[a+480228>>2]=48;break I}v[d+32>>2]=w[d+227|0]&127;v[22692]=0;v[d+144>>2]=16;e=Gf(d+32|0,d+144|0);f=v[22692];v[22692]=0;if((f|0)==1){break G}v[a+480228>>2]=v[e>>2]}l=v[a+1074308>>2]!=0|t[d+227|0]<0;if(!l){e=v[a+480228>>2];f=e>>>29|0;H=a,I=Qc(mqa(e<<3|5,f,11,0),jb),v[H+480228>>2]=I}u[a+480188>>1]=4;v[a+480232>>2]=h?(g|0)<3299?64:36:36;e=tr(d+120|0);f=0;while(1){v[22692]=0;g=(f<<5)+a|0;s=g+480280|0;Ue(s);h=v[22692];v[22692]=0;if((h|0)==1){break F}h=d+f|0;j=w[h+240|0];N:{if(w[h+240|0]==255){break N}u[a+480188>>1]=f+1;if(!l){break N}u[g+480284>>1]=j&8?204:51}if(t[h+240|0]<=-1){v[s>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[g+480284>>1]=128;tl(d+32|0,e,f);Af(d+32|0,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}g=Sb(a+484360|0);f=w[d+208|0]|w[d+209|0]<<8;v[22692]=0;fa(519,g|0,b|0,f|0,255,254)|0;g=v[22692];v[22692]=0;O:{P:{Q:{R:{S:{if((g|0)!=1){y=mc(d+144|0);g=w[d+210|0]|w[d+211|0]<<8;v[22692]=0;W(327,b|0,y|0,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break S}s=mc(d+128|0);g=w[d+212|0]|w[d+213|0]<<8;v[22692]=0;W(327,b|0,s|0,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break O}if(w[d+229|0]==252){f=0;v[22692]=0;R(875,b|0,d+32|0);g=v[22692];v[22692]=0;if((g|0)==1){break R}while(1){h=(d+32|0)+f|0;g=w[h|0];T:{if(!(g&32)){break T}j=((f<<5)+a|0)+480284|0;if(r){tl(d+16|0,e,f);if(Cb(d+16|0)){break T}g=w[h|0]}u[j>>1]=(((g&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}u[d+32>>1]=w[d+210|0]|w[d+211|0]<<8;f=0;v[22692]=0;u[d+16>>1]=3999;g=Pc(d+32|0,d+16|0);e=v[22692];v[22692]=0;if((e|0)==1){break Q}g=x[g>>1];u[a+480190>>1]=g;if(g){break P}l=0;j=0;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break B}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}h=c&2;g=d+45|0;n=d+80|0;j=0;l=0;U:{V:{W:{while(1){e=rc(y,f);e=w[e|0]|w[e+1|0]<<8;v[22692]=0;e=Q(188,b|0,e<<4)|0;o=v[22692];v[22692]=0;if((o|0)==1){break E}X:{Y:{if(!e){break Y}v[22692]=0;e=Q(876,b|0,d+32|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break E}if(!e){break Y}v[22692]=0;e=f+1|0;o=(B(e,104)+a|0)+484380|0;U(877,d+32|0,o|0,r|0);m=v[22692];v[22692]=0;if((m|0)==1){break E}v[22692]=0;Fk(d,1,n);m=v[22692];v[22692]=0;if((m|0)==1){break X}v[22692]=0;R(324,d+16|0,d|0);m=v[22692];v[22692]=0;if((m|0)==1){break X}v[22692]=0;Q(301,((e<<5)+a|0)+946304|0,d+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break W}vb(d+16|0);if(w[d+32|0]>1){break Y}m=w[d+46|0];z=w[d+47|0];e=g;Z:{if(!h|!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break Z}e=w[e|0];v[22692]=0;e=Q(188,b|0,z<<12|m<<4|e<<20)|0;m=v[22692];v[22692]=0;if((m|0)==1){break V}if(!e){break Z}e=w[d+218|0]|w[d+219|0]<<8;v[22692]=0;XQ(d+16|0,d+32|0,(e|0)==1);e=v[22692];v[22692]=0;if((e|0)==1){break U}v[22692]=0;W(329,d+16|0,o|0,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break U}l=1}j=w[d+72|0]|w[d+73|0]<<8|j}f=f+1|0;if(f>>>0>=x[a+480190>>1]){break D}continue}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;vb(d+16|0);break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break C}_:{$:{aa:{ba:{if(!r){break ba}if((w[i|0]|w[i+1|0]<<8)!=4864?!l|j&65535:1){v[22692]=0;g=a+1074312|0;e=j&65535;W(409,g|0,79,e>>>0>1|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break $}v[22692]=0;W(409,g|0,107,e>>>0<2|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break $}v[22692]=0;g=j&65535;Q(152,q|0,(g>>>0>1?14222:14229)|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break $}if(g>>>0<2){break ba}v[a+480228>>2]=48;break ba}v[22692]=0;g=Q(2,d+32|0,6846)|0;e=v[22692];v[22692]=0;if((e|0)==1){break aa}Eb(q,g);vb(g)}g=i;r=1;if(c&1){break _}break z}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=w[g|0]|w[g+1|0]<<8;u[d+32>>1]=w[d+212|0]|w[d+213|0]<<8;v[22692]=0;u[d+16>>1]=255;g=Pc(d+32|0,d+16|0);e=v[22692];v[22692]=0;ca:{da:{if((e|0)!=1){o=x[g>>1];v[22692]=0;g=a+484344|0;R(330,g|0,o|0);e=v[22692];v[22692]=0;if((e|0)==1){break da}m=c>>>0<4896;if(o){break ca}l=0;q=0;break A}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}C=d+32|5;D=d+32|3;z=d+32|4;E=d+32|2;F=d+32|1;f=0;q=0;l=0;ea:{fa:{while(1){ga:{v[22692]=0;c=W(331,g|0,f&65535,64)|0;e=v[22692];v[22692]=0;if((e|0)==1){break ga}ha:{if(!c){break ha}c=rc(s,f);if(!(w[c|0]|w[c+1|0]<<8)){break ha}c=rc(s,f);c=w[c|0]|w[c+1|0]<<8;v[22692]=0;c=Q(188,b|0,c<<4)|0;e=v[22692];v[22692]=0;if((e|0)==1){break ga}if(!c){break ha}v[22692]=0;Q(318,b|0,2)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ga}j=0;c=_b(g,f);v[22692]=0;A=Rf(c,0);c=v[22692];v[22692]=0;if((c|0)==1){break fa}while(1){v[22692]=0;n=T(374,b|0)|0;c=v[22692];v[22692]=0;ia:{ja:{if((c|0)!=1){if(n){break ja}if(j>>>0>62){break ha}c=_b(g,f);v[22692]=0;j=j+1|0;A=Rf(c,j);c=v[22692];v[22692]=0;if((c|0)!=1){break ia}}b=P()|0;O()|0;break C}G=_i(d+32|0);e=n&31;c=e>>>0<x[a+480188>>1];e=B(e,6)+A|0;if(n&32){v[22692]=0;R(403,d+16|0,b|0);h=v[22692];v[22692]=0;ka:{la:{ma:{if((h|0)!=1){p=od(d+16|0);h=w[d+16|0];if(h>>>0>239){break ma}h=(B(h>>>4|0,12)+(h&15)|0)+13|0;break la}b=P()|0;O()|0;break C}na:{switch(h-254|0){case 0:break la;case 1:break na;default:break ka}}h=0}t[(c?e:d+32|0)|0]=h}t[(c?e+1|0:F)|0]=w[p|0]}oa:{if(!(n&64)){break oa}v[22692]=0;h=T(374,b|0)|0;p=v[22692];v[22692]=0;pa:{if((p|0)!=1){p=c?e+2|0:E;t[d+16|0]=h;if(h<<24>>24>-1|h>>>0>192){break pa}t[p|0]=2;t[(c?e+4|0:z)|0]=w[d+16|0]^128;break oa}b=P()|0;O()|0;break C}t[p|0]=1;v[22692]=0;t[d|0]=64;h=ac(d+16|0,d);p=v[22692];v[22692]=0;if((p|0)==1){break ea}t[(c?e+4|0:z)|0]=w[h|0]}if(!(n&128)){break ia}v[22692]=0;R(403,d+16|0,b|0);h=v[22692];v[22692]=0;qa:{if((h|0)!=1){p=od(d+16|0);n=c?e+3|0:D;t[n|0]=w[d+16|0];h=c?e+5|0:C;t[h|0]=w[p|0];Pu(c?e:G,0);ra:{c=w[n|0];if((c|0)==20){if((w[h|0]&240)!=160){break ia}if((w[i|0]|w[i+1|0]<<8)>>>0<4896){break ra}c=w[n|0]}if((c|0)!=31){break ia}c=w[h|0];if(c>>>0<=15){break qa}m=0;break ia}t[h|0]=w[h|0]&15^136;break ia}b=P()|0;O()|0;break C}if(c>>>0<=7){q=q+1|0;break ia}l=((c|0)!=8)+l|0}if(j>>>0<64){continue}break}}f=f+1|0;if((o|0)!=(f|0)){continue}break A}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0}Ik(s)}Ik(y);break a}if(!m){break z}a=x[a+480188>>1];if((a|0)>(l+q|0)|(a|0)<=(l-q|0)){break z}c=Re(g)-1&65535;a=0;h=0;if(Re(g)>>>0>c>>>0){while(1){if(gi(af(g,a))){b=Vb(af(g,a));i=Zb(af(g,a));a=gb-16|0;gb=a;v[a>>2]=i;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){b=v[a+8>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Xj(a+8|0);if(Gb(a+8|0,a)){continue}break}}gb=a+16|0}h=h+1|0;a=h&65535;if(c>>>0>=a>>>0){continue}break}}}Ik(s);Ik(y);vb(k)}gb=d+272|0;return r|0}b=P()|0;O()|0}vb(k);S(b|0);L()}function r6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=C(0),I=0,J=0,K=0,L=0,M=C(0),N=0,O=0,P=0,Q=0,R=C(0),S=0,T=0,U=C(0),V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=C(0);D=gb-17168|0;gb=D;v[D+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!aq(a+6152|0,b)){break c}k=iy(b,v[a+6148>>2])+$p(b)|0;v[D+17164>>2]=k;if((c|0)==(k|0)){k=c;break b}d:{if((k+4|0)<=(c|0)){if(aq(b,b+k|0)){break d}}v[D+17164>>2]=0;break c}if(k){break b}}g=b;n=Qb(a,0,6668)+6148|0;I=D+17164|0;f=c;e:{if((f|0)>=5){J=f-4|0;while(1){if(iJ(g)){y=iy(g,v[n>>2]);k=y+$p(g)|0;j=0;f:{g:{if(y){break g}l=4;q=h+4|0;while(1){if((J|0)<=((l<<1)+h|0)){break f}y=0;r=g+l|0;h:{if(!aq(g,r)){break h}s=l-$p(g)|0;F=$p(r)+s|0;if((f|0)<(F+(l+q|0)|0)){break h}if(!aq(g,r+F|0)){break h}v[n>>2]=s;y=s;k=l}j=!y;if(y){break g}s=l>>>0<2303;l=l+1|0;if(s){continue}break}}if((f|0)<(h+k|0)|j){break f}s=g;l=f-h|0;j=0;o=0;i:{while(1){F=j+s|0;j=(iy(F,y)+j|0)+$p(F)|0;q=(o|0)!=0;if((l|0)<(j+4|0)){break i}q=0;if(!aq(s,j+s|0)){break i}o=o+1|0;if((o|0)!=10){continue}break}q=1}if(q){break e}}if(!((f|0)!=(k|0)|h)){h=0;k=f;break e}v[n>>2]=0}g=g+1|0;h=h+1|0;if((J|0)!=(h|0)){continue}break}}k=0;h=f}v[I>>2]=k;o=h;k=v[D+17164>>2];if((h+k|0)<=(c|0)?k:0){break b}v[e>>2]=o;o=0;break a}F=b+o|0;v[a+6152>>2]=w[F|0]|w[F+1|0]<<8|(w[F+2|0]<<16|w[F+3|0]<<24);v[e+4>>2]=o;v[e>>2]=k+o;v[e+8>>2]=w[F+3|0]>191?1:2;ba=e,ca=lJ(F),v[ba+12>>2]=ca;v[e+16>>2]=4-(w[F+1|0]>>>1&3);ba=e,ca=hy(F),v[ba+20>>2]=ca;if(!d){o=gy(F);break a}kJ(D+17152|0,F+4|0,k-4|0);if(!(t[F+1|0]&1)){ae(D+17152|0,16)}j:{if(v[e+16>>2]==3){o=0;r=D+17152|0;k=D+3740|0;h=0;c=F;g=w[c+1|0];b=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;f=b-((b|0)!=0)|0;l=w[c+3|0]>191?1:2;k:{if(g&8){j=ae(r,9);l=l<<1;h=ae(r,l+7|0);break k}j=ae(r,l|8)>>>l|0}b=B(f,40);I=b+62e3|0;q=b+62320|0;s=B(f,23)+61808|0;A=-1;l:{while(1){g=w[c+3|0];f=ae(r,12);u[k+4>>1]=f;b=ae(r,9);u[k+6>>1]=b;if((b&65535)>>>0>288){break l}y=g>>>0>191?h<<4:h;ba=k,ca=ae(r,8),t[ba+10|0]=ca;b=ae(r,w[c+1|0]&8?4:9);t[k+13|0]=22;t[k+14|0]=0;v[k>>2]=s;u[k+8>>1]=b;m:{if(ae(r,1)){b=ae(r,2);t[k+11|0]=b;if(!(b&255)){break l}h=ae(r,1);u[k+18>>1]=65287;t[k+12|0]=h;if(w[k+11|0]==2){b=k;n:{if(!(h&255)){v[k>>2]=I;t[k+18|0]=8;g=39;h=0;break n}v[k>>2]=q;g=30;h=w[c+1|0]&8?8:6}t[b+14|0]=g;t[k+13|0]=h;y=y&3855}b=ae(r,10);ba=k,ca=ae(r,3),t[ba+21|0]=ca;ba=k,ca=ae(r,3),t[ba+22|0]=ca;ba=k,ca=ae(r,3),t[ba+23|0]=ca;h=b<<5;break m}t[k+11|0]=0;t[k+12|0]=0;h=ae(r,15);ba=k,ca=ae(r,4),t[ba+18|0]=ca;b=ae(r,3);t[k+20|0]=255;t[k+19|0]=b}t[k+17|0]=h&31;t[k+15|0]=h>>>10;t[k+16|0]=h>>>5&31;i=(f&65535)+i|0;b=k;o:{if(w[c+1|0]&8){f=ae(r,1);break o}f=x[k+8>>1]>499}t[b+24|0]=f;ba=k,ca=ae(r,1),t[ba+25|0]=ca;b=ae(r,1);t[k+27|0]=y>>>12&15;t[k+26|0]=b;k=k+28|0;h=y<<4;l=l-1|0;if(l){continue}break}A=(v[r+4>>2]+i|0)>(v[r+8>>2]+(j<<3)|0)?-1:j}if(!((A|0)<0|v[D+17156>>2]>v[D+17160>>2])){s=D+17152|0;h=v[s+4>>2];k=v[s+8>>2];c=D+912|0;f=v[a+6144>>2];b=f-A|0;g=(f|0)>(A|0)?A:f;f=hc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,g);b=(k-h|0)/8|0;hc(f+g|0,v[s>>2]+(v[s+4>>2]/8|0)|0,b);kJ(c,f,b+g|0);k=v[a+6144>>2]>=(A|0);if(k){Y=a+2304|0;o=v[e+8>>2];Z=D+8620|0;_=D+3852|0;b=0;while(1){$=Qb(_,0,4608);s=D+912|0;y=(B(B(b,o),28)+D|0)+3740|0;l=0;r=a;J=r+6152|0;if((o|0)>=1){h=s+7548|0;while(1){f=B(l,28)+y|0;L=x[f+4>>1];N=v[s+4>>2];O=(s+B(l,39)|0)+16156|0;q=s;i=h;g=l;n=gb-48|0;gb=n;j=f;S=!w[f+13|0]+(w[f+14|0]!=0)|0;V=w[f+25|0];c=n;A=c+44|0;I=J;p:{if(w[J+1|0]&8){p=w[j+27|0];m=w[x[j+8>>1]+62736|0];g=m&3;t[n+47|0]=g;t[n+46|0]=g;g=m>>>2|0;t[n+45|0]=g;t[n+44|0]=g;g=B(S,28)+62640|0;break p}g=w[I+3|0]>>>4&(g|0)!=0;G=g?12:0;Q=x[j+8>>1]>>>g|0;while(1){E=1;m=3;while(1){g=m;p=w[(g+G|0)+62752|0];t[g+(n+44|0)|0]=((Q|0)/(E|0)|0)%(p|0);m=g-1|0;E=B(p,E);if(g){continue}break}G=G+4|0;Q=Q-E|0;if((Q|0)>-1){continue}break}p=-16;g=(B(S,28)+G|0)+62640|0}E=0;while(1){P=w[g+E|0];if(P){q:{if(p&8){hc(c,O,P);break q}T=w[A+E|0];if(!T){Qb(c,0,P);Qb(O,0,P);break q}m=(p|0)>-1?-1:-1<<T^-1;G=0;while(1){S=ae(q,T);t[G+O|0]=(m|0)==(S|0)?-1:S;t[c+G|0]=S;G=G+1|0;if((P|0)!=(G|0)){continue}break}}p=p<<1;c=c+P|0;O=O+P|0;E=E+1|0;if((E|0)!=4){continue}}break}t[c+2|0]=0;t[c|0]=0;t[c+1|0]=0;m=w[j+14|0];r:{if(m){c=2-V|0;p=w[j+23|0]<<c;q=w[j+22|0]<<c;g=w[j+21|0]<<c;c=w[j+13|0];E=0;while(1){A=n+(c+E|0)|0;t[A|0]=g+w[A|0];t[A+1|0]=q+w[A+1|0];t[A+2|0]=p+w[A+2|0];E=E+3|0;if(m>>>0>E>>>0){continue}break}break r}if(!w[j+24|0]){break r}p=0;while(1){c=n+p|0;t[c+11|0]=w[c+11|0]+w[p+62776|0];p=p+1|0;if((p|0)!=10){continue}break}}M=fy(C(2048),((((w[I+3|0]&224)==96)<<1)-w[j+10|0]|0)+258|0);p=0;if((m|0)!=(0-w[j+13|0]|0)){c=V+1|0;while(1){ba=i+(p<<2)|0,da=fy(M,w[n+p|0]<<c),z[ba>>2]=da;p=p+1|0;if(p>>>0<w[j+14|0]+w[j+13|0]>>>0){continue}break}}gb=n+48|0;n=(s+B(l,2304)|0)+2940|0;c=h;S=L+N|0;H=C(0);X=0;I=s;g=v[s+4>>2];q=v[s>>2]+((g|0)/8|0)|0;i=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);i=(i<<24|i<<8&16711680|(i>>>8&65280|i>>>24))<<(g&7);m=g|-8;K=q+4|0;q=f;E=v[f>>2];G=x[f+6>>1];s:{if(!G){G=0;break s}while(1){f=q+X|0;g=w[f+15|0];W=(u[(g<<1)+67200>>1]<<1)+62816|0;O=w[f+18|0];t:{if(g>>>0>=16){L=w[g+67264|0];A=32-L|0;while(1){N=w[E|0]>>>1|0;p=(G|0)>(N|0)?N:G;H=z[c>>2];while(1){j=u[W+(i>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[W+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}P=j&65535;f=P>>>8|0;m=f+m|0;i=i<<f;Q=1;while(1){aa=n;f=P&15;u:{if((f|0)==15){j=i<<L;f=(i>>>A|0)+15|0;m=m+L|0;if((m|0)>=0){while(1){j=w[K|0]<<m|j;i=(m|0)>7;m=m-8|0;K=K+1|0;if(i){continue}break}}i=f;v:{if((f|0)<=128){R=z[(i<<2)+67360>>2];break v}T=i<<3;g=i;i=(i|0)<1024;V=i?T:g;T=V<<1&64;M=C(C((V&63)-T|0)/C(T+(V&-64)|0));R=C(C(C(C(C(C(M*C(.2222222238779068))+C(1.3333333730697632))*M)+C(1))*(i?C(16):C(256)))*z[(V+T>>6<<2)+67360>>2])}R=C(C(R*H)*C(((j|0)>-1?1:-1)|0));break u}j=i;R=C(z[(((i>>>27&16|f)^16)<<2)+67296>>2]*H)}z[aa>>2]=R;P=P>>>4|0;n=n+4|0;f=(f|0)!=0;m=f+m|0;i=j<<f;f=Q&1;Q=0;if(f){continue}break}if((m|0)>-1){while(1){i=w[K|0]<<m|i;f=(m|0)>7;m=m-8|0;K=K+1|0;if(f){continue}break}}p=p-1|0;if(p){continue}break}c=c+4|0;E=E+1|0;G=G-N|0;if((G|0)<1){break t}f=(O|0)>0;O=O-1|0;if(f){continue}break}break t}while(1){p=w[E|0]>>>1|0;Q=(p|0)<(G|0)?p:G;H=z[c>>2];while(1){j=u[W+(i>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[W+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}j=j&65535;f=j>>>8|0;m=f+m|0;i=i<<f;f=1;while(1){g=j&15;z[n>>2]=z[(((g|i>>>27&16)^16)<<2)+67296>>2]*H;j=j>>>4|0;n=n+4|0;g=(g|0)!=0;m=g+m|0;i=i<<g;g=f&1;f=0;if(g){continue}break}if((m|0)>-1){while(1){i=w[K|0]<<m|i;f=(m|0)>7;m=m-8|0;K=K+1|0;if(f){continue}break}}Q=Q-1|0;if(Q){continue}break}c=c+4|0;E=E+1|0;G=G-p|0;if((G|0)<1){break t}f=(O|0)>0;O=O-1|0;if(f){continue}break}}X=X+1|0;if((G|0)>0){continue}break}}f=1-G|0;while(1){w:{g=w[q+26|0]?67184:67152;j=w[g+(i>>>28|0)|0];if(!(j&8)){j=w[g+((i<<4>>>32-(j&3))+(j>>>3)|0)|0]}g=j&7;m=g+m|0;if((S|0)<((m+(K-v[I>>2]<<3)|0)-24|0)){break w}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;H=z[c>>2];f=f>>>1|0;c=c+4|0}i=i<<g;if(j&128){z[n>>2]=(i|0)<0?C(-H):H;m=m+1|0;i=i<<1}if(j&64){z[n+4>>2]=(i|0)<0?C(-H):H;m=m+1|0;i=i<<1}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;H=z[c>>2];f=f>>>1|0;c=c+4|0}if(j&32){z[n+8>>2]=(i|0)<0?C(-H):H;m=m+1|0;i=i<<1}if(j&16){z[n+12>>2]=(i|0)<0?C(-H):H;m=m+1|0;i=i<<1}if((m|0)>=0){while(1){i=w[K|0]<<m|i;g=(m|0)>7;m=m-8|0;K=K+1|0;if(g){continue}break}}n=n+16|0;continue}break}v[I+4>>2]=S;l=l+1|0;if((o|0)!=(l|0)){continue}break}}c=w[r+6155|0];x:{if(c&16){j=0;L=gb-16|0;gb=L;p=s+2940|0;f=p+2304|0;i=y;m=v[i>>2];n=w[i+14|0];A=n+w[i+13|0]|0;I=A;N=L+4|0;v[N+8>>2]=-1;v[N>>2]=-1;v[N+4>>2]=-1;if(A>>>0>=1){while(1){c=0;q=j+m|0;g=w[q|0];h=0;y:{if(!g){break y}z:{while(1){l=c<<2;if(z[l+f>>2]!=C(0)|z[(l|4)+f>>2]!=C(0)){break z}c=c+2|0;if(g>>>0>c>>>0){continue}break}h=g;break y}v[N+((j>>>0)%3<<2)>>2]=j;h=w[q|0]}f=((h&255)<<2)+f|0;j=j+1|0;if((I|0)!=(j|0)){continue}break}}if(w[i+13|0]){f=v[L+12>>2];h=v[L+8>>2];c=v[L+4>>2];c=(c|0)<(h|0)?h:c;c=(c|0)<(f|0)?f:c;v[L+12>>2]=c;v[L+8>>2]=c;v[L+4>>2]=c}N=s+16195|0;g=n?3:1;f=A-g|0;j=0;while(1){h=f+j|0;c=h-g|0;if((c|0)<=v[(L+4|0)+(j<<2)>>2]){c=w[J+1|0]<<28>>31&3}else{c=w[c+N|0]}t[h+N|0]=c;j=j+1|0;if((g|0)!=(j|0)){continue}break}I=L+4|0;q=u[i+36>>1]&1;f=0;l=v[i>>2];c=w[l|0];if(c){i=w[J+1|0]&8?7:64;g=l;while(1){h=w[J+3|0]&32;A:{B:{if(v[I+((f>>>0)%3<<2)>>2]>=(f|0)){break B}n=w[f+N|0];if(n>>>0>=i>>>0){break B}U=h?C(1.4142135381698608):C(1);C:{if(w[J+1|0]&8){h=n<<3;M=z[h+67888>>2];H=z[(h|4)+67888>>2];break C}M=fy(C(1),n+1>>>1<<q);h=n&1;H=h?C(1):M;M=h?M:C(1)}h=p;R=C(M*U);M=C(H*U);m=0;while(1){n=h+(m<<2)|0;U=z[n>>2];z[n+2304>>2]=U*M;z[n>>2]=U*R;m=m+1|0;if((m|0)!=(c|0)){continue}break}break A}if(!h){break A}hJ(p,c)}p=(w[g|0]<<2)+p|0;f=f+1|0;g=l+f|0;c=w[g|0];if(c){continue}break}}gb=L+16|0;break x}if((c&224)!=96){break x}hJ(s+2940|0,576)}if((o|0)>=1){c=s+7708|0;l=0;while(1){h=w[r+6153|0];J=(w[y+12|0]!=0)<<1<<((B((h>>>3&1)+(h>>>4&1)|0,3)+(w[r+6154|0]>>>2&3)|0)==2);q=(s+B(l,2304)|0)+2940|0;m=q;if(w[y+14|0]){g=((s+B(l,2304)|0)+B(J,72)|0)+2940|0;f=c;p=f;K=v[y>>2]+w[y+13|0]|0;A=w[K|0];if(A){h=g;while(1){I=A<<1;n=0;while(1){z[p>>2]=z[h>>2];z[p+4>>2]=z[(A<<2)+h>>2];i=I<<2;z[p+8>>2]=z[i+h>>2];h=h+4|0;p=p+12|0;n=n+1|0;if((n|0)!=(A|0)){continue}break}h=h+i|0;A=w[K+3|0];K=K+3|0;if(A){continue}break}}hc(g,f,p-f|0);i=J-1|0}else{i=31}if((i|0)>=1){while(1){h=0;while(1){g=h<<2;f=g+m|0;I=f;H=z[g+67952>>2];U=z[f+72>>2];R=z[g+67984>>2];f=(17-h<<2)+m|0;M=z[f>>2];z[I+72>>2]=C(H*U)-C(R*M);z[f>>2]=C(R*U)+C(H*M);h=h+1|0;if((h|0)!=8){continue}break}m=m+72|0;h=(i|0)>1;i=i-1|0;if(h){continue}break}}h=q;i=r+B(l,1152)|0;f=w[y+11|0];if(J){gJ(h,i,68016,J);i=B(J,36)+i|0;h=B(J,72)+h|0}D:{if((f|0)==2){j=gb-80|0;gb=j;g=32-J|0;if((g|0)>=1){n=j|8;J=j|4;while(1){I=hc(j,h,72);f=v[i+20>>2];v[h+16>>2]=v[i+16>>2];v[h+20>>2]=f;f=v[i+12>>2];v[h+8>>2]=v[i+8>>2];v[h+12>>2]=f;f=v[i+4>>2];v[h>>2]=v[i>>2];v[h+4>>2]=f;f=i+24|0;ey(I,h+24|0,f);ey(J,h+48|0,f);ey(n,i,f);h=h+72|0;i=i+36|0;f=(g|0)>1;g=g-1|0;if(f){continue}break}}gb=j+80|0;break D}gJ(h,i,B((f|0)==3,72)+68016|0,32-J|0)}g=0;j=q+72|0;while(1){h=1;while(1){f=(h<<2)+j|0;z[f>>2]=-z[f>>2];f=h>>>0<16;h=h+2|0;if(f){continue}break}j=j+144|0;h=g>>>0<30;g=g+2|0;if(h){continue}break}y=y+28|0;l=l+1|0;if((o|0)!=(l|0)){continue}break}}jJ(Y,$,18,v[e+8>>2],d,Z);o=v[e+8>>2];d=B(o,1152)+d|0;b=b+1|0;if(b>>>0<(w[F+1|0]&8?2:1)>>>0){continue}break}}b=a;g=D+912|0;d=v[g+8>>2]>>>3|0;c=v[g+4>>2]+7>>>3|0;f=d-c|0;h=(f|0)>511;e=h?511:f;if((f|0)>=1){vh(b+6156|0,(g+(h?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}ot(a);break a}q=D+17152|0;o=0;k=0;y=0;b=D;s=b;h=0;E:{F:{G:{c=F;f=w[c+3|0];g=f>>>6|0;switch(g-1|0){case 2:break E;case 0:break G;default:break F}}h=(f>>>2&12)+4|0;break E}h=32}f=w[c+1|0];H:{if((f&6)==6){l=32;c=69420;break H}if(!(f&8)){l=30;c=69423;break H}f=w[c+2|0]>>>2&3;c=hy(c)>>>((g|0)!=3)|0;c=c?c:192;if(c>>>0<=55){l=(f|0)==2?12:8;c=69444;break H}l=c>>>0>95?(f|0)!=1?30:27:27;c=69432}t[s+768|0]=l;t[s+769|0]=(h|0)>(l|0)?l:h;h=c;I:{if(!w[b+768|0]){break I}j=69328;while(1){if((o|0)==(y|0)){j=w[h|0]+69328|0;y=w[h+2|0]+y|0;k=w[h+1|0];h=h+3|0}c=o<<1;g=w[ae(q,k)+j|0];t[(c+b|0)+770|0]=g;i=w[b+769|0];if(o>>>0<i>>>0){g=w[ae(q,k)+j|0];i=w[b+769|0]}t[(b+(c|1)|0)+770|0]=i?g:0;g=w[b+768|0];o=o+1|0;if(g>>>0>o>>>0){continue}break}if(!g){k=g<<1;break I}o=0;while(1){c=b+o|0;J:{if(!w[c+770|0]){k=6;break J}k=2;if((w[F+1|0]&6)==6){break J}k=ae(q,2);g=w[b+768|0]}t[c+834|0]=k;k=g<<1&510;o=o+1|0;if(k>>>0>o>>>0){continue}break}}l=b+770|0;F=b+834|0;c=b;h=0;if((k|0)>=1){while(1){g=w[l|0];f=g?19>>>w[h+F|0]&3|4:0;l=l+1|0;s=B(g,3)-6|0;y=4;H=C(0);while(1){if(f&y){g=ae(q,6);i=(g|0)/3|0;H=C(z[(s+(g-B(i,3)|0)<<2)+69456>>2]*C(2097152>>>i|0))}z[c>>2]=H;c=c+4|0;g=y>>>0>1;y=y>>>1|0;if(g){continue}break}h=h+1|0;if((k|0)!=(h|0)){continue}break}}o=w[b+769|0];c=w[b+768|0];if(o>>>0<c>>>0){while(1){t[(b+(o<<1|1)|0)+770|0]=0;o=o+1|0;if((c|0)!=(o|0)){continue}break}}o=0;f=Qb(D+3852|0,0,4608);y=a+2304|0;F=D+8620|0;c=0;K:{while(1){s=((c<<2)+D|0)+3852|0;I=D+17152|0;r=v[e+16>>2]|1;i=0;h=D;l=w[h+768|0];b=576;while(1){L:{if(!(l&255)){l=0;break L}j=s+(B(i,r)<<2)|0;A=0;while(1){k=b;l=w[(h+A|0)+770|0];M:{if(!l){break M}if(l>>>0<=16){if((r|0)<1){break M}g=(-1<<l-1)+1|0;b=0;while(1){ba=(b<<2)+j|0,da=C(ae(I,l)+g|0),z[ba>>2]=da;b=b+1|0;if((r|0)!=(b|0)){continue}break}break M}l=2<<l-17;b=ae(I,(l-(l>>>3|0)|0)+3|0);if((r|0)<1){break M}g=l>>>1|0;q=l|1;l=0;while(1){p=b;b=(b>>>0)/(q>>>0)|0;z[(l<<2)+j>>2]=(p-B(q,b)|0)-g|0;l=l+1|0;if((r|0)!=(l|0)){continue}break}}b=18-k|0;j=(k<<2)+j|0;A=A+1|0;l=w[h+768|0];if(A>>>0<l<<1>>>0){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){g=(o<<2)+D|0;b=f;c=D;h=w[c+769|0];k=f+B(h,72)|0;hc(k+2304|0,k,B(w[c+768|0]-h|0,72));if(w[c+768|0]){l=0;while(1){h=0;while(1){k=(h<<2)+b|0;z[k>>2]=z[k>>2]*z[g>>2];k=k+2304|0;z[k>>2]=z[k>>2]*z[g+12>>2];h=h+1|0;if((h|0)!=12){continue}break}g=g+24|0;b=b+72|0;l=l+1|0;if(l>>>0<w[c+768|0]){continue}break}}jJ(y,f,12,v[e+8>>2],d,F);Qb(f,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[D+17156>>2]<=v[D+17160>>2]){o=o+1|0;if((o|0)==3){break K}continue}break}ot(a);o=0;break a}k=1}o=B(gy(a+6152|0),k)}gb=D+17168|0;return o|0}function nJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;M=gb-144|0;gb=M;k=v[f>>2];N=g&4;K=N?-1:k+((d^-1)+e|0)|0;s=K+1|0;a:{if(d>>>0<=e>>>0?s&K:1){v[f>>2]=0;v[c>>2]=0;l=-3;break a}D=e+k|0;r=v[c>>2];z=r+b|0;E=v[a+60>>2];q=v[a+40>>2];k=v[a+36>>2];C=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];j=b;p=e;l=-1;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(v[a>>2]){case 37:v[a>>2]=37;break b;case 21:v[a>>2]=21;break b;case 17:v[a>>2]=17;break b;case 35:v[a>>2]=35;break b;case 10:v[a>>2]=10;break b;case 39:v[a>>2]=39;break b;case 36:v[a>>2]=36;break b;case 34:break g;case 42:break j;case 41:break k;case 53:break l;case 52:break m;case 51:break n;case 38:break o;case 27:break p;case 26:break q;case 25:break r;case 24:break s;case 23:break t;case 18:break u;case 16:break v;case 14:break w;case 11:break x;case 9:break y;case 7:break z;case 6:break A;case 3:break B;case 32:break C;case 5:break D;case 2:break F;case 1:break G;case 0:break H;default:break b}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;q=0;k=0;C=0;i=0;if(g&1){break G}break E}l=1;if((r|0)<1){break c}v[a+8>>2]=w[b|0];j=b+1|0}l=2;if(j>>>0>=z>>>0){break c}n=w[j|0];v[a+12>>2]=n;h=1;j=j+1|0;l=-1;A=36;k=v[a+8>>2];if(((n|k<<8)>>>0)%31|n&32){break d}n=k&15;if(!N){if((n|0)!=8){break d}n=256<<(k>>>4);if(n>>>0>32768){break d}k=0;if(n>>>0<=s>>>0){break E}break d}k=0;if((n|0)!=8){break d}}h=0;break i}if((r|0)<1){l=5;break c}O=i+8|0;j=b+1|0;m=w[b|0]<<i|m;h=2;break i}if((r|0)<1){l=32;break c}j=b+1|0;m=w[b|0]<<i|m;i=i+8|0;break h}h=1;break i}h=4;break i}h=3;break i}h=7;break i}h=9;break i}h=10;break i}h=11;break i}h=12;break i}h=13;break i}h=14;break i}h=15;break i}h=16;break i}h=17;break i}h=8;break i}h=5;break i}h=6;break i}h=18;break i}o=2;break e}o=1;break e}I:while(1){J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{switch(h|0){case 0:if(i>>>0>2){break wa}h=1;continue;case 17:break ea;case 16:break fa;case 15:break ga;case 14:break ha;case 13:break ia;case 12:break ja;case 11:break ka;case 10:break la;case 9:break ma;case 8:break oa;case 7:break pa;case 6:break qa;case 5:break ra;case 4:break ta;case 3:break ua;case 2:break va;case 1:break xa;default:break da}}l=3;while(1){if(j>>>0>=z>>>0){break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h}h=m&7;v[a+20>>2]=h;s=h>>>1|0;v[a+24>>2]=s;i=i-3|0;m=m>>>3|0;if(h>>>0>=2){break na}O=i;break ca}i=O&-8;m=m>>>(O&7)|0;k=0;h=0;break aa}if(j>>>0<z>>>0){break sa}l=7;break c}while(1){if(j>>>0>=z>>>0){l=6;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;h=1;break aa}t[(a+k|0)+10528|0]=w[j|0];j=j+1|0;h=2;break aa}while(1){if(j>>>0>=z>>>0){l=51;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;break M}if(p>>>0>=D>>>0){l=2;A=52;h=k;break d}t[p|0]=C;k=k-1|0;p=p+1|0;break N}if(p>>>0<D>>>0){break ba}l=2;A=9;h=k;break d}if(j>>>0<z>>>0){n=D-p|0;h=z-j|0;h=h>>>0>n>>>0?n:h;h=h>>>0<k>>>0?h:k;k=k-h|0;p=hc(p,j,h)+h|0;j=h+j|0;break L}l=38;break c}l=-1;A=10;n=0;h=k;ya:{switch(s-1|0){case 0:break ya;case 2:break d;default:break $}}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Qb(a- -64|0,8,144);Qb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;F=1;break R}l=k+18680|0;while(1){if(j>>>0>=z>>>0){l=11;break c}m=w[j|0]<<i|m;n=j+1|0;j=n;h=i+8|0;i=h;G=t[l|0];if(h>>>0<G>>>0){continue}break}j=n;n=k;i=h;k=1;break T}while(1){if(j>>>0>=z>>>0){l=14;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h;h=1;break S}if(j>>>0>=z>>>0){l=16;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break _}break Z}while(1){if(j>>>0>=z>>>0){l=18;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}P=C-16|0;j=h;h=3;break Q}if(j>>>0>=z>>>0){l=23;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break Y}break X}if(p>>>0>=D>>>0){l=2;A=24;h=k;break d}t[p|0]=k;p=p+1|0;break P}while(1){if(j>>>0>=z>>>0){l=25;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=3;break O}if(j>>>0>=z>>>0){l=26;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break W}break V}while(1){if(j>>>0>=z>>>0){l=27;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=6;break O}if(p>>>0>=D>>>0){l=2;A=53;h=k;break d}t[p|0]=w[(E-C&K)+d|0];p=p+1|0;E=E+1|0;break U}h=2;continue}h=8;continue}while(1){za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:if(k>>>0>3){break Ca}if(!i){i=0;h=3;continue I}if(i>>>0>7){break Aa}h=4;continue I;case 1:t[(a+k|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break za;default:break Da}}k=k+1|0;break Ba}h=x[a+10528>>1];if((h|0)==(x[a+10530>>1]^65535)){k=h;break N}l=-1;A=39;break d}h=0;continue}h=1;continue}h=2;continue}}k=0;break T}h=1;break Q}h=2;break Q}h=0;break O}h=1;break O}h=4;break O}h=5;break O}h=7;break O}while(1){Ea:{Fa:{Ga:{if(!k){if(n>>>0>2){break Ga}k=n;G=t[k+18680|0];if(G>>>0<=i>>>0){break Ea}h=9;continue I}k=n<<2;v[(k+a|0)+44>>2]=v[k+61684>>2]+((-1<<G^-1)&m);n=n+1|0;i=i-G|0;m=m>>>G|0;break Fa}k=0;Qb(a+7040|0,0,288);h=0;break S}k=0;continue}k=1;continue}}while(1){Ha:{Ia:{Ja:{if(!h){if(y[a+52>>2]<=k>>>0){break Ja}if(i>>>0>2){break Ha}h=10;continue I}t[(w[k+61664|0]+a|0)+7040|0]=m&7;k=k+1|0;i=i-3|0;m=m>>>3|0;break Ia}v[a+52>>2]=19;F=v[a+24>>2];break R}h=0;continue}h=1;continue}}h=0}while(1){Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(h|0){case 0:h=0;if((F|0)<0){break P}H=Qb(M,0,64);l=B(F,3488)+a|0;Qb(l+352|0,0,3200);r=v[a+24>>2];s=v[((r<<2)+a|0)+44>>2];if(s){while(1){n=(w[(h+l|0)- -64|0]<<2)+H|0;v[n>>2]=v[n>>2]+1;h=h+1|0;if((s|0)!=(h|0)){continue}break}}v[H+64>>2]=0;v[H+68>>2]=0;n=0;A=0;h=1;while(1){l=h<<2;h=h+1|0;l=v[l+H>>2];n=l+n<<1;v[(H- -64|0)+(h<<2)>>2]=n;A=l+A|0;if((h|0)!=16){continue}break};if(!((n|0)==65536|A>>>0<=1)){l=-1;A=35;h=k;break d}if(s){l=-1;I=0;J=B(F,3488)+a|0;while(1){r=w[(I+J|0)- -64|0];Va:{if(!r){break Va}n=(H- -64|0)+(r<<2)|0;h=v[n>>2];v[n>>2]=h+1;n=0;A=r;while(1){s=n;n=h&1|n<<1;h=h>>>1|0;A=A-1|0;if(A){continue}break}if(r>>>0<=10){if(n>>>0>1023){break Va}s=1<<r;h=r<<9|I;while(1){u[((n<<1)+J|0)+352>>1]=h;n=n+s|0;if(n>>>0<1024){continue}break}break Va}n=((n&1023)<<1)+J|0;h=u[n+352>>1];Wa:{if(h){n=l;l=h;break Wa}u[n+352>>1]=l;n=l-2|0}h=s>>>8&8388607;if(r>>>0>=12){while(1){h=h>>>1|0;s=(((h&1)+(l^-1)<<1)+J|0)+2400|0;l=u[s>>1];if(!l){u[s>>1]=n;l=n;n=n-2|0}r=r-1|0;if(r>>>0>11){continue}break}}u[(((h>>>1&1)+(l^-1)<<1)+J|0)+2400>>1]=I;l=n}I=I+1|0;r=v[a+24>>2];if(I>>>0<y[((r<<2)+a|0)+44>>2]){continue}break}}h=0;if((r|0)!=2){break Na}break Ra;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];Xa:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break Xa}break Qa}if(i>>>0<11){break Xa}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Qa}}h=11;continue I;case 2:l=u[(((m&1023)<<1)+a|0)+7328>>1];if((l|0)>=0){break Ta}h=10;while(1){n=m>>>h|0;h=h+1|0;l=u[(((n&1)+(l^-1)<<1)+a|0)+9376>>1];if((l|0)<0){continue}break};break Sa;default:break Ua}}l=t[P+14898|0]+((-1<<q^-1)&m)|0;i=i-q|0;m=m>>>q|0;n=a+k|0;Qb(n+10532|0,(C|0)==16?w[n+10531|0]:0,l);h=l+k|0;break Ra}h=l>>9;l=l&511}i=i-h|0;m=m>>>h|0;C=l;if(l>>>0>15){break Pa}t[(a+k|0)+10532|0]=C;h=k+1|0}n=v[a+48>>2];l=v[a+44>>2];k=n+l|0;if(k>>>0<=h>>>0){break Oa}if(i>>>0<=14){if((z-j|0)<=1){k=h;h=1;continue}m=w[j|0]<<i|m|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}k=h}h=2;continue}if(!((C|0)!=16|k)){l=-1;h=0;A=17;C=16;break d}q=t[C+18655|0];if(q>>>0>i>>>0){break Ma}P=C-16|0;break Ka}if((h|0)!=(k|0)){l=-1;A=21;break d}k=a+10532|0;hc(a- -64|0,k,l);hc(a+3552|0,l+k|0,n);r=v[a+24>>2];k=h}F=r-1|0;v[a+24>>2]=F;break La}h=12;continue I}h=0;continue}h=3;continue}}o=m;h=2}Ya:while(1){Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];mb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break mb}break Za}if(i>>>0<11){break mb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Za}}h=13;continue I;case 1:l=u[(((m&1023)<<1)+a|0)+352>>1];if((l|0)>=0){break kb}h=10;while(1){k=m>>>h|0;h=h+1|0;l=u[(((k&1)+(l^-1)<<1)+a|0)+2400>>1];if((l|0)<0){continue}break};k=l;break jb;case 3:break ab;case 4:break bb;case 5:break fb;case 6:break gb;case 2:break lb;default:break hb}}while(1){h=z-j|0;if(!((D-p|0)>1?(h|0)>=4:0)){if(i>>>0>14){m=o;break Za}if((h|0)<=1){m=o;h=0;continue Ya}m=w[j|0]<<i|o|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0;break Za}nb:{if(i>>>0>14){m=i;h=j;break nb}m=i+16|0;o=(w[j|0]|w[j+1|0]<<8)<<i|o;h=j+2|0}k=u[(((o&1023)<<1)+a|0)+352>>1];ob:{if((k|0)<0){j=10;while(1){i=o>>>j|0;j=j+1|0;k=u[(((i&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}break ob}j=k>>9}i=m-j|0;m=o>>>j|0;if(k&256){j=h;break ib}if(!(i>>>0>14)){m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;i=i+16|0}l=i;j=h;h=u[(((m&1023)<<1)+a|0)+352>>1];pb:{if((h|0)<0){o=10;while(1){i=m>>>o|0;o=o+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break pb}o=h>>9}t[p|0]=k;i=l-o|0;o=m>>>o|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=o;k=h;break ib}h=l>>9;k=l&511}i=i-h|0;m=m>>>h|0;if(k>>>0>255){break ib}h=14;continue I}l=k&511;k=256;if((l|0)==256){break K}q=0;h=m;n=l<<2;k=v[n+60124>>2];s=k;if(l-265>>>0>19){break $a}q=v[n+60252>>2];if(q>>>0>i>>>0){h=15;continue I}h=3;continue}if(!k){o=m;k=-1;break db}k=k-1|0;h=18;continue I}i=i-q|0;o=m>>>q|0;C=((-1<<q^-1)&m)+C|0;break eb}q=u[(((m&1023)<<1)+a|0)+3840>>1];qb:{if((q|0)<0){h=10;while(1){n=m>>>h|0;h=h+1|0;q=u[(((n&1)+(q^-1)<<1)+a|0)+5888>>1];if((q|0)<0){continue}break}n=q;break qb}h=q>>9;n=q&511}i=i-h|0;m=m>>>h|0;h=n<<2;C=v[h+61408>>2];q=0;if(n-4>>>0>25){o=m;break eb}q=v[h+61536>>2];if(q>>>0<=i>>>0){break cb}h=17;continue I}E=p-d|0;if(!(!N|E>>>0>=C>>>0)){l=-1;A=37;m=o;h=k;break d}h=(E-C&K)+d|0;if((h>>>0<p>>>0?p:h)+k>>>0>D>>>0){m=o;h=7;continue}if(k>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;k=k-3|0;if(k>>>0>2){continue}break}}if(!k){break db}t[p|0]=w[h|0];if((k|0)!=1){t[p+1|0]=w[h+1|0]}p=k+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];rb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break rb}break _a}if(i>>>0<11){break rb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break _a}}h=16;continue I}i=i-q|0;h=m>>>q|0;s=((-1<<q^-1)&m)+k|0}k=s;m=h;if(i>>>0>14){break _a}if((z-j|0)<=1){h=4;continue}m=m|w[j|0]<<i|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}h=5;continue}h=1;continue}}if(!k|!i){break L}if(i>>>0>7){break M}h=5;continue}i=i-8|0;C=m&255;m=m>>>8|0;h=6;continue}if(k){break J}k=0}if(t[a+20|0]&1){break h}h=0;continue}h=7;continue}}o=i&-8;sb:{if(!o|b>>>0>=j>>>0){break sb}while(1){o=o-8|0;j=j-1|0;if(j>>>0<=b>>>0){break sb}if(o){continue}break}}if(o){break f}m=(((o&63)>>>0>=32?0:-1<<o)^-1)&m>>>(i&7);h=0;n=0;i=0;if(!(g&1)){break g}o=0;break e}v[a>>2]=34;l=0;break b}aa(3893,10460,2787,3903);L()}while(1){tb:{ub:{vb:{wb:{xb:{yb:{switch(o|0){case 0:if(h>>>0>3){l=0;A=34;i=n;break d}if(n){break xb}i=0;k=h;o=1;continue;case 1:break yb;default:break wb}}if(j>>>0<z>>>0){break ub}l=42;break c}k=h;i=n;if(i>>>0>7){break vb}o=2;continue}while(1){if(j>>>0>=z>>>0){l=41;break c}m=w[j|0]<<i|m;h=i>>>0>4294967287;d=j+1|0;j=d;n=i+8|0;i=n;if(h){continue}break}j=d;h=k}o=m&255;m=m>>>8|0;n=n-8|0;break tb}o=w[j|0];j=j+1|0;h=k;n=i}v[a+16>>2]=v[a+16>>2]<<8|o;h=h+1|0;o=0;continue}}v[a>>2]=A;zb:{if(i>>>0<8|b>>>0>=j>>>0){break zb}while(1){i=i-8|0;j=j-1|0;if(j>>>0<=b>>>0){break zb}if(i>>>0>7){continue}break}}k=h;break b}v[a>>2]=l;l=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=E;v[a+40>>2]=q;v[a+36>>2]=k;v[a+32>>2]=C;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=j-b;c=p-e|0;v[f>>2]=c;if(!(g&9)|(l|0)<0){break a}b=v[a+28>>2];j=b>>>16|0;i=b&65535;if(c){o=(c>>>0)%5552|0;while(1){k=0;if(o>>>0>7){while(1){p=w[e|0]+i|0;n=p+w[e+1|0]|0;m=n+w[e+2|0]|0;h=m+w[e+3|0]|0;f=h+w[e+4|0]|0;d=f+w[e+5|0]|0;b=d+w[e+6|0]|0;i=b+w[e+7|0]|0;j=i+(b+(d+(f+(h+(m+(n+(j+p|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;k=k+8|0;if((k|7)>>>0<o>>>0){continue}break}k=o&8184}m=e;h=k;if(o>>>0>h>>>0){while(1){i=w[m|0]+i|0;j=j+i|0;m=m+1|0;h=h+1|0;if((o|0)!=(h|0)){continue}break}e=(o-k|0)+e|0}c=c-o|0;j=(j>>>0)%65521|0;i=(i>>>0)%65521|0;o=5552;if(c){continue}break}}b=j<<16|i;v[a+28>>2]=b;if(l){break a}l=0;if(!(g&1)){break a}l=(b|0)==v[a+16>>2]?0:-2}gb=M+144|0;return l}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Y=0;e=gb-400|0;gb=e;vc(b);k=gb-32|0;gb=k;j=e+192|0;$T(k+24|0,j);i=yb(k+24|0);h=v[k+28>>2];l=v[k+24>>2];v[k+8>>2]=l;v[k+12>>2]=h;v[k>>2]=l;v[k+4>>2]=h;h=b;cc(k+16|0,h,k);l=yb(k+16|0);if((l|0)==(i|0)){Rb(h,yb(k+24|0))}gb=k+32|0;h=(i|0)==(l|0);if(!h){_T(j)}a:{if(!h){break a}if(!hU(e+192|0)){break a}if(!c){d=1;break a}Id(a,134217728);Df(e+136|0,1084);v[22692]=0;o=e+192|4;U(881,e+8|0,e+136|0,o|0);d=v[22692];v[22692]=0;b:{c:{d:{e:{f:{g:{h:{if((d|0)!=1){Eb(a+1298304|0,e+8|0);vb(e+8|0);Hb(e+136|0);d=Tb(e+8|0,6090);Eb(a+1298316|0,d);vb(d);v[a+480188>>2]=4;v[a+1298364>>2]=2;X=a,Y=Ib(w[e+328|0]|w[e+329|0]<<8),v[X+480196>>2]=Y;d=Ib(w[e+332|0]|w[e+333|0]<<8);v[a+480260>>2]=56;v[a+480264>>2]=13696;X=a,Y=gU(d),v[X+480204>>2]=Y;Br(Sb(a+484360|0),e+200|0,w[e+192|6]);r=a+480190|0;p=cd(e+176|0);q=mc(e+160|0);i:{j:{k:{l:{m:{n:{if(Ib(w[e+392|0]|w[e+393|0]<<8)){while(1){v[22692]=0;d=T(416,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break h}u[e+112>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=Ib(w[e+394|0]|w[e+395|0]<<8);if((Ib(w[o|0]|w[o+1|0]<<8)|0)==2){v[22692]=0;d=T(426,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break i}d=d-2|0}v[22692]=0;U(288,e+136|0,b|0,d|0);d=v[22692];v[22692]=0;o:{p:{q:{if((d|0)!=1){d=jc(e+8|0,e+136|0);xb(e+136|0);v[22692]=0;h=Je(r,e+112|0);k=v[22692];v[22692]=0;if((k|0)==1){break q}C=x[h>>1];u[a+480190>>1]=C;v[22692]=0;h=B(x[e+112>>1],104)+a|0;i=h+484380|0;R(424,i|0,1);k=v[22692];v[22692]=0;r:{if((k|0)==1){break r}if(Ib(w[o|0]|w[o+1|0]<<8)>>>0>1){break p}v[22692]=0;R(882,d|0,h+484423|0);k=v[22692];v[22692]=0;if((k|0)==1){break r}v[22692]=0;Q(318,e+8|0,1)|0;k=v[22692];v[22692]=0;if((k|0)==1){break r}v[22692]=0;W(501,d|0,((x[e+112>>1]<<5)+a|0)+946304|0,30)|0;k=v[22692];v[22692]=0;if((k|0)!=1){break o}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}k=Kb(e+136|0);v[22692]=0;W(531,d|0,k|0,257)|0;j=v[22692];v[22692]=0;s:{t:{if((j|0)==1){break t}v[22692]=0;Q(303,h+484423|0,k|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break t}v[22692]=0;Q(318,e+8|0,1)|0;j=v[22692];v[22692]=0;if((j|0)==1){break t}v[22692]=0;W(531,d|0,k|0,31)|0;j=v[22692];v[22692]=0;if((j|0)==1){break t}v[22692]=0;Q(301,((x[e+112>>1]<<5)+a|0)+946304|0,k|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break t}if(!(v[e+16>>2]&1)){break s}v[22692]=0;Q(318,e+8|0,1)|0;j=v[22692];v[22692]=0;if((j|0)!=1){break s}}d=P()|0;O()|0;vb(k);break f}vb(k)}v[22692]=0;R(883,d|0,e+136|0);d=v[22692];v[22692]=0;if((d|0)==1){break n}v[22692]=0;eU(e+136|0,i);d=v[22692];v[22692]=0;if((d|0)==1){break n}if((Ib(w[o|0]|w[o+1|0]<<8)|0)==2){t[h+484417|0]=w[e+154|0]<<3}u:{if(!Ib(w[o|0]|w[o+1|0]<<8)){break u}v[22692]=0;R(317,q|0,C|0);d=v[22692];v[22692]=0;if((d|0)==1){break n}v[22692]=0;R(885,p|0,C|0);d=v[22692];v[22692]=0;if((d|0)==1){break n}i=Ad(p,x[e+112>>1]-1|0);Pd(i);v[22692]=0;k=T(416,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break j}v[22692]=0;d=Q(189,b|0,k<<3)|0;j=v[22692];v[22692]=0;if((j|0)==1){break j}if(!d){break l}v[22692]=0;R(886,i|0,k|0);d=v[22692];v[22692]=0;if((d|0)==1){break j}d=0;v[e+128>>2]=0;if(!k){if(!(w[h+484414|0]&2)){break u}d=v[h+484384>>2];v[e+120>>2]=d;h=v[h+484388>>2];v[22692]=0;v[e+124>>2]=h-d;R(887,i|0,e+120|0);d=v[22692];v[22692]=0;if((d|0)!=1){break u}d=P()|0;O()|0;break f}while(1){v[22692]=0;h=T(426,b|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break k}v[22692]=0;v[e+120>>2]=h;h=T(426,b|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break k}v[22692]=0;v[e+124>>2]=h;R(887,i|0,e+120|0);h=v[22692];v[22692]=0;if((h|0)==1){break k}d=d+1|0;if(k>>>0>(d&65535)>>>0){continue}break}}xb(e+8|0);g=g+1|0;if(Ib(w[e+392|0]|w[e+393|0]<<8)>>>0>(g&65535)>>>0){continue}break}}D=128;if(Ib(w[o|0]|w[o+1|0]<<8)){break m}v[22692]=0;D=T(416,b|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break m}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}h=a+480188|0;E=w[e+192|7];u[e+118>>1]=4;v:{w:{x:{if(!Ib(w[o|0]|w[o+1|0]<<8)){g=x[h>>1];break x}k=v[b+8>>2];y:{if(!D){break y}while(1){v[22692]=0;d=T(416,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break w}if((d|0)==65535){break y}v[22692]=0;E=T(416,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break w}v[22692]=0;d=T(416,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break w}v[22692]=0;u[e+118>>1]=d;d=Je(h,e+118|0);g=v[22692];v[22692]=0;if((g|0)==1){break w}u[h>>1]=x[d>>1];v[22692]=0;Q(318,b|0,B(x[e+118>>1],E)<<2)|0;d=v[22692];v[22692]=0;if((d|0)==1){break w}f=f+1|0;if((f&65535)>>>0<D>>>0){continue}break}}d=0;v[22692]=0;Q(188,b|0,k|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break v}g=x[h>>1];if(g>>>0>127){break b}}v[22692]=0;G=Q(888,e+136|0,g&65535)|0;d=v[22692];v[22692]=0;if((d|0)!=1){H=Ib(w[e+330|0]|w[e+331|0]<<8);z:{if(!D){break z}K=a+484344|0;V=c&1;h=0;k=0;while(1){d=k;if(Ib(w[o|0]|w[o+1|0]<<8)){v[22692]=0;d=T(416,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break g}if((d|0)==65535){break z}v[22692]=0;E=T(416,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break g}v[22692]=0;g=T(416,b|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break g}u[e+118>>1]=g}F=E&65535;A:{B:{C:{if(!V){break C}v[22692]=0;M=d&65535;d=W(331,K|0,M|0,F|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break g}if(!d){break C}s=0;if(F){break B}break A}v[22692]=0;Q(318,b|0,B(x[e+118>>1],F)<<2)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break A}break g}while(1){d=_b(K,M);v[22692]=0;j=Rf(d,s);d=v[22692];v[22692]=0;D:{if((d|0)!=1){g=0;A=0;E:{F:{switch((H&3)-1|0){case 0:A=!(s&3);break E;case 1:A=!(s&1);break E;case 2:break F;default:break E}}A=(s&3)!=3}I=0;if(!x[e+118>>1]){break D}while(1){d=v[G>>2];v[22692]=0;R(529,e+120|0,b|0);i=v[22692];v[22692]=0;if((i|0)==1){break g}i=B(g,9)+d|0;d=od(e+120|0);z=Te(e+120|0);f=bj(e+120|0);m=B(g,6)+j|0;t[m+1|0]=w[e+120|0];d=w[d|0];t[m|0]=d;f=w[f|0];t[m+5|0]=f;l=m+5|0;if(d){t[m|0]=d+25;t[i+8|0]=0;t[i|0]=0;t[i+1|0]=0;t[i+2|0]=0;t[i+3|0]=0;t[i+4|0]=0;t[i+5|0]=0;t[i+6|0]=0;t[i+7|0]=0;f=w[l|0]}n=f&255;z=w[z|0];G:{if(z>>>0>=240){d=(z&15)<<8|n;if(d){v[22692]=0;d=bn(+(gU(d)>>>0)*1e-4);f=v[22692];v[22692]=0;if((f|0)!=1){t[l|0]=d;t[m+3|0]=17;break G}break g}t[m+3|0]=0;break G}J=n>>>4|0;N=n<<4;d=J|N;H:{switch(z|0){case 0:d=B(g,6)+j|0;if(f&255){t[d+3|0]=1;break G}t[d+3|0]=0;break G;case 1:t[(B(g,6)+j|0)+3|0]=2;break G;case 2:t[(B(g,6)+j|0)+3|0]=3;break G;case 3:v[22692]=0;t[e+8|0]=15;d=ac(l,e+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[i|0]=w[d|0]|16;t[i+7|0]=0;t[i+1|0]=0;t[i+2|0]=0;t[(B(g,6)+j|0)+3|0]=0;break G}break g;case 4:v[22692]=0;t[e+8|0]=15;d=ac(l,e+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[i|0]=w[d|0]|32;t[i+7|0]=0;t[i+1|0]=0;t[i+2|0]=0;t[(B(g,6)+j|0)+3|0]=0;break G}break g;case 5:t[i+7|0]=0;t[i+2|0]=0;t[i+1|0]=f;t[i|0]=0;t[(B(g,6)+j|0)+3|0]=0;break G;case 6:t[i+7|0]=0;t[i+2|0]=f;t[i|0]=0;t[i+1|0]=0;t[(B(g,6)+j|0)+3|0]=0;break G;case 7:t[(B(g,6)+j|0)+3|0]=23;h=0;break G;case 8:t[(B(g,6)+j|0)+3|0]=0;h=d;break G;case 9:t[(B(g,6)+j|0)+3|0]=19;v[22692]=0;t[e+8|0]=15;d=ac(l,e+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[l|0]=w[d|0]|16;break G}break g;case 10:t[(B(g,6)+j|0)+3|0]=19;v[22692]=0;t[e+8|0]=15;d=ac(l,e+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[l|0]=w[d|0]|32;break G}break g;case 11:t[i+3|0]=d;t[(B(g,6)+j|0)+3|0]=0;break G;case 12:d=B(g,6)+j|0;t[d+4|0]=f;t[d+2|0]=1;t[i+3|0]=0;t[d+3|0]=0;break G;case 13:z=B(g,6)+j|0;I:{J:{if(n&240){t[(B(g,6)+j|0)+2|0]=4;d=(f&240)>>>4|0;break J}if(!(n&15)){break I}t[(B(g,6)+j|0)+2|0]=3;d=f&15}t[z+4|0]=d}t[i+3|0]=0;t[(B(g,6)+j|0)+3|0]=0;break G;case 14:t[(B(g,6)+j|0)+3|0]=19;t[l|0]=!(f&255);break G;case 15:t[(B(g,6)+j|0)+3|0]=16;t[l|0]=(f&240)>>>4;H=f&15;break G;case 16:t[i+5|0]=0;t[i+4|0]=f;t[(B(g,6)+j|0)+3|0]=0;break G;case 17:t[i+6|0]=n&15?f:0;t[(B(g,6)+j|0)+3|0]=0;break G;case 18:t[(B(g,6)+j|0)+3|0]=14;break G;case 19:t[i+8|0]=0;t[i+7|0]=f;t[i+2|0]=0;t[i|0]=0;t[i+1|0]=0;t[(B(g,6)+j|0)+3|0]=0;break G;case 20:t[(B(g,6)+j|0)+3|0]=12;break G;case 22:K:{d=w[m+1|0];L:{if(!d){break L}if(Ec(p)>>>0<d>>>0){break L}d=Ad(p,d-1|0);f=f-1|0;t[l|0]=f;v[22692]=0;Q(890,e+8|0,0)|0;n=v[22692];v[22692]=0;if((n|0)==1){break g}v[e+112>>2]=9;d=Ec(d);v[22692]=0;v[e+4>>2]=d;d=Fb(e+112|0,e+4|0);n=v[22692];v[22692]=0;if((n|0)==1){break K}if(y[d>>2]<=(f&255)>>>0){break L}d=B(g,6)+j|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}t[(B(g,6)+j|0)+3|0]=0;break G}break g;case 23:d=w[m+1|0];M:{if(!d){break M}if(Ec(p)>>>0<d>>>0){break M}d=Ad(p,d-1|0);f=f-1|0;t[l|0]=f;f=f&255;if(Ec(d)>>>0<=f>>>0){break M}N:{if(x[Ad(d,f)+8>>1]){break N}if(!fi(a)){f=w[l|0];break N}n=x[r>>1]+1|0;u[r>>1]=n;f=w[l|0];X=Ad(d,f),Y=n,u[X+8>>1]=Y}X=m,Y=w[Ad(d,f)+8|0],t[X+1|0]=Y}t[(B(g,6)+j|0)+3|0]=0;break G;case 24:O:{d=w[m+1|0];P:{if(!d){break P}if(Ec(p)>>>0<d>>>0){break P}d=Ad(p,d-1|0);f=f-1|0;t[l|0]=f;v[22692]=0;Q(890,e+8|0,0)|0;n=v[22692];v[22692]=0;if((n|0)==1){break g}v[e+112>>2]=9;d=Ec(d);v[22692]=0;v[e+4>>2]=d;d=Fb(e+112|0,e+4|0);n=v[22692];v[22692]=0;if((n|0)==1){break O}if(y[d>>2]>(f&255)>>>0){d=B(g,6)+j|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}Q:{if(x[rc(q,w[m+1|0]-1|0)>>1]){break Q}if(!fi(a)){break Q}d=x[r>>1]+1|0;u[r>>1]=d;X=rc(q,w[m+1|0]-1|0),Y=d,u[X>>1]=Y}X=m,Y=w[rc(q,w[m+1|0]-1|0)|0],t[X+1|0]=Y}t[(B(g,6)+j|0)+3|0]=0;break G}break g;case 25:d=w[m+1|0];R:{if(!d){break R}if(Ec(p)>>>0<d>>>0){break R}d=Ad(p,d-1|0);f=f-1|0;t[l|0]=f;f=f&255;if(Ec(d)>>>0<=f>>>0){break R}S:{if(x[Ad(d,f)+10>>1]){break S}if(!fi(a)){f=w[l|0];break S}n=x[r>>1]+1|0;u[r>>1]=n;f=w[l|0];X=Ad(d,f),Y=n,u[X+10>>1]=Y}X=m,Y=w[Ad(d,f)+10|0],t[X+1|0]=Y}t[(B(g,6)+j|0)+3|0]=0;break G;case 29:t[(B(g,6)+j|0)+3|0]=11;t[l|0]=d;if(n&15){t[l|0]=N|15;break G}if((f&255)>>>0<16){break G}t[l|0]=J|240;break G;case 32:if(n&240){t[i+3|0]=J;t[(B(g,6)+j|0)+3|0]=0;break G}t[(B(g,6)+j|0)+3|0]=19;t[l|0]=f&15|192;break G;case 33:t[(B(g,6)+j|0)+3|0]=19;v[22692]=0;t[e+8|0]=15;d=ac(l,e+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[l|0]=w[d|0]|208;break G}break g;case 34:t[(B(g,6)+j|0)+3|0]=19;v[22692]=0;t[e+8|0]=15;d=ac(l,e+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[l|0]=w[d|0]|144;break G}break g;case 73:t[(B(g,6)+j|0)+3|0]=10;break G;case 78:if((f&112|128)==224){t[(B(g,6)+j|0)+3|0]=19;break G}t[(B(g,6)+j|0)+3|0]=0;break G;case 79:d=B(g,6)+j|0;if((f&255)>>>0<=31){t[d+3|0]=16;H=0;break G}t[d+3|0]=17;break G;default:break H}}t[(B(g,6)+j|0)+3|0]=0}n=0;f=w[i+3|0];if(!(w[m+2|0]|!f)){T:{if(f>>>0>=16){t[m+2|0]=5;f=f>>>4|0;break T}t[m+2|0]=6}t[m+4|0]=f;n=1}U:{if(w[m+3|0]){break U}d=w[i+1|0];V:{if(d){t[m+3|0]=2;break V}d=w[i+2|0];if(d){t[m+3|0]=3;break V}d=w[i|0];if(d){t[m+3|0]=19;break V}d=w[i+7|0];if(d){t[m+3|0]=4;t[i+8|0]=d;break V}d=w[i+4|0];if(d){t[m+3|0]=5;t[i+5|0]=d;break V}d=w[i+3|0];if(!(!d|n)){t[m+3|0]=11;t[l|0]=d;if(d&15){d=d|-16;break V}if(!(d&240)){break U}d=d|15;break V}d=w[i+6|0];if(d){t[m+3|0]=8;break V}if(A){t[m+3|0]=20;A=0;d=97;break V}A=0;if(I){break U}d=h&255;if(!d){break U}t[m+3|0]=24;t[l|0]=h;if(h&15){d=h|-16}else{if(!(d&240)){I=1;break U}d=h|15}I=1}t[l|0]=d}g=g+1|0;if(g>>>0<x[e+118>>1]){continue}break}break D}break g}s=s+1|0;if((F|0)!=(s|0)){continue}break}}k=k+1|0;if((k&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[22692]=0;uh(a,1);d=v[22692];v[22692]=0;if((d|0)==1){break g}if(Ib(w[o|0]|w[o+1|0]<<8)){W:{while(1){v[22692]=0;d=Q(189,b|0,2)|0;h=v[22692];v[22692]=0;if((h|0)==1){break g}if(!d){break W}v[22692]=0;d=T(416,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break g}if((d|0)==65535){break W}v[22692]=0;Q(318,b|0,2)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}v[22692]=0;d=T(426,b|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;Q(318,b|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}}break}break g}v[22692]=0;Q(318,b|0,34)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}}X:{if(!(!(c&2)|!C)){d=1;g=1;while(1){c=(B(d,104)+a|0)+484380|0;Y:{if(!v[c>>2]){break Y}h=Rc(e+8|0,8,1,0,0);v[22692]=0;W(329,h|0,c|0,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break X}if(Ec(p)>>>0<d>>>0){break Y}d=d-1|0;h=Ad(p,d);v[22692]=0;R(891,c|0,h|0);h=v[22692];v[22692]=0;Z:{if((h|0)!=1){if(!x[rc(q,d)>>1]){break Z}h=x[rc(q,d)>>1];k=v[c>>2];v[22692]=0;ha(892,c|0,(B(h,104)+a|0)+484380|0,0,k|0,0);h=v[22692];v[22692]=0;if((h|0)!=1){break Z}}break g}d=Ad(p,d);X=e,Y=Vb(d),v[X+8>>2]=Y;X=e,Y=Zb(d),v[X+120>>2]=Y;if(!Gb(e+8|0,e+120|0)){break Y}while(1){d=v[e+8>>2];h=x[d+8>>1];if(h){k=v[d+4>>2];i=v[d>>2];v[22692]=0;ha(892,c|0,(B(h,104)+a|0)+484380|0,i|0,k|0,1);h=v[22692];v[22692]=0;if((h|0)==1){break g}}h=x[d+10>>1];if(h){k=v[d+4>>2];d=v[d>>2];v[22692]=0;ha(892,c|0,(B(h,104)+a|0)+484380|0,d|0,k|0,0);d=v[22692];v[22692]=0;if((d|0)==1){break g}}pr(e+8|0);if(Gb(e+8|0,e+120|0)){continue}break}}g=g+1|0;d=g&65535;if(C>>>0>=d>>>0){continue}break}}GB(G);d=1;break b}break g}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}xb(e+8|0);break c}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;Hb(e+136|0);break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;GB(G);break e}xb(e+8|0)}We(q);aU(p)}S(d|0);L()}d=0}We(q);aU(p)}gb=e+400|0;return d|0}function Cd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=gb-16|0;gb=m;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){f=v[116499];i=a>>>0<11?16:a+11&-8;c=i>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+466044>>2];a=e+8|0;c=v[e+8>>2];b=b+466036|0;m:{if((c|0)==(b|0)){n=465996,o=nqa(-2,d)&f,v[n>>2]=o;break m}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116501];if(k>>>0>=i>>>0){break l}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+466044>>2];b=v[g+8>>2];a=a+466036|0;n:{if((b|0)==(a|0)){f=nqa(-2,c)&f;v[116499]=f;break n}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=i|3;d=g+i|0;b=c<<3;e=b-i|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+466036|0;g=v[116504];b=1<<b;o:{if(!(b&f)){v[116499]=b|f;b=c;break o}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[116504]=d;v[116501]=e;break a}h=v[116500];if(!h){break l}b=(h&0-h)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+466300>>2];d=(v[b+4>>2]&-8)-i|0;c=b;while(1){p:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break p}}c=(v[a+4>>2]&-8)-i|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}j=b+i|0;if(j>>>0<=b>>>0){break k}l=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}i=-1;if(a>>>0>4294967231){break l}a=a+11|0;i=a&-8;j=v[116500];if(!j){break l}d=0-i|0;f=0;q:{if(i>>>0<256){break q}f=31;if(i>>>0>16777215){break q}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|i>>>a+21&1)+28|0}c=v[(f<<2)+466300>>2];r:{s:{t:{if(!c){a=0;break t}a=0;b=i<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){u:{g=(v[c+4>>2]&-8)-i|0;if(g>>>0>=d>>>0){break u}e=c;d=g;if(d){break u}d=0;a=c;break s}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){e=0;a=2<<f;a=(0-a|a)&j;if(!a){break l}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+466300>>2]}if(!a){break r}}while(1){b=(v[a+4>>2]&-8)-i|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[116501]-i>>>0<=d>>>0){break l}h=e+i|0;if(h>>>0<=e>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116501];if(c>>>0>=i>>>0){d=v[116504];b=c-i|0;v:{if(b>>>0>=16){v[116501]=b;a=d+i|0;v[116504]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=i|3;break v}v[116504]=0;v[116501]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}h=v[116502];if(h>>>0>i>>>0){b=h-i|0;v[116502]=b;c=v[116505];a=c+i|0;v[116505]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}a=0;j=i+47|0;b=j;if(v[116617]){c=v[116619]}else{v[116620]=-1;v[116621]=-1;v[116618]=4096;v[116619]=4096;v[116617]=m+12&-16^1431655768;v[116622]=0;v[116610]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=i>>>0){break a}d=v[116609];if(d){b=v[116607];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[466440]&4){break f}w:{x:{d=v[116505];if(d){a=466444;while(1){b=v[a>>2];if(d>>>0<b+v[a+4>>2]>>>0?b>>>0<=d>>>0:0){break x}a=v[a+8>>2];if(a){continue}break}}b=Pp(0);if((b|0)==-1){break g}f=c;d=v[116618];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=i>>>0|f>>>0>2147483646){break g}d=v[116609];if(d){a=v[116607];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=Pp(f);if((b|0)!=(a|0)){break w}break e}f=e&g-h;if(f>>>0>2147483646){break g}b=Pp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|i+48>>>0<=f>>>0)){b=v[116619];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Pp(b)|0)!=-1){f=b+f|0;b=a;break e}Pp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}L()}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116610]=v[116610]|4}if(c>>>0>2147483646){break d}b=v[22688];c=c+3&-4;a=b+c|0;y:{z:{if(a>>>0<=b>>>0?c:0){break z}if(Sw()>>>0<a>>>0){if(!(va(a|0)|0)){break z}}v[22688]=a;break y}v[115173]=48;a=v[22688];b=-1}A:{if(Sw()>>>0>=a>>>0){break A}if(va(a|0)|0){break A}v[115173]=48;break d}v[22688]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=i+40>>>0){break d}}a=v[116607]+f|0;v[116607]=a;if(a>>>0>y[116608]){v[116608]=a}B:{C:{D:{g=v[116505];if(g){a=466444;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break D}a=v[a+8>>2];if(a){continue}break}break C}a=v[116503];if(!(a>>>0<=b>>>0?a:0)){v[116503]=b}a=0;v[116612]=f;v[116611]=b;v[116507]=-1;v[116508]=v[116617];v[116614]=0;while(1){d=a<<3;c=d+466036|0;v[d+466044>>2]=c;v[d+466048>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116502]=c;a=a+b|0;v[116505]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116506]=v[116621];break B}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break C}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[116505]=c;b=v[116502]+f|0;a=b-a|0;v[116502]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116506]=v[116621];break B}if(y[116503]>b>>>0){v[116503]=b}c=b+f|0;a=466444;E:{F:{G:{H:{I:{J:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break J}break}if(!(w[a+12|0]&8)){break I}}a=466444;while(1){c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break H}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=i|3;f=c+(c+8&7?-8-c&7:0)|0;h=i+j|0;c=f-h|0;if((g|0)==(f|0)){v[116505]=h;a=v[116502]+c|0;v[116502]=a;v[h+4>>2]=a|1;break F}if(v[116504]==(f|0)){v[116504]=h;a=v[116501]+c|0;v[116501]=a;v[h+4>>2]=a|1;v[a+h>>2]=a;break F}a=v[f+4>>2];if((a&3)==1){g=a&-8;K:{if(a>>>0<=255){d=v[f+8>>2];a=a>>>3|0;b=v[f+12>>2];if((b|0)==(d|0)){n=465996,o=v[116499]&nqa(-2,a),v[n>>2]=o;break K}v[d+12>>2]=b;v[b+8>>2]=d;break K}i=v[f+24>>2];b=v[f+12>>2];L:{if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break L}M:{a=f+20|0;d=v[a>>2];if(d){break M}a=f+16|0;d=v[a>>2];if(d){break M}b=0;break L}while(1){e=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[e>>2]=0}if(!i){break K}d=v[f+28>>2];a=(d<<2)+466300|0;N:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break N}n=466e3,o=v[116500]&nqa(-2,d),v[n>>2]=o;break K}v[i+(v[i+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break K}}v[b+24>>2]=i;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break K}v[b+20>>2]=a;v[a+24>>2]=b}f=g+f|0;c=c+g|0}v[f+4>>2]=v[f+4>>2]&-2;v[h+4>>2]=c|1;v[c+h>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+466036|0;c=v[116499];a=1<<a;O:{if(!(c&a)){v[116499]=a|c;a=b;break O}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break F}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;e=(a<<2)+466300|0;d=v[116500];b=1<<a;P:{if(!(d&b)){v[116500]=b|d;v[e>>2]=h;v[h+24>>2]=e;break P}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break G}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=h;v[h+24>>2]=d}v[h+12>>2]=h;v[h+8>>2]=h;break F}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116502]=c;a=a+b|0;v[116505]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116506]=v[116621];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116614];v[c+16>>2]=v[116613];v[c+20>>2]=a;a=v[116612];v[c+8>>2]=v[116611];v[c+12>>2]=a;v[116613]=c+8;v[116612]=f;v[116611]=b;v[116614]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break B}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+466036|0;c=v[116499];a=1<<a;Q:{if(!(c&a)){v[116499]=a|c;a=b;break Q}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break B}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+466300|0;c=v[116500];b=1<<a;R:{if(!(c&b)){v[116500]=b|c;v[d>>2]=g;v[g+24>>2]=d;break R}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break E}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break B}a=v[d+8>>2];v[a+12>>2]=h;v[d+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=d;v[h+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116502];if(a>>>0<=i>>>0){break d}b=a-i|0;v[116502]=b;c=v[116505];a=c+i|0;v[116505]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}v[115173]=48;a=0;break a}S:{if(!f){break S}c=v[e+28>>2];a=(c<<2)+466300|0;T:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break T}j=nqa(-2,c)&j;v[116500]=j;break S}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break S}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break S}v[b+20>>2]=a;v[a+24>>2]=b}U:{if(d>>>0<=15){a=d+i|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break U}v[e+4>>2]=i|3;v[h+4>>2]=d|1;v[d+h>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+466036|0;c=v[116499];a=1<<a;V:{if(!(c&a)){v[116499]=a|c;a=b;break V}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break U}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;c=(a<<2)+466300|0;W:{b=1<<a;X:{if(!(b&j)){v[116500]=b|j;v[c>>2]=h;v[h+24>>2]=c;break X}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);i=v[c>>2];while(1){b=i;if((v[b+4>>2]&-8)==(d|0)){break W}c=a>>>29|0;a=a<<1;c=b+(c&4)|0;i=v[c+16>>2];if(i){continue}break}v[c+16>>2]=h;v[h+24>>2]=b}v[h+12>>2]=h;v[h+8>>2]=h;break U}a=v[b+8>>2];v[a+12>>2]=h;v[b+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=b;v[h+8>>2]=a}a=e+8|0;break a}Y:{if(!l){break Y}c=v[b+28>>2];a=(c<<2)+466300|0;Z:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break Z}n=466e3,o=nqa(-2,c)&h,v[n>>2]=o;break Y}v[(v[l+16>>2]==(b|0)?16:20)+l>>2]=e;if(!e){break Y}}v[e+24>>2]=l;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break Y}v[e+20>>2]=a;v[a+24>>2]=e}_:{if(d>>>0<=15){a=d+i|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break _}v[b+4>>2]=i|3;v[j+4>>2]=d|1;v[d+j>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+466036|0;e=v[116504];a=1<<a;$:{if(!(a&f)){v[116499]=a|f;a=c;break $}a=v[c+8>>2]}v[c+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=c;v[e+8>>2]=a}v[116504]=j;v[116501]=d}a=b+8|0}gb=m+16|0;return a|0}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;a:{b:{c:{d:{e:{f:{if(oe(b,18699)){Kb(a);break f}if(oe(b,7105)){b=gb-96|0;gb=b;c=Kb(a);v[22692]=0;_(153,b- -64|0);a=v[22692];v[22692]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22692]=0;v[b+32>>2]=0;R(2020,b+48|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break p}v[22692]=0;Q(1161,c|0,b+48|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break o}vb(b+48|0);v[22692]=0;Q(1901,c|0,13818)|0;a=v[22692];v[22692]=0;q:{if((a|0)==1){break q}v[22692]=0;v[b+32>>2]=6;R(2020,b+48|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break n}v[22692]=0;Q(1161,c|0,b+48|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break m}vb(b+48|0);v[22692]=0;Q(1901,c|0,13818)|0;a=v[22692];v[22692]=0;if((a|0)==1){break q}v[22692]=0;v[b+32>>2]=0;R(2020,b+48|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break l}v[22692]=0;Q(1161,c|0,b+48|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break k}vb(b+48|0);v[22692]=0;a=Q(70,b+48|0,12166)|0;e=v[22692];v[22692]=0;if((e|0)==1){break j}e=Ab(a);vb(a);if(!e){break i}v[22692]=0;Q(1901,c|0,12166)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}e=mc(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[22692]=0;v[b+12>>2]=a;R(2020,b+16|0,b+12|0);a=v[22692];v[22692]=0;if((a|0)==1){break D}v[22692]=0;U(2021,b+32|0,6080,b+16|0);a=v[22692];v[22692]=0;if((a|0)==1){break C}v[22692]=0;R(1407,e|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break B}vb(b+32|0);vb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[22692]=0;d=Q(70,b+32|0,10033)|0;a=v[22692];v[22692]=0;if((a|0)==1){break z}v[22692]=0;R(1407,e|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break y}vb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(!w[(b- -64|0)+17|0]){break w}v[22692]=0;d=Q(70,b+32|0,9733)|0;a=v[22692];v[22692]=0;if((a|0)==1){break v}v[22692]=0;R(1407,e|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break u}vb(d)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}v[22692]=0;d=Q(70,b+32|0,8275)|0;a=v[22692];v[22692]=0;E:{if((a|0)!=1){v[22692]=0;R(1407,e|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break E}vb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(bd(e)){break g}v[22692]=0;Q(1901,c|0,13848)|0;a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;d=Q(70,b+16|0,13818)|0;a=v[22692];v[22692]=0;F:{G:{H:{if((a|0)!=1){v[22692]=0;U(2022,b+32|0,e|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break H}v[22692]=0;Q(1161,c|0,b+32|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break G}vb(b+32|0);vb(d);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;vb(b+32|0)}vb(d);break r}a=P()|0;O()|0}yd(e)}Ef(b- -64|0);break c}yd(e);Ef(b- -64|0);gb=b+96|0;break f}if(oe(b,5250)){v[f>>2]=0;Iq(a,f);break f}if(oe(b,5228)){v[f>>2]=6;Iq(a,f);break f}if(oe(b,8040)){v[f>>2]=0;Iq(a,f);break f}if(oe(b,7837)){Tb(a,12166);break f}if(oe(b,8647)){b=Tb(f,12166);e=Ab(b);v[22692]=0;Q(70,a|0,(e?12881:12562)|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break e}vb(b);break f}if(oe(b,4441)){b=gb-48|0;gb=b;AG(b+16|0);v[22692]=0;_(171,b|0);e=v[22692];v[22692]=0;I:{J:{K:{L:{if((e|0)!=1){v[22692]=0;U(172,b+32|0,b+16|0,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break L}v[22692]=0;R(2023,a|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break K}vb(b+32|0);vb(b);vb(b+16|0);gb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(b+16|0);break a}if(oe(b,7133)){b=gb-16|0;gb=b;h=gb-16|0;gb=h;v[h+8>>2]=101;e=b;d=gb-112|0;gb=d;g=mc(d+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{c=v[h+8>>2];if(c&1){v[22692]=0;v[d+48>>2]=19923014;R(160,d- -64|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break $}v[22692]=0;R(140,g|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break _}vb(d- -64|0);c=v[h+8>>2]}if(!(c&4)){break Y}v[22692]=0;c=ga(161)|0;i=v[22692];v[22692]=0;if((i|0)==1){break X}if(!c){break Z}break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}v[22692]=0;_(162,d- -64|0);c=v[22692];v[22692]=0;aa:{if((c|0)!=1){v[22692]=0;R(140,g|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break aa}vb(d- -64|0);break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}ba:{c=v[h+8>>2];if(!(c&32)){break ba}v[22692]=0;_(153,d- -64|0);c=v[22692];v[22692]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((c|0)!=1){v[22692]=0;R(163,d+48|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break da}c=ed(d+48|0);vb(d+48|0);if(!c){v[22692]=0;_(164,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break ua}v[22692]=0;R(163,d+16|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break ta}v[22692]=0;U(165,d+48|0,d+32|0,d+16|0);c=v[22692];v[22692]=0;if((c|0)==1){break sa}v[22692]=0;R(140,g|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break ra}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}if(!ed(Sp(d- -64|0))){v[22692]=0;_(166,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break oa}c=Sp(d- -64|0);v[22692]=0;U(167,d+48|0,d+32|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break na}v[22692]=0;R(140,g|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break ma}vb(d+48|0);Hb(d+32|0)}v[22692]=0;R(168,d+48|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break ka}c=ed(d+48|0);vb(d+48|0);if(!c){v[22692]=0;_(164,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break ja}v[22692]=0;R(168,d+16|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break ia}v[22692]=0;U(165,d+48|0,d+32|0,d+16|0);c=v[22692];v[22692]=0;if((c|0)==1){break ha}v[22692]=0;R(140,g|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break ga}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}Ef(d- -64|0);c=v[h+8>>2];break ba}c=P()|0;O()|0;break N}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break pa}c=P()|0;O()|0;break qa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break la}c=P()|0;O()|0;vb(d+48|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ea}c=P()|0;O()|0;break fa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0}Ef(d- -64|0);break N}va:{if(!(c&64)){break va}v[22692]=0;c=ga(161)|0;i=v[22692];v[22692]=0;if((i|0)==1){break X}if(c){break va}Kb(d- -64|0);v[22692]=0;R(140,g|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break O}vb(d- -64|0)}if(w[h+8|0]&128){v[22692]=0;_(169,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break W}v[22692]=0;R(140,g|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break V}vb(d- -64|0)}v[22692]=0;i=Q(2,d- -64|0,18699)|0;c=v[22692];v[22692]=0;if((c|0)==1){break U}v[22692]=0;U(170,d|0,g|0,i|0);c=v[22692];v[22692]=0;if((c|0)==1){break T}v[22692]=0;_(171,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break S}v[22692]=0;U(172,e|0,d|0,d+48|0);e=v[22692];v[22692]=0;if((e|0)==1){break R}vb(d+48|0);vb(d);vb(i);mm(g);gb=d+112|0;break M}c=P()|0;O()|0;break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;break P}c=P()|0;O()|0;break Q}c=P()|0;O()|0;vb(d+48|0)}vb(d)}vb(i);break N}c=P()|0;O()|0;vb(d- -64|0)}mm(g);S(c|0);L()}gb=h+16|0;v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,7749)){b=gb-48|0;gb=b;Is(b);v[22692]=0;R(163,b+32|0,b|0);e=v[22692];v[22692]=0;wa:{xa:{if((e|0)!=1){v[22692]=0;R(2023,a|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break xa}vb(b+32|0);Ef(b);gb=b+48|0;break f}a=P()|0;O()|0;break wa}a=P()|0;O()|0;vb(b+32|0)}Ef(b);break a}if(oe(b,8610)){b=gb-32|0;gb=b;Is(b);e=Sp(b);v[22692]=0;R(2023,a|0,e|0);a=v[22692];v[22692]=0;if((a|0)!=1){Ef(b);gb=b+32|0;break f}a=P()|0;O()|0;Ef(b);break a}if(oe(b,7146)){b=gb-48|0;gb=b;Is(b+16|0);ya:{if(v[b+28>>2]){e=v[b+28>>2];v[22692]=0;v[b+12>>2]=e;R(2020,a|0,b+12|0);a=v[22692];v[22692]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Ef(b+16|0);break a}Kb(a)}Ef(b+16|0);gb=b+48|0;break f}if(oe(b,10023)){Is(f);b=w[f+16|0];v[22692]=0;Q(70,a|0,(b?12562:12881)|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(oe(b,7162)){Is(f);b=w[f+17|0];v[22692]=0;Q(70,a|0,(b?12562:12881)|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(oe(b,9421)){Is(f);b=w[f+18|0];v[22692]=0;Q(70,a|0,(b?12562:12881)|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(oe(b,9707)){b=gb-16|0;gb=b;e=gb-32|0;gb=e;d=Kb(b);v[22692]=0;_(153,e|0);c=v[22692];v[22692]=0;za:{Aa:{Ba:{if((c|0)!=1){c=Sp(e);v[22692]=0;Q(154,d|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Ba}Ef(e);gb=e+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Ef(e)}vb(d);break a}v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,5371)){b=gb-16|0;gb=b;e=gb-48|0;gb=e;d=Kb(b);v[22692]=0;R(156,e+16|0,1244);c=v[22692];v[22692]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((c|0)!=1){v[e+12>>2]=13;v[e+8>>2]=0;v[22692]=0;v[e+4>>2]=0;ha(157,e+32|0,e+16|0,e+12|0,e+8|0,e+4|0);c=v[22692];v[22692]=0;if((c|0)==1){break Ga}v[22692]=0;Q(113,d|0,e+32|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Fa}vb(e+32|0);Hb(e+16|0);gb=e+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;vb(e+32|0)}Hb(e+16|0)}vb(d);S(a|0);L()}v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,3876)){b=gb-16|0;gb=b;bo(b,0,16645);v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,3509)){b=gb-48|0;gb=b;c=Tb(b+16|0,14729);v[22692]=0;R(2024,b|0,2);e=v[22692];v[22692]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22692]=0;U(3,b+32|0,c|0,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break Ka}v[22692]=0;R(2023,a|0,b+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break Ja}vb(b+32|0);vb(b);vb(c);gb=b+48|0;break f}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(b+32|0)}vb(b)}break c}if(oe(b,8633)){b=gb-16|0;gb=b;bo(b,0,15045);v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,7756)){b=gb-16|0;gb=b;ws(b,0);v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,7731)){b=gb-16|0;gb=b;ws(b,2);v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(oe(b,7716)){b=gb-16|0;gb=b;ws(b,3);v[22692]=0;R(2023,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}Kb(a)}gb=f+32|0;break d}a=P()|0;O()|0;vb(b);break a}return}vb(c);break a}a=P()|0;O()|0;vb(b)}S(a|0);L()}function rZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-288|0;gb=e;vc(b);if(Pr(b,14886)){o=Kb(e+272|0);v[22692]=0;f=W(352,b|0,o|0,-1)|0;h=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((h|0)!=1){if(!f){break a}v[22692]=0;f=Q(366,b|0,e+264|0)|0;h=v[22692];v[22692]=0;s:{if((h|0)==1){break s}if(!f){break a}if(!TD(e+264|0)){break a}f=Qc(SD(e+264|0),jb);v[22692]=0;f=Q(189,b|0,f|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break s}if(!f){break a}if(!c){break b}v[22692]=0;R(367,a|0,4096);d=v[22692];v[22692]=0;if((d|0)==1){break s}v[22692]=0;Q(368,a+1298268|0,o|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break s}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[22692]=0;uh(a,1);d=v[22692];v[22692]=0;if((d|0)==1){break s}v[22692]=0;d=Q(2,e+112|0,6587)|0;f=v[22692];v[22692]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{if((f|0)!=1){Eb(a+1298304|0,d);vb(d);v[22692]=0;d=Q(2,e+112|0,4104)|0;f=v[22692];v[22692]=0;if((f|0)==1){break B}Eb(a+1298316|0,d);vb(d);v[22692]=0;_(370,e+56|0);d=v[22692];v[22692]=0;if((d|0)==1){break A}t[e+232|0]=w[e+264|1];d=w[e+264|0];v[22692]=0;t[e+16|0]=d;R(371,e+248|0,e+16|0);d=v[22692];v[22692]=0;if((d|0)==1){break z}v[22692]=0;Y(372,e+112|0,e+56|0,e+232|0,e+248|0);d=v[22692];v[22692]=0;if((d|0)==1){break y}Eb(a+1298328|0,e+112|0);vb(e+112|0);vb(e+248|0);Hb(e+56|0);v[a+1298364>>2]=5;if(w[e+264|0]<2){break u}u[e+112>>1]=8192;v[22692]=0;d=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break w}v[22692]=0;u[e+56>>1]=d;d=Je(e+112|0,e+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break w}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[22692]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break v}v[22692]=0;t[e+56|0]=d;d=Bf(e+112|0,e+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break v}v[a+480196>>2]=w[d|0];v[22692]=0;Q(318,b|0,3)|0;d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;d=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break t}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(e+248|0)}Hb(e+56|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+112|0]=32;v[22692]=0;d=T(374,b|0)|0;f=v[22692];v[22692]=0;C:{D:{if((f|0)==1){break D}v[22692]=0;t[e+56|0]=d;d=Bf(e+112|0,e+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break D}v[a+480204>>2]=B(w[d|0],1e4);v[22692]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break C}v[22692]=0;t[e+56|0]=d;d=Bf(e+112|0,e+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break C}v[a+480196>>2]=w[d|0];v[22692]=0;d=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=mc(e+248|0);m=mc(e+232|0);E:{F:{G:{H:{I:{J:{if(!x[a+480192>>1]){break J}i=1;h=e+88|1;p=e+112|12;while(1){v[22692]=0;f=W(376,a|0,i&65535,0)|0;d=v[22692];v[22692]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[22692]=0;d=W(353,b|0,f+492|0,-1)|0;l=v[22692];v[22692]=0;if((l|0)==1){break M}if(!d){break J}v[22692]=0;l=T(374,b|0)|0;d=v[22692];v[22692]=0;N:{O:{P:{Q:{R:{if((d|0)!=1){Qb(e+112|0,0,120);if(!l){break K}if(w[e+264|0]){v[22692]=0;d=Q(377,b|0,e+112|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break R}if(!d){break K}}if(!w[e+264|0]){d=vd(e+104|0,p,96);v[22692]=0;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;U(199,e+56|0,b|0,e+8|0);d=v[22692];v[22692]=0;if((d|0)==1){break Q}if(!yb(e+56|0)){break K}}g=f+236|0;d=0;while(1){j=w[(e+112|0)+d|0];k=x[a+480190>>1];r=wd(g,d),s=(j+k|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[22692]=0;d=f+48|0;U(378,e+16|0,d|0,b|0);g=v[22692];v[22692]=0;if((g|0)==1){break P}v[22692]=0;g=f+68|0;U(378,e+40|0,g|0,b|0);j=v[22692];v[22692]=0;if((j|0)==1){break P}v[22692]=0;j=f+88|0;U(378,e+96|0,j|0,b|0);k=v[22692];v[22692]=0;if((k|0)==1){break P}v[22692]=0;R(379,b|0,e+88|0);k=v[22692];v[22692]=0;if((k|0)==1){break O}v[f>>2]=(w[h|0]|w[h+1|0]<<8)&4095;f=w[h|0]|w[h+1|0]<<8;Uv(e+88|0,d,0);Uv(e+88|0,g,1);Uv(e+88|0,j,2);r=e,s=Vb(d),v[r+56>>2]=s;r=e,s=Zb(d),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){break N}break L}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){S:{d=v[e+56>>2];t[e+76|0]=64;k=w[d+2|0];v[22692]=0;t[e+79|0]=((k<<6)- -64>>>0)/127;k=ac(e+76|0,e+79|0);q=v[22692];v[22692]=0;if((q|0)==1){break S}t[d+2|0]=w[k|0];Oe(e+56|0);if(Gb(e+56|0,e+80|0)){continue}break L}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}r=e,s=Vb(g),v[r+56>>2]=s;r=e,s=Zb(g),v[r+80>>2]=s;T:{if(!Gb(e+56|0,e+80|0)){break T}while(1){U:{d=v[e+56>>2];t[e+76|0]=64;g=w[d+2|0];v[22692]=0;t[e+79|0]=((g<<6)+128>>>0)/255;g=ac(e+76|0,e+79|0);k=v[22692];v[22692]=0;if((k|0)==1){break U}t[d+2|0]=w[g|0];Oe(e+56|0);if(Gb(e+56|0,e+80|0)){continue}break T}break}b=P()|0;O()|0;break d}r=e,s=Vb(j),v[r+56>>2]=s;r=e,s=Zb(j),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){j=1<<(f>>>12&3);while(1){k=v[e+56>>2];d=t[k+2|0];d=jqa(d^-128,d>>31^-1,j,0);g=jb;f=g;V:{if((f|0)>-1?1:(f|0)>=-1?d>>>0>=4294967292:0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break V}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=k,s=Ac(d,f)^128,t[r+2|0]=s;Oe(e+56|0);if(Gb(e+56|0,e+80|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+76>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){d=0;f=0;while(1){v[22692]=0;W(353,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Z}v[22692]=0;R(381,b|0,e+56|0);g=v[22692];v[22692]=0;if((g|0)==1){break Y}v[22692]=0;R(382,e+56|0,(B(x[e+76>>1]+f|0,104)+a|0)+484380|0);f=v[22692];v[22692]=0;if((f|0)==1){break Y}f=w[e+88|0];g=w[e+75|0];v[22692]=0;u[e+80>>1]=f|d<<8&32512|((g&3)!=0)<<15;R(383,m|0,e+80|0);f=v[22692];v[22692]=0;if((f|0)==1){break X}d=d+1|0;f=d&65535;if(l>>>0<=f>>>0){break W}g=x[e+76>>1]+f|0;if(g>>>0<=3999){continue}break}}v[22692]=0;Q(318,b|0,20)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22692]=0;R(383,n|0,e+76|0);d=v[22692];v[22692]=0;if((d|0)==1){break I}v[e+56>>2]=3999;d=x[a+480190>>1];v[22692]=0;v[e+80>>2]=d+l;d=nd(e+56|0,e+80|0);f=v[22692];v[22692]=0;if((f|0)==1){break H}u[a+480190>>1]=v[d>>2]}i=i+1|0;if(x[a+480192>>1]>=(i&65535)>>>0){continue}break}}d=Kb(e+112|0);v[22692]=0;f=W(352,b|0,d|0,-1)|0;h=v[22692];v[22692]=0;if((h|0)==1){break n}if(f){v[22692]=0;U(13,e+56|0,7,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break E}Eb(a+1298280|0,e+56|0);vb(e+56|0)}vb(d);d=0;while(1){v[22692]=0;f=(d<<5)+a|0;Ue(f+480280|0);h=v[22692];v[22692]=0;if((h|0)==1){break G}v[22692]=0;U(355,b|0,f+480289|0,-1);f=v[22692];v[22692]=0;if((f|0)==1){break G}d=d+1|0;if((d|0)!=32){continue}break}v[22692]=0;d=Q(385,b|0,e+40|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break l}if(!d){break i}if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))>>>0<12){break m}d=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);v[22692]=0;d=Q(189,b|0,d-11|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break l}if(d){break F}break m}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[e+96>>2]=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))-11;i=mc(e+112|0);v[22692]=0;W(358,b|0,i|0,v[e+96>>2])|0;d=v[22692];v[22692]=0;if((d|0)==1){break p}v[22692]=0;v[e+56>>2]=50529027;d=Fb(e+96|0,e+56|0);f=v[22692];v[22692]=0;if((f|0)==1){break q}v[e+88>>2]=B(v[d>>2],85);h=Kb(e+56|0);d=e+40|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22692]=0;v[e+16>>2]=d;d=Fb(e+88|0,e+16|0);f=v[22692];v[22692]=0;if((f|0)==1){break r}d=v[d>>2];v[22692]=0;R(60,h|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break r}if(v[e+96>>2]){f=0;while(1){_:{l=w[kc(i,f)|0];d=f+1|0;if(!((l|0)!=255|v[e+96>>2]-d>>>0<2)){d=t[kc(i,d)|0];l=w[kc(i,f+2|0)|0];r=e,s=ef(h),v[r+16>>2]=s;Hd(e+32|0,e+16|0);v[22692]=0;ca(359,h|0,v[e+32>>2],l|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){d=f+3|0;break _}break r}v[22692]=0;R(61,h|0,l<<24>>24);f=v[22692];v[22692]=0;if((f|0)!=1){break _}break r}f=d;if(y[e+96>>2]>d>>>0){continue}break}}v[22692]=0;Y(360,e+16|0,5,7,h|0);d=v[22692];v[22692]=0;$:{if((d|0)!=1){Eb(h,e+16|0);vb(e+16|0);d=zb(Jb(h));f=Ab(h);v[22692]=0;fa(361,a+1298292|0,d|0,f|0,74,0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break $}vb(h);gc(i);break m}break r}break r}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;vb(h);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}gc(i);break d}b=P()|0;O()|0;vb(d);break d}d=Sb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[22692]=0;fa(362,d|0,b|0,f|0,65535,65535)|0;d=v[22692];v[22692]=0;if((d|0)==1){break l}l=c&1;if(l){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[22692]=0;R(330,a+484344|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break l}}f=e+264|3;aa:{if(!(w[f|0]|w[f+1|0]<<8)){break aa}h=a+484344|0;d=0;while(1){v[22692]=0;i=Q(189,b|0,4)|0;g=v[22692];v[22692]=0;ba:{if((g|0)!=1){if(i){break ba}break aa}b=P()|0;O()|0;break d}v[22692]=0;i=T(190,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}v[22692]=0;U(288,e+56|0,b|0,i|0);i=v[22692];v[22692]=0;if((i|0)==1){break g}i=jc(e+112|0,e+56|0);xb(e+56|0);ca:{if(!l){break ca}v[22692]=0;g=T(374,i|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break e}v[22692]=0;Q(318,e+112|0,1)|0;j=v[22692];v[22692]=0;if((j|0)==1){break e}v[22692]=0;g=W(331,h|0,d&65535,g+1|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break e}if(!g){break ca}v[22692]=0;U(356,i|0,e+56|0,-1);g=v[22692];v[22692]=0;if((g|0)==1){break e}g=_b(h,d);v[22692]=0;R(357,g|0,e+56|0);g=v[22692];v[22692]=0;if((g|0)==1){break e}g=_b(h,d);v[22692]=0;U(364,g|0,1,i|0);i=v[22692];v[22692]=0;if((i|0)==1){break e}}xb(e+112|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break i}if(!x[a+480190>>1]){break j}d=0;while(1){if(w[rc(m,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Rc(e+112|0,u[f+484414>>1]&1?16:8,1,0,u[rc(m,d)>>1]>-1?0:6);v[22692]=0;W(329,d|0,f+484380|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break k}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break j}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(!x[a+480190>>1]){break i}b=0;while(1){c=w[rc(m,b)|0];da:{if(!c){break da}c=c-1&65535;if(sc(n)>>>0<=c>>>0){break da}c=(w[rc(m,b)+1|0]&127)+x[rc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break da}f=B(c,104);d=(f+a|0)+484380|0;if(!Nd(d)){break da}h=a+484380|0;c=h+B(b+1|0,104)|0;f=f+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[f+34>>1]&1;v[c>>2]=v[d>>2];v[22692]=0;h=T(386,c|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break h}if(!h){break da}hc(zb(v[c+20>>2]),zb(v[f+20>>2]),Zi(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}We(m);We(n);break b}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;xb(e+112|0)}We(m);We(n)}vb(o);S(b|0);L()}d=1}vb(o)}gb=e+288|0;return d|0}function i8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-48|0;gb=e;d=Tb(e+32|0,8844);f=_g(c,d);vb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){ql(a,v[b+24>>2]+1298316|0);break k}d=Tb(e+32|0,8192);f=_g(c,d);vb(d);if(f){ql(a,v[b+24>>2]+1298304|0);break k}d=Tb(e+32|0,8674);f=_g(c,d);vb(d);if(f){ql(a,v[b+24>>2]+1298352|0);break k}d=Tb(e+32|0,8184);f=_g(c,d);vb(d);if(f){ql(a,v[b+24>>2]+1298340|0);break k}d=Tb(e+32|0,5361);f=_g(c,d);vb(d);if(f){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=39040;l:{while(1){if((d|0)==v[b>>2]){bo(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=39088){continue}break}Kb(c)}v[22692]=0;R(2023,a|0,e+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break j}vb(e+32|0);break k}d=Tb(e+32|0,8169);f=_g(c,d);vb(d);if(f){m=v[v[b+24>>2]+480184>>2];c=gb-48|0;gb=c;b=39040;h=Bk(c+32|0);d=Kb(e+32|0);while(1){if((m|0)==v[b>>2]){f=v[b+4>>2];v[22692]=0;f=Q(2,c+16|0,f|0)|0;i=v[22692];v[22692]=0;m:{n:{o:{p:{q:{r:{if((i|0)!=1){v[22692]=0;U(1398,c|0,h|0,f|0);i=v[22692];v[22692]=0;if((i|0)==1){break p}if(!w[c+4|0]){break m}if(!ed(d)){v[22692]=0;i=Q(2,c|0,14840)|0;g=v[22692];v[22692]=0;if((g|0)==1){break r}v[22692]=0;Q(113,d|0,i|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break q}vb(i)}v[22692]=0;Q(113,d|0,f|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(i);break o}b=P()|0;O()|0}vb(f)}vb(d);$N(h);S(b|0);L()}vb(f)}b=b+12|0;if((b|0)!=39088){continue}break}$N(h);gb=c+48|0;v[22692]=0;R(2023,a|0,e+32|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,5427);f=_g(c,d);vb(d);if(f){ql(a,v[b+24>>2]+1298328|0);break k}d=Tb(e+32|0,2712);f=_g(c,d);vb(d);if(f){ql(a,v[b+24>>2]+1298280|0);break k}d=Tb(e+32|0,9212);f=_g(c,d);vb(d);if(f){eg(e+32|0,v[b+24>>2]+1298268|0);v[22692]=0;U(2076,a|0,b|0,e+32|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,8617);f=_g(c,d);vb(d);if(f){s:{if(!bd(zy(v[b+24>>2]))){if(v[TK(zy(v[b+24>>2]))+12>>2]){break s}}Kb(a);break k}b=TK(zy(v[b+24>>2]));g=gb-192|0;gb=g;hc(g+144|0,b,44);h=v[b+44>>2];if(h){hc(g+44|0,b,44);c=gb-16|0;gb=c;b=bz(v[g+64>>2]+1900|0,v[g+60>>2]+1|0,v[g+56>>2])-bz(1970,1,1)|0;b=jqa(b,b>>31,86400,0);d=B(v[g+52>>2],3600);f=d;b=b+d|0;d=jb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[g+48>>2],60);i=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<i>>>0?b+1|0:b;d=v[g+44>>2];i=d;f=d+f|0;d=(d>>31)+b|0;b=zN(c+8|0,f,f>>>0<i>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];gb=c+16|0;v[g+96>>2]=b;v[g+100>>2]=d;d=g+88|0;f=v[g+96>>2];i=v[g+100>>2];c=2147483647;l=fe(+(h>>>0)*.054945054945054944);b=-1;t:{if(!(l<0x8000000000000000)){break t}c=-2147483648;b=0;if(!(l>-0x8000000000000000)){break t}if(D(l)<0x8000000000000000){c=D(l)>=1?~~(l>0?F(H(l*2.3283064365386963e-10),4294967295):I((l-+(~~l>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~l>>>0;break t}b=0}j=d;d=c+i|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=zN(j,f,d);k=gb-16|0;gb=k;h=v[b>>2];n=v[b+4>>2];v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=bz(1970,1,1)+kqa(h,n,86400,0)|0;m=b>>31;c=b;d=jqa(b,m,1e4,0)+14780|0;b=jb;i=d;b=d>>>0<14780?b+1|0:b;f=b;d=kqa(d,b,-14609700,-1);b=c;j=d+b|0;d=m+jb|0;d=b>>>0>j>>>0?d+1|0:d;b=j;j=kqa(i,f,365242500,0);b=b+j|0;d=jb+d|0;d=b>>>0<j>>>0?d+1|0:d;j=kqa(i,f,-146097e4,-1);b=j+b|0;d=jb+d|0;d=b>>>0<j>>>0?d+1|0:d;j=b;b=kqa(i,f,3652425,0);f=jb;o=f;i=j;j=jqa(b,f,-365,-1);i=i+j|0;f=jb+d|0;f=i>>>0<j>>>0?f+1|0:f;d=f;if(!((d|0)>0?1:(d|0)>=0)){d=o-(b>>>0<1)|0;b=b-1|0;f=jqa(b,d,-365,-1)+c|0;d=m+jb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;i=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=(b|0)/100|0;i=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<i>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;i=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<i>>>0?d+1|0:d;i=f}f=b;c=jqa(i,d,100,0)+52|0;b=jb;b=kqa(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c-B(d,12)|0)+1;b=jqa(b,jb,306,0)+5|0;d=jb;b=kqa(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[k+4>>2]=b+1;v[g+136>>2]=0;v[g+128>>2]=0;v[g+132>>2]=0;v[g+120>>2]=0;v[g+124>>2]=0;v[g+116>>2]=v[k+12>>2]-1900;v[g+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];p=g,q=lqa(kqa(h,n,3600,0),jb,24),v[p+104>>2]=q;v[g+108>>2]=b;b=kqa(h,n,60,0);c=jb;p=g,q=lqa(b,c,60),v[p+100>>2]=q;p=g,q=h-jqa(b,c,60,0)|0,v[p+96>>2]=q;gb=k+16|0;hc(g+144|0,g+96|0,44)}i=e+32|0;m=hc(g,g+144|0,44);c=m;b=gb-112|0;gb=b;d=Kb(b+96|0);v[22692]=0;f=Q(2,b+80|0,10758)|0;h=v[22692];v[22692]=0;u:{v:{w:{x:{y:{if((h|0)!=1){h=v[c+20>>2];if(!h){break v}v[22692]=0;v[b+48>>2]=h+1900;R(112,b- -64|0,b+48|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;Q(113,d|0,b- -64|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break y}vb(b- -64|0);if(y[c+16>>2]>11){break v}v[22692]=0;h=Q(2,b+48|0,13846)|0;g=v[22692];v[22692]=0;z:{A:{B:{C:{D:{E:{if((g|0)!=1){g=v[c+16>>2];v[22692]=0;v[b+16>>2]=g+1;R(114,b+32|0,b+16|0);g=v[22692];v[22692]=0;if((g|0)==1){break E}v[22692]=0;U(3,b- -64|0,h|0,b+32|0);g=v[22692];v[22692]=0;if((g|0)==1){break D}v[22692]=0;Q(113,d|0,b- -64|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break C}vb(b- -64|0);vb(b+32|0);vb(h);if(v[c+12>>2]-1>>>0<=30){break z}break v}a=P()|0;O()|0;break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(h);break x}v[22692]=0;h=Q(2,b+48|0,13846)|0;g=v[22692];v[22692]=0;F:{G:{H:{I:{J:{K:{L:{M:{if((g|0)!=1){v[22692]=0;R(114,b+32|0,c+12|0);g=v[22692];v[22692]=0;if((g|0)==1){break M}v[22692]=0;U(3,b- -64|0,h|0,b+32|0);g=v[22692];v[22692]=0;if((g|0)==1){break L}v[22692]=0;Q(113,d|0,b- -64|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break K}vb(b- -64|0);vb(b+32|0);vb(h);h=v[c+8>>2];if(h){break H}h=v[c+4>>2];if(h){break G}if(!v[c>>2]){break v}break F}a=P()|0;O()|0;break x}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(h);break x}if(h>>>0>23){break v}h=v[c+4>>2]}if(h>>>0>59){break v}}v[22692]=0;h=Q(2,b- -64|0,10925)|0;g=v[22692];v[22692]=0;N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((g|0)!=1){v[22692]=0;Q(113,d|0,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ea}vb(h);if(v[c+32>>2]>=1){v[22692]=0;h=Q(2,b- -64|0,12655)|0;g=v[22692];v[22692]=0;if((g|0)==1){break da}Eb(f,h);vb(h)}v[22692]=0;R(114,b+32|0,c+8|0);h=v[22692];v[22692]=0;if((h|0)==1){break ca}v[22692]=0;h=Q(2,b+16|0,11794)|0;g=v[22692];v[22692]=0;if((g|0)==1){break ba}v[22692]=0;U(3,b+48|0,b+32|0,h|0);g=v[22692];v[22692]=0;if((g|0)==1){break aa}v[22692]=0;R(114,b|0,c+4|0);g=v[22692];v[22692]=0;if((g|0)==1){break $}v[22692]=0;U(3,b- -64|0,b+48|0,b|0);g=v[22692];v[22692]=0;if((g|0)==1){break _}v[22692]=0;Q(113,d|0,b- -64|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break Z}vb(b- -64|0);vb(b);vb(b+48|0);vb(h);vb(b+32|0);if(y[c>>2]<62){break U}v[22692]=0;U(115,i|0,d|0,f|0);c=v[22692];v[22692]=0;if((c|0)==1){break T}break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(h);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break V}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;break Y}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(h)}vb(b+32|0);break x}v[22692]=0;h=Q(2,b+48|0,11794)|0;g=v[22692];v[22692]=0;if((g|0)==1){break S}v[22692]=0;R(114,b+32|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break R}v[22692]=0;U(3,b- -64|0,h|0,b+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break Q}v[22692]=0;Q(113,d|0,b- -64|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break P}vb(b- -64|0);vb(b+32|0);vb(h);v[22692]=0;Q(113,d|0,f|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break v}}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break N}a=P()|0;O()|0;break O}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(h);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(b- -64|0)}vb(f)}vb(d);S(a|0);L()}Dc(i,d)}vb(f);vb(d);gb=b+112|0;gb=m+192|0;v[22692]=0;R(2023,a|0,e+32|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,9413);f=_g(c,d);vb(d);if(f){c=b;OS(e+32|0,v[b+24>>2]+1298292|0);fa:{ga:{ha:{if(!ed(e+32|0)){break ha}c=v[c+24>>2];v[22692]=0;c=GO(c);d=v[22692];v[22692]=0;if((d|0)==1){break fa}ia:{switch(c|0){case 0:v[22692]=0;R(2078,e+16|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 1:v[22692]=0;R(2079,e+16|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 2:if(ed(e+32|0)){v[22692]=0;R(2078,e+16|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}Eb(e+32|0,e+16|0);vb(e+16|0)}if(!ed(e+32|0)){break ha}v[22692]=0;R(2079,e+16|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 3:if(ed(e+32|0)){v[22692]=0;R(2079,e+16|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break h}Eb(e+32|0,e+16|0);vb(e+16|0)}if(!ed(e+32|0)){break ha}v[22692]=0;R(2078,e+16|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 4:v[22692]=0;R(2078,e+16|0,b|0);c=v[22692];v[22692]=0;ja:{ka:{if((c|0)!=1){v[22692]=0;R(2079,e|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break ja}if(ed(e+16|0)){break ka}v[22692]=0;Q(1161,e+32|0,e+16|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break ka}break d}c=P()|0;O()|0;break b}if(!ed(e)){v[22692]=0;Q(1161,e+32|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}}vb(e);vb(e+16|0);break ha}c=P()|0;O()|0;break c;case 5:break ia;default:break ha}}v[22692]=0;R(2078,e+16|0,b|0);c=v[22692];v[22692]=0;la:{if((c|0)!=1){v[22692]=0;R(2079,e|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break ga}if(ed(e)){break la}v[22692]=0;Q(1161,e+32|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break la}break f}c=P()|0;O()|0;break b}if(!ed(e+16|0)){v[22692]=0;Q(1161,e+32|0,e+16|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}}vb(e);vb(e+16|0)}v[22692]=0;U(2076,a|0,b|0,e+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break fa}vb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Tb(e+32|0,2564);f=_g(c,d);vb(d);if(f){OS(e+32|0,v[b+24>>2]+1298292|0);v[22692]=0;U(2076,a|0,b|0,e+32|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}i=c;c=Tb(e+32|0,4376);d=_g(i,c);vb(c);if(d){a=Kb(a);b=b+68|0;p=e,q=Vb(b),v[p+32>>2]=q;p=e,q=Zb(b),v[p+16>>2]=q;if(!Gb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[22692]=0;Q(1901,a|0,18669)|0;c=v[22692];v[22692]=0;if((c|0)==1){break g}}v[22692]=0;Q(1161,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[e+32>>2]=v[e+32>>2]+12;c=0;if(Gb(e+32|0,e+16|0)){continue}break}break k}Tb(a,18699)}gb=e+48|0;return}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;vb(a);break a}c=P()|0;O()|0;vb(e)}vb(e+16|0);break b}c=P()|0;O()|0;vb(e)}vb(e+16|0)}vb(e+32|0)}S(c|0);L()}function wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=gb-352|0;gb=e;vc(b);f=e+328|0;g=KD(b,f);if(!g){Pv(f)}a:{b:{c:{d:{e:{f:{g:{if(!g){break g}if(!UX(e+328|0)){break g}if(!Pb(b,Qc(72,0))){break g}if(!c){d=1;break g}Id(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;d=w[e+337|0];u[a+480190>>1]=63;u[a+480188>>1]=d;h:{if(d){d=0;while(1){_t(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}if(!x[a+480190>>1]){break h}}d=1;f=1;while(1){g=(B(d,104)+a|0)+484380|0;td(g,1);h=(e+256|0)+d|0;d=Ae(b);t[h|0]=d;if(d<<24>>24>=0){A=g,C=RX(b)<<1,v[A>>2]=C}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}UD(b,a+1298268|0,-1);g=e+248|0;f=gb-32|0;gb=f;d=b;i:{if(!Pb(d,8)){t[f+16|0]=0;li(g,8,f+16|0);break i}Bp(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;id(f+16|0,d,f+8|0)}gb=f+32|0;m=mc(e+232|0);j:{if(w[e+338|0]|w[e+339|0]<<8){f=w[e+338|0]|w[e+339|0]<<8;g=w[e+337|0];d=0;v[22692]=0;f=W(496,b|0,m|0,B(f,g)<<1)|0;g=v[22692];v[22692]=0;if((g|0)==1){f=P()|0;O()|0;break a}if(!f){break j}}en(e+224|0,v[m>>2],pc(m)>>>1|0);l=mc(e+208|0);k:{l:{m:{n:{o:{p:{if(!(w[e+340|0]|w[e+341|0]<<8)){break p}d=w[e+340|0]|w[e+341|0]<<8;f=0;v[22692]=0;R(497,l|0,d<<8);d=v[22692];v[22692]=0;if((d|0)==1){break o}if(!(w[e+340|0]|w[e+341|0]<<8)){break p}while(1){v[e+136>>2]=(w[e+340|0]|w[e+341|0]<<8)-f;v[22692]=0;v[e+160>>2]=2e3;d=nd(e+136|0,e+160|0);g=v[22692];v[22692]=0;q:{if((g|0)!=1){g=v[d>>2];d=mc(e+136|0);v[22692]=0;g=W(496,b|0,d|0,g<<8)|0;h=v[22692];v[22692]=0;if((h|0)==1){break c}if(g){break q}gc(d);d=0;break k}f=P()|0;O()|0;break b}A=e,C=Zb(l),v[A+160>>2]=C;Hd(e+200|0,e+160|0);g=Vb(d);h=Zb(d);v[22692]=0;Y(498,l|0,v[e+200>>2],g|0,h|0);g=v[22692];v[22692]=0;if((g|0)==1){break c}gc(d);f=f+2e3&65535;if(f>>>0<(w[e+340|0]|w[e+341|0]<<8)>>>0){continue}break}}v[22692]=0;Vd(e+184|0,l);d=v[22692];v[22692]=0;if((d|0)==1){break m}d=v[e+188>>2];v[e+64>>2]=v[e+184>>2];v[e+68>>2]=d;Sh(e+192|0,e- -64|0);p=a+484360|0;d=Sb(p);f=w[e+338|0]|w[e+339|0]<<8;v[22692]=0;R(500,d|0,f|0);d=v[22692];v[22692]=0;if((d|0)==1){break m}if(!(w[e+338|0]|w[e+339|0]<<8)){break l}q=a+484344|0;s=c&1;h=0;while(1){r:{A=rc(Sb(p),h),C=h,u[A>>1]=C;s:{if(!s){break s}v[22692]=0;r=h&65535;d=W(331,q|0,r|0,64)|0;f=v[22692];v[22692]=0;if((f|0)==1){break r}j=0;f=x[a+480188>>1];if(!(d&(f|0)!=0)){break s}while(1){d=rc(e+224|0,B(f&65535,h)+j|0);f=w[d|0]|w[d+1|0]<<8;t:{if(f>>>0>=(w[e+340|0]|w[e+341|0]<<8)>>>0){f=x[a+480188>>1];break t}d=_b(q,h);v[22692]=0;d=Wc(d,0,j&65535);g=v[22692];v[22692]=0;if((g|0)==1){break n}i=0;y=0-j|0;z=f<<8;while(1){vd(e+136|0,v[e+192>>2]+((i<<2)+z|0)|0,4);n=w[kc(e+136|0,0)|0]&63;t[d|0]=n?n+48|0:0;f=kc(e+136|0,0);A=d,C=w[kc(e+136|0,1)|0]<<2&60|w[f|0]>>>6,t[A+1|0]=C;g=w[kc(e+136|0,1)|0];o=w[kc(e+136|0,2)|0];f=kc(e+136|0,2);k=w[kc(e+136|0,3)|0];f=k<<4|w[f|0]>>>4;u[e+182>>1]=f;g=o<<2&60|g>>>6;u:{if(!(w[lc(e+248|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break u}t[d+5|0]=f;t[d+3|0]=g;o=k>>>4|0;t[d+4|0]=o;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;v[22692]=0;Nf(d);f=v[22692];v[22692]=0;if((f|0)==1){break G}if(!w[d+4|0]){break u}t[d+2|0]=g>>>0<32?3:4;break u;case 3:case 4:case 5:case 6:case 7:case 12:v[22692]=0;Nf(d);f=v[22692];v[22692]=0;if((f|0)==1){break G}break u;case 9:t[d+3|0]=10;A=d,C=ei(f>>>1|0),t[A+5|0]=C;break u;case 50:break w;case 48:break x;case 43:break y;case 47:break z;case 17:case 18:case 26:case 27:break A;case 22:case 25:case 28:case 29:case 30:break B;case 16:case 19:case 20:case 21:case 23:case 31:break C;case 13:break D;case 11:case 15:break E;case 10:case 42:break H;default:break v}}if(f>>>0>254){break F}t[d+3|0]=g&15;v[22692]=0;Nf(d);f=v[22692];v[22692]=0;if((f|0)!=1){break u}}f=P()|0;O()|0;break b}t[d+3|0]=19;t[d+5|0]=o|(g>>>0<32?16:32);g=k&15;if(g){t[d+2|0]=3;t[d+4|0]=g;break u}t[d+2|0]=4;t[d+4|0]=f&15;break u}t[d+3|0]=(g|0)==11?12:16;A=d,C=xv(f),t[A+5|0]=C;break u}t[d+3|0]=14;if((f&255)>>>0<64){break u}t[d+5|0]=0;break u}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break u}t[d+3|0]=19;v[22692]=0;u[e+160>>1]=15;f=Pc(e+182|0,e+160|0);k=v[22692];v[22692]=0;if((k|0)!=1){t[d+5|0]=w[f|0]|g<<4;break u}f=P()|0;O()|0;break b}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(k&240)){break u}t[d+2|0]=g>>>0>25?6:5;break u}t[d+5|0]=o|(g>>>0>25?-80:-96);break u}if(!f){break v}t[d+3|0]=17;v[e+160>>2]=8;v[22692]=0;v[e+176>>2]=f+4;f=Gf(e+160|0,e+176|0);g=v[22692];v[22692]=0;if((g|0)!=1){A=d,C=ei(v[f>>2]/8|0),t[A+5|0]=C;break u}f=P()|0;O()|0;break b}t[d+3|0]=14;g=x[a+480188>>1];if(!g){break u}n=B(y,6)+d|0;f=0;while(1){k=n+B(f,6)|0;if(!w[k+3|0]){t[k+3|0]=12;A=k,C=xv(r),t[A+5|0]=C;g=x[a+480188>>1]}f=f+1|0;if(g>>>0>f>>>0){continue}break}break u}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+28569|0];break u}g=f>>>4|0;if((g|0)==128){break v}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break u}t[d+5|0]=g^-1;break u}t[d+5|0]=0;t[d+3|0]=0;if(!n){t[d|0]=255;break u}t[d+3|0]=25;break u}t[d+3|0]=0}f=x[a+480188>>1];d=B(f,6)+d|0;i=i+1|0;if((i|0)!=64){continue}break}}j=j+1|0;if(j>>>0<(f&65535)>>>0){continue}break}}h=h+1|0;if(h>>>0<(w[e+338|0]|w[e+339|0]<<8)>>>0){continue}break l}break}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(x[a+480190>>1]){j=c&2;d=1;f=1;while(1){v[22692]=0;c=w[(e+256|0)+d|0];W(501,b|0,((d<<5)+a|0)+946304|0,c&63)|0;g=v[22692];v[22692]=0;I:{J:{K:{L:{M:{N:{if((g|0)!=1){if(c<<24>>24<=-1){break I}v[22692]=0;g=T(502,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}c=B(d,104)+a|0;d=c+484392|0;v[d>>2]=g<<1;v[22692]=0;g=T(502,b|0)|0;h=v[22692];v[22692]=0;O:{if((h|0)!=1){g=g<<1;if(g>>>0>=3){v[c+484396>>2]=g+v[d>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22692]=0;d=T(374,b|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){break O}break d}f=P()|0;O()|0;break b}u[c+484410>>1]=d<<2;v[22692]=0;d=T(374,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}t[c+484417|0]=d<<4;c=c+484380|0;if(!v[c>>2]){break I}v[22692]=0;h=T(374,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break L}d=0;P:{Q:{R:{S:{switch(h|0){case 0:if(!j){break Q}g=mc(e+160|0);h=v[c>>2];v[22692]=0;h=Q(189,b|0,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break N}if(!h){break R}d=v[c>>2];v[22692]=0;W(503,b|0,g|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break N}A=e,C=Vb(g),v[A+136>>2]=C;A=e,C=Zb(g),v[A+176>>2]=C;if(Gb(e+136|0,e+176|0)){break M}break K;case 1:g=mc(e+160|0);d=v[c>>2];v[22692]=0;U(504,e+136|0,b|0,d|0);d=v[22692];v[22692]=0;T:{U:{V:{W:{if((d|0)!=1){gp(g,e+136|0);gc(e+136|0);if(!j){break V}v[22692]=0;Vd(e+112|0,g);d=v[22692];v[22692]=0;if((d|0)!=1){d=Ud(e+104|0);v[22692]=0;h=v[e+116>>2];v[e+40>>2]=v[e+112>>2];v[e+44>>2]=h;h=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=h;d=W(505,e+136|0,e+40|0,e+32|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){break W}}f=P()|0;O()|0;break T}f=V(27348)|0;if((O()|0)!=(ea(27348)|0)){break T}Z(f|0)|0;d=0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break P}f=P()|0;O()|0;break T}h=Rc(e+176|0,8,1,0,2);v[22692]=0;W(329,h|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break U}xb(e+136|0)}gc(g);break I}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b;case 2:case 3:if(j){d=Rc(e+136|0,(h|0)==2?8:16,1,0,0);v[22692]=0;W(329,d|0,c|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break I}f=P()|0;O()|0;break b}c=v[c>>2];v[22692]=0;Q(318,b|0,B(c,h-1|0)|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break I}break L;case 4:case 5:break S;default:break k}}g=mc(e+160|0);d=v[c>>2];v[22692]=0;U(506,e+136|0,b|0,d|0);d=v[22692];v[22692]=0;X:{Y:{Z:{if((d|0)!=1){gp(g,e+136|0);gc(e+136|0);if(j){_:{if((h|0)!=5){break _}A=e,C=Vb(g),v[A+136>>2]=C;A=e,C=Zb(g),v[A+176>>2]=C;if(!Gb(e+136|0,e+176|0)){break _}while(1){i=v[e+136>>2];d=zb(w[i|0]);A=i,C=zb((d^w[(d>>>7|0)+28577|0])&255),t[A|0]=C;Ne(e+136|0);if(Gb(e+136|0,e+176|0)){continue}break}}v[22692]=0;Vd(e+96|0,g);d=v[22692];v[22692]=0;if((d|0)==1){break Z}d=Ud(e+88|0);v[22692]=0;i=v[e+100>>2];v[e+56>>2]=v[e+96>>2];v[e+60>>2]=i;i=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=i;d=W(505,e+136|0,e+56|0,e+48|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break Z}h=(h|0)==5;h=Rc(e+176|0,h?16:8,1,0,h?17:1);v[22692]=0;W(329,h|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break Y}xb(e+136|0)}gc(g);break I}f=V(27348)|0;if((O()|0)!=(ea(27348)|0)){break X}Z(f|0)|0;d=0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){f=P()|0;O()|0;break X}gc(g);break k}f=P()|0;O()|0;break X}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}gc(g);break k}c=v[c>>2];v[22692]=0;Q(318,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break L}break I}gc(g);break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break J}while(1){h=v[e+136>>2];d=zb(w[h|0]);A=h,C=zb((d<<7|(d^-1)<<24>>>25)&255),t[A|0]=C;Ne(e+136|0);if(Gb(e+136|0,e+176|0)){continue}break}break K}f=P()|0;O()|0;break b}v[22692]=0;Vd(e+128|0,g);d=v[22692];v[22692]=0;$:{aa:{if((d|0)==1){break aa}d=Ud(e+120|0);v[22692]=0;h=v[e+132>>2];v[e+24>>2]=v[e+128>>2];v[e+28>>2]=h;h=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=h;d=W(505,e+136|0,e+24|0,e+16|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break aa}h=Rc(e+176|0,16,1,0,17);v[22692]=0;W(329,h|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break $}xb(e+136|0);gc(g);break I}f=P()|0;O()|0;break J}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}ba:{ca:{da:{ea:{fa:{ga:{ha:{d=w[e+342|0]|w[e+343|0]<<8|w[e+344|0]<<16;if(d){c=mc(e+160|0);v[22692]=0;b=W(496,b|0,c|0,d|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}if(!b){break fa}v[22692]=0;Vd(e+80|0,c);b=v[22692];v[22692]=0;if((b|0)==1){break ha}b=Ud(e+72|0);v[22692]=0;f=v[e+84>>2];v[e+8>>2]=v[e+80>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=W(505,e+136|0,e+8|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break ha}v[22692]=0;ca(507,a+1298292|0,b|0,d|0,1)|0;d=v[22692];v[22692]=0;if((d|0)==1){break ga}xb(b);gc(c)}v[22692]=0;_(508,e+160|0);b=v[22692];v[22692]=0;if((b|0)==1){break ea}v[22692]=0;U(316,e+136|0,e+160|0,e+336|0);b=v[22692];v[22692]=0;if((b|0)==1){break da}Eb(a+1298304|0,e+136|0);vb(e+136|0);Hb(e+160|0);v[22692]=0;b=Q(2,e+136|0,7320)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ca}Eb(a+1298316|0,b);vb(b);v[22692]=0;b=Q(2,e+136|0,2197)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ba}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;d=1;break k}f=P()|0;O()|0;break e}f=P()|0;O()|0;xb(b);break e}gc(c);d=0;break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;Hb(e+160|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}gc(l)}gc(m)}gb=e+352|0;return d|0}f=P()|0;O()|0}gc(c);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;gc(d)}gc(l)}gc(m);S(f|0);L()}function d_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;p=Hh(b,11082);a:{if(!p){break a}if(!Pb(b,6)){break a}while(1){b:{l=qg(b);c:{if((l|0)==(tn(10932)|0)){break c}i=w[18675]|w[18676]<<8|(w[18677]<<16|w[18678]<<24);if(!(l&1616928864)|l&-2139062144){break c}if((i|0)!=(l|0)){break b}}ng(b,4);break a}m=1;r=Mg(b);if(x[a+480192>>1]){while(1){j=v[(((m&65535)<<2)+a|0)+900380>>2];if(j){d:{i=r;n=b;q=l;if((tn(13802)|0)==(l|0)){Rb(n,i);break d}e=q;c=i;d=n;g=0;h=gb-48|0;gb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+23|0]=z;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+18|0]=z;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=Zl(d,c),v[s>>2]=z;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+21|0]=z;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;while(1){v[22692]=0;f=T(307,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break F}s=wd(e,d),z=f,u[s>>1]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+31|0]=z;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+34|0]=z;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+16|0]=z;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+24>>2]=240;s=h,z=Zl(d,c),v[s>>2]=z;hh(f+68|0,v[Fb(h+24|0,h)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22692]=0;e=hi(f,1);f=v[22692];v[22692]=0;if((f|0)==1){break k}if(Nb(e)){while(1){v[22692]=0;f=T(309,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break k}s=Lb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+82|0]=z;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+27|0]=z;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22692]=0;e=hi(f,1);f=v[22692];v[22692]=0;if((f|0)==1){break h}if(Nb(e)){while(1){v[22692]=0;f=T(307,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break h}s=Lb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+83|0]=z;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}s=f,z=B(Tr(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[s+40>>2]=z;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+36|0]=z;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22692]=0;e=hi(f,2);f=v[22692];v[22692]=0;if((f|0)==1){break l}if(Nb(e)){while(1){v[22692]=0;f=T(309,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break l}s=Lb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22692]=0;e=hi(f,2);f=v[22692];v[22692]=0;if((f|0)==1){break i}if(Nb(e)){while(1){v[22692]=0;f=T(307,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break i}s=Lb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+24|0]=z;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22692]=0;e=hi(f,0);f=v[22692];v[22692]=0;if((f|0)==1){break j}if(Nb(e)){while(1){v[22692]=0;f=T(309,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break j}s=Lb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+62|0]=z;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22692]=0;e=hi(f,0);f=v[22692];v[22692]=0;if((f|0)==1){break g}if(Nb(e)){while(1){v[22692]=0;f=T(307,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break g}s=Lb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+63|0]=z;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+15|0]=z;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}ud(h,d,c);k=jc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22692]=0;g=T(310,k|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break E}v[22692]=0;R(311,e|0,g|0);g=v[22692];v[22692]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22692]=0;Q(301,f+492|0,e|0)|0;c=v[22692];v[22692]=0;g=1;if((c|0)==1){break E}vb(e);xb(k);break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=Zl(d,c),v[s+4>>2]=z;g=1;break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=Zl(d,c),v[s+8>>2]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+61|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f- -64|0,z=xd(d,c),t[s|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+81|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+84|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+101|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+102|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+103|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+104|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+17|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+19|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+20|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+22|0]=z;g=1;break n}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=Tr(d,c),u[s+28>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+30|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=KE(d,c),t[s+26|0]=z;g=1;break n}if(c>>>0>128){break n}e=f+108|0;ud(h,d,c);c=jc(h+24|0,h);xb(h);d=0;while(1){v[22692]=0;f=T(309,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break p}s=lc(e,d),z=f,t[s|0]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;vb(e);xb(k);break f}if(c>>>0>32){break n}ud(h,d,c);k=jc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22692]=0;g=T(310,k|0)|0;o=v[22692];v[22692]=0;if((o|0)==1){break m}v[22692]=0;R(311,e|0,g|0);g=v[22692];v[22692]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22692]=0;Q(301,f+524|0,e|0)|0;c=v[22692];v[22692]=0;g=1;if((c|0)!=1){vb(e);xb(k);break n}break m}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=Tr(d,c),u[s+12>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+25|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+35|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+105|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+85|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+65|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+100|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+80|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+60|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=KE(d,c),t[s+33|0]=z;g=1;break n}g=1;c=Zl(d,c);if(!rp(c)){break n}t[f+14|0]=c;break n}v[h+24>>2]=240;s=h,z=Zl(d,c),v[s>>2]=z;hh(f+48|0,v[Fb(h+24|0,h)>>2]);g=1;break n}v[h+24>>2]=240;s=h,z=Zl(d,c),v[s>>2]=z;hh(f+88|0,v[Fb(h+24|0,h)>>2]);g=1;break n}d=P()|0;O()|0;xb(c);break f}c=Tr(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}gb=h+48|0;break e}d=P()|0;O()|0;vb(e);xb(k);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c)}S(d|0);L()}if(!g){Rb(n,i);break d}if((tn(13807)|0)==(q|0)){i=w[j+15|0];t[j+15|0]=0;t[j+100|0]=w[j+100|0]&224|(i>>>5&4|i>>>6&1);t[j+60|0]=i>>>1&2|(i<<1&4|(w[j+60|0]&240|i&1));t[j+80|0]=w[j+80|0]&240|(i>>>4&2|(i>>>2&4|i>>>3&1))}}}m=m+1|0;if(x[a+480192>>1]>=(m&65535)>>>0){continue}break}}if(Pb(b,6)){continue}break}}return p|0}function qfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;f=gb-48|0;gb=f;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Pf(a+1074312|0,0)}g=a+1074312|0;Db(f+32|0,g,0);if(Cb(f+32|0)){q=(v[a+480180>>2]&16777248)!=0}Db(f+32|0,g,0);if(Cb(f+32|0)){C=v[a+480180>>2]==4}l=a+1074308|0;b=v[l>>2];if(b>>>0<=18874367){c=1;e=!q;a:{if(!x[a+480192>>1]){break a}while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[f+32>>2]=B(w[b+20|0],100)>>>6;v[f+16>>2]=100;D=b,E=v[Fb(f+32|0,f+16|0)>>2],t[D+20|0]=E;if(!(e|y[l>>2]<18350080)){break b}k=t[b+26|0];t[b+26|0]=(((k|0)>-1?1:-1)+k|0)/2;if(!(e|y[l>>2]<18285314)){break b}FS(hi(b,2),4,v[a+480180>>2]);k=v[a+1074308>>2];if(k>>>0>=18284544){if(k>>>0>18285135){break b}c:{if(!w[b+34|0]){break c}if(!Ej(b)){break c}Ob(g,2,1)}if(y[l>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Ob(g,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}d:{if(!(v[a+480180>>2]&16777248)){break d}b=1;if(!(e|y[l>>2]<18285314)|!x[a+480190>>1]){break d}while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;d=SS(b);if((d|0)!=(b|0)){while(1){b=c;j=b+32|0;while(1){e=w[b|0];e:{f:{if((e-97&255)>>>0<=5){k=e-32|0;break f}k=99;g:{if(e>>>0<=106){if(e-88>>>0<2){break g}if((e|0)==75){break f}break e}if(e-120>>>0<2){break g}if((e|0)==107){break f}break e}k=122}t[b|0]=k}b=b+1|0;if((j|0)!=(b|0)){continue}break}c=c+32|0;if((d|0)!=(c|0)){continue}break}}b=v[a+1074308>>2]}h:{if(!x[a+480192>>1]|(!(v[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895))){break h}b=1;c=0;while(1){i:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break i}break h}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Ob(g,3,1)}b=v[l>>2];j:{if(!(v[a+480180>>2]&16777248)|(b>>>0>19006225|(b|0)==19005440)){break j}Db(f+32|0,g,0);if(!Cb(f+32|0)){Db(f+16|0,g,1);if(!Cb(f+16|0)){break j}}if(!x[a+480192>>1]){break j}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}k:{l:{m:{if(y[l>>2]<=19007232){c=a+946300|0;b=a+906300|0;while(1){e=b+80|0;MO(f+16|0,e);v[22692]=0;Y(360,f+32|0,0,8,f+16|0);k=v[22692];v[22692]=0;if((k|0)==1){break l}vb(f+16|0);v[22692]=0;Fr(e,f+32|0);e=v[22692];v[22692]=0;if((e|0)==1){break m}vb(f+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}n:{o:{p:{q:{if(v[a+480180>>2]!=4){break q}b=v[l>>2];if(b>>>0<19007257){break o}if(b>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}aA(a,5)}b=v[l>>2]}if((b|0)==19202048|b>>>0>19202054){break n}}if(!x[a+480192>>1]){break n}c=1;while(1){k=(((c&65535)<<2)+a|0)+900380|0;b=v[k>>2];r:{if(!b|!w[b+20|0]|!w[b+31|0]){break r}b=b+236|0;e=Eu(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break r}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[k>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[l>>2];if(b>>>0<=19267583){if(x[a+480192>>1]){b=1;e=!q;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];s:{if(!c){break s}k=t[c+26|0];t[c+26|0]=(((k|0)>-1?1:-1)+k|0)/2;if(!(e|y[l>>2]<18350080)){break s}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[l>>2]}t:{if(!x[a+480192>>1]|b>>>0>19398673){break t}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Ob(g,94,1);break t}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}u:{if(!x[a+480192>>1]|y[l>>2]>19399427){break u}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Ob(g,101,1);break u}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=gb-16|0;gb=b;u[f+12>>1]=0;v[f+8>>2]=a;Db(b+8|0,a+1074312|0,0);D=f,E=Cb(b+8|0),t[D+14|0]=E;gb=b+16|0;b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;c=gb-16|0;gb=c;o=a+484344|0;k=Re(o);b=v[f+4>>2];e=v[f>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=gb-32|0;gb=e;A=k-1&65535;v:{if(Re(o)>>>0>A>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(gi(af(o,b))){d=Vb(af(o,b));j=Zb(af(o,b));b=e;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;k=b+8|0;m=gb-16|0;gb=m;v[m>>2]=j;v[m+8>>2]=d;if(Gb(m+8|0,m)){while(1){d=v[m+8>>2];b=k;n=x[b+4>>1];j=n+1|0;u[b+4>>1]=j;if(x[v[b>>2]+480188>>1]<=(j&65535)>>>0){u[b+4>>1]=0}w:{if(zg(d)){break w}h=v[b>>2];j=v[h+1074308>>2];x:{y:{z:{A:{B:{C:{D:{p=v[h+480180>>2];E:{F:{if((p|0)==2){if(j>>>0>18415615){break F}if(w[d+3|0]!=23){break E}xf(d+5|0,64);break E}G:{if(p&16777248){H:{I:{if(j>>>0>=18285314){if(w[b+6|0]){break I}h=0;i=0;if(j>>>0>18874367){break H}}J:{switch(w[d+3|0]-20|0){case 3:xf(d+5|0,128);break I;case 0:break J;default:break I}}h=w[d+5|0];if((h|0)!=208){if((h|0)!=192){break I}t[d|0]=254;t[d+3|0]=0;break I}t[d+3|0]=0}K:{L:{M:{if(j>>>0>=18350080){if(w[b+6|0]){break M}h=0;i=0;if(j>>>0>18874367){break H}}i=w[d+3|0];if(i>>>0>29){break L}h=1;if(!(1<<i&536873152)){break L}break K}h=0;i=0;if(j>>>0>18874367){break H}i=w[d+3|0]}h=0}i=(i|0)==24|(i|0)==22}N:{if(!(i?1:h)){break N}i=w[d+5|0];h=i&15;if(!h|(h|0)==15){break N}i=i&240;if(!i|(i|0)==240){break N}t[d+5|0]=w[d+3|0]==24?i:h}if(j>>>0>19005699){break z}if((j|0)==19005440){break D}if(w[b+6|0]|(!x[v[b>>2]+480192>>1]|x[v[b>>2]+480192>>1]>=w[d+1|0])){break F}t[d+2|0]=1;i=d+4|0;break G}if((p|0)!=4){break F}O:{P:{Q:{R:{S:{if(j>>>0<18285314){break S}h=!w[b+6|0]&j>>>0<18874368;if(h){break S}if(j>>>0>19137025){break z}if(!(w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}if(!(h|j>>>0<18415616)){break R}}if(w[d+3|0]!=10|w[d+2|0]!=11){break Q}t[d+3|0]=0;break Q}if(j>>>0>18874639){break P}}if(w[d+2|0]!=11|w[d+3|0]!=4){break O}h=w[d+4|0];if(!(w[b+6|0]?1:h)){break O}i=w[d+5|0];if(!i){break O}t[d+2|0]=0;D=d,E=xv(i+(h<<4)|0),t[D+5|0]=E;break O}if(j>>>0>19007240){break z}}if(w[d+5|0]|w[d+3|0]!=16){break F}i=d+3|0}t[i|0]=0}if(j>>>0>18874367){break z}}h=w[d+3|0];i=w[d+5|0]&240;if((h|0)!=28|(i|0)!=96){b=0}else{if(!w[b+6|0]|(p|0)!=4){break C}b=j>>>0<18350080}if(!(b|(h|0)==20&(i|0)==96)|!n){break A}break B}h=d+2|0;b=w[d+2|0];if((b|0)==8){break y}break x}if(!n){break z}}b=d+B(0-n|0,6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}h=w[d+3|0]}if(!n|((h&255)!=20|(i|0)!=224)){break z}b=d+B(0-n|0,6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}h=d+2|0;b=w[d+2|0];if((b|0)!=8){break x}if((j|0)==19333120|j>>>0>19333174){break w}}T:{U:{V:{W:{b=w[d+3|0];switch(b-5|0){case 2:break W;case 1:break w;case 0:break U;default:break V}}if(!w[d+4|0]){break T}t[d+3|0]=11;break w}if((b|0)!=26){break w}}j=w[d+5|0];if(!(j&15)){t[d+3|0]=5;t[d+5|0]=j|w[d+4|0]&15;break T}X:{switch(b-5|0){case 1:break w;case 0:case 2:break T;default:break X}}if((b|0)!=26){break w}}t[h|0]=0;break w}if(!(w[d+3|0]|((p|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break w}if(w[d+3|0]!=10|j>>>0>19922963|(b|0)!=15){break w}if(w[d+4|0]?w[d+5|0]:1){t[h|0]=0;break w}t[d+3|0]=0}Xj(m+8|0);if(Gb(m+8|0,m)){continue}break}}b=v[k+4>>2];v[e+16>>2]=v[k>>2];v[e+20>>2]=b;gb=m+16|0}z=z+1|0;if((z&65535)>>>0<=A>>>0){continue}break}v[f+32>>2]=r;v[f+36>>2]=s;break v}k=v[b+4>>2];v[f+32>>2]=v[b>>2];v[f+36>>2]=k}gb=e+32|0;gb=c+16|0;b=v[a+1074308>>2];c=b>>>0<19267584;Y:{if(c&q){Ob(g,8,(b|0)==18284544|b>>>0>18285313);b=48216;while(1){c=v[l>>2];e=v[b+4>>2];Ob(g,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=48552){continue}break}break Y}if(!(c&C)){break Y}Ob(g,8,b>>>0>18285313);b=48568;while(1){Ob(g,v[b>>2],y[l>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=48800){continue}break}}Z:{if(v[a+480180>>2]&16777248){b=48800;while(1){c=v[l>>2];e=v[b+4>>2];k=e&-65536;if(!(c>>>0<=k>>>0|c>>>0>=e>>>0?c>>>0>=k>>>0:0)){Pf(g,v[b>>2])}b=b+8|0;if((b|0)!=48848){continue}break}break Z}if(v[a+480180>>2]==4){b=48848;while(1){if(y[l>>2]<y[b+4>>2]){Pf(g,v[b>>2])}b=b+8|0;if((b|0)!=48912){continue}break}break Z}if(v[a+480180>>2]!=2){break Z}b=48912;while(1){if(y[l>>2]<y[b+4>>2]){Pf(g,v[b>>2])}b=b+8|0;if((b|0)!=49e3){continue}break}}_:{if(v[a+480180>>2]==4){b=v[l>>2];if(b>>>0>18415615){break _}Ob(g,98,1)}b=v[l>>2]}if(b-19333159>>>0<=33){b=0;while(1){c=b+77|0;Db(f+32|0,g,c);Ob(g,b+86|0,Cb(f+32|0));Pf(g,c);b=b+1|0;if((b|0)!=5){continue}break}b=v[l>>2]}c=8;$:{if(b>>>0>=18284544){if(b>>>0>18874627){break $}c=6;if((b|0)==18874368){break $}}Ob(g,c,1);b=v[l>>2]}aa:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Pf(g,7);break aa}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break aa}Ob(g,7,1);break aa}if((b|0)==19922944|b>>>0>19922997){break aa}Pf(g,7)}Db(f+32|0,g,31);ba:{if(!Cb(f+32|0)){break ba}b=v[l>>2];if(!x[a+480192>>1]|(b>>>0<19071234|b>>>0>19398722)){break ba}b=1;while(1){ca:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break ca}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break ca}Ob(g,97,1);break ba}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}da:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break da}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break da}break}ea:{fa:{ga:{if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216)){b=v[l>>2];if(b>>>0<19398688){break fa}if(b>>>0>19464277){break ga}Ob(g,109,1)}b=v[l>>2]}if((b|0)==19922944|b>>>0>19922996){break ea}}Pf(g,111)}if(!(v[a+480180>>2]!=2|y[a+1074308>>2]>19464191)){Ob(g,108,1);break da}if(v[a+480180>>2]==2){break da}Pf(g,108)}ha:{if(!(!(v[a+480180>>2]&16777252)|v[l>>2]-19333186>>>0>589827)){c=a+946300|0;a=a+906300|0;while(1){ia:{if((w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))!=1146637647|(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))!=-271958638){break ia}if((pc(a+4|0)|0)!=32){break ia}b=Tb(f+32|0,13899);v[22692]=0;Fr(a+80|0,b);e=v[22692];v[22692]=0;if((e|0)==1){break ha}vb(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}gb=f+48|0;return}a=P()|0;O()|0;vb(b);break k}a=P()|0;O()|0;vb(f+32|0);break k}a=P()|0;O()|0;vb(f+16|0)}S(a|0);L()}function dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-784|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if(!Jh(b,d+776|0)){break M}if(!LN(d+776|0)){break M}if(!nC(b,d+768|0)){break M}if(!KN(d+768|0)){break M}i=1313423693;f=w[d+768|0]|w[d+769|0]<<8|(w[d+770|0]<<16|w[d+771|0]<<24);if((f|0)!=1179012417){i=1414090313;if((f|0)!=538987841){break M}}k=Fh(d+744|0,b);j=eh(d+728|0);N:{if(!c){v[22692]=0;Y(1436,d+144|0,k|0,((f|0)==1179012417?1:2)|0,i|0);b=v[22692];v[22692]=0;if((b|0)!=1){break N}b=P()|0;O()|0;break a}v[22692]=0;U(1437,d+144|0,k|0,((f|0)==1179012417?1:2)|0);b=v[22692];v[22692]=0;if((b|0)==1){break y}}LU(j,d+144|0);Ed(d+144|0);v[22692]=0;U(1438,d+704|0,j|0,i|0);b=v[22692];v[22692]=0;if((b|0)==1){break z}v[22692]=0;b=T(275,d+704|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break x}g=0;O:{if(!b){break O}v[22692]=0;b=Q(1439,d+704|0,d+624|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break x}if(!b|!w[d+689|0]){break O}b=w[d+689|0];v[22692]=0;g=Q(189,d+704|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break x}if(!g|!c){break O}v[22692]=0;R(367,a|0,8388608);b=v[22692];v[22692]=0;if((b|0)==1){break x}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+688|0]<<4^-1)&16;u[d+144>>1]=w[d+689|0];v[22692]=0;u[d+512>>1]=127;b=Pc(d+144|0,d+512|0);g=v[22692];v[22692]=0;if((g|0)==1){break c}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[22692]=0;Q(155,a+1298304|0,((f|0)==1179012417?14017:13983)|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break x}v[22692]=0;b=Q(2,d+144|0,10551)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;v[22692]=0;Dr(d+512|0,2,d+624|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;R(324,d+144|0,d+512|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}Eb(a+1298268|0,d+144|0);vb(d+144|0);if(x[a+480188>>1]){b=0;h=(f|0)==1179012417;while(1){v[22692]=0;i=(b<<5)+a|0;e=i+480280|0;Ue(e);g=v[22692];v[22692]=0;P:{Q:{R:{S:{T:{if((g|0)!=1){v[22692]=0;g=T(374,d+704|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break T}if(h){break S}if(g>>>0<129){break R}break Q}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}if(g<<24>>24<=-1){break Q}v[d+144>>2]=g<<2;v[22692]=0;v[d+512>>2]=256;g=nd(d+144|0,d+512|0);e=v[22692];v[22692]=0;if((e|0)!=1){u[i+480284>>1]=v[g>>2];break P}b=P()|0;O()|0;break b}u[i+480284>>1]=g<<1;break P}v[e>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=gb-16|0;gb=b;v[b+12>>2]=1380209231;m=b,n=qY(Vb(j),Zb(j),b+12|0),v[m+8>>2]=n;m=b,n=Zb(j),v[m>>2]=n;g=Gb(b+8|0,b);gb=b+16|0;if(g){v[22692]=0;U(1438,d+144|0,j|0,1380209231);b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;b=T(374,d+144|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break g}g=Sb(a+484360|0);v[22692]=0;fa(519,g|0,d+144|0,b+1&255,255,254)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}xb(d+144|0)}if(c&1){u[d+496>>1]=0;v[22692]=0;U(1441,d+576|0,j|0,1414807888);b=v[22692];v[22692]=0;if((b|0)==1){break h}b=$e(d+576|0);v[22692]=0;g=a+484344|0;R(330,g|0,b&65535);b=v[22692];v[22692]=0;if((b|0)==1){break o}m=d,n=Vb(d+576|0),v[m+88>>2]=n;m=d,n=Zb(d+576|0),v[m+56>>2]=n;if(Gb(d+88|0,d+56|0)){i=(f|0)!=1179012417;while(1){b=Pe(d+144|0,v[d+88>>2]);v[22692]=0;h=T(374,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break k}v[22692]=0;u[d+128>>1]=h;b=T(190,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break l}v[22692]=0;U(288,d+512|0,d+144|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break m}b=jc(d+600|0,d+512|0);v[22692]=0;h=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[b+16>>2];h=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=h;Y(1442,d|0,x[d+128>>1],i|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break n}xb(d+512|0);v[22692]=0;b=Je(d+496|0,d+128|0);h=v[22692];v[22692]=0;if((h|0)==1){break l}u[d+496>>1]=x[b>>1];xb(d+144|0);Bh(d+88|0);if(Gb(d+88|0,d+56|0)){continue}break}}if(x[d+496>>1]){b=0;while(1){v[22692]=0;i=b&65535;h=le(g,i);e=v[22692];v[22692]=0;U:{if((e|0)!=1){if(h){break U}v[22692]=0;W(331,g|0,i|0,64)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break U}}b=P()|0;O()|0;break i}b=b+1|0;if(x[d+496>>1]>(b&65535)>>>0){continue}break}}hd(d+576|0)}V:{if((f|0)==1179012417){v[22692]=0;U(1441,d+88|0,j|0,1414745673);b=v[22692];v[22692]=0;if((b|0)==1){break K}m=d,n=Vb(d+88|0),v[m+128>>2]=n;m=d,n=Zb(d+88|0),v[m+40>>2]=n;W:{if(Gb(d+128|0,d+40|0)){g=c&2;i=d+520|0;h=d+144|1;while(1){c=Pe(d+576|0,v[d+128>>2]);v[22692]=0;b=Q(1443,c|0,d+144|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break W}X:{if(!b){break X}b=w[h|0];if((b|0)==255){break X}v[22692]=0;b=W(376,a|0,b+1|0,0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break J}if(!b){break X}f=x[a+480190>>1];v[22692]=0;U(1444,d+144|0,b|0,f|0);b=v[22692];v[22692]=0;if((b|0)==1){break J}b=0;if(!w[d+174|0]){break X}while(1){Y:{if(!fi(a)){break Y}v[22692]=0;f=Q(1445,c|0,d+512|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break I}if(!f){break Y}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;if((w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24))!=1347240275){break Y}v[22692]=0;Fk(d+496|0,2,i);e=v[22692];v[22692]=0;Z:{_:{$:{if((e|0)==1){break $}v[22692]=0;R(324,d+56|0,d+496|0);e=v[22692];v[22692]=0;if((e|0)==1){break $}v[22692]=0;f=f&65535;Q(301,((f<<5)+a|0)+946304|0,d+56|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break _}vb(d+56|0);v[22692]=0;f=(B(f,104)+a|0)+484380|0;U(1446,d+512|0,d+144|0,f|0);e=v[22692];v[22692]=0;if((e|0)==1){break q}if(!g){break Z}e=d+550|0;Rc(d+56|0,(w[e|0]|w[e+1|0]<<8)&4?16:8,1,0,0);v[22692]=0;W(329,d+56|0,f|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break Y}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;vb(d+56|0);break p}f=Zi(f);v[22692]=0;Q(318,d+576|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break q}}b=b+1|0;if(b>>>0<w[d+174|0]){continue}break}}xb(d+576|0);Bh(d+128|0);if(Gb(d+128|0,d+40|0)){continue}break}}hd(d+88|0);break V}b=P()|0;O()|0;break p}v[22692]=0;U(1441,d+496|0,j|0,1179011410);b=v[22692];v[22692]=0;if((b|0)==1){break H}m=d,n=Vb(d+496|0),v[m+488>>2]=n;m=d,n=Zb(d+496|0),v[m+480>>2]=n;if(Gb(d+488|0,d+480|0)){f=c&2;g=d+512|4;b=d+80|4;i=d+144|5;while(1){c=v[d+488>>2];v[22692]=0;h=Fh(d+576|0,c);c=v[22692];v[22692]=0;if((c|0)==1){break s}v[22692]=0;c=T(190,d+576|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break u}aa:{if((c|0)!=538986817){break aa}v[22692]=0;c=Q(1447,d+576|0,d+472|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break G}if(!c|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24))!=1414745673){break aa}v[22692]=0;c=Q(1448,d+576|0,d+144|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break F}if(!c){break aa}c=w[i|0];if((c|0)==255){break aa}v[22692]=0;c=W(376,a|0,c+1|0,0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break E}if(!c){break aa}e=x[a+480190>>1];v[22692]=0;U(1449,d+144|0,c|0,e|0);c=v[22692];v[22692]=0;if((c|0)==1){break E}v[22692]=0;U(1437,d+512|0,h|0,2);c=v[22692];v[22692]=0;if((c|0)==1){break L}v[22692]=0;U(1441,d+128|0,d+512|0,1179011410);c=v[22692];v[22692]=0;if((c|0)==1){break D}Ed(d+512|0);m=d,n=Vb(d+128|0),v[m+120>>2]=n;m=d,n=Zb(d+128|0),v[m+112>>2]=n;ba:{if(!Gb(d+120|0,d+112|0)){break ba}ca:{while(1){c=Pe(d+88|0,v[d+120>>2]);v[22692]=0;h=T(190,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break C}da:{ea:{if((h|0)!=538989377){break ea}if(!fi(a)){break ea}h=w[d+468|0]|w[d+469|0]<<8;e=h-1|0;t[d+468|0]=e;t[d+469|0]=e>>>8;if(!h){xb(d+88|0);break ba}h=x[a+480190>>1]+1|0;u[a+480190>>1]=h;v[22692]=0;c=Q(1447,c|0,d+80|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break B}fa:{if(!(!c|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275)){c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22692]=0;U(288,d+512|0,d+88|0,c|0);c=v[22692];v[22692]=0;ga:{if((c|0)!=1){c=jc(d+56|0,d+512|0);xb(d+512|0);v[22692]=0;e=Q(1450,c|0,d+512|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break da}if(!e){break ca}v[22692]=0;Ie(d+24|0,2,g);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;R(324,d+40|0,d+24|0);e=v[22692];v[22692]=0;if((e|0)!=1){break ga}}b=P()|0;O()|0;break w}b=P()|0;O()|0;break v}v[22692]=0;h=h&65535;Q(301,((h<<5)+a|0)+946304|0,d+40|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break A}vb(d+40|0);v[22692]=0;h=(B(h,104)+a|0)+484380|0;U(1451,d+512|0,d+144|0,h|0);e=v[22692];v[22692]=0;if((e|0)==1){break da}if(!f){break fa}e=w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24);v[22692]=0;Q(188,d+56|0,e+4|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break da}e=d+552|0;Rc(d+40|0,(w[e|0]|w[e+1|0]<<8)&4?16:8,1,0,0);v[22692]=0;W(329,d+40|0,h|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break fa}b=P()|0;O()|0;break w}xb(d+88|0);break ba}xb(d+56|0)}xb(d+88|0);Bh(d+120|0);if(Gb(d+120|0,d+112|0)){continue}break ba}break}b=P()|0;O()|0;break w}xb(d+56|0);xb(d+88|0)}hd(d+128|0)}xb(d+576|0);Bh(d+488|0);if(Gb(d+488|0,d+480|0)){continue}break}}hd(d+496|0)}g=1}xb(d+704|0);Ed(j);xb(k)}gb=d+784|0;return g|0}b=P()|0;O()|0;break t}b=P()|0;O()|0;break b}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break b}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;Ed(d+512|0);break t}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;vb(d+40|0);break w}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}xb(d+56|0)}xb(d+88|0);hd(d+128|0);break t}b=P()|0;O()|0}xb(d+576|0);break r}b=P()|0;O()|0}hd(d+496|0);break b}b=P()|0;O()|0}xb(d+576|0);hd(d+88|0);break b}b=P()|0;O()|0;break i}b=P()|0;O()|0;xb(d+512|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0}xb(d+144|0)}hd(d+576|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;xb(d+144|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(d+704|0)}Ed(j);xb(k);S(b|0);L()}function Npa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=gb+-64|0;gb=f;vc(a);a:{b:{if(b>>>0<=2){C=f,D=Ae(a),t[C+56|0]=D;Rb(a,2);b=f+56|2;e=Mg(a);t[b|0]=e;t[b+1|0]=e>>>8;b=f+56|4;e=qg(a);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;break b}zr(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{m=d+484344|0;b=f+56|2;r=Gd(w[b|0]|w[b+1|0]<<8,1,1024);l=az(m,r,0);if((l|0)!=65535){i=Rf(_b(m,l),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];s=x[Pc(f,f+40|0)>>1];e=s+1|0;if(x[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){t[i+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Ev(f+40|0,e,f);if(r){b=(b|0)!=0;while(1){d:{e:{if(!w[kc(o,0)|0]){v[22692]=0;e=T(374,a|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}e=e<<24>>24;if((e|0)<=-1){v[22692]=0;i=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}C=kc(o,0),D=i,t[C|0]=D}y=0;t[f|0]=0;g=e&63;f:{g:{if(!g){break g}v[22692]=0;e=T(374,a|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}t[f|0]=e;i=0;h:{switch(g-1|0){case 0:t[c+12|0]=0;v[22692]=0;t[f+36|0]=1;b=Bf(f+36|0,f);e=v[22692];v[22692]=0;if((e|0)!=1){t[c+14|0]=w[b|0];t[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}t[c+15|0]=e;b=1;t[c+12|0]=1;i=w[c+13|0];if(!i){break g}t[c+14|0]=B(B(e,i),15);break g;case 2:t[c+13|0]=e>>>4;if(e>>>0>=16){b=w[c+12|0]!=0;break f}t[c+12|0]=0;break f;case 3:i=e;break f;case 5:if(!e){break f}i=(w[c+12|0]?15:14)+c|0;b=w[i|0];t[i|0]=b>>>0<256-e>>>0?b+e|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(w[c+12|0]?15:14)+c|0;i=w[g|0];t[g|0]=i>>>0>e+1>>>0?i-e|0:1}i=0}v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d}i=0;e=kc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;y=0;if(!(b&1)){break d}}b=w[c+12|0];e=w[c+13|0];if(e?0:b){break d}i:{if(b){v[f>>2]=1;b=w[c+15|0];v[22692]=0;v[f+28>>2]=B(b,e)<<1;b=Gf(f,f+28|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}e=v[b>>2];break i}e=B(w[c+14|0],30)+30|0}b=255;j:{while(1){g=B(b,e);if(g-1536>>>0<10752){e=g;break j}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(e|0)/48;Sd(f+32|0,32,255);v[22692]=0;v[f>>2]=1;b=Gf(f,f+36|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}t[c+16|0]=v[b>>2];y=1}b=_b(m,l);v[22692]=0;b=Wc(b,k,1);e=v[22692];v[22692]=0;if((e|0)==1){break c}if(s){z=k-1|0;h=1;p=1;while(1){k:{l:{m:{n:{if(!w[kc(o,h)|0]){v[22692]=0;j=T(374,a|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}if(j&128){v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}C=kc(o,h),D=e,t[C|0]=D}A=1;if(j&64){v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}t[b+1|0]=e;A=!e}if(!(j&32)){e=w[b|0];break n}v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}t[b|0]=e;if((e-1&255)>>>0<=107){e=hn(e+24|0);t[b|0]=e;C=$c(c,h),D=e,t[C+1|0]=D;break n}if((e+127&255)>>>0<=107){e=hn((e&127)+24|0);t[b|0]=e;C=$c(c,h),D=e,t[C|0]=D;t[b|0]=0;break m}if((e|0)!=255){break n}t[b|0]=254;break l}e=kc(o,h);t[e|0]=w[e|0]-1;break k}if(e&255){break l}}if(!w[b+1|0]){break l}e=w[$c(c,h)+1|0];t[b+1|0]=0;t[b|0]=e}v[22692]=0;e=de(b);g=v[22692];v[22692]=0;if((g|0)==1){break c}if(e){C=$c(c,h),D=0,t[C+5|0]=D}t[f+28|0]=0;t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;if(j&16){t[b+2|0]=1;v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}t[b+4|0]=e+2>>>2}o:{if(!(j&8)){break o}v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}v[22692]=0;t[f+28|0]=e;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}t[f+25|0]=e;p:{q:{r:{s:{t:{u:{v:{w:{g=w[f+28|0];switch(g-1|0){case 0:break q;case 9:break r;case 5:case 6:case 7:case 8:break s;case 4:break t;case 3:break u;case 2:break v;case 1:break w;default:break p}}t[b|0]=255;break p}C=b,D=w[$c(c,h)+1|0],t[C|0]=D;C=$c(c,h),D=0,t[C+5|0]=D;break p}e=Dv(e,w[c+16|0]);t[f+25|0]=e;x:{if(e){t[f+28|0]=20;t[f+25|0]=e|208;break x}t[f+28|0]=0}if(w[b|0]){break o}C=b,D=w[$c(c,h)+1|0],t[C|0]=D;C=$c(c,h),D=0,t[C+5|0]=D;break o}t[f|0]=1;e=Dv(e,w[c+16|0]);v[22692]=0;t[f+22|0]=e;e=Bf(f,f+22|0);g=v[22692];v[22692]=0;if((g|0)!=1){t[f+25|0]=w[e|0];t[f+28|0]=15;C=$c(c,h),D=0,t[C+5|0]=D;break o}break c}y:{if(!k){break y}if((g|0)==w[$c(c,h)+4|0]){break y}e=_b(m,l);v[22692]=0;g=Be(f,20,(w[f+28|0]+122|160)&255);n=v[22692];v[22692]=0;if((n|0)==1){break c}g=jp(ip(Se(g,z),p&65535));v[22692]=0;e=Q(431,e|0,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!e){break y}C=$c(c,h),D=w[f+28|0],t[C+4|0]=D}t[f+28|0]=10;if(!w[b|0]){C=b,D=w[$c(c,h)+1|0],t[C|0]=D}C=$c(c,h),D=0,t[C+5|0]=D;break o}t[f+28|0]=20;C=f,D=w[$c(c,h)+5|0]?-98:-97,t[C+25|0]=D;e=$c(c,h);t[e+5|0]=w[e+5|0]^1;break o}t[b|0]=254}t[f+28|0]=0}n=0;e=0;z:{if(!(j&4)){break z}v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}v[22692]=0;t[f+27|0]=e;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}t[f+24|0]=e;g=f;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{q=w[f+27|0];switch(q-1|0){case 11:break C;case 10:break D;case 7:case 8:case 9:break E;case 6:break F;case 5:break G;case 3:case 4:break H;case 2:break I;case 1:break J;case 0:break K;default:break B}}v[22692]=0;ht(f,e<<24>>24<<3,128);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;e=de(b);g=v[22692];v[22692]=0;if((g|0)==1){break c}if(e){C=b,D=hn(v[f>>2]+w[b|0]|0),t[C|0]=D}t[f+27|0]=35;t[f+24|0]=w[f+4|0]^128;e=0;break z}e=Dv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|208;e=1;break z}t[f+27|0]=0;e=1;break z}e=1;break A}g=w[c+16|0];v[22692]=0;e=gD(e,g,1);g=v[22692];v[22692]=0;if((g|0)==1){break c}t[f+24|0]=e;t[f+27|0]=w[f+27|0]==4?2:3;e=1;break z}if(!w[b|0]){C=b,D=w[$c(c,h)|0],t[C|0]=D;e=w[f+24|0]}g=w[c+16|0];v[22692]=0;e=gD(e&255,g,0);g=v[22692];v[22692]=0;if((g|0)==1){break c}t[f+27|0]=4;t[f+24|0]=e;e=1;break z}C=b,D=hn(e+25|0),t[C|0]=D;t[f+24|0]=255;t[f+27|0]=4;e=1;break z}L:{if(!k){break L}if((q|0)==w[$c(c,h)+2|0]){break L}e=_b(m,l);v[22692]=0;g=Be(f,20,(w[f+27|0]-8|48)&255);q=v[22692];v[22692]=0;if((q|0)==1){break c}g=jp(ip(Se(g,z),p&65535));v[22692]=0;e=Q(431,e|0,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!e){break L}C=$c(c,h),D=w[f+27|0],t[C+2|0]=D}t[f+27|0]=5;e=w[c+16|0];v[22692]=0;e=Cv(w[f+24|0],e);g=v[22692];v[22692]=0;if((g|0)==1){break c}t[f+24|0]=e;e=1;break z}e=pY(e,w[c+16|0]);t[f+27|0]=18;t[f+24|0]=e;e=1;break z}e=Dv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|192;e=1;break z}t[f+27|0]=0;t[b|0]=254;e=1;break z}e=0}t[g+27|0]=e}M:{if(!(j&2)){break M}v[22692]=0;g=T(374,a|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}v[22692]=0;t[f+26|0]=g;g=T(374,a|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}t[f+23|0]=g;N:{O:{P:{Q:{R:{S:{T:{j=w[f+26|0];switch(j-1|0){case 9:break O;case 7:case 8:break P;case 6:break Q;case 3:case 4:case 5:break R;case 2:break S;case 0:case 1:break T;default:break N}}h=w[c+16|0];v[22692]=0;g=fD(g,h,(j|0)==1);h=v[22692];v[22692]=0;if((h|0)==1){break c}t[f+26|0]=11;t[f+23|0]=g;n=1;break M}g=pY(g,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=g;n=1;break M}U:{if(!k){break U}if((j|0)==w[$c(c,h)+3|0]){break U}g=_b(m,l);v[22692]=0;j=Be(f,20,(w[f+26|0]-4|64)&255);n=v[22692];v[22692]=0;if((n|0)==1){break c}j=jp(ip(Se(j,z),p&65535));v[22692]=0;g=Q(431,g|0,j|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}if(!g){break U}C=$c(c,h),D=w[f+26|0],t[C+3|0]=D}t[f+26|0]=8;g=w[c+16|0];v[22692]=0;g=Cv(w[f+23|0],g);h=v[22692];v[22692]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=9;break M}h=w[c+16|0];v[22692]=0;g=fD(g,h,(j|0)==8);h=v[22692];v[22692]=0;if((h|0)==1){break c}t[f+26|0]=29;t[f+23|0]=g;n=1;break M}t[f+26|0]=27;h=w[c+16|0];v[22692]=0;g=Cv(g,h);h=v[22692];v[22692]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=0}if(e){oY(b,k,x[d+480188>>1],w[f+27|0],f+24|0)}if(n){oY(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}V:{if(!A){break V}v[22692]=0;e=de(b);g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!e){break V}e=w[f+27|0];if(!e){t[f+24|0]=255;t[f+27|0]=4;break V}if(w[f+26|0]|(e|0)==4){break V}t[f+23|0]=255;t[f+26|0]=4}W:{if(w[b+2|0]!=1){break W}X:{if(!w[f+27|0]){t[f+27|0]=13;t[f+24|0]=w[b+4|0];break X}if(w[f+26|0]){break W}t[f+26|0]=13;t[f+23|0]=w[b+4|0]}t[b+2|0]=0}v[22692]=0;mo(f,f+27|0,f+24|0,f+26|0,f+23|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}Y:{if(w[b+2|0]){break Y}e=w[f+27|0];if(!e){break Y}t[b+2|0]=e;t[b+4|0]=w[f+24|0]}Z:{if(w[f+28|0]){v[22692]=0;mo(f,f+26|0,f+23|0,f+28|0,f+25|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}_:{if(w[b+2|0]){break _}e=w[f+26|0];if(!e){break _}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}h=f+25|0;e=w[f+28|0];break Z}h=f+23|0;e=w[f+26|0];if(!e){break k}}t[b+3|0]=e;t[b+5|0]=w[h|0]}b=b+6|0;p=p+1|0;h=p&65535;if(s>>>0>=h>>>0){continue}break}}$:{if(!y){break $}b=_b(m,l);v[22692]=0;e=Be(f,17,w[f+32|0]);g=v[22692];v[22692]=0;if((g|0)==1){break c}e=Gh(ip(Se(e,k),0));v[22692]=0;Q(431,b|0,e|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}b=_b(m,l);v[22692]=0;e=Be(f,16,w[f+36|0]);g=v[22692];v[22692]=0;if((g|0)!=1){e=Gh(Se(e,k));v[22692]=0;Q(431,b|0,e|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break $}}break c}aa:{if(!(i&240)){break aa}b=_b(m,l);v[22692]=0;e=Be(f,20,i>>>4|224);g=v[22692];v[22692]=0;if((g|0)!=1){e=nY(Se(e,k));v[22692]=0;Q(431,b|0,e|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break aa}}break c}ba:{b=i&15;if(!b){break ba}e=w[c+16|0];i=_b(m,l);b=Gd((B(b,e)>>>0)/15&255,1,15);v[22692]=0;b=Be(f,20,b|96);e=v[22692];v[22692]=0;if((e|0)!=1){b=nY(Se(b,k));v[22692]=0;Q(431,i|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break ba}}break c}b=0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}gc(o)}gb=f- -64|0;return l|0}a=P()|0;O()|0;gc(o);S(a|0);L()}function Eka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-240|0;gb=i;a:{if(!Iu(a)){hc(i+80|0,a,128);of(i+208|0,i+80|0,128,2);Bc(i+224|0,i+208|0);v[22692]=0;Q(301,b+492|0,i+224|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break a}vb(i+224|0)}u[c+34>>1]=x[c+34>>1]&65489;e=c;h=gb-48|0;gb=h;f=a;b:{if(!(w[f+128|0]==4|w[f+128|0]==8)){v[h+44>>2]=0;v[h+40>>2]=0;break b}t[h+40|0]=w[f+129|0];t[h+36|0]=100;g=w[ac(h+40|0,h+36|0)|0];v[h+44>>2]=g;t[h+36|0]=w[f+130|0];t[h+32|0]=100;m=w[ac(h+36|0,h+32|0)|0];v[h+40>>2]=m;c:{if(w[f+140|0]&16){g=Ib(w[f+150|0]|w[f+151|0]<<8)|g<<16;v[h+44>>2]=g;f=Ib(w[f+152|0]|w[f+153|0]<<8)|m<<16;v[h+40>>2]=f;p=+y[e>>2]*1.52587890625e-7;g=dr(p*+(g>>>0));v[h+44>>2]=g;v[h+36>>2]=v[e>>2]-g;s=h,z=dr(p*+(f>>>0)),v[s+32>>2]=z;s=h,z=v[Fb(h+36|0,h+32|0)>>2],v[s+40>>2]=z;break c}if(!Nd(e)){break c}f=v[e>>2];j=f>>>7|0;g=B(j,(g<<7>>>0)/100|0);v[h+44>>2]=g;v[h+36>>2]=f-g;v[h+32>>2]=B(j,(m<<7>>>0)/100|0);f=v[Fb(h+36|0,h+32|0)>>2];v[h+40>>2]=f;m=h;d:{if(t[e+34|0]&1){en(h+24|0,v[e+20>>2],B(v[e>>2],dd(e)));j=dd(e);e=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=e;e=v[h+8>>2];e:{if(f){l=u[e+(B(g,j)<<1)>>1];e=e+(B(j,f+g|0)<<1)|0;o=0-j<<1;while(1){g=u[e>>1]-l|0;j=g>>31;n=f;if((j^g+j)>>>0<1536){break e}e=e+o|0;f=f-1|0;if(f){continue}break}}n=0}break d}bc(h+16|0,v[e+20>>2],B(v[e>>2],dd(e)));e=dd(e);j=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=j;j=v[h>>2];f:{if(f){l=0-e|0;o=t[j+B(e,g)|0];e=j+B(e,f+g|0)|0;while(1){g=t[e|0]-o|0;j=g>>31;n=f;if((j^g+j)>>>0<6){break f}e=e+l|0;f=f-1|0;if(f){continue}break}}n=0}}v[m+40>>2]=n}}v[i+224>>2]=v[h+44>>2];v[i+228>>2]=v[h+40>>2];gb=h+48|0;e=128;m=fc(i+224|0);if(!(!v[m>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[i+224>>2];v[c+8>>2]=v[m>>2]+v[i+224>>2]}f=i;if(!(!w[a+134|0]|w[a+134|0]>199)){t[i+80|0]=w[a+134|0];t[i+208|0]=100;e=(w[ac(i+80|0,i+208|0)|0]<<7>>>0)/100|0}t[f+79|0]=e;t[i+80|0]=64;s=c,z=w[Bf(i+79|0,i+80|0)|0]>>>1|0,u[s+32>>1]=z;t[i+80|0]=64;s=b,z=w[ac(i+79|0,i+80|0)|0],v[s+4>>2]=z;v[c+24>>2]=40460;Ho(c,+t[a+139|0]*.08333333333333333+ +(0-w[a+143|0]|0)+ +t[a+138|0]*.0006510416666666666);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){am(b,127,1);$l(b,0,1)}g:{if(!Nd(c)){break g}if(t[a+140|0]&1){f=d;b=c;h:{if(!Nd(b)){break h}e=v[b>>2];if(e>>>0<2){break h}i:{if((gj(b)|0)==4){h=v[b+20>>2];g=0;j=e>>>1|0;while(1){xc(h+(g<<2)|0,h+((g^-1)+e<<2)|0);g=g+1|0;if((j|0)!=(g|0)){continue}break}break i}if((gj(b)|0)==2){h=v[b+20>>2];g=0;j=e>>>1|0;while(1){Ez(h+(g<<1)|0,h+((g^-1)+e<<1)|0);g=g+1|0;if((j|0)!=(g|0)){continue}break}break i}if((gj(b)|0)!=1){break h}h=v[b+20>>2];g=0;j=e>>>1|0;while(1){l=h+g|0;o=w[l|0];n=l;l=h+((g^-1)+e|0)|0;t[n|0]=w[l|0];t[l|0]=o;g=g+1|0;if((j|0)!=(g|0)){continue}break}}_h(b,f,0)}}if(w[a+140|0]&4){f=d;b=c;j:{if(!Nd(b)){break j}e=v[b>>2];dd(b);g=0;h=B(dd(b),e);k:{if((fj(b)|0)==2){j=v[b+20>>2]+(g<<1)|0;e=0;g=h-g|0;if(g){while(1){h=j+(e<<1)|0;u[h>>1]=x[h>>1]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}break k}if((fj(b)|0)!=1){break j}j=g+v[b+20>>2]|0;e=0;g=h-g|0;if(g){while(1){h=e+j|0;t[h|0]=w[h|0]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}}_h(b,f,0)}}if(!(!(w[a+141|0]?1:w[a+160|0]|w[a+170|0]==2)|t[c+34|0]&1)){e=Oq(v[c>>2],dd(c)<<1);if(!e){break g}b=e;g=B(v[c>>2],dd(c));f=v[c+20>>2];j=Zi(c);h=gb-16|0;gb=h;v[h+12>>2]=g;tc(h+12|0,j);g=v[h+12>>2];if(g){while(1){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;g=g-1|0;if(g){continue}break}v[h+12>>2]=-1}gb=h+16|0;u[c+34>>1]=x[c+34>>1]|1;HN(c,e,v[c>>2],d)}l:{if(t[a+141|0]>-1){break l}en(i+80|0,v[c+20>>2],B(v[c>>2],dd(c)));if(t[a+141|0]>=0){break l}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=gd(u[b>>1]-gd(e,1)|0,1);u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}k=k+1|0;if((k|0)<(0-t[a+141|0]|0)){continue}break}}m:{if(w[a+170|0]!=2){break m}en(i+80|0,v[c+20>>2],B(v[c>>2],dd(c)));h=w[a+171|0];b=w[a+172|0];e=w[a+171|0];f=0-(b>>>0<e>>>0)|0;e=b-e|0;b=f<<24|e>>>8;f=e<<24;e=BB(i+80|0);g=(e|0)/2|0;f=f+g|0;b=(g>>31)+b|0;g=Ac(kqa(f,f>>>0<g>>>0?b+1|0:b,e,e>>31),jb);b=v[i+80>>2];j=v[i+84>>2];if((b|0)==(j|0)){break m}e=h<<24;h=e;f=e>>31;e=g;l=e>>31;while(1){g=u[b>>1];k=jqa(h,f,g,g>>31)+838860800|0;g=jb;s=b,z=Ac(kqa(k,k>>>0<838860800?g+1|0:g,1677721600,0),jb),u[s>>1]=z;f=f+l|0;h=e+h|0;f=h>>>0<e>>>0?f+1|0:f;b=b+2|0;if((j|0)!=(b|0)){continue}break}}n:{if(!w[a+160|0]){break n}en(i+208|0,v[c+20>>2],B(v[c>>2],dd(c)));h=w[a+162|0];k=w[a+163|0];if(w[a+161|0]>=2){b=w[a+164|0];e=w[a+162|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;g=f<<23|b>>>9;f=b<<23;e=BB(i+208|0);b=(e|0)/2|0;j=b;f=f+b|0;b=(b>>31)+g|0;q=Ac(kqa(f,f>>>0<j>>>0?b+1|0:b,e,e>>31),jb)}if(w[a+161|0]>=2){b=w[a+165|0];e=w[a+163|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;g=f<<23|b>>>9;e=b<<23;b=BB(i+208|0);f=(b|0)/2|0;j=f;e=e+f|0;f=(f>>31)+g|0;r=Ac(kqa(e,e>>>0<j>>>0?f+1|0:f,b,b>>31),jb)}b=v[i+208>>2];j=v[i+212>>2];if((b|0)==(j|0)){break n}e=h<<23;f=k<<23;h=(i+80|0)+((w[a+160|0]&2)<<2)|0;k=0;g=0;while(1){l=(u[b>>1]>>1)-g|0;v[i+88>>2]=l;n=l;l=(e|0)/8388608|0;k=gd(B(n,l),8)+k|0;v[i+84>>2]=k;g=gd(B(k,l),6)+g|0;g=gd(gd(B(g,(f|0)/8388608|0),6)+g|0,2);v[i+80>>2]=g;s=b,z=Uc(v[h>>2]),u[s>>1]=z;f=f+r|0;e=e+q|0;b=b+2|0;if((j|0)!=(b|0)){continue}break}}o:{if(t[a+141|0]<1){break o}en(i+80|0,v[c+20>>2],B(v[c>>2],dd(c)));k=0;if(t[a+141|0]<=0){break o}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=((u[b>>1]<<1)+e|0)/3|0;u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}k=k+1|0;if((k|0)<t[a+141|0]){continue}break}}p:{if(t[c+34|0]&1){en(i- -64|0,v[c+20>>2],B(v[c>>2],dd(c)));b=v[i+68>>2];v[i+32>>2]=v[i+64>>2];v[i+36>>2]=b;k=gb-16|0;gb=k;l=v[i+36>>2];j=gb-16|0;gb=j;v[j+12>>2]=v[i+32>>2];f=Hu(k+8|0,j+12|0,j+12|0);e=v[j+12>>2];q:{if((e|0)==(l|0)){break q}b=e+2|0;v[j+12>>2]=b;if((b|0)==(l|0)){break q}s=(Jj(b,v[f>>2])?0:4)+f|0,z=b,v[s>>2]=z;e=e+4|0;if((l|0)==(e|0)){break q}g=f+4|0;while(1){h=b;b=b+4|0;v[j+12>>2]=b;if((b|0)==(l|0)){if(!Jj(e,v[f>>2])){f=g;if(Jj(e,v[f>>2])){break q}}v[f>>2]=e;break q}o=v[f>>2];r:{s:{if(Jj(b,e)){if(Jj(b,o)){v[f>>2]=b}if(!Jj(e,v[g>>2])){break s}break r}if(Jj(e,o)){v[f>>2]=e}e=b;if(Jj(b,v[g>>2])){break r}}v[g>>2]=e}e=h+6|0;v[j+12>>2]=e;if((e|0)!=(l|0)){continue}break}}gb=j+16|0;v[k+4>>2]=0-u[v[k+8>>2]>>1];s=k,z=u[v[fc(k+8|0)>>2]>>1],v[s>>2]=z;b=v[Gf(k+4|0,k)>>2];t:{if((b|0)>=32767|!b){break t}e=v[i+32>>2];f=v[i+36>>2];if((e|0)==(f|0)){break t}while(1){u[e>>1]=(B(u[e>>1],32767)|0)/(b|0);e=e+2|0;if((f|0)!=(e|0)){continue}break}}gb=k+16|0;break p}bc(i+56|0,v[c+20>>2],B(v[c>>2],dd(c)));b=v[i+60>>2];v[i+24>>2]=v[i+56>>2];v[i+28>>2]=b;h=gb-16|0;gb=h;k=v[i+28>>2];f=gb-16|0;gb=f;v[f+4>>2]=v[i+24>>2];b=Hu(h+8|0,f+4|0,f+4|0);e=v[f+4>>2];u:{if((e|0)==(k|0)){break u}e=e+1|0;v[f+4>>2]=e;if((e|0)==(k|0)){break u}e=(Ij(e,v[b>>2])?0:4)+b|0;j=v[f+4>>2];v[e>>2]=j;g=j+1|0;if((k|0)==(g|0)){break u}e=b+4|0;while(1){j=j+2|0;v[f+4>>2]=j;if((j|0)==(k|0)){if(!Ij(g,v[b>>2])){b=e;if(Ij(g,v[b>>2])){break u}}v[b>>2]=g;break u}v:{w:{if(Ij(j,g)){if(Ij(v[f+4>>2],v[b>>2])){v[b>>2]=v[f+4>>2]}if(!Ij(g,v[e>>2])){break w}break v}if(Ij(g,v[b>>2])){v[b>>2]=g}if(Ij(v[f+4>>2],v[e>>2])){break v}g=v[f+4>>2]}v[e>>2]=g}j=v[f+4>>2];g=j+1|0;v[f+4>>2]=g;if((g|0)!=(k|0)){continue}break}}gb=f+16|0;v[h+4>>2]=0-t[v[h+8>>2]];s=h,z=t[v[fc(h+8|0)>>2]],v[s>>2]=z;b=v[Gf(h+4|0,h)>>2];x:{if((b|0)>=127|!b){break x}e=v[i+24>>2];f=v[i+28>>2];if((e|0)==(f|0)){break x}while(1){t[e|0]=(B(t[e|0],127)|0)/(b|0);e=e+1|0;if((f|0)!=(e|0)){continue}break}}gb=h+16|0}y:{if(w[a+134|0]<101|w[a+134|0]>199){break y}b=B(v[c>>2],dd(c));if(t[c+34|0]&1){e=v[c+20>>2];b=sd(i+48|0,e,e+(b<<1)|0);e=w[a+134|0];f=v[b+4>>2];v[i+16>>2]=v[b>>2];v[i+20>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+16>>2];k=v[i+20>>2];if((b|0)!=(k|0)){j=0-f|0;g=32768-f|0;while(1){e=b;h=u[b>>1];z:{if((h|0)>(f|0)){l=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break z}l=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(j|0)){break z}l=(B(h,g)|0)/(f|0)|0}s=e,z=Uc(l),u[s>>1]=z;b=b+2|0;if((k|0)!=(b|0)){continue}break}}break y}e=v[c+20>>2];b=sd(i+40|0,e,b+e|0);e=w[a+134|0];f=v[b+4>>2];v[i+8>>2]=v[b>>2];v[i+12>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+8>>2];k=v[i+12>>2];if((b|0)!=(k|0)){j=0-f|0;g=32768-f|0;while(1){e=b;h=t[b|0]<<8;A:{if((h|0)>(f|0)){l=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break A}l=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(j|0)){break A}l=(B(h,g)|0)/(f|0)|0}s=e,z=EV((l|0)/256|0),t[s|0]=z;b=b+1|0;if((k|0)!=(b|0)){continue}break}}}if(!v[m>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break g}v[c+12>>2]=v[i+224>>2];v[c+16>>2]=v[m>>2]+v[i+224>>2];if(y[m>>2]>268435456/w[a+131|0]>>>0|y[c>>2]>268435456-B(v[m>>2],w[a+131|0])>>>0){break g}b=gj(c);h=v[i+224>>2];k=v[m>>2];j=w[a+131|0];g=v[c>>2]+B(v[m>>2],w[a+131|0])|0;e=Oq(g,b);if(!e){break g}v[c>>2]=g;f=hc(e,zb(v[c+20>>2]),B(b,v[m>>2]+v[i+224>>2]|0));if(w[a+131|0]){e=0;while(1){e=e+1|0;hc(f+B(b,v[i+224>>2]+B(e,v[m>>2])|0)|0,zb(v[c+20>>2])+B(b,v[i+224>>2])|0,B(b,v[m>>2]));if(w[a+131|0]>e>>>0){continue}break}}a=h+B(k,j+1|0)|0;hc(f+B(a,b)|0,zb(v[c+20>>2])+B(b,v[m>>2]+v[i+224>>2]|0)|0,B(b,g-a|0));HN(c,f,v[c>>2],d)}gb=i+240|0;return}a=P()|0;O()|0;vb(i+224|0);S(a|0);L()}function oH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=gb-144|0;gb=d;x=Qb(d,0,144);v[x+76>>2]=-1;v[x+44>>2]=a;v[x+32>>2]=2432;v[x+84>>2]=a;D=c;c=0;j=gb-304|0;gb=j;e=x;d=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(tm(a&255)){while(1){a=d;d=d+1|0;if(tm(w[a+1|0])){continue}break}xi(e,0,0);while(1){b=v[e+4>>2];h:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break h}b=kd(e)}if(tm(b)){continue}break}d=v[e+4>>2];if(v[e+104>>2]){d=d-1|0;v[e+4>>2]=d}b=d-v[e+8>>2]|0;f=b>>31;g=b;k=o+v[e+124>>2]|0;b=q+v[e+120>>2]|0;k=b>>>0<q>>>0?k+1|0:k;d=b;b=g+b|0;f=f+k|0;q=b;o=b>>>0<d>>>0?f+1|0:f;break g}i:{j:{k:{b=w[d|0];if((b|0)==37){a=w[d+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}xi(e,0,0);a=((b|0)==37)+d|0;b=v[e+4>>2];l:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break l}b=kd(e)}if((b|0)!=w[a|0]){if(v[e+104>>2]){v[e+4>>2]=v[e+4>>2]-1}if((b|0)>-1){break a}s=0;if(E){break a}break c}b=q+1|0;o=b>>>0<1?o+1|0:o;q=b;break g}n=0;a=d+2|0;break i}if(!(!Qh(a)|w[d+2|0]!=36)){a=w[d+1|0]-48|0;b=gb-16|0;v[b+12>>2]=D;a=a>>>0>1?((a<<2)+D|0)-4|0:D;v[b+8>>2]=a+4;n=v[a>>2];a=d+3|0;break i}n=v[D>>2];D=D+4|0;a=d+1|0}s=0;d=0;if(Qh(w[a|0])){while(1){d=(w[a|0]+B(d,10)|0)-48|0;b=w[a+1|0];a=a+1|0;if(Qh(b)){continue}break}}i=w[a|0];if((i|0)==109){c=0;s=(n|0)!=0;i=w[a+1|0];p=0;a=a+1|0}b=a;a=b+1|0;g=3;m:{n:{switch(i-65|0){case 39:f=b+2|0;b=w[b+1|0]==104;a=b?f:a;g=b?-2:-1;break m;case 43:f=b+2|0;b=w[b+1|0]==108;a=b?f:a;g=b?3:1;break m;case 51:case 57:g=1;break m;case 11:g=2;break m;case 41:break m;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break n;default:break d}}g=0;a=b}b=w[a|0];f=(b&47)==3;F=f?1:g;r=f?b|32:b;o:{if((r|0)==91){break o}p:{if((r|0)!=110){if((r|0)!=99){break p}d=(d|0)>1?d:1;break o}pH(n,F,q,o);break g}xi(e,0,0);while(1){b=v[e+4>>2];q:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break q}b=kd(e)}if(tm(b)){continue}break}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}b=b-v[e+8>>2]|0;g=b>>31;m=b;b=o+v[e+124>>2]|0;f=q+v[e+120>>2]|0;b=f>>>0<q>>>0?b+1|0:b;i=f;o=m+f|0;f=b+g|0;q=o;o=i>>>0>o>>>0?f+1|0:f}m=d;l=d>>31;xi(e,d,l);b=v[e+104>>2];f=v[e+4>>2];r:{if(b>>>0>f>>>0){v[e+4>>2]=f+1;break r}if((kd(e)|0)<0){break d}b=v[e+104>>2]}if(b){v[e+4>>2]=v[e+4>>2]-1}b=16;s:{t:{u:{v:{w:{x:{y:{switch(r-88|0){default:b=r-65|0;if(b>>>0>6|!(1<<b&113)){break s}case 9:case 13:case 14:case 15:rI(j,e,F,0);b=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-b|0)&v[e+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!n){break s}b=v[j+8>>2];d=v[j+12>>2];f=v[j>>2];g=v[j+4>>2];switch(F|0){case 2:break u;case 1:break v;case 0:break w;default:break s};case 3:case 11:case 27:if((r&239)==99){Qb(j+32|0,-1,257);t[j+32|0]=0;if((r|0)!=115){break t}t[j+65|0]=0;t[j+46|0]=0;u[j+42>>1]=0;u[j+44>>1]=0;break t}f=w[a+1|0];g=(f|0)==94;Qb(j+32|0,g,257);t[j+32|0]=0;b=g?a+2|0:a+1|0;z:{A:{B:{a=w[(g?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break B}g=(f|0)!=94;a=b;break z}g=(f|0)!=94;t[j+78|0]=g;break A}g=(f|0)!=94;t[j+126|0]=g}a=b+1|0}while(1){b=w[a|0];C:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break C}break t}b=45;f=w[a+1|0];if(!f|(f|0)==93){break C}i=a+1|0;a=w[a-1|0];D:{if(f>>>0<=a>>>0){b=f;break D}while(1){a=a+1|0;t[a+(j+32|0)|0]=g;b=w[i|0];if(b>>>0>a>>>0){continue}break}}a=i}t[(b+j|0)+33|0]=g;a=a+1|0;continue};case 23:b=8;break x;case 12:case 29:b=10;break x;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break s;case 0:case 24:case 32:break x;case 17:break y}}b=0}h=e;m=0;f=0;i=0;g=0;I=0;G=gb-16|0;gb=G;E:{F:{G:{H:{I:{J:{if(b>>>0<=36){while(1){d=v[h+4>>2];K:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break K}d=kd(h)}if(tm(d)){continue}break}L:{M:{switch(d-43|0){case 0:case 2:break M;default:break L}}I=(d|0)==45?-1:0;d=v[h+4>>2];if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break L}d=kd(h)}N:{if(!(b&-17|(d|0)!=48)){d=v[h+4>>2];O:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break O}d=kd(h)}if((d&-33)==88){b=16;d=v[h+4>>2];P:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break P}d=kd(h)}if(w[d+74433|0]<16){break I}if(!v[h+104>>2]){break F}v[h+4>>2]=v[h+4>>2]-1;break F}if(b){break N}b=8;break I}b=b?b:10;if(b>>>0>w[d+74433|0]){break N}if(v[h+104>>2]){v[h+4>>2]=v[h+4>>2]-1}xi(h,0,0);v[115173]=28;b=0;d=0;break E}if((b|0)!=10){break I}i=d-48|0;if(i>>>0<=9){b=0;while(1){b=B(b,10)+i|0;d=v[h+4>>2];Q:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break Q}d=kd(h)}i=d-48|0;if(b>>>0<429496729?i>>>0<=9:0){continue}break}m=b}if(i>>>0>9){break J}k=jqa(m,0,10,0);l=jb;g=i;while(1){b=v[h+4>>2];R:{if(b>>>0<y[h+104>>2]){v[h+4>>2]=b+1;d=w[b|0];break R}d=kd(h)}i=d-48|0;H=i>>>0>9;f=l;b=g+k|0;f=b>>>0<k>>>0?f+1|0:f;m=b;if((f|0)==429496729&b>>>0>=2576980378|f>>>0>429496729|H){break J}k=jqa(m,f,10,0);b=k;l=jb;g=i;if((l|0)==-1&(g^-1)>>>0>=b>>>0|(l|0)!=-1){continue}break}b=10;break H}v[115173]=28;b=0;d=0;break E}b=10;if(i>>>0<=9){break H}break G}if(b-1&b){g=w[d+74433|0];if(g>>>0<b>>>0){while(1){i=B(b,i)+g|0;d=v[h+4>>2];S:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break S}d=kd(h)}g=w[d+74433|0];if(i>>>0<119304647?g>>>0<b>>>0:0){continue}break}m=i}if(b>>>0<=g>>>0){break H}i=b;k=jqa(m,0,b,0);l=jb;if((l|0)==-1&(g^-1)>>>0<k>>>0){break H}while(1){f=l;d=g+k|0;f=d>>>0<k>>>0?f+1|0:f;m=d;d=v[h+4>>2];T:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break T}d=kd(h)}g=w[d+74433|0];if(g>>>0>=b>>>0){break H}pf(G,i,0,0,0,m,f,0,0);if(v[G+8>>2]|v[G+12>>2]){break H}k=jqa(m,f,i,0);l=jb;if((l|0)==-1&(g^-1)>>>0>=k>>>0|(l|0)!=-1){continue}break}break H}k=t[(B(b,23)>>>5&7)+74689|0];i=w[d+74433|0];if(i>>>0<b>>>0){while(1){g=g<<k|i;d=v[h+4>>2];U:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break U}d=kd(h)}i=w[d+74433|0];if(g>>>0<134217728?i>>>0<b>>>0:0){continue}break}m=g}if(b>>>0<=i>>>0){break H}g=k;l=g&31;if((g&63)>>>0>=32){k=0;H=-1>>>l|0}else{k=-1>>>l|0;H=(1<<l)-1<<32-l|-1>>>l}if(!k&m>>>0>H>>>0){break H}while(1){l=i&255;d=g;i=d&31;if((d&63)>>>0>=32){f=m<<i;d=0}else{f=(1<<i)-1&m>>>32-i|f<<i;d=m<<i}m=l|d;l=b;d=v[h+4>>2];V:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break V}d=kd(h)}i=w[d+74433|0];if(l>>>0<=i>>>0){break H}if((f|0)==(k|0)&m>>>0<=H>>>0|f>>>0<k>>>0){continue}break}}if(w[d+74433|0]>=b>>>0){break G}while(1){f=v[h+4>>2];W:{if(f>>>0<y[h+104>>2]){v[h+4>>2]=f+1;d=w[f|0];break W}d=kd(h)}if(w[d+74433|0]<b>>>0){continue}break}v[115173]=68;I=0;m=-1;f=-1}if(v[h+104>>2]){v[h+4>>2]=v[h+4>>2]-1}if((m|0)==-1&(f|0)==-1){if(!(I|1)){v[115173]=68;b=-2;d=-1;break E}}b=I;g=b^m;d=b;b=g-b|0;i=f;f=d>>31;d=(i^f)-((d>>>0>g>>>0)+f|0)|0;break E}xi(h,0,0);b=0;d=0}gb=G+16|0;f=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-f|0)&v[e+124>>2]==(0-((f>>31)+((f|0)!=0)|0)|0)){break b}if(!(!n|(r|0)!=112)){v[n>>2]=b;break s}pH(n,F,b,d);break s}J=n,K=pI(f,g,b,d),z[J>>2]=K;break s}J=n,L=Vx(f,g,b,d),A[J>>3]=L;break s}v[n>>2]=f;v[n+4>>2]=g;v[n+8>>2]=b;v[n+12>>2]=d;break s}f=(r|0)==99;g=f?d+1|0:31;i=(F|0)!=1;X:{if(!i){b=n;if(s){b=Cd(g<<2);if(!b){break e}}v[j+296>>2]=0;v[j+300>>2]=0;d=0;c=s;while(1){p=b;Y:{while(1){b=v[e+4>>2];Z:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break Z}b=kd(e)}if(!w[(b+j|0)+33|0]){break Y}t[j+27|0]=b;b=Wp(j+28|0,j+27|0,1,j+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(p){v[(d<<2)+p>>2]=v[j+28>>2];d=d+1|0}if(!(c&(d|0)==(g|0))){continue}break}g=g<<1|1;b=Qp(p,g<<2);if(b){continue}break f}break}if(j+296|0?v[j+296>>2]:0){break f}c=0;break X}if(s){d=0;b=Cd(g);if(!b){break e}while(1){c=b;while(1){b=v[e+4>>2];_:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break _}b=kd(e)}if(!w[(b+j|0)+33|0]){p=0;break X}t[c+d|0]=b;d=d+1|0;if((g|0)!=(d|0)){continue}break}p=0;g=g<<1|1;b=Qp(c,g);if(b){continue}break}break d}d=0;if(n){while(1){b=v[e+4>>2];$:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break $}b=kd(e)}if(w[(b+j|0)+33|0]){t[d+n|0]=b;d=d+1|0;continue}else{p=0;c=n;break X}}}while(1){b=v[e+4>>2];aa:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break aa}b=kd(e)}if(w[(b+j|0)+33|0]){continue}break}c=0;p=0}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}g=b-v[e+8>>2]|0;h=g;b=h+v[e+120>>2]|0;k=v[e+124>>2]+(h>>31)|0;k=b>>>0<h>>>0?k+1|0:k;if(!(k|b)|((b|0)!=(m|0)|(k|0)!=(l|0)?(r|0)==99:0)){break b}ba:{if(!s){break ba}if(!i){v[n>>2]=p;break ba}v[n>>2]=c}if(f){break s}if(p){v[(d<<2)+p>>2]=0}if(!c){c=0;break s}t[c+d|0]=0}b=v[e+4>>2]-v[e+8>>2]|0;f=b>>31;g=b;o=o+v[e+124>>2]|0;b=q+v[e+120>>2]|0;o=b>>>0<q>>>0?o+1|0:o;d=b;b=g+b|0;o=f+o|0;o=b>>>0<d>>>0?o+1|0:o;q=b;E=((n|0)!=0)+E|0}d=a+1|0;a=w[a+1|0];if(a){continue}break a}break}c=0;break d}c=0;p=0}if(E){break b}}E=-1}if(!s){break a}Xb(c);Xb(p)}gb=j+304|0;gb=x+144|0;return E}function fha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;j=gb-288|0;gb=j;f=gb-112|0;gb=f;g=j+104|0;h=Fh(g,c);v[22692]=0;i=T(214,g+20|0)|0;c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((c|0)!=1){v[22692]=0;n=T(214,g+40|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break A}v[22692]=0;o=T(214,g+60|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break z}v[22692]=0;p=T(214,g+80|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break y}v[22692]=0;m=T(214,g+100|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break x}v[22692]=0;q=T(214,g+120|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break w}r=Ao(g+140|0);vc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22692]=0;c=Q(1412,g|0,f+96|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break v}if(!c){break m}c=f+96|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1179011410){c=f+96|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1414744396){break m}}c=f+104|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1702257015?(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1163280727:0){break m}c=f+96|0;t[g+176|0]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==1414744396;v[22692]=0;U(1413,f+80|0,h|0,2);c=v[22692];v[22692]=0;if((c|0)==1){break u}B:{if(Ch(f+80|0)>>>0<4){break B}c=Ut(f+80|0,1);if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break B}if(!(Zm(Ut(f+80|0,1))&1)){break B}if(Zm(Ut(f+80|0,2))){break B}c=Ut(f+80|0,3);if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break B}v[22692]=0;Q(188,g|0,12)|0;c=v[22692];v[22692]=0;if((c|0)==1){break t}v[22692]=0;U(1413,f+32|0,h|0,1);c=v[22692];v[22692]=0;if((c|0)==1){break s}PN(f+80|0,f+32|0);Wm(f+32|0)}v[22692]=0;U(1414,f+56|0,f+80|0,544501094);c=v[22692];v[22692]=0;if((c|0)==1){break r}v[22692]=0;c=g+156|0;h=Q(1415,f+56|0,c|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break k}if(!h){break n}if((w[c|0]|w[c+1|0]<<8)==1){v[22692]=0;h=T(465,f+56|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break k}if((h|0)==4){break q}}if((w[c|0]|w[c+1|0]<<8)!=65534){break o}v[22692]=0;h=Q(1416,f+56|0,f+32|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break p}if(!h){break n}h=v[f+52>>2];v[f+8>>2]=v[f+48>>2];v[f+12>>2]=h;h=v[f+44>>2];v[f>>2]=v[f+40>>2];v[f+4>>2]=h;h=f+16|0;v[h>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);u[h+4>>1]=w[f+4|0]|w[f+5|0]<<8;u[h+6>>1]=w[f+6|0]|w[f+7|0]<<8;s=h,y=GC(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24)),v[s+8>>2]=y;v[h+12>>2]=jb;u[g+172>>1]=v[h>>2];break o}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}v[22692]=0;h=T(307,f+56|0)|0;k=v[22692];v[22692]=0;C:{if((k|0)!=1){v[22692]=0;k=T(307,f+56|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break C}if((h|0)!=2|(k|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22692]=0;U(1414,f+32|0,f+80|0,1635017060);h=v[22692];v[22692]=0;D:{E:{F:{G:{H:{I:{if((h|0)!=1){qd(i,f+32|0);xb(f+32|0);v[22692]=0;h=T(275,i|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break k}if(!h){v[22692]=0;U(1414,f+32|0,f+80|0,544039792);h=v[22692];v[22692]=0;if((h|0)==1){break I}qd(i,f+32|0);xb(f+32|0)}v[22692]=0;U(1414,f+32|0,f+80|0,1952670054);h=v[22692];v[22692]=0;if((h|0)==1){break H}v[22692]=0;h=T(190,f+32|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break G}v[g+152>>2]=h;xb(f+32|0);if(v[g+152>>2]?(w[c|0]|w[c+1|0]<<8)==17:0){break D}if(!rz(g)){break D}if(Bo(g)){c=Bo(g);h=Hj(g);if((c>>>0)/(h>>>0)>>>0<rz(g)<<1>>>0){break F}}v[22692]=0;c=T(193,i|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break k}l=rz(g);break E}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;xb(f+32|0);break j}v[22692]=0;c=T(193,i|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break k}l=Bo(g)}h=l;v[g+152>>2]=(c>>>0)/(h>>>0)}v[22692]=0;c=Q(1417,g|0,f+80|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break k}u[g+174>>1]=c;v[22692]=0;R(1418,g|0,f+80|0);c=v[22692];v[22692]=0;if((c|0)==1){break k}v[22692]=0;U(1414,f+32|0,f+80|0,1886221175);c=v[22692];v[22692]=0;if((c|0)==1){break l}qd(m,f+32|0);xb(f+32|0)}xb(f+56|0);Wm(f+80|0)}gb=f+112|0;c=g;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}xb(f+56|0)}Wm(f+80|0)}Wm(r);xb(q)}xb(m)}xb(p)}xb(o)}xb(n)}xb(i)}xb(g);S(c|0);L()}v[22692]=0;g=T(1132,c|0)|0;f=v[22692];v[22692]=0;J:{K:{L:{M:{if((f|0)==1){break M}N:{O:{if(!g){break O}if(!Hj(c)){break O}if(Hj(c)>>>0>2){break O}if(!Jl(c)){v[22692]=0;g=$h(c);f=v[22692];v[22692]=0;if((f|0)==1){break M}if((g|0)!=85){break O}}if(Jl(c)>>>0<=31){v[22692]=0;g=$h(c);f=v[22692];v[22692]=0;if((f|0)==1){break M}if((g|0)==3){break O}}if(Jl(c)>>>0>64){break O}i=0;v[22692]=0;g=$h(c);f=v[22692];v[22692]=0;if((f|0)==1){break L}v[j+80>>2]=g;h=v[j+80>>2];g=36528;P:{while(1){f=g;l=f;if((h|0)==v[f>>2]){break P}g=g+4|0;if((g|0)!=36552){continue}break}l=36552}if((l|0)==36552){break N}v[22692]=0;Q(1127,a|0,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break M}v[22692]=0;g=Q(70,j+80|0,18699)|0;f=v[22692];v[22692]=0;Q:{R:{S:{T:{U:{V:{if((f|0)!=1){v[22692]=0;i=((b<<5)+a|0)+946304|0;Q(301,i|0,g|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break V}vb(g);v[22692]=0;g=B(b,104)+a|0;f=g+484380|0;R(424,f|0,0);h=v[22692];v[22692]=0;if((h|0)==1){break U}v[f>>2]=v[c+152>>2];v[g+484404>>2]=w[c+160|0]|w[c+161|0]<<8|(w[c+162|0]<<16|w[c+163|0]<<24);v[22692]=0;g=Ck(a);h=v[22692];v[22692]=0;if((h|0)==1){break U}v[22692]=0;Y(1134,c|0,f|0,g|0,i|0);g=v[22692];v[22692]=0;if((g|0)==1){break U}Pe(j+80|0,c+20|0);g=Rc(j+72|0,8,Hj(c)>>>0>1?2:1,0,0);v[22692]=0;i=$h(c);h=v[22692];v[22692]=0;if((h|0)==1){break K}if((i|0)!=17){break T}if(Hj(c)>>>0>2){break T}tc(f,268435456);d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|1;g=Hj(c);u[d>>1]=x[d>>1]&65471|((g|0)==2)<<6;i=0;v[22692]=0;d=T(386,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break K}if(!d){break R}d=v[(B(b,104)+a|0)+484400>>2];g=v[f>>2];b=Pe(j+48|0,j+80|0);i=Bo(c);h=Hj(c);v[22692]=0;m=v[b+12>>2];v[j+8>>2]=v[b+8>>2];v[j+12>>2]=m;v[j+16>>2]=v[b+16>>2];m=v[b+4>>2];v[j>>2]=v[b>>2];v[j+4>>2]=m;ha(1135,d|0,g|0,j|0,i|0,h|0);b=v[22692];v[22692]=0;if((b|0)==1){break K}v[22692]=0;_h(f,a,0);b=v[22692];v[22692]=0;if((b|0)==1){break K}break S}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(g);break J}a=P()|0;O()|0;break J}v[22692]=0;i=$h(c);h=v[22692];v[22692]=0;if((h|0)==1){break K}if((i|0)==85){v[22692]=0;b=fa(745,a|0,b|0,j+80|0,0,1)|0;d=v[22692];v[22692]=0;if((d|0)==1){break Q}if(b){break S}i=0;v[22692]=0;a=v[22692];v[22692]=0;if((a|0)==1){break Q}break R}W:{if(mB(c)|!w[c+177|0]){break W}v[22692]=0;b=$h(c);i=v[22692];v[22692]=0;if((i|0)==1){break K}if((b|0)!=1){break W}if((Jl(c)|0)!=32){break W}if((Bo(c)|0)!=Hj(c)<<2){break W}Xi(g,32);zf(g,13);v[22692]=0;W(329,g|0,f|0,j+80|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break S}break K}X:{if(mB(c)){break X}v[22692]=0;b=$h(c);i=v[22692];v[22692]=0;if((i|0)==1){break K}if((b|0)!=1){break X}if((Jl(c)|0)!=24){break X}if((Bo(c)|0)!=Hj(c)<<2){break X}Xi(g,32);zf(g,14);v[22692]=0;W(329,g|0,f|0,j+80|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break K}break S}v[22692]=0;b=$h(c);i=v[22692];v[22692]=0;if((i|0)==1){break K}Y:{if((b|0)!=6){v[22692]=0;b=$h(c);i=v[22692];v[22692]=0;if((i|0)==1){break K}if((b|0)!=7){break Y}}Xi(g,16);v[22692]=0;b=$h(c);d=v[22692];v[22692]=0;if((d|0)==1){break K}zf(g,(b|0)==6?18:17);v[22692]=0;W(329,g|0,f|0,j+80|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break K}break S}i=(Jl(c)-1>>>3|0)-1|0;h=i<<3;b=h&31;Xi(g,(i>>>0<7?(h&63)>>>0>=32?4196360>>>b|0:((1<<b)-1&4196360)<<32-b|136321040>>>b:8)&255);if(Jl(c)>>>0<9){zf(g,1)}v[22692]=0;b=$h(c);i=v[22692];v[22692]=0;if((i|0)==1){break K}if((b|0)==3){zf(g,3)}if(d){VQ(g)}v[22692]=0;W(329,g|0,f|0,j+80|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break K}}if(e){Pe(j+24|0,c+100|0);qd(e,j+24|0);xb(j+24|0)}b=v[a+480180>>2];v[22692]=0;U(1129,f|0,32,b|0);b=v[22692];v[22692]=0;i=1;if((b|0)==1){break K}v[22692]=0;_h(f,a,0);a=v[22692];v[22692]=0;if((a|0)==1){break K}}xb(j+80|0);break N}break K}i=0}gT(c);gb=j+288|0;return i|0}a=P()|0;O()|0;break J}a=P()|0;O()|0;break J}a=P()|0;O()|0;xb(j+80|0)}gT(c);S(a|0);L()}function xK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-128|0;gb=h;v[h+124>>2]=c;a:{b:{if(g){Ge(h+112|0,f,32);v[22692]=0;W(708,h+96|0,f|0,32)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+112|0);Kb(h+96|0)}u[h+80>>1]=0;u[h+64>>1]=65535;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(At(h+124|0,h+80|0,h- -64|0)){i=b+24|0;b=v[i>>2];v[22692]=0;b=le(b+484344|0,c&65535);j=v[22692];v[22692]=0;if((j|0)==1){break t}if(b){break u}}v[22692]=0;U(2085,a|0,h+112|0,h+96|0);a=v[22692];v[22692]=0;if((a|0)!=1){break p}f=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){v[22692]=0;U(2085,a|0,h+112|0,h+96|0);a=v[22692];v[22692]=0;if((a|0)!=1){break p}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){v[22692]=0;U(2085,a|0,h+112|0,h+96|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}break p}v[22692]=0;c=Wc(b,d,e&65535);b=v[22692];v[22692]=0;if((b|0)==1){break h}_e(h+112|0);_e(h+96|0);v[22692]=0;b=de(c);d=v[22692];v[22692]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((d|0)!=1){H:{I:{if(!b){if(!St(c)){break I}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[22692]=0;Y(2087,h- -64|0,b|0,e|0,d|0);d=v[22692];v[22692]=0;b=1;if((d|0)==1){break G}v[22692]=0;R(2023,h+80|0,h- -64|0);d=v[22692];v[22692]=0;if((d|0)!=1){break H}f=P()|0;O()|0;break D}b=0;v[22692]=0;Q(70,h+80|0,13812)|0;d=v[22692];v[22692]=0;if((d|0)==1){break F}}v[22692]=0;Q(1161,h+112|0,h+80|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break E}vb(h+80|0);if(b){vb(h- -64|0)}v[22692]=0;b=de(c);d=v[22692];v[22692]=0;if((d|0)==1){break e}J:{if(b){v[22692]=0;Q(70,h+80|0,7192)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}break J}if(St(c)){v[22692]=0;Q(70,h+80|0,7502)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break J}break e}v[22692]=0;Q(70,h+80|0,13812)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}}v[22692]=0;Q(1161,h+96|0,h+80|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break C}vb(h+80|0);j=f-1|0;if(j>>>0<5){break v}v[22692]=0;b=Q(70,h+80|0,14884)|0;d=v[22692];v[22692]=0;if((d|0)==1){break B}v[22692]=0;Q(1161,h+112|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break A}vb(b);v[22692]=0;b=Q(70,h+80|0,14884)|0;d=v[22692];v[22692]=0;if((d|0)==1){break z}v[22692]=0;Q(1161,h+96|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break y}vb(b);b=c+1|0;K:{if(w[c+1|0]){v[22692]=0;R(729,h+80|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){break K}break f}v[22692]=0;Q(70,h+80|0,13817)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}}v[22692]=0;Q(1161,h+112|0,h+80|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break x}vb(h+80|0);L:{if(w[b|0]){v[22692]=0;Q(70,h+80|0,8009)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break L}break g}v[22692]=0;Q(70,h+80|0,13817)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}}v[22692]=0;Q(1161,h+96|0,h+80|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break w}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}}vb(h- -64|0);break c}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;vb(h+80|0);break c}vb(h+80|0);if(j>>>0<8){break v}v[22692]=0;b=zg(c);d=v[22692];v[22692]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){T:{if(b){v[22692]=0;b=Q(70,h+48|0,14884)|0;d=v[22692];v[22692]=0;if((d|0)==1){break S}v[22692]=0;e=Cq(c);d=v[22692];v[22692]=0;if((d|0)==1){break R}d=0;v[22692]=0;v[h+16>>2]=e&255;R(727,h+32|0,h+16|0);k=v[22692];v[22692]=0;e=1;if((k|0)==1){break R}v[22692]=0;U(2042,h+80|0,b|0,h+32|0);b=v[22692];v[22692]=0;if((b|0)!=1){break T}f=P()|0;O()|0;break j}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[22692]=0;b=lz(b,d);d=v[22692];v[22692]=0;if((d|0)==1){break N}v[22692]=0;b=W(708,h+48|0,1,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break N}e=0;v[22692]=0;R(729,h+32|0,c+4|0);k=v[22692];v[22692]=0;d=1;if((k|0)==1){break Q}v[22692]=0;U(2042,h+80|0,b|0,h+32|0);b=v[22692];v[22692]=0;if((b|0)!=1){break T}f=P()|0;O()|0;vb(h+32|0);break l}e=0;v[22692]=0;Q(70,h+80|0,13816)|0;b=v[22692];v[22692]=0;d=0;if((b|0)==1){break O}}v[22692]=0;Q(1161,h+112|0,h+80|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break P}vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(e){vb(h+32|0);vb(h+48|0)}v[22692]=0;b=zg(c);d=v[22692];v[22692]=0;if((d|0)==1){break m}U:{if(b){v[22692]=0;Q(70,h+80|0,2580)|0;b=v[22692];v[22692]=0;if((b|0)==1){break m}break U}if(w[c+2|0]){v[22692]=0;Q(70,h+80|0,2576)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break U}break m}v[22692]=0;Q(70,h+80|0,13816)|0;b=v[22692];v[22692]=0;if((b|0)==1){break m}}v[22692]=0;Q(1161,h+96|0,h+80|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break M}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break i}f=P()|0;O()|0;break l}f=P()|0;O()|0;vb(h+80|0);if(!d){break k}vb(h+32|0);break l}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}vb(h+80|0);if(j>>>0<12){break v}v[22692]=0;b=Q(70,h+80|0,14884)|0;d=v[22692];v[22692]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){v[22692]=0;Q(1161,h+112|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break ba}vb(b);v[22692]=0;b=Q(70,h+80|0,14884)|0;d=v[22692];v[22692]=0;if((d|0)==1){break aa}v[22692]=0;Q(1161,h+96|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break $}vb(b);v[22692]=0;b=zg(c);d=v[22692];v[22692]=0;if((d|0)==1){break _}ca:{if(b){b=0;v[22692]=0;d=yo(c);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;v[h+28>>2]=d&4095;R(2089,h+80|0,h+28|0);d=v[22692];v[22692]=0;if((d|0)!=1){break ca}}f=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[22692]=0;b=kz(b,d);d=v[22692];v[22692]=0;if((d|0)==1){break Z}v[22692]=0;d=W(708,h+16|0,1,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break Z}v[22692]=0;R(729,h|0,c+5|0);e=v[22692];v[22692]=0;b=1;if((e|0)==1){break Y}v[22692]=0;U(2042,h+80|0,d|0,h|0);d=v[22692];v[22692]=0;if((d|0)!=1){break ca}f=P()|0;O()|0;vb(h);break n}b=0;v[22692]=0;Q(70,h+80|0,13812)|0;d=v[22692];v[22692]=0;if((d|0)==1){break W}}v[22692]=0;Q(1161,h+112|0,h+80|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break X}vb(h+80|0);if(b){vb(h);vb(h+16|0)}v[22692]=0;b=zg(c);d=v[22692];v[22692]=0;if((d|0)==1){break o}da:{if(b){v[22692]=0;Q(70,h+80|0,8295)|0;b=v[22692];v[22692]=0;if((b|0)==1){break o}break da}if(w[c+3|0]){v[22692]=0;Q(70,h+80|0,8295)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break da}break o}v[22692]=0;Q(70,h+80|0,13812)|0;b=v[22692];v[22692]=0;if((b|0)==1){break o}}v[22692]=0;Q(1161,h+96|0,h+80|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break V}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break n}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}vb(h);break n}f=P()|0;O()|0;break c}vb(h+80|0);if(!f){break q}}ea:{fa:{if(Ab(h+112|0)>>>0>f>>>0){v[22692]=0;Y(149,h+80|0,h+112|0,0,f|0);b=v[22692];v[22692]=0;if((b|0)!=1){break fa}f=P()|0;O()|0;break c}if(g){b=Ab(h+112|0);v[22692]=0;b=W(708,h+80|0,f-b|0,32)|0;c=v[22692];v[22692]=0;if((c|0)==1){break s}v[22692]=0;Q(1161,h+112|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){f=P()|0;O()|0;vb(b);break c}vb(b);if(Ab(h+96|0)>>>0>f>>>0){break r}break ea}if(Ab(h+96|0)>>>0<=f>>>0){break q}break r}Eb(h+112|0,h+80|0);vb(h+80|0);if(Ab(h+96|0)>>>0>f>>>0){break r}if(!g){break q}}b=Ab(h+96|0);v[22692]=0;b=W(708,h+80|0,f-b|0,32)|0;c=v[22692];v[22692]=0;ga:{if((c|0)!=1){v[22692]=0;Q(1161,h+96|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break ga}vb(b);break q}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}v[22692]=0;Y(149,h+80|0,h+96|0,0,f|0);b=v[22692];v[22692]=0;if((b|0)!=1){Eb(h+96|0,h+80|0);vb(h+80|0);break q}f=P()|0;O()|0;break c}v[22692]=0;U(2085,a|0,h+112|0,h+96|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}}vb(h+96|0);vb(h+112|0);gb=h+128|0;return}f=P()|0;O()|0;break c}vb(h+16|0);break c}f=P()|0;O()|0;break c}vb(h+48|0)}if(!e){break c}}vb(h+32|0)}vb(h+48|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}vb(h+96|0)}vb(h+112|0);S(f|0);L()}function Yla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-1344|0;gb=d;vc(b);h=gb-32|0;gb=h;XU(h+24|0,d+232|0);e=yb(h+24|0);f=v[h+28>>2];m=v[h+24>>2];v[h+8>>2]=m;v[h+12>>2]=f;v[h>>2]=m;v[h+4>>2]=f;f=b;cc(h+16|0,b,h);m=yb(h+16|0);if((m|0)==(e|0)){Rb(f,yb(h+24|0))}gb=h+32|0;a:{if((e|0)!=(m|0)){break a}if(!_U(d+232|0)){break a}if(!Pb(b,Qc(ZU(d+232|0),jb))){break a}if(!c){p=1;break a}vc(b);b=Fh(d+232|0,b);v[22692]=0;R(809,d+216|0,b|0);f=v[22692];v[22692]=0;b:{c:{d:{e:{f:{g:{h:{if((f|0)!=1){xb(b);v[22692]=0;U(810,d+200|0,d+216|0,1196314451);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;U(810,d+184|0,d+216|0,1280331091);b=v[22692];v[22692]=0;if((b|0)!=1){if(bd(d+200|0)){break b}if(bd(d+184|0)){break b}v[22692]=0;R(367,a|0,1);b=v[22692];v[22692]=0;i:{if((b|0)==1){break i}v[22692]=0;yg(a);b=v[22692];v[22692]=0;if((b|0)==1){break i}v[a+480188>>2]=4;v[a+480208>>2]=16842752;E=d,F=Vb(d+184|0),v[E+24>>2]=F;E=d,F=Zb(d+184|0),v[E+144>>2]=F;if(!Gb(d+24|0,d+144|0)){break h}m=c&2;j:{k:{while(1){h=v[d+24>>2];if(!fi(a)){break h}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22692]=0;b=B(b&65535,104)+a|0;e=b+484380|0;R(424,e|0,1);f=v[22692];v[22692]=0;l:{m:{if((f|0)!=1){v[22692]=0;f=Q(811,h|0,d+232|0)|0;n=v[22692];v[22692]=0;if((n|0)==1){break m}if(!f){break c}if(Yu(d+232|0)){break l}break c}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}v[22692]=0;f=Q(70,d+56|0,d+232|0)|0;n=v[22692];v[22692]=0;if((n|0)!=1){n=x[a+480190>>1];v[22692]=0;Q(301,((n<<5)+a|0)+946304|0,f|0)|0;n=v[22692];v[22692]=0;if((n|0)==1){break k}vb(f);f=w[d+268|0]|w[d+269|0]<<8|(w[d+270|0]<<16|w[d+271|0]<<24);v[e>>2]=f;v[b+484388>>2]=f;v[b+484384>>2]=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);u[b+484410>>1]=255;b=b+484414|0;u[b>>1]=x[b>>1]|2;if(m){b=Rc(d+56|0,8,1,0,0);v[22692]=0;W(329,b|0,e|0,h|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break j}}Bh(d+24|0);if(Gb(d+24|0,d+144|0)){continue}break h}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break f}a=P()|0;O()|0;break e}a=P()|0;O()|0;xb(b);break d}E=d,F=Vb(d+200|0),v[E+176>>2]=F;E=d,F=Zb(d+200|0),v[E+168>>2]=F;o=a+484360|0;n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!Gb(d+176|0,d+168|0)){break B}q=a+484344|0;p=1;s=c&1;m=d+1324|0;n=d+1328|0;k=d+1320|0;y=d+1318|0;z=a+484380|0;c=1;while(1){f=v[d+176>>2];if(!(c&1)){v[22692]=0;b=T(417,o|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break w}if(!b){break B}}Vl(Sb(o));v[22692]=0;b=Q(812,f|0,d+232|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break v}if(!b|(w[y|0]|w[y+1|0]<<8)|(!(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))|(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))>>>0>4)){break c}b=Sb(o);v[22692]=0;U(6,d+56|0,5,d+232|0);c=v[22692];v[22692]=0;if((c|0)==1){break n}v[22692]=0;R(418,b|0,d+56|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}vb(d+56|0);C:{if(s){b=n;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22692]=0;U(288,d+56|0,f|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break C}a=P()|0;O()|0;break g}v[22692]=0;T(214,d+120|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break p}Hw(d+56|0,d+120|0)}r=jc(d+144|0,d+56|0);xb(d+56|0);if(!s){xb(d+120|0)}Qb(d+56|0,0,64);j=1;A=1;D:{E:{while(1){v[22692]=0;b=(B(j,34)+d|0)+198|0;c=b+32|0;R(813,d+8|0,c|0);f=v[22692];v[22692]=0;if((f|0)==1){break u}F:{if(!w[v[d+8>>2]]){break F}f=w[b- -64|0];if(f>>>0>15){break E}b=w[b+65|0];if(b>>>0>64){break E}if(!Yu(c)){break E}if(!x[a+480190>>1]){break F}h=b<<2;e=f<<4;c=1;f=0;b=1;while(1){v[22692]=0;R(814,d+24|0,d+8|0);g=v[22692];v[22692]=0;G:{H:{if((g|0)!=1){v[22692]=0;g=Q(815,d+24|0,((c<<5)+a|0)+946304|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break H}vb(d+24|0);if(g){break G}E=wd(d+56|0,j),F=b,u[E>>1]=F;c=B(c,104)+a|0;g=c+484410|0;l=x[g>>1];if((l|0)!=255){f=b;if(w[c+484417|0]!=(e&255)|(h|0)!=(l|0)){break G}}t[c+484417|0]=e;u[g>>1]=h;break F}a=P()|0;O()|0;break q}a=P()|0;O()|0;vb(d+24|0);break q}b=b+1|0;c=b&65535;if(c>>>0<=x[a+480190>>1]){continue}break}c=f&65535;if(!c){break F}if(!fi(a)){break F}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;E=wd(d+56|0,j),F=b,u[E>>1]=F;b=x[a+480190>>1];v[22692]=0;f=B(b,104);b=f+z|0;Hl(b);g=v[22692];v[22692]=0;if((g|0)==1){break t}g=B(c,104)+z|0;Uo(b,g);f=a+f|0;u[f+484410>>1]=h;t[f+484417|0]=e;v[22692]=0;Q(739,b|0,g|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break t}f=a+946304|0;b=f+(x[a+480190>>1]<<5)|0;c=f+(c<<5)|0;f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=f;f=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=f;f=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=f}A=j>>>0<31;j=j+1|0;if((j|0)!=32){continue}break}h=0;v[d+48>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;C=w[k|0]|w[k+1|0]<<8;c=64;l=65535;j=0;while(1){I:{if(!j){v[22692]=0;b=Q(189,d+144|0,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break A}if(!b){break I}}c=c+1|0;if(c>>>0>=64){v[22692]=0;l=W(540,q|0,64,0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break A}if((l|0)==65535){break D}c=0;b=Sb(o);v[22692]=0;R(704,b|0,l|0);b=v[22692];v[22692]=0;if((b|0)==1){break A}}b=_b(q,l&65535);v[22692]=0;b=Wc(b,c,0);f=v[22692];v[22692]=0;if((f|0)==1){break s}if(!C){continue}e=0;f=0;while(1){g=(d+24|0)+B(e,7)|0;e=w[g+6|0];J:{if(e){t[g+6|0]=e-1;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;j=j-1|0;break J}v[22692]=0;e=Q(189,d+144|0,1)|0;i=v[22692];v[22692]=0;if((i|0)==1){break r}if(!e){break J}e=m;if(v[d+152>>2]==(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){h=Sb(o);e=Sb(o);v[22692]=0;e=T(466,e|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break r}bf(h,e);h=c}v[22692]=0;e=T(374,r|0)|0;i=v[22692];v[22692]=0;K:{if((i|0)!=1){e=e<<24>>24;if((e|0)>-1){break K}i=e&127;t[g+6|0]=i;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;j=i+j|0;break J}a=P()|0;O()|0;break q}if((e-1&255)>>>0<=35){t[b|0]=e+48}v[22692]=0;e=T(374,r|0)|0;i=v[22692];v[22692]=0;L:{M:{if((i|0)!=1){E=b,F=w[wd(d+56|0,e&31)|0],t[E+1|0]=F;if(!(e&128)){break M}t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];break L}a=P()|0;O()|0;break q}v[22692]=0;R(403,d+8|0,r|0);e=v[22692];v[22692]=0;N:{if((e|0)!=1){i=od(d+8|0);D=d+8|0;e=w[D|0];if(e>>>0>19){break L}t[b+3|0]=w[(e<<1)+33248|0];i=w[i|0];t[b+5|0]=i;if((e|0)!=18|i>>>0<32){break N}t[b+3|0]=17;break L}a=P()|0;O()|0;break q}e=w[D|0];if(819137>>>e&1){break L}t[b+5|0]=w[(e<<1)+33249|0]|i&15}e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24;e=w[b+4|0]|w[b+5|0]<<8;t[g+4|0]=e;t[g+5|0]=e>>>8}b=b+6|0;f=f+1|0;e=f&65535;if(C>>>0>e>>>0){continue}break}continue}break}if(!h&c>>>0>62){break D}b=l&65535;if((b|0)==65535){break D}b=_b(q,b);v[22692]=0;f=Be(d+8|0,14,h&255);h=v[22692];v[22692]=0;if((h|0)!=1){c=Gh(Se(f,c));v[22692]=0;Q(431,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break D}}a=P()|0;O()|0;break q}p=0}xb(d+144|0);if(A){break b}Bh(d+176|0);c=0;if(Gb(d+176|0,d+168|0)){continue}break}}v[22692]=0;Pi(o,0);b=v[22692];v[22692]=0;if((b|0)==1){break z}v[22692]=0;b=Q(2,d+232|0,3521)|0;c=v[22692];v[22692]=0;if((c|0)==1){break y}Eb(a+1298304|0,b);vb(b);v[22692]=0;b=Q(2,d+232|0,3823)|0;c=v[22692];v[22692]=0;p=1;if((c|0)==1){break x}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;break b}a=P()|0;O()|0;break q}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0}xb(d+144|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(d+56|0);break g}a=P()|0;O()|0}hd(d+184|0)}hd(d+200|0)}Ed(d+216|0)}S(a|0);L()}p=0}hd(d+184|0);hd(d+200|0);Ed(d+216|0)}gb=d+1344|0;return p|0}function Kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-304|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!Vu(b,d+208|0)){break j}if(!QU(d+208|0)){break j}if(!Pb(b,Qc(PU(d+208|0),jb))){break j}if(!c){n=1;break j}if(!Yc(b,w[d+208|4])){break j}Id(a,268435456);yg(a);v[a+480208>>2]=4;e=Tb(d+88|0,12421);Eb(a+1298304|0,e);vb(e);e=Tb(d+88|0,7506);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;of(d+16|0,d+208|6,48,3);Bc(d+88|0,d+16|0);Eb(a+1298268|0,d+88|0);vb(d+88|0);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){e=0;while(1){u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;if(e>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;l=d+192|0;i=rh(l);k:{if(!e){break k}v[22692]=0;R(837,l|0,e|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;ir(l,e);e=v[22692];v[22692]=0;if((e|0)!=1){break k}}a=P()|0;O()|0;ci(i);S(a|0);L()}e=w[d+302|0]|w[d+303|0]<<8;v[22692]=0;U(829,b|0,l|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break i}s=mc(d+176|0);o=mc(d+160|0);e=w[d+301|0];v[22692]=0;W(560,b|0,s|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}i=w[d+300|0];e=0;v[22692]=0;W(560,b|0,o|0,i|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break f}if(w[d+300|0]){p=c&2;q=d+88|4;m=d+126|0;r=d+88|6;while(1){v[22692]=0;i=e;e=e+1|0;h=B(e,104)+a|0;g=h+484380|0;R(424,g|0,0);f=v[22692];v[22692]=0;l:{m:{if((f|0)!=1){f=Lb(o,i);if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break l}f=Lb(o,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22692]=0;f=Q(188,b|0,f|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break c}if(!f){break l}v[22692]=0;f=Q(830,b|0,d+88|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break c}if(!f){break l}v[22692]=0;Ie(d+72|0,2,r);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;R(324,d+16|0,d+72|0);f=v[22692];v[22692]=0;if((f|0)!=1){break m}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22692]=0;Q(301,((e<<5)+a|0)+946304|0,d+16|0)|0;f=v[22692];v[22692]=0;n:{o:{p:{q:{r:{if((f|0)!=1){vb(d+16|0);v[22692]=0;Ek(d+72|0,2,m);f=v[22692];v[22692]=0;if((f|0)==1){break r}v[22692]=0;R(324,d+16|0,d+72|0);f=v[22692];v[22692]=0;if((f|0)==1){break r}v[22692]=0;Q(303,h+484423|0,d+16|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break q}vb(d+16|0);if(w[d+138|0]<=15){f=h+484414|0;u[f>>1]=x[f>>1]|32;u[h+484408>>1]=B(w[d+138|0],17)}t[d+16|0]=w[d+139|0];v[22692]=0;t[d+72|0]=64;f=ac(d+16|0,d+72|0);k=v[22692];v[22692]=0;if((k|0)==1){break p}u[h+484412>>1]=w[f|0];v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;f=h+484384|0;v[f>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);k=h+484388|0;v[k>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break o}n=v[f>>2];f=v[k>>2];break n}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}n=v[f>>2]>>>1|0;v[f>>2]=n;f=v[k>>2]>>>1|0;v[k>>2]=f;v[g>>2]=v[g>>2]>>>1}s:{if(f>>>0<=n>>>0){break s}h=h+484414|0;u[h>>1]=x[h>>1]|2;if(!(w[d+140|0]&2)){break s}u[h>>1]=x[h>>1]|4}v[22692]=0;rk(g);h=v[22692];v[22692]=0;if((h|0)==1){break c}if(!p){break l}i=Lb(o,i);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);h=w[q|0];v[22692]=0;Q(188,b|0,h+i|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}i=Rc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[22692]=0;W(329,i|0,g|0,b|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break l}e=P()|0;O()|0;break b}if(w[d+300|0]>e>>>0){continue}break}}n=1;t:{if(!(c&1)){break t}v[d+68>>2]=0;f=a+484360|0;Vl(Sb(f));F=d,G=Vb(l),v[F+64>>2]=G;F=d,G=Zb(l),v[F+56>>2]=G;k=a+484344|0;if(Gb(d- -64|0,d+56|0)){r=d+88|5;p=d+88|4;while(1){i=v[d- -64>>2];c=i;u:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break u}c=Lb(s,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22692]=0;c=Q(188,b|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}if(!c){break u}v[22692]=0;R(833,b|0,d+88|0);c=v[22692];v[22692]=0;if((c|0)==1){break h}if(!w[p|0]){break u}c=w[i|0]|w[i+1|0]<<8;e=w[i|0]|w[i+1|0]<<8;t[d+16|0]=w[r|0];h=w[d+262|0];g=w[i+2|0];v[22692]=0;t[d+72|0]=h-g;h=ac(d+16|0,d+72|0);g=v[22692];v[22692]=0;if((g|0)==1){break d}q=w[h|0];h=w[i|0]|w[i+1|0]<<8;g=w[p|0];v[22692]=0;v[d+52>>2]=g+h;h=Mc(d+68|0,d+52|0);g=v[22692];v[22692]=0;if((g|0)==1){break e}v[d+68>>2]=v[h>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break u}y=c>>>6|0;e=e&63;A=0;while(1){v:{w:{x:{y:{z:{A:{B:{h=e>>>0>63;y=h+y|0;c=y&65535;if(sc(Sb(f))>>>0<=c>>>0){g=Sb(f);v[22692]=0;R(500,g|0,y+1&65535);g=v[22692];v[22692]=0;if((g|0)==1){break B}v[22692]=0;g=W(540,k|0,64,0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break B}F=rc(Sb(f),c),G=g,u[F>>1]=G}m=x[rc(Sb(f),c)>>1];v[22692]=0;c=le(k,m);g=v[22692];v[22692]=0;if((g|0)==1){break z}if(!c){break u}c=_b(k,m);g=w[i+2|0];v[22692]=0;z=h?0:e;e=Wc(c,z,g);c=v[22692];v[22692]=0;if((c|0)==1){break w}h=0;if(q){break A}break x}e=P()|0;O()|0;break b}while(1){v[22692]=0;R(835,d+72|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break y}g=od(d+72|0);D=Te(d+72|0);C=bj(d+72|0);E=fc(d+72|0);j=0;c=w[d+72|0];if((c-1&255)>>>0<=142){j=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+h|0]=j}t[e|0]=j;c=w[g|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];C:{if((c|0)!=255){t[e+4|0]=c;break C}t[e+2|0]=0}c=w[C|0];D:{if(c>>>0>22){break D}t[e+3|0]=w[c+33296|0];g=w[E|0];t[e+5|0]=g;c=e+5|0;E:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break D;case 4:t[c|0]=g&3|48;break D;case 7:if(Nb(l)>>>0<=g>>>0){break D}j=c;c=Lb(l,g);g=w[c|0]|w[c+1|0]<<8;t[j|0]=g>>>6;c=_b(k,m);j=x[a+480188>>1];v[22692]=0;c=Wc(c,z,j-1&65535);j=v[22692];v[22692]=0;if((j|0)!=1){t[c+3|0]=14;t[c+5|0]=g&63;break D}e=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(k,m);g=x[a+480188>>1];v[22692]=0;c=Wc(c,z,g-1&65535);g=v[22692];v[22692]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break D}e=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break D;case 12:v[22692]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22692];v[22692]=0;if((j|0)!=1){t[c|0]=w[g|0]|208;break D}e=P()|0;O()|0;break b;case 13:v[22692]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22692];v[22692]=0;if((j|0)!=1){t[c|0]=w[g|0]|192;break D}e=P()|0;O()|0;break b;case 14:v[22692]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22692];v[22692]=0;if((j|0)!=1){t[c|0]=w[g|0]|224;break D}e=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}j=g&240;if(!j|(j|0)==240){break D}t[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(j&255){break D}t[e|0]=w[(d+16|0)+h|0]}e=e+6|0;h=h+1|0;if((q|0)!=(h|0)){continue}break}break x}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(q>>>0>=w[r|0]){break v}c=w[r|0];v[22692]=0;Q(318,b|0,B(c-q|0,5)|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break v}}e=P()|0;O()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}Oe(d- -64|0);if(Gb(d- -64|0,d+56|0)){continue}break}}F:{a=v[d+68>>2];b=a&63;if(!b){break F}c=Sb(f);v[22692]=0;a=a>>>6|0;c=Q(470,c|0,a&65535)|0;e=v[22692];v[22692]=0;if((e|0)!=1){if(!c){break F}a=_b(k,x[rc(Sb(f),a&65535)>>1]);v[22692]=0;ca(836,a|0,b|0,0,1)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break F}}e=P()|0;O()|0;break b}a=Sb(f);F=d,G=Vb(a),v[F+88>>2]=G;F=d,G=Zb(a),v[F+16>>2]=G;if(!Gb(d+88|0,d+16|0)){break t}h=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){G:{if((h&65535)!=65535){break G}v[22692]=0;h=W(540,k|0,64,0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break G}e=P()|0;O()|0;break b}u[a>>1]=h}nf(d+88|0);if(Gb(d+88|0,d+16|0)){continue}break}}di(o);di(s);ci(l)}gb=d+304|0;return n|0}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}di(o);di(s)}ci(l);S(e|0);L()}function k$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=gb-1504|0;gb=e;vc(b);os(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!Ow(b,e+1480|0)){break p}if(!$F(e+1480|0)){break p}if(!c){g=1;break p}E=e+1498|0;c=E;if(!ns(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break p}c=E;r=e+1492|0;if(!ns(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[r|0]|w[r+1|0]<<8)<<2)|0)){break p}Nw(a);G=e,H=Mw(),v[G+104>>2]=H;Lw(hj(a)+32|0,e+104|0);ms(e+104|0);n=v[hj(a)+32>>2];c=e+1494|0;v[e+1476>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);G=e,H=em(b),v[G+1216>>2]=H;v[e+1176>>2]=214748364;G=e,H=B(v[Fb(e+1216|0,e+1176|0)>>2],20),v[G+104>>2]=H;It(n,v[Fb(e+1476|0,e+104|0)>>2]);Qb(e+1216|0,0,256);C=cd(e+1200|0);q:{if(w[r|0]|w[r+1|0]<<8){k=e+1176|4;l=e+1192|0;D=e+1194|0;q=e+1190|0;i=e+1188|0;while(1){c=E;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22692]=0;c=Q(188,b|0,c+(F<<2)|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break o}g=0;if(!c){break q}v[22692]=0;c=Q(189,b|0,4)|0;d=v[22692];v[22692]=0;if((d|0)==1){break o}if(!c){break q}v[22692]=0;d=T(190,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break n}v[22692]=0;c=Q(188,b|0,d|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break n}if(!c){break q}v[22692]=0;c=Q(191,b|0,e+1176|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break m}if(!c){break q}c=w[i|0]|w[i+1|0]<<8;v[22692]=0;c=W(192,b|0,C|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break m}if(!c){break q}c=w[i|0]|w[i+1|0]<<8?v[C>>2]:0;f=w[i|0]|w[i+1|0]<<8;v[22692]=0;j=T(193,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break l}d=d+20|0;if(j>>>0<=d+(f<<3)>>>0){break q}j=d+((w[i|0]|w[i+1|0]<<8)<<3)|0;r:{if(!(t[q|0]&1)){f=0;if(!(w[i|0]|w[i+1|0]<<8)){break r}while(1){if(!c){break q}v[22692]=0;d=W(194,c|0,n|0,v[e+1476>>2])|0;h=v[22692];v[22692]=0;if((h|0)==1){break k}if(!d){break q}v[22692]=0;d=Q(188,b|0,j|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break k}if(!d){break q}d=c;h=d+4|0;h=vd(e+1168|0,kc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));v[22692]=0;m=v[h+4>>2];v[e+32>>2]=v[h>>2];v[e+36>>2]=m;U(195,e+104|0,b|0,e+32|0);h=v[22692];v[22692]=0;if((h|0)==1){break j}if((yb(e+104|0)|0)!=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))){break q}c=c+8|0;f=f+1|0;if(f>>>0<(w[i|0]|w[i+1|0]<<8)>>>0){continue}break}break r}s:{t:{u:{v:{if(w[q|0]&4){if(!c){break q}v[22692]=0;d=W(194,c|0,n|0,v[e+1476>>2])|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}if(!d){break q}s=kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));z=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[D|0]|w[D+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[22692]=0;d=Q(188,b|0,d+j|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break h}if(!d){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22692]=0;d=Q(189,b|0,d-f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break h}if(!d){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22692]=0;U(196,e+80|0,b|0,d-f|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;p=Gp(e+104|0,e+80|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}xb(e+80|0);m=0;u=0;j=0;w:{x:{y:{if(!(w[i|0]|w[i+1|0]<<8)){break y}while(1){z:{v[22692]=0;f=Q(198,p|0,h+1|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break z}d=h&15;o=x[(d<<1)+27360>>1];A:{B:{if(o>>>0<=f>>>0){v[22692]=0;d=w[d+27440|0];y=Q(198,p|0,d|0)|0;A=v[22692];v[22692]=0;if((A|0)==1){break z}d=y+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&15;break A}v[22692]=0;d=Q(198,p|0,4)|0;f=v[22692];v[22692]=0;if((f|0)==1){break z}if((d|0)==15){v[22692]=0;d=Q(198,p|0,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break z}f=65535;if(!d){break B}xb(e+104|0);break r}f=d+65520|0}if(f>>>0>65535){break A}}d=f&1?0-(f+1>>>1|0)|0:f>>>1|0;o=j+s|0;A=o;C:{if(w[q|0]&2){u=d+u|0;d=u;break C}d=w[q+1|0]&2?d:d^32768}f=d>>>8|0;y=(w[q|0]|w[q+1|0]<<8)&1024;t[A+1|0]=y?d:f;t[o|0]=y?f:d;j=j+2|0}if(j>>>0>=z>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break t}v[22692]=0;d=(m<<3)+c|0;f=W(194,d|0,n|0,v[e+1476>>2])|0;j=v[22692];v[22692]=0;if((j|0)==1){break z}if(!f){break v}z=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);s=kc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break y}break}g=V(27348)|0;if((O()|0)!=(ea(27348)|0)){break w}Z(g|0)|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)==1){break x}}xb(e+104|0);break r}g=P()|0;O()|0}xb(e+104|0);break a}if(!c){break q}v[22692]=0;d=W(194,c|0,n|0,v[e+1476>>2])|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}if(!d){break q}u=kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));z=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break q}v[22692]=0;d=Q(188,b|0,j|0)|0;f=v[22692];v[22692]=0;D:{E:{if((f|0)!=1){if(!d){break q}d=vd(e+72|0,e+1216|0,w[l|0]|w[l+1|0]<<8);v[22692]=0;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;U(199,e+104|0,b|0,e+40|0);d=v[22692];v[22692]=0;if((d|0)==1){break E}if(yb(e+104|0)>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22692]=0;d=Q(189,b|0,d-f|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break D}}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}if(!d){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22692]=0;U(196,e+80|0,b|0,d-f|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;p=Gp(e+104|0,e+80|0);d=v[22692];v[22692]=0;if((d|0)==1){break e}xb(e+80|0);s=0;j=0;m=0;F:{G:{H:{if(!(w[i|0]|w[i+1|0]<<8)){break H}while(1){I:{v[22692]=0;f=Q(198,p|0,h+1|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break I}d=h&7;o=w[d+27392|0];J:{K:{if(o>>>0<=f>>>0){v[22692]=0;d=w[d+27400|0];y=Q(198,p|0,d|0)|0;A=v[22692];v[22692]=0;if((A|0)==1){break I}d=y+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&7;break J}v[22692]=0;d=Q(198,p|0,3)|0;f=v[22692];v[22692]=0;if((f|0)==1){break I}if((d|0)==7){v[22692]=0;d=Q(198,p|0,1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break I}f=255;if(!d){break K}xb(e+104|0);break r}f=d+248|0}if(f>>>0>255){break J}}d=w[(e+1216|0)+f|0];f=d+s|0;o=d;d=(w[q|0]|w[q+1|0]<<8)&2;t[j+u|0]=d?f:o;s=d?f:s;j=j+1|0}if(j>>>0>=z>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break s}v[22692]=0;d=(m<<3)+c|0;f=W(194,d|0,n|0,v[e+1476>>2])|0;j=v[22692];v[22692]=0;if((j|0)==1){break I}if(!f){break u}z=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);u=kc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break H}break}g=V(27348)|0;if((O()|0)!=(ea(27348)|0)){break F}Z(g|0)|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)==1){break G}}xb(e+104|0);break r}g=P()|0;O()|0}xb(e+104|0);break a}xb(e+104|0);break q}xb(e+104|0);break q}xb(e+104|0);break r}xb(e+104|0)}F=F+1|0;if(F>>>0<(w[r|0]|w[r+1|0]<<8)>>>0){continue}break}}v[22692]=0;Vd(e+56|0,n);b=v[22692];v[22692]=0;if((b|0)==1){break f}b=v[e+60>>2];v[e+24>>2]=v[e+56>>2];v[e+28>>2]=b;Sh(e- -64|0,e+24|0);b=Ud(e+48|0);v[22692]=0;c=v[e+68>>2];v[e+16>>2]=v[e+64>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;b=W(201,e+104|0,e+16|0,e+8|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}qd(hj(a)+12|0,b);xb(b);g=1}js(C)}gb=e+1504|0;return g|0}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0}js(C);S(g|0);L()}function XE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;k=gb-336|0;gb=k;m=h;n=i&65535;o=d;q=e&65535;t=(e^i)&-2147483648;B=i>>>16&32767;F=e>>>16&32767;a:{b:{if(B-1>>>0<32766?F-1>>>0<=32765:0){break b}u=e&2147483647;l=u;j=d;if(!(!j&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){G=d;t=e|32768;break a}u=i&2147483647;e=u;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){G=h;t=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;t=2147450880;break a}t=t|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){b=0;c=0;break a}if(!(b|j|(c|l))){b=!(d|f|(e|g));G=b?0:G;t=b?2147450880:t;b=0;c=0;break a}if(!(d|f|(e|g))){t=t|2147418112;b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){i=b;d=!(o|q);h=d<<6;j=E(d?b:o)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;Kf(k+320|0,i,c,o,q,b-15|0);p=16-b|0;o=v[k+328>>2];q=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(m|n);e=d<<6;h=E(d?f:m)+32|0;d=E(d?g:n);d=e+((d|0)==32?h:d)|0;Kf(k+304|0,f,g,m,n,d-15|0);p=(d+p|0)-16|0;m=v[k+312>>2];n=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=n|65536;D=e;u=m;d=m;j=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=j;i=1963258675-(j+((d|0)!=0)|0)|0;pf(k+288|0,d,j,0,0,h,i,0,0);j=v[k+296>>2];pf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[k+280>>2];i=h<<1|v[k+276>>2]>>>31;h=v[k+284>>2]<<1|h>>>31;pf(k+256|0,i,h,0,0,d,e,0,0);j=h;h=v[k+264>>2];pf(k+240|0,i,j,0,0,0-h|0,0-(v[k+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+248>>2];l=v[k+252>>2]<<1|h>>>31;i=h<<1|v[k+244>>2]>>>31;h=l;pf(k+224|0,i,h,0,0,d,e,0,0);h=v[k+232>>2];pf(k+208|0,i,l,0,0,0-h|0,0-(v[k+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+216>>2];i=h<<1|v[k+212>>2]>>>31;h=v[k+220>>2]<<1|h>>>31;pf(k+192|0,i,h,0,0,d,e,0,0);j=h;h=v[k+200>>2];pf(k+176|0,i,j,0,0,0-h|0,0-(v[k+204>>2]+((h|0)!=0)|0)|0,0,0);j=d;h=v[k+184>>2];l=v[k+188>>2]<<1|h>>>31;d=h<<1|v[k+180>>2]>>>31;i=d-1|0;l=l-(d>>>0<1)|0;pf(k+160|0,j,e,0,0,i,l,0,0);e=f;pf(k+144|0,e<<15,g<<15|e>>>17,0,0,i,l,0,0);h=v[k+172>>2];n=v[k+160>>2];e=v[k+152>>2];d=n+e|0;m=v[k+164>>2];j=m+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(m|0)==(j|0)&n>>>0>e>>>0|j>>>0<m>>>0;m=n+v[k+168>>2]|0;j=h;j=m>>>0<n>>>0?j+1|0:j;h=m;m=!d&e>>>0>1|(d|0)!=0;h=h+m|0;j=h>>>0<m>>>0?j+1|0:j;pf(k+112|0,i,l,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);pf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,i,l,0,0);P=(F-B|0)+p|0;e=v[k+116>>2];z=e;d=v[k+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;e=j;i=v[k+140>>2];H=i;h=v[k+136>>2];j=i<<1|h>>>31;i=h<<1|v[k+132>>2]>>>31;d=i+m|0;l=e+j|0;l=d>>>0<i>>>0?l+1|0:l;i=d;d=l;e=i;j=d-(e>>>0<13927)|0;e=e-13927|0;l=j;I=j;h=0;p=h;j=q|65536;B=j;F=o;w=(j&2147483647)<<1|o>>>31;A=jqa(l,h,w,0);h=jb;r=A;s=h;h=c;L=(h&2147483647)<<1|b>>>31;J=L;x=0;l=(d|0)==(l|0)&e>>>0<i>>>0|d>>>0>l>>>0;m=(d|0)==(n|0)&i>>>0<m>>>0|d>>>0<n>>>0;d=v[k+120>>2];j=v[k+124>>2]<<1|d>>>31;i=H>>>31|0;d=i+(d<<1|z>>>31)|0;j=d>>>0<i>>>0?j+1|0:j;h=d;d=m+d|0;j=d>>>0<h>>>0?j+1|0:j;i=d;d=l+d|0;h=d>>>0<i>>>0?j+1|0:j;i=d-1|0;C=h-(d>>>0<1)|0;m=0;h=jqa(J,x,C,m);d=h+r|0;j=jb+s|0;j=d>>>0<h>>>0?j+1|0:j;h=j;r=(s|0)==(j|0)&d>>>0<r>>>0|j>>>0<s>>>0;j=0;A=j;z=j;R=0;j=o;Q=c>>>31|0;J=Q|j<<1;M=0;q=jqa(i,z,J,M);l=q+d|0;j=jb+h|0;j=l>>>0<q>>>0?j+1|0:j;n=l;q=j;j=(h|0)==(j|0)&d>>>0>l>>>0|h>>>0>j>>>0;d=j+r|0;h=0;h=d>>>0<j>>>0?1:h;l=jqa(w,K,C,m);d=l+d|0;j=jb+h|0;h=d>>>0<l>>>0?j+1|0:j;o=jqa(w,K,i,z);l=jb;s=d;z=jqa(C,m,J,M);d=z+o|0;j=jb+l|0;j=d>>>0<z>>>0?j+1|0:j;r=d;d=j;j=(l|0)==(j|0)&o>>>0>r>>>0|j>>>0<l>>>0;o=s+d|0;l=h+j|0;l=o>>>0<d>>>0?l+1|0:l;s=o;o=0;d=o+n|0;j=q+r|0;j=d>>>0<o>>>0?j+1|0:j;h=j;o=(q|0)==(j|0)&n>>>0>d>>>0|j>>>0<q>>>0;q=s+o|0;j=l;N=q;l=o>>>0>q>>>0?j+1|0:j;s=d;n=h;o=b<<1;q=c<<1|b>>>31;O=o&-2;r=jqa(i,A,O,0);h=jb;z=e;e=jqa(e,0,J,M);d=e+r|0;j=jb+h|0;j=d>>>0<e>>>0?j+1|0:j;r=(h|0)==(j|0)&d>>>0<r>>>0|h>>>0>j>>>0;h=d;e=j;S=r;H=jqa(I,p,L,x);d=H+d|0;j=jb+j|0;j=d>>>0<H>>>0?j+1|0:j;H=d;r=d;d=j;j=(j|0)==(e|0)&h>>>0>r>>>0|e>>>0>j>>>0;e=S+j|0;h=0;h=e>>>0<j>>>0?1:h;r=e;e=s+e|0;j=h+n|0;j=e>>>0<r>>>0?j+1|0:j;r=e;h=e;e=j;n=(j|0)==(n|0)&h>>>0<s>>>0|j>>>0<n>>>0;h=n+N|0;j=l;N=h;n=h>>>0<n>>>0?j+1|0:j;K=jqa(w,K,z,T);w=jb;l=jqa(C,m,O,U);h=l+K|0;j=jb+w|0;j=h>>>0<l>>>0?j+1|0:j;C=h;l=jqa(L,x,i,A);i=h+l|0;h=j;j=j+jb|0;j=i>>>0<l>>>0?j+1|0:j;m=i;A=jqa(I,p,J,M);i=i+A|0;l=j+jb|0;l=i>>>0<A>>>0?l+1|0:l;A=i;i=l;l=0;s=(i|0)==(j|0)&A>>>0<m>>>0|i>>>0<j>>>0;m=(h|0)==(j|0)&C>>>0>m>>>0|h>>>0>j>>>0;j=m+((h|0)==(w|0)&K>>>0>C>>>0|h>>>0<w>>>0)|0;h=0;m=s+j|0;j=m;h=r+i|0;j=(j|l)+e|0;j=h>>>0<i>>>0?j+1|0:j;s=h;m=j;h=(e|0)==(j|0)&h>>>0<r>>>0|e>>>0>j>>>0;e=h+N|0;j=n;C=e;n=e>>>0<h>>>0?j+1|0:j;r=s;w=H;I=jqa(I,p,O,U);p=jb;h=jqa(L,x,z,T);e=h+I|0;j=jb+p|0;j=e>>>0<h>>>0?j+1|0:j;l=j;j=0;h=(l|0)==(p|0)&e>>>0<I>>>0|l>>>0<p>>>0;e=l+w|0;j=(h|j)+d|0;j=e>>>0<l>>>0?j+1|0:j;h=e;s=(d|0)==(j|0)&h>>>0<w>>>0|d>>>0>j>>>0;l=j+A|0;p=0;i=p+h|0;d=i;l=d>>>0<p>>>0?l+1|0:l;e=(j|0)==(l|0)&d>>>0<h>>>0|j>>>0>l>>>0;d=s+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+r|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;i=(m|0)==(j|0)&d>>>0<r>>>0|j>>>0<m>>>0;h=i+C|0;l=n;l=h>>>0<i>>>0?l+1|0:l;i=l;c:{if((i|0)==131071|i>>>0<131071){j=F;l=B<<1|j>>>31;F=Q|j<<1;B=l|R;pf(k+80|0,d,e,h,i,f,g,u,D);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];n=v[k+84>>2];p=(j|0)!=0|(n|0)!=0;x=m-p|0;p=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<p>>>0)|0;m=0-j|0;n=0-(((j|0)!=0)+n|0)|0;b=P+16382|0;break c}d=(e&1)<<31|d>>>1;j=h<<31|e>>>1;e=j;h=(i&1)<<31|h>>>1;i=i>>>1|0;pf(k+96|0,d,j,h,i,f,g,u,D);o=0;m=v[k+104>>2];n=o-m|0;j=v[k+96>>2];q=v[k+100>>2];p=(j|0)!=0|(q|0)!=0;x=n-p|0;p=((b<<16)-(v[k+108>>2]+(m>>>0>o>>>0)|0)|0)-(n>>>0<p>>>0)|0;m=0-j|0;n=0-(((j|0)!=0)+q|0)|0;o=b;q=c;b=P+16383|0}if((b|0)>=32767){t=t|2147418112;b=0;c=0;break a}d:{if((b|0)>=1){c=x;j=p<<1|c>>>31;x=c<<1|n>>>31;p=j;o=h;q=i&65535|b<<16;b=m;j=n<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}hm(k- -64|0,d,e,h,i,1-b|0);Kf(k+48|0,o,q,F,B,b+112|0);d=v[k+64>>2];e=v[k+68>>2];o=v[k+72>>2];q=v[k+76>>2];pf(k+32|0,f,g,u,D,d,e,o,q);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;m=v[k+36>>2];h=m;b=v[k+56>>2];m=h>>>31|i;i=b-m|0;l=v[k+60>>2]-((b>>>0<m>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;B=v[k+52>>2];j=B;b=v[k+48>>2];j=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;x=i-j|0;p=l-(i>>>0<j>>>0)|0;i=b;b=i-c|0;j=B-((c>>>0>i>>>0)+h|0)|0}pf(k+16|0,f,g,u,D,3,0,0,0);pf(k,f,g,u,D,5,0,0,0);i=d;c=e;l=f;f=g;r=o;m=0;h=j+m|0;n=d&1;d=b+n|0;h=d>>>0<b>>>0?h+1|0:h;o=d;g=h;l=(h|0)==(f|0)&d>>>0>l>>>0|f>>>0<h>>>0;d=(h|0)==(m|0)&n>>>0>d>>>0|h>>>0<m>>>0;b=d+x|0;j=p;j=b>>>0<d>>>0?j+1|0:j;h=b;f=j;d=(h|0)==(u|0)&(j|0)==(D|0)?l:(D|0)==(j|0)&h>>>0>u>>>0|j>>>0>D>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;e=(j|0)==(c|0)&d>>>0<i>>>0|c>>>0>j>>>0;c=r+e|0;j=q;i=c;j=i>>>0<e>>>0?j+1|0:j;c=j;e=d;l=i;d=v[k+20>>2];m=(d|0)==(g|0)&y[k+16>>2]<o>>>0|d>>>0<g>>>0;d=v[k+28>>2];i=v[k+24>>2];i=j>>>0<2147418112&((h|0)==(i|0)&(d|0)==(f|0)?m:(d|0)==(f|0)&i>>>0<h>>>0|d>>>0<f>>>0);d=e+i|0;j=b;j=d>>>0<i>>>0?j+1|0:j;i=d;d=j;e=(j|0)==(b|0)&e>>>0>i>>>0|b>>>0>j>>>0;b=l+e|0;j=c;j=b>>>0<e>>>0?j+1|0:j;e=j;l=b;b=v[k+4>>2];g=(b|0)==(g|0)&y[k>>2]<o>>>0|b>>>0<g>>>0;b=v[k+12>>2];c=v[k+8>>2];c=j>>>0<2147418112&((c|0)==(h|0)&(b|0)==(f|0)?g:(b|0)==(f|0)&c>>>0<h>>>0|b>>>0<f>>>0);b=c+i|0;j=d;j=b>>>0<c>>>0?j+1|0:j;c=j;f=(d|0)==(j|0)&b>>>0<i>>>0|d>>>0>j>>>0;d=l+f|0;j=e;G=d|G;t=t|(d>>>0<f>>>0?j+1|0:j)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=G;v[a+12>>2]=t;gb=k+336|0}function Toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;j=d+112|0;tX(f+24|0,j);h=yb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;cc(f+16|0,e,f);i=yb(f+16|0);if((i|0)==(h|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(h|0)==(i|0);if(!e){sX(j)}a:{b:{c:{d:{if(!e){break d}if(!uX(d+112|0)){break d}if(!c){g=1;break d}Id(a,v[((w[d+228|0]|w[d+229|0]<<8)<<2)+28608>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;e=Tb(d+48|0,10395);Eb(a+1298304|0,e);vb(e);e=Tb(d+48|0,7537);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=Tb(e,1498);Dc(d+8|0,f);vb(f);gb=e+16|0;v[22692]=0;Y(349,d+48|0,d+8|0,d+191|0,d+188|0);e=v[22692];v[22692]=0;e:{f:{if((e|0)!=1){Eb(a+1298328|0,d+48|0);vb(d+48|0);Hb(d+8|0);Vc(a+1298352|0,((w[d+228|0]|w[d+229|0]<<8)<<2)+28656|0);Vc(a+1298340|0,v[((w[d+228|0]|w[d+229|0]<<8)<<2)+28704>>2]);v[a+1298364>>2]=5;Ie(d+8|0,2,d+112|4);Bc(d+48|0,d+8|0);Eb(a+1298268|0,d+48|0);vb(d+48|0);Ie(d+8|0,2,d+148|0);Bc(d+48|0,d+8|0);g:{if(ur(d+48|0,6846)){v[22692]=0;U(13,d+8|0,5,d+48|0);e=v[22692];v[22692]=0;if((e|0)==1){break g}Eb(a+1298280|0,d+8|0);vb(d+8|0)}vb(d+48|0);u[a+480188>>1]=32;e=0;h:{while(1){g=(e<<5)+a|0;h=g+480280|0;Ue(h);i:{f=d+e|0;if(w[f+193|0]<=15){v[d+48>>2]=w[f+193|0]<<4|8;v[d+8>>2]=256;r=g+480284|0,s=v[nd(d+48|0,d+8|0)>>2],u[r>>1]=s;break i}if(w[f+193|0]==16){u[g+480284>>1]=128;v[h>>2]=256;break i}if(w[f+193|0]!=255){break i}u[a+480188>>1]=e;break h}e=e+1|0;if((e|0)!=32){continue}break}e=x[a+480188>>1]}g=0;if(!(e&65535)){break d}v[d+48>>2]=w[d+225|0]<<2;v[d+8>>2]=256;r=a,s=v[Fb(d+48|0,d+8|0)>>2],v[r+480200>>2]=s;v[a+480196>>2]=w[d+226|0];v[a+480204>>2]=B(w[d+227|0],1e4);if(Yc(b,w[d+230|0]|w[d+231|0]<<8|(w[d+232|0]<<16|w[d+233|0]<<24))){cp(Sb(a+484360|0),b,w[d+234|0]+1|0,255,254)}if(!Yc(b,w[d+240|0]|w[d+241|0]<<8|(w[d+242|0]<<16|w[d+243|0]<<24))){break d}u[a+480190>>1]=w[d+248|0]+1;i=d+80|0;e=1;j=1;while(1){g=gb-32|0;gb=g;l=d+48|0;bc(g+24|0,l,62);h=yb(g+24|0);f=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=k;v[g+4>>2]=f;f=b;cc(g+16|0,f,g);k=yb(g+16|0);if((k|0)==(h|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(h|0)==(k|0);if(!f){Qb(l,0,62)}if(f){f=B(e,104)+a|0;g=f+484380|0;td(g,0);Ie(d+32|0,2,d+48|0);Bc(d+8|0,d+32|0);v[22692]=0;Q(301,((e<<5)+a|0)+946304|0,d+8|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}vb(d+8|0);Ek(d+32|0,2,i);Bc(d+8|0,d+32|0);v[22692]=0;Q(303,f+484423|0,d+8|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}vb(d+8|0);e=f+484404|0;v[e>>2]=w[d+106|0]|w[d+107|0]<<8;j:{if(!bp(a)){break j}h=v[e>>2];e=0;while(1){if((h|0)==x[(e<<1)+28752>>1]){t[f+484417|0]=e<<4;break j}e=e+1|0;if((e|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[d+93|0]|w[d+94|0]<<8|(w[d+95|0]<<16|w[d+96|0]<<24);if(w[d+105|0]&2){e=f+484414|0;u[e>>1]=x[e>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[d+97|0]|w[d+98|0]<<8|(w[d+99|0]<<16|w[d+100|0]<<24);v[f+484388>>2]=(w[d+101|0]|w[d+102|0]<<8|(w[d+103|0]<<16|w[d+104|0]<<24))-1;if(t[d+105|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}k:{if(!(!(w[d+105|0]&4)|w[d+108|0]==255)){t[d+8|0]=w[d+108|0];t[d+32|0]=64;r=f+484410|0,s=w[ac(d+8|0,d+32|0)|0]<<2,u[r>>1]=s;break k}e=f+484414|0;u[e>>1]=x[e>>1]|32768}l:{if(!(w[d+105|0]&8)){u[f+484408>>1]=128;break l}e=f+484414|0;u[e>>1]=x[e>>1]|32;g=f+484408|0;if(w[d+109|0]<=15){f=w[d+109|0];v[d+32>>2]=256;v[d+8>>2]=f<<4|8;f=v[nd(d+8|0,d+32|0)>>2]}else{f=128}u[g>>1]=f;u[e>>1]=x[e>>1]&65279|(w[d+109|0]==16)<<8}j=j+1|0;e=j&65535;if(e>>>0<=x[a+480190>>1]){continue}}break}m:{if(!(c&2)){break m}if(!Yc(b,w[d+244|0]|w[d+245|0]<<8|(w[d+246|0]<<16|w[d+247|0]<<24))|!x[a+480190>>1]){break m}e=1;while(1){f=B(e&65535,104)+a|0;Ag(Rc(d+48|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}n=a+484344|0;xg(n,w[d+239|0]+1|0);f=uq(a);e=gb-16|0;gb=e;v[e+12>>2]=0;$t(e+12|0,f);i=v[e+12>>2];gb=e+16|0;Yc(b,w[d+235|0]|w[d+236|0]<<8|(w[d+237|0]<<16|w[d+238|0]<<24));p=c&1;l=0;j=1;n:{while(1){o:{c=Mg(b);if(c>>>0>=3){ud(d+8|0,b,c-2|0);k=jc(d+48|0,d+8|0);xb(d+8|0);p:{if(!p){break p}v[22692]=0;c=T(275,d+48|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break o}if(!c){break p}v[22692]=0;c=W(331,n|0,l&65535,64)|0;e=v[22692];v[22692]=0;if((e|0)==1){break o}m=0;if(!c){break p}while(1){c=_b(n,l);v[22692]=0;q=Rf(c,m);c=v[22692];v[22692]=0;if((c|0)==1){break f}q:while(1){v[22692]=0;c=T(374,k|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break n}r:{if(!c){break r}e=c&31;if(e>>>0>=x[a+480188>>1]){break r}f=B(e,6)+q|0;if(c&32){v[22692]=0;R(403,d+8|0,k|0);e=v[22692];v[22692]=0;if((e|0)==1){break f}g=od(d+8|0);e=w[d+8|0];if(e){e=(e&127)-1|0;t[d+8|0]=e;t[f|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+13;v[22692]=0;e=tv(f);h=v[22692];v[22692]=0;if((h|0)==1){break f}j=e&j}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[22692]=0;c=Q(189,d+48|0,2)|0;e=v[22692];v[22692]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((e|0)!=1){if(!c){continue q}o=w[g|0];c=w[f+3|0];v[22692]=0;R(403,d+8|0,k|0);e=v[22692];v[22692]=0;if((e|0)==1){break f}h=w[od(d+8|0)|0];t[g|0]=h;e=w[(w[d+8|0]&31)+28784|0];t[f+3|0]=e;switch(e-2|0){case 4:case 5:break w;case 18:break x;case 13:break y;case 17:break z;case 11:break A;case 0:case 1:break B;default:break t}}break f}if(h>>>0<224){break u}e=223;if(v[a+480180>>2]!=1){break v}break u}v[22692]=0;t[d+32|0]=64;e=ac(g,d+32|0);h=v[22692];v[22692]=0;if((h|0)!=1){t[g|0]=w[e|0];v[22692]=0;e=mz(i,1);h=v[22692];v[22692]=0;if((h|0)==1){break f}if(!e){break u}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;e=c;break t}break f}C:{switch(((h&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=h&15|224;break s;case 1:t[f+3|0]=3;t[g|0]=h&15|224;break s;default:break C}}v[22692]=0;e=kq(i,19);h=v[22692];v[22692]=0;if((h|0)==1){break f}if(e){break u}v[22692]=0;Tt(f);e=v[22692];v[22692]=0;if((e|0)!=1){break u}break f}v[22692]=0;e=kq(i,15);h=v[22692];v[22692]=0;if((h|0)==1){break f}if(e){break u}v[22692]=0;e=kq(i,19);h=v[22692];v[22692]=0;if((h|0)==1){break f}if(!e){break u}t[f+3|0]=19;t[g|0]=w[g|0]&15|144;break s}e=145;if((h|0)==1){break v}if((h&240)==128){v[22692]=0;e=kq(i,20);h=v[22692];v[22692]=0;if((h|0)==1){break f}if(e){break u}t[f+3|0]=19;break s}t[f+3|0]=0;break s}e=h&240;if(!e){break u}}t[g|0]=e}e=w[f+3|0]}if((e&255)!=20){break s}e=w[g|0];if(w[f+2|0]|(e&240)!=128){break s}t[f+2|0]=2;t[f+4|0]=(((e&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o}if(w[d+8|0]&32){continue}break}continue}break}m=m+1|0;if((m|0)!=64){continue}break}}xb(d+48|0)}c=w[d+239|0]>l>>>0;l=l+1|0;if(c){continue}break e}break}break f}break f}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;Hb(d+8|0);break a}e=P()|0;O()|0;xb(d+48|0);break a}c=a;if(v[a+480180>>2]!=1){e=v[a+480208>>2]&-8454145}else{e=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?j&1?8454144:0:0)}v[c+480208>>2]=e;g=1;if(!(w[d+253|0]|w[d+254|0]<<8|(w[d+255|0]<<16|w[d+256|0]<<24))){break d}if(!Yc(b,w[d+249|0]|w[d+250|0]<<8|(w[d+251|0]<<16|w[d+252|0]<<24))){break d}hB(a+1298292|0,b,w[d+253|0]|w[d+254|0]<<8|(w[d+255|0]<<16|w[d+256|0]<<24),4)}gb=d+272|0;return g|0}e=P()|0;O()|0;vb(d+8|0);break a}e=P()|0;O()|0;vb(d+8|0)}S(e|0);L()}function Upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-272|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!vY(b,d+200|0)){break j}if(!wY(d+200|0)){break j}if(!c){e=1;break j}Id(a,131072);e=gb-16|0;gb=e;k=Tb(e,1061);Dc(d+112|0,k);vb(k);gb=e+16|0;v[22692]=0;U(461,d+152|0,d+112|0,d+200|4);e=v[22692];v[22692]=0;if((e|0)==1){break i}Eb(a+1298304|0,d+152|0);vb(d+152|0);Hb(d+112|0);e=Tb(d+152|0,8287);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;Hr(d+112|0,3,d+213|0);Bc(d+152|0,d+112|0);Eb(a+1298268|0,d+152|0);vb(d+152|0);Uj(d+88|0,3,d+243|0);Bc(d+112|0,d+88|0);v[22692]=0;U(13,d+152|0,5,d+112|0);e=v[22692];v[22692]=0;k:{l:{m:{n:{o:{if((e|0)!=1){Eb(a+1298280|0,d+152|0);vb(d+152|0);vb(d+112|0);e=Ar(d+152|0);m=e,n=Gd(w[d+263|0],1,31),v[m+12>>2]=n;m=e,n=Gd(w[d+264|0],1,12)-1|0,v[m+16>>2]=n;v[e+20>>2]=w[d+265|0];k=a+1298368|0;jD(k);tY(k,e);j=d+88|4;k=eh(d+136|0);while(1){v[22692]=0;e=Q(189,b|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break o}if(!e){break k}v[22692]=0;R(462,b|0,d+88|0);e=v[22692];v[22692]=0;if((e|0)==1){break n}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);e=w[d+204|0];p:{if((e|0)==3){g=2;if((w[d+88|0]|w[d+89|0]<<8|(w[d+90|0]<<16|w[d+91|0]<<24))==1431389523){break p}e=w[d+204|0]}if((e&255)==4){g=4;if((w[d+88|0]|w[d+89|0]<<8|(w[d+90|0]<<16|w[d+91|0]<<24))==1431389523){break p}e=w[d+204|0]}g=0;if((e&255)>>>0>7){break p}f=(w[d+88|0]|w[d+89|0]<<8|(w[d+90|0]<<16|w[d+91|0]<<24))==1146113363?-1:f}v[22692]=0;U(288,d+112|0,b|0,f|0);e=v[22692];v[22692]=0;if((e|0)==1){break m}v[22692]=0;U(463,k|0,d+88|0,d+112|0);e=v[22692];v[22692]=0;if((e|0)==1){break l}xb(d+112|0);v[22692]=0;Q(318,b|0,g|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+112|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+112|0);break b}v[22692]=0;b=T(214,d+112|0)|0;e=v[22692];v[22692]=0;q:{r:{s:{if((e|0)!=1){v[22692]=0;U(464,d+88|0,k|0,1431389523);e=v[22692];v[22692]=0;if((e|0)==1){break s}qd(b,d+88|0);xb(d+88|0);u[d+86>>1]=0;u[d+84>>1]=65534;if(w[d+204|0]<3){break q}v[22692]=0;e=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break r}break d}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}u[d+86>>1]=e;if(w[d+204|0]<4){break q}v[22692]=0;e=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}u[d+84>>1]=w[d+204|0]==4?e?e:-2:e}e=a+484360|0;f=Sb(e);v[22692]=0;g=T(465,b|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break d}v[22692]=0;fa(362,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}f=Sb(e);v[22692]=0;f=T(466,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}wg(d+86|0,f);f=Sb(e);v[22692]=0;f=T(466,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}wg(d+84|0,f);v[22692]=0;U(464,d+88|0,k|0,1414807888);f=v[22692];v[22692]=0;t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){qd(b,d+88|0);xb(d+88|0);v[22692]=0;f=T(275,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}if(!f|!(c&1)){break t}v[22692]=0;R(467,b|0,d+80|0);f=v[22692];v[22692]=0;if((f|0)==1){break A}m=a,n=Gd(w[d+80|2],1,32)+1|0,u[m+480188>>1]=n;f=w[d+80|0]|w[d+81|0]<<8;v[22692]=0;f=Q(328,d+8|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break z}m=d,n=Vb(f),v[m+32>>2]=n;m=d,n=Zb(f),v[m+72>>2]=n;if(Gb(d+32|0,d+72|0)){while(1){j=v[d+32>>2];v[22692]=0;g=w[d+204|0]<3?9:8;Q(318,b|0,g-4|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break y}v[22692]=0;h=T(190,b|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break x}ng(b,g);v[22692]=0;U(288,d+48|0,b|0,g+h|0);g=v[22692];v[22692]=0;if((g|0)==1){break w}qd(j,jc(d+88|0,d+48|0));xb(d+88|0);xb(d+48|0);Bh(d+32|0);if(Gb(d+32|0,d+72|0)){continue}break}}g=x[a+480188>>1];v[22692]=0;g=Q(468,d+88|0,g|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break v}h=Tl(Sb(e));v[22692]=0;j=a+484344|0;R(330,j|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break f}h=Sb(e);m=d,n=Vb(h),v[m+48>>2]=n;m=d,n=Zb(h),v[m+32>>2]=n;if(Gb(d+48|0,d+32|0)){while(1){h=v[d+48>>2];i=x[h>>1];if($e(f)>>>0>i>>>0){i=Jg(f,x[h>>1]);v[22692]=0;i=ca(469,i|0,w[d+204|0],g|0,a|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break f}u[h>>1]=i}nf(d+48|0);if(Gb(d+48|0,d+32|0)){continue}break}}h=Sb(e);v[22692]=0;h=Q(470,h|0,x[d+84>>1])|0;i=v[22692];v[22692]=0;if((i|0)==1){break f}if(!h){break u}if(!x[d+86>>1]){h=x[d+84>>1];i=Sb(e);v[22692]=0;i=T(466,i|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break f}if(h>>>0>=i>>>0){break u}}e=x[rc(Sb(e),x[d+84>>1])>>1];h=_b(j,e);v[22692]=0;i=Be(d+48|0,12,w[d+86|0]);l=v[22692];v[22692]=0;if((l|0)!=1){e=jp(Se(i,v[_b(j,e)+12>>2]-1|0));v[22692]=0;Q(431,h|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break u}}break f}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}dD(g);hd(f)}v[22692]=0;U(464,d+88|0,k|0,1196641603);e=v[22692];v[22692]=0;if((e|0)==1){break h}qd(b,d+88|0);xb(d+88|0);v[22692]=0;e=T(275,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}if(e){v[22692]=0;Q(318,b|0,1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;e=T(465,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}v[22692]=0;fa(471,a+1298292|0,b|0,e|0,40,0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}}v[22692]=0;U(464,d+88|0,k|0,1146113363);e=v[22692];v[22692]=0;if((e|0)==1){break g}v[22692]=0;U(464,d+48|0,k|0,1229999443);e=v[22692];v[22692]=0;B:{C:{if((e|0)!=1){qd(b,d+48|0);xb(d+48|0);v[22692]=0;f=T(374,b|0)|0;g=v[22692];v[22692]=0;e=1;D:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){j=c&2;g=1;while(1){f=30;E:{F:{G:{if(w[d+204|0]>=2){v[22692]=0;f=T(374,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break G}}v[22692]=0;W(472,b|0,((e<<5)+a|0)+946304|0,f|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break G}v[22692]=0;R(473,b|0,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break F}v[22692]=0;c=B(e,104)+a|0;f=c+484380|0;R(474,d+32|0,f|0);e=v[22692];v[22692]=0;if((e|0)==1){break F}e=w[d+204|0];if(e>>>0>=8){v[22692]=0;W(475,b|0,c+484423|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break F}e=w[d+204|0]}v[22692]=0;Q(318,b|0,((e&255)>>>0>1?6:2)|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break F}v[22692]=0;e=T(190,d+88|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;U(288,d+8|0,d+88|0,e|0);e=v[22692];v[22692]=0;if((e|0)!=1){break E}}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}e=jc(d+48|0,d+8|0);xb(d+8|0);v[22692]=0;h=T(275,d+48|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break D}H:{if(!h|!j){break H}c=Rc(d+8|0,u[c+484414>>1]&1?16:8,1,0,(w[d+47|0]&12)==4?7:0);v[22692]=0;W(329,c|0,f|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break H}break D}xb(d+48|0);g=g+1|0;e=g&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}v[22692]=0;yg(a);c=v[22692];v[22692]=0;e=1;if((c|0)!=1){break B}}a=P()|0;O()|0;break C}a=P()|0;O()|0;xb(d+48|0);break C}a=P()|0;O()|0}xb(d+88|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;xb(d+88|0);xb(b);Ed(k)}gb=d+272|0;return e|0}a=P()|0;O()|0;Hb(d+112|0);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;dD(g)}hd(f);break c}a=P()|0;O()|0}xb(b)}Ed(k)}S(a|0);L()}function YZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=gb-224|0;gb=e;vc(b);a:{if(!sE(b,e+176|0)){break a}if(!tE(e+176|0)){break a}if(!c){i=1;break a}Id(a,2048);yg(a);d=gb-16|0;gb=d;g=Tb(d,1075);Dc(e+8|0,g);vb(g);gb=d+16|0;v[22692]=0;l=e+176|3;U(316,e+80|0,e+8|0,l|0);d=v[22692];v[22692]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){Eb(a+1298304|0,e+80|0);vb(e+80|0);Hb(e+8|0);d=Tb(e+80|0,8291);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;u[a+480188>>1]=w[e+216|0];u[a+480190>>1]=w[e+212|0];Ie(e+8|0,2,e+176|4);Bc(e+80|0,e+8|0);Eb(a+1298268|0,e+80|0);vb(e+80|0);if(w[l|0]<=8){u[a+480188>>1]=4;ng(b,1);uh(a,1)}d=w[l|0];n:{if(w[l|0]>=11){g=d>>>0>11?32:16;d=0;while(1){h=qE(b);o:{if((h|0)==100){v[((f<<5)+a|0)+480280>>2]=256;break o}v[e+80>>2]=(h<<1)+128;v[e+8>>2]=0;v[e+160>>2]=256;y=((f<<5)+a|0)+480284|0,z=v[Wj(e+80|0,e+8|0,e+160|0)>>2],u[y>>1]=z}d=d+1|0;f=d&65535;if(g>>>0>f>>>0){continue}break}break n}if(d>>>0<9){break n}d=e+80|0;h=gb-32|0;gb=h;g=b;p:{if(!Pb(g,16)){g=gb-16|0;gb=g;n=d+16|0;while(1){Hf(d);d=d+1|0;if((n|0)!=(d|0)){continue}break}gb=g+16|0;break p}_v(h+24|0,d);d=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=d;id(h+16|0,g,h+8|0)}gb=h+32|0;while(1){u[((f<<5)+a|0)+480284>>1]=t[(e+80|0)+f|0]&1?64:192;f=f+1|0;if((f|0)!=16){continue}break}}q:{if(w[l|0]>=13){bw(e+80|0,b);f=od(e+80|0);g=a;d=w[e+80|0];if(d>>>0<=31){t[e+80|0]=125;d=125}v[g+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break q}v[a+480196>>2]=6;v[a+480204>>2]=125e4}d=a+484360|0;yf(Sb(d),w[e+213|0]);n=mc(e+160|0);j=v[b+8>>2];q=w[l|0];r:{if(w[l|0]<14){break r}g=w[e+213|0];v[22692]=0;R(317,n|0,g|0);g=v[22692];v[22692]=0;if((g|0)!=1){break r}a=P()|0;O()|0;break e}s:{if(w[e+213|0]){f=0;while(1){y=rc(Sb(d),f),z=f,u[y>>1]=z;if(w[l|0]>=14){v[22692]=0;g=T(287,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break s}y=rc(n,f),z=g,u[y>>1]=z}g=x[a+480188>>1];v[22692]=0;Q(318,b|0,g<<1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break s}f=f+1|0;if(f>>>0<w[e+213|0]){continue}break}}d=0;t:{u:{if(w[l|0]==10){h=v[b+8>>2];d=0;v:{if(!x[a+480190>>1]){break v}f=1;while(1){v[22692]=0;d=Q(319,b|0,e+80|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break u}w:{if(!d){break w}g=0;d=e+80|0;x:{if(w[d|0]>1|w[e+212|0]<(w[d+46|0]|w[d+47|0]<<8|(w[d+48|0]<<16|w[d+49|0]<<24))>>>0|((w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0>1048576|w[d+56|0]>64)){break x}if((w[d+57|0]|w[d+58|0]<<8|(w[d+59|0]<<16|w[d+60|0]<<24))>>>0>(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0){break x}g=(w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24))>>>0<=(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0}if(g){break w}d=1;break v}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}d=0}v[22692]=0;Q(188,b|0,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break t}}g=x[a+480190>>1];v[22692]=0;v[e+80>>2]=0;p=W(320,e- -64|0,g|0,e+80|0)|0;g=v[22692];v[22692]=0;f=1;if((g|0)!=1){if(x[a+480190>>1]){o=d?59:65;h=e+80|1;g=1;while(1){y:{if(w[l|0]<=9){v[22692]=0;R(321,b|0,e+80|0);i=v[22692];v[22692]=0;z:{A:{B:{if((i|0)==1){break B}v[22692]=0;R(322,e+80|0,(B(f,104)+a|0)+484380|0);i=v[22692];v[22692]=0;if((i|0)==1){break B}v[22692]=0;Ie(e+48|0,2,h);i=v[22692];v[22692]=0;if((i|0)==1){break A}v[22692]=0;R(324,e+8|0,e+48|0);i=v[22692];v[22692]=0;if((i|0)==1){break A}v[22692]=0;Q(301,((f<<5)+a|0)+946304|0,e+8|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break z}break y}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(e+8|0);break f}v[22692]=0;U(325,b|0,e+80|0,o|0);i=v[22692];v[22692]=0;if((i|0)==1){break g}v[22692]=0;U(326,e+80|0,(B(f,104)+a|0)+484380|0,d|0);i=v[22692];v[22692]=0;if((i|0)==1){break g}v[22692]=0;Ie(e+48|0,2,h);i=v[22692];v[22692]=0;if((i|0)==1){break h}v[22692]=0;R(324,e+8|0,e+48|0);i=v[22692];v[22692]=0;if((i|0)==1){break h}v[22692]=0;Q(301,((f<<5)+a|0)+946304|0,e+8|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break i}}vb(e+8|0);i=w[e+126|0]|w[e+127|0]<<8|(w[e+128|0]<<16|w[e+129|0]<<24);y=Lb(p,f-1|0),z=i,v[y>>2]=z;g=g+1|0;f=g&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}h=mc(e+48|0);d=w[e+214|0]|w[e+215|0]<<8;v[22692]=0;i=W(327,b|0,h|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break m}if(!i){break b}d=0;if(!bd(h)){g=Vb(h);f=Zb(h);d=gb-32|0;gb=d;v[d+16>>2]=f;v[d+24>>2]=g;C:{if(!Gb(d+24|0,d+16|0)){break C}v[d>>2]=g;f=nf(d);if(!Gb(f,d+16|0)){break C}while(1){if(kE(v[d+24>>2],v[f>>2])){g=v[d>>2];v[d+24>>2]=g}if(Gb(nf(f),d+16|0)){continue}break}}gb=d+32|0;v[e+80>>2]=g;d=v[e+80>>2];d=w[d|0]|w[d+1|0]<<8}v[22692]=0;g=d;o=Q(328,e+32|0,d|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){D:{if(g){f=0;while(1){v[22692]=0;k=T(287,b|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break l}v[22692]=0;Q(318,b|0,1)|0;m=v[22692];v[22692]=0;if((m|0)==1){break l}if(k){m=w[l|0];v[22692]=0;U(288,e+8|0,b|0,B(k,3)+((m|0)==1?3:0)|0);k=v[22692];v[22692]=0;if((k|0)==1){break D}k=jc(e+80|0,e+8|0);qd(Jg(o,f),k);xb(e+80|0);xb(e+8|0)}f=f+1|0;if((g|0)!=(f|0)){continue}break}}E:{if(!(c&2)){break E}g=1;m=Rc(e+80|0,8,1,0,1);if(!x[a+480190>>1]){break E}k=1;while(1){v[22692]=0;f=Q(189,b|0,1)|0;r=v[22692];v[22692]=0;F:{if((r|0)!=1){if(!f){break E}f=0;if(!x[a+480190>>1]){break F}r=v[b+8>>2];while(1){G:{H:{if(v[Lb(p,f)>>2]!=(g|0)){f=f+1|0;break H}v[22692]=0;Q(188,b|0,r|0)|0;s=v[22692];v[22692]=0;if((s|0)==1){break G}v[22692]=0;f=f+1|0;W(329,m|0,(B(f,104)+a|0)+484380|0,b|0)|0;s=v[22692];v[22692]=0;if((s|0)==1){break G}}if(x[a+480190>>1]>f>>>0){continue}break F}break}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}k=k+1|0;g=k&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}if(!(c&1)){break c}g=w[e+213|0];c=0;v[22692]=0;k=a+484344|0;R(330,k|0,g|0);g=v[22692];v[22692]=0;I:{if((g|0)!=1){if(!w[e+213|0]){break c}q=j+((q>>>0>13)<<1)|0;while(1){J:{f=64;if(sc(n)>>>0>c>>>0){f=x[rc(n,c)>>1]}v[22692]=0;g=W(331,k|0,c&65535,f&65535)|0;f=v[22692];v[22692]=0;if((f|0)==1){break I}K:{if(g){g=x[a+480188>>1];f=w[l|0];v[22692]=0;Q(188,b|0,q+B(((f>>>0>13)<<1)+(g<<1)|0,c)|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break I}g=mc(e+80|0);f=x[a+480188>>1];v[22692]=0;f=W(327,b|0,g|0,f|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break K}L:{if(!f){break L}f=0;if(!x[a+480188>>1]){break L}while(1){M:{j=rc(g,f);if(!(w[j|0]|w[j+1|0]<<8)){break M}j=rc(g,f);if((w[j|0]|w[j+1|0]<<8)>>>0>(w[e+214|0]|w[e+215|0]<<8)>>>0){break M}j=rc(g,f);j=rc(h,(w[j|0]|w[j+1|0]<<8)-1|0);j=w[j|0]|w[j+1|0]<<8;if(!j|d>>>0<j>>>0){break M}m=_b(k,c);j=Jg(o,j-1&65535);v[22692]=0;U(332,m|0,f&65535,j|0);j=v[22692];v[22692]=0;if((j|0)!=1){break M}break J}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}Ik(g)}c=c+1|0;if(c>>>0>=w[e+213|0]){break c}continue}}break}a=P()|0;O()|0;Ik(g);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Hb(e+8|0);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0}hd(o)}Ik(h);break f}a=P()|0;O()|0;vb(e+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}Lc(p)}We(n)}S(a|0);L()}hd(o)}Ik(h);Lc(p);We(n)}gb=e+224|0;return i|0}function E2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2491;r=he(l+136|0,l+144|0,l+96|0);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Kb(l+96|0);m=Kb(l+80|0);n=Kb(l- -64|0);o=Kb(l+48|0);s=Kb(l+32|0);v[22692]=0;na(2500,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,m|0,n|0,o|0,l+28|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;e=v[l+28>>2];k=0;f:{while(1){v[22692]=0;c=Q(2469,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}g:{if(!c){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+p|0]){case 1:if((p|0)==3){break g}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;c=W(2501,h|0,8192,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(c){v[22692]=0;R(2502,l+16|0,a|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=v[l+16>>2];v[22692]=0;R(63,s|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((p|0)==3){break g}}while(1){v[22692]=0;c=Q(2469,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!c){break h}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;c=W(2501,h|0,8192,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!c){break h}v[22692]=0;R(2502,l+16|0,a|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=v[l+16>>2];v[22692]=0;R(63,s|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}r:{if(Ab(n)){if(Ab(o)){break r}}if(Ab(n)){v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if((c|0)!=v[Jb(n)>>2]){break l}v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if((c|0)!=v[Jb(o)>>2]){break h}v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if((c|0)==v[Jb(n)>>2]){v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if((c|0)==v[Jb(o)>>2]){v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(p>>>0<2|k|((p|0)==2&w[l+123|0]!=0|z))){k=0;break h}B=l,C=zd(m),v[B+8>>2]=C;c=Hd(l+16|0,l+8|0);s:{if(!p|w[(l+p|0)+119|0]>1){break s}B=l,C=ti(m),v[B+8>>2]=C;t:{if(!Gb(c,l+8|0)){break t}while(1){d=v[v[c>>2]>>2];v[22692]=0;d=W(2501,h|0,8192,d|0)|0;q=v[22692];v[22692]=0;if((q|0)==1){break k}if(!d){break t}Oe(c);B=l,C=ti(m),v[B+8>>2]=C;if(Gb(c,l+8|0)){continue}break}}B=l,C=zd(m),v[B+8>>2]=C;d=iv(c,l+8|0);if(Ab(s)>>>0>=d>>>0){B=l,C=ti(s),v[B+8>>2]=C;c=gb-16|0;gb=c;v[c+8>>2]=v[l+8>>2];v[c+8>>2]=v[c+8>>2]+(0-d<<2);d=v[c+8>>2];gb=c+16|0;q=ti(s);x=zd(m);c=gb-32|0;gb=c;v[c+16>>2]=q;v[c+24>>2]=d;v[c+8>>2]=x;d=1;u:{if(!Gb(c+24|0,c+16|0)){break u}while(1){d=Zo(v[c+24>>2],v[c+8>>2]);if(!d){break u}Oe(c+24|0);Oe(c+8|0);if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;if(d){break s}}B=l,C=zd(m),v[B>>2]=C;Hd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];B=l,C=ti(m),v[B>>2]=C;v:{w:{x:{if(!Gb(l+8|0,l)){break x}while(1){v[22692]=0;c=Q(2469,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break w}if(!c){break x}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break w}if((c|0)!=v[v[l+8>>2]>>2]){break x}v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break v}Oe(l+8|0);B=l,C=ti(m),v[B>>2]=C;if(Gb(l+8|0,l)){continue}break}}if(!y){break h}B=l,C=ti(m),v[B>>2]=C;if(!Gb(l+8|0,l)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+28>>2]=e;break a}a=P()|0;O()|0;v[l+28>>2]=e;break a}c=0;x=v[l+112>>2];d=b;y:{while(1){z:{v[22692]=0;b=Q(2469,a|0,l+552|0)|0;q=v[22692];v[22692]=0;if((q|0)==1){break z}if(!b){break y}v[22692]=0;q=T(2471,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;b=W(2501,h|0,2048,q|0)|0;A=v[22692];v[22692]=0;if((A|0)==1){break e}A:{if(b){b=v[j>>2];if((b|0)==v[l+548>>2]){v[22692]=0;U(2503,i|0,j|0,l+548|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}b=v[j>>2]}v[j>>2]=b+4;v[b>>2]=q;c=c+1|0;break A}if(!Ab(u)|!c|(q|0)!=(x|0)){break y}if(v[l+128>>2]==(d|0)){v[22692]=0;U(2497,r|0,l+132|0,l+128|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;d=b;c=0}v[22692]=0;T(2473,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!c|v[r>>2]==(d|0)){break j}if(v[l+128>>2]==(d|0)){v[22692]=0;U(2497,r|0,l+132|0,l+128|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;break i}t[g|0]=1;break h}a=P()|0;O()|0;v[l+28>>2]=e;break a}b=d}B:{if((e|0)<1){break B}v[22692]=0;c=Q(2470,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}C:{if(!c){v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if((c|0)==v[l+116>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}while(1){if((e|0)<1){e=0;break B}v[22692]=0;c=Q(2470,a|0,l+552|0)|0;d=v[22692];v[22692]=0;D:{if((d|0)==1){break D}E:{if(!c){v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break D}v[22692]=0;c=W(2501,h|0,2048,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break D}if(c){break E}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22692]=0;U(2503,i|0,j|0,l+548|0);c=v[22692];v[22692]=0;if((c|0)==1){break D}}v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break D}d=v[j>>2];v[j>>2]=d+4;v[d>>2]=c;v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;e=e-1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}p=p+1|0;if((p|0)!=4){continue}}break}v[l+28>>2]=e;F:{if(!k){break F}e=1;while(1){if(Ab(k)>>>0<=e>>>0){break F}v[22692]=0;c=Q(2470,a|0,l+552|0)|0;d=v[22692];v[22692]=0;G:{if((d|0)==1){break G}H:{if(!c){v[22692]=0;c=T(2471,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break G}if((c|0)==v[sk(k,e)>>2]){break H}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22692]=0;T(2473,a|0)|0;c=v[22692];v[22692]=0;e=e+1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[r>>2]==(b|0)){break f}a=0;v[l+16>>2]=0;gf(u,v[r>>2],b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}Ic(s);Ic(o);Ic(n);Ic(m);vb(u);Hc(r);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ic(s);Ic(o);Ic(n);Ic(m);vb(u);Hc(r);S(a|0);L()}function yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=gb-320|0;gb=d;a:{if(!Yc(b,1080)){break a}if(!ap(b,d+316|0)){break a}Id(a,1);n=BV(d+296|0);if(!AV(d+316|0,n)){break a}f=x[n+8>>1];if((f-1&65535)>>>0>126){break a}if(!c){h=1;break a}u[a+480188>>1]=f;o=w[n+12|0];H=w[n+11|0];e=w[n+10|0];D=1;if(!ke(d+316|0,33176)){D=ke(d+316|0,33181)}if(w[n+13|0]){Ob(a+1074312|0,5,1);f=x[a+480188>>1]}p=ke(d+316|0,13792);j=1;if(!ke(d+316|0,14569)){j=ke(d+316|0,10842)}z=a+480188|0;y=(f&65535)==8&(H|0)!=0;Yc(b,0);LC(b,a+1298268|0,20);u[a+480190>>1]=31;l=(e|0)!=0;h=1;e=p;while(1){f=B(h,104)+a|0;g=f+484380|0;q=YB(b,d+160|0,g,((h<<5)+a|0)+946304|0,x[a+480188>>1]==4);g=v[g>>2];b:{if(j){t[f+484417|0]=0-(w[d+184|0]<<3);break b}l=g>>>0<65536&l}c:{d:{if(!Ib(w[d+182|0]|w[d+183|0]<<8)){break d}if(Ib(w[d+188|0]|w[d+189|0]<<8)){break d}$=1;break c}if(Ib(w[d+182|0]|w[d+183|0]<<8)){break c}I=w[d+185|0]==64|I}f=e&1;e=0;e:{if(!f){break e}k=(Ib(w[d+182|0]|w[d+183|0]<<8)<<1)+k|0;if(w[d+184|0]){break e}if(!Ib(w[d+182|0]|w[d+183|0]<<8)){e=1;break e}e=w[d+185|0]==64}E=q+E|0;i=g+i|0;h=h+1|0;if((h|0)!=32){continue}break}f:{g:{h:{i:{j:{k:{J=v[n+4>>2];if(J>>>0>=E>>>0){yV(b,d+160|0);Rb(b,4);q=d+160|1;f=w[q|0];g=128;j=a+484360|0;Br(Sb(j),d+160|2,128);h=!f&e;k=h?k:0;e=w[d+160|0];l:{if(e>>>0>128){break l}g=e;if(e){break l}e=128;while(1){f=e-1|0;if(!x[rc(Sb(j),f)>>1]){g=1;e=f;if(e>>>0>1){continue}break l}break}g=e}F=(o|0)!=0;o=xV(b,Sb(j),g&65535,i,z,k,0);if(!(!h|x[a+480188>>1]!=8)){v[n>>2]=8507;F=1}m:{if(!y){break m}e=Sb(j);da=d,ea=Vb(e),v[da+144>>2]=ea;da=d,ea=Zb(e),v[da+128>>2]=ea;if(!Gb(d+144|0,d+128|0)){break m}while(1){e=v[d+144>>2];u[e>>1]=x[e>>1]>>>1;nf(d+144|0);if(Gb(d+144|0,d+128|0)){continue}break}}bf(Sb(j),w[q|0]);K=g-1&65535;n:{if(K>>>0>=w[q|0]){h=x[z>>1];if(w[q|0]!=120|(h|0)!=4){break n}}bf(Sb(j),0);h=x[z>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;e=Mb(256/((h&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;uh(a,0);t[d+159|0]=0;h=1;k=0;M=1;if(!l){o:{if(!o){e=p;break o}s=d+144|5;e=p;l=0;j=0;while(1){g=0;i=0;while(1){f=_i(d+144|0);av(b,f);r=tv(f);p:{q:{r:{f=w[d+147|0];if((f-7&255)>>>0<3){e=0;break r}e=r?e:0;s:{t:{u:{switch(f-13|0){case 2:if(w[d+149|0]>31){break t}break p;case 1:break s;case 0:break u;default:break r}}i=i+1|0;if((i&65535)>>>0<2){break p}}e=0;break p}f=w[d+149|0];e=f>>>0>1?0:e;break q}if((f|0)!=8){if((f|0)!=14){break p}f=w[d+149|0];break q}da=d,ea=w[Bf(d+159|0,s)|0],t[da+159|0]=ea;f=t[d+149|0];if((f|0)>-1){j=1;break p}l=(f|0)!=-92&(f&255)>>>0>143|l;break p}if((f&240)!=128){break p}t[d+128|0]=f<<4;da=d,ea=w[Bf(d+159|0,d+128|0)|0],t[da+159|0]=ea}h=h&r;g=g+1|0;if((g|0)!=256){continue}break}k=k+1|0;if(o>>>0>(k&65535)>>>0){continue}break}k=0;if((j^-1|l)&1){break o}k=w[d+159|0]>47}M=e&1}Yc(b,1084);e=x[a+480188>>1];r=a+484344|0;g=o+y|0;i=g&65535;xg(r,i);N=y?4:e;j=a+1074312|0;v:{if(!i){s=0;break v}aa=k^1;ba=c&1;Q=N&65535;T=g&65535;k=0;s=0;w:{while(1){x:{if(y){e=(k&65534)>>>1|0;g=k&1;if(!g){if(!sh(r,e,64)){break v}}l=Wc(_b(r,e),0,g<<2);break x}if(!sh(r,k&65535,64)){break v}l=Wc(_b(r,k),0,0)}if(!l|!ba){break v}e=x[a+480188>>1];t[d+128|0]=0;o=Ev(d+144|0,e,d+128|0);e=x[a+480188>>1];v[22692]=0;t[d+64|0]=0;C=W(772,d+128|0,e|0,d- -64|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){G=0;while(1){i=0;V=0;f=0;if(Q){while(1){v[22692]=0;e=B(f,6)+l|0;R(773,b|0,e|0);g=v[22692];v[22692]=0;y:{z:{if((g|0)!=1){g=w[e+3|0];A:{B:{C:{if(!g){if(w[e+5|0]){break C}break B}if(!H){break C}D:{switch(g-14|0){case 0:t[e+3|0]=0;t[e+5|0]=0;break C;case 1:break D;default:break C}}if(w[e+5|0]<32){break C}t[e+5|0]=31}Nf(e);g=1;E:{F:{G:{m=w[e+3|0];switch(m-14|0){case 2:break A;case 0:break F;case 3:break G;default:break E}}s=w[e+5|0]<100|s;V=1;break B}if(!M){break B}t[e+5|0]=0;break B}if(!((m|0)!=9|aa)){g=w[e+5|0];if((g|0)==164){t[e+3|0]=20;t[e+5|0]=145;break B}da=e,ea=ei(g<<1),t[da+5|0]=ea;break B}if((m|0)!=19){break B}g=w[e+5|0];if(g>>>0>15){break B}m=g&1;g=!m;ca=!m;m=X&1;X=(m|0)==(g|0)?X:ca;Y=((g|0)!=(m|0))+Y|0}g=i}if(w[e|0]){break z}if(!w[e+1|0]|y){break y}if(!w[kc(o,f)|0]){break y}if(w[kc(o,f)|0]==w[e+1|0]){break y}m=kc(C,f);i=w[m|0]+1|0;t[m|0]=i;if((i&255)>>>0<4){break y}v[22692]=0;W(409,j|0,85,1)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break y}}f=P()|0;O()|0;gc(C);break w}da=kc(C,f),ea=0,t[da|0]=ea}e=w[e+1|0];if(e){da=kc(o,f),ea=e,t[da|0]=ea}i=g;f=f+1|0;if((Q|0)!=(f|0)){continue}break}}Z=i&V|Z;l=B(x[z>>1],6)+l|0;G=G+1|0;if((G|0)!=64){continue}break}gc(C);gc(o);k=k+1|0;if((T|0)==(k|0)){break v}continue}break}f=P()|0;O()|0}gc(o);break f}H:{I:{J:{if((h^-1|$)&1){break J}K:{if(ke(d+316|0,13792)){break K}if(ke(d+316|0,14574)){break K}if(!ke(d+316|0,10837)){break J}}v[a+480208>>2]=v[a+480208>>2]|2162688;Ob(j,85,1);Ob(j,91,1);Ob(j,92,1);L:{if(w[d+159|0]>47){break L}Ob(j,84,1);if(w[q|0]==127){break L}Ob(j,83,1)}if(!h){break H}break I}if(h){break I}if(p^1|w[q|0]!=127|w[q|0]+1>>>0<K>>>0){break H}v[n>>2]=5470;break H}if((Y|0)>6|F){break H}v[a+480208>>2]=v[a+480208>>2]|8388608}if((p|F)==1){Ob(j,89,1)}if(D){Ob(j,84,1)}if(c&2){Yc(b,(B(N&65535,T)<<8)+1084|0);g=(h&p^1|I)&1;h=1;while(1){i=B(h,104)+a|0;c=i+484380|0;if(v[c>>2]){f=d+144|0;if(D){e=2}else{e=wV(b,11097)?11:0}e=Rc(f,8,1,0,e);l=v[b+8>>2]+rv(e,v[c>>2])|0;if(!g){da=c,ea=v[Mc(c,i+484388|0)>>2],v[da>>2]=ea}Ag(e,c,b);Yc(b,l)}h=h+1|0;if((h|0)!=32){continue}break}}M:{if((p&s^-1|Z)&1){break M}b=vV(d+104|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;nu(d+144|0,a,0,d+24|0);_=A[v[d+144>>2]>>3];$m(d+144|0);if(_<600){break M}Ob(j,5,1);b=uV(d+80|0,_);c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;nu(d+144|0,a,0,d);b=w[v[d+144>>2]+26|0];$m(d+144|0);if(b){Pf(j,5);break M}v[n>>2]=14126}g=d+316|0;e=g;b=e;c=fc(d+316|0);p=c;if((c|0)!=(e|0)){while(1){i=w[e|0];t[b|0]=i>>>0>32?i:32;b=b+1|0;e=e+1|0;if((p|0)!=(e|0)){continue}break}}Df(d+128|0,13879);v[22692]=0;b=W(774,d+48|0,g|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break k}v[22692]=0;U(13,d- -64|0,1,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break j}v[22692]=0;U(165,d+144|0,d+128|0,d- -64|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}Eb(a+1298304|0,d+144|0);vb(d+144|0);vb(d- -64|0);vb(b);Hb(d+128|0);b=Tb(d+144|0,9510);Eb(a+1298316|0,b);vb(b);b=v[n>>2];if(b){Vc(a+1298328|0,b)}v[a+1298364>>2]=2}h=E>>>0<=J>>>0;break a}f=P()|0;O()|0;break g}f=P()|0;O()|0;break h}f=P()|0;O()|0;vb(d- -64|0)}vb(b)}Hb(d+128|0)}S(f|0);L()}gb=d+320|0;return h|0}function sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;j=d+120|0;xU(f+24|0,j);k=yb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;cc(f+16|0,e,f);i=yb(f+16|0);if((i|0)==(k|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(k|0)==(i|0);if(!e){wU(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!EU(d+120|0)){break e}if(!c){h=1;break e}Id(a,4194304);e=Tb(d+32|0,14085);Eb(a+1298304|0,e);vb(e);e=Tb(d+32|0,7361);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;n=a,o=Gd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[n+480188>>1]=o;e=w[d+189|0];v[a+480228>>2]=(e|0)==255?48:e;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);of(d+96|0,d+120|4,59,3);Bc(d+32|0,d+96|0);Eb(a+1298268|0,d+32|0);vb(d+32|0);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Yc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!Hh(b,11419)){break f}cp(Sb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Yc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!Hh(b,11056)){break g}while(1){e=(h<<5)+a|0;Ue(e+480280|0);n=e+480284|0,o=((((Ae(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;h=h+1|0;if((h|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Yc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!Hh(b,11332)){break h}ud(d+32|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);e=jc(d+96|0,d+32|0);xb(d+32|0);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}k=c&2;j=a+480190|0;i=d+45|0;while(1){v[22692]=0;f=Q(864,e|0,d+32|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!f){break i}f=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=f;j:{if((f-1&65535)>>>0>3998){break j}if(Nd((B(f,104)+a|0)+484380|0)){break j}v[22692]=0;f=Je(j,d+30|0);h=v[22692];v[22692]=0;if((h|0)==1){break c}u[a+480190>>1]=x[f>>1];v[22692]=0;R(865,d+32|0,(B(x[d+30>>1],104)+a|0)+484380|0);f=v[22692];v[22692]=0;if((f|0)==1){break c}of(d,i,24,1);v[22692]=0;R(324,d+16|0,d|0);f=v[22692];v[22692]=0;k:{if((f|0)!=1){v[22692]=0;Q(301,((x[d+30>>1]<<5)+a|0)+946304|0,d+16|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break k}vb(d+16|0);if(!k){break j}f=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22692]=0;Q(188,b|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}h=1;f=d+79|0;g=Rc(d+16|0,w[f|0]&4?16:8,1,0,0);l:{m:{if(w[f|0]&8){break m}h=2;if(w[f|0]&16){break m}if(w[f|0]&127){break l}}zf(g,h)}v[22692]=0;W(329,d+16|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break j}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+16|0);break b}l=l+1|0;if((l&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}xb(e)}h=1;if(!(c&1)){break e}n:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break n}if(!Yc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break n}if(!Hh(b,10922)){break n}i=a+484344|0;xg(i,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break n}k=d+16|2;l=0;while(1){if(!nC(b,d+16|0)){break n}if((w[d+16|0]|w[d+17|0]<<8)>>>0>3){ud(d+96|0,b,((w[d+16|0]|w[d+17|0]<<8)+15&131056)-4|0);f=jc(d+32|0,d+96|0);xb(d+96|0);c=w[k|0];v[22692]=0;c=W(331,i|0,l&65535,c|0)|0;e=v[22692];v[22692]=0;o:{if((e|0)!=1){p:{j=0;if(!c){break o}while(1){v[22692]=0;c=Q(189,d+32|0,1)|0;e=v[22692];v[22692]=0;q:{r:{s:{if((e|0)!=1){if(!c|w[k|0]<=j>>>0){break r}v[22692]=0;e=T(374,f|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break p}if(e){break s}j=j+1|0;continue}break p}c=_b(i,l);u[d+96>>1]=e&31;g=x[a+480188>>1];v[22692]=0;u[d>>1]=g-1;g=Pc(d+96|0,d);m=v[22692];v[22692]=0;if((m|0)==1){break p}g=x[g>>1];v[22692]=0;c=Wc(c,j,g);g=v[22692];v[22692]=0;if((g|0)==1){break p}if(e&128){v[22692]=0;R(403,d+96|0,f|0);g=v[22692];v[22692]=0;if((g|0)==1){break p}g=od(d+96|0);t[c|0]=w[d+96|0]+36;t[c+1|0]=w[g|0]}if(!(e&64)){break q}t[c+2|0]=1;v[22692]=0;g=T(374,f|0)|0;m=v[22692];v[22692]=0;t:{if((m|0)!=1){t[d+96|0]=g;v[22692]=0;t[d|0]=64;g=ac(d+96|0,d);m=v[22692];v[22692]=0;if((m|0)==1){break t}t[c+4|0]=w[g|0];break q}break p}break p}if(w[k|0]==64){break o}c=_b(i,l);v[22692]=0;e=Be(d+96|0,14,0);f=v[22692];v[22692]=0;if((f|0)!=1){e=Gh(Se(e,w[k|0]-1|0));v[22692]=0;Q(431,c|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break o}}break p}if(!(e&32)){continue}v[22692]=0;R(403,d+96|0,f|0);e=v[22692];v[22692]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((e|0)!=1){e=w[od(d+96|0)|0];t[c+5|0]=e;switch(w[d+96|0]-1|0){case 71:break v;case 70:break w;case 69:break x;case 60:break y;case 59:break z;case 52:break A;case 51:break B;case 50:break C;case 49:break D;case 42:break E;case 41:break F;case 40:break G;case 39:break H;case 30:break I;case 29:break J;case 22:break K;case 21:break L;case 20:break M;case 19:break N;case 16:break O;case 15:break P;case 14:break Q;case 13:break R;case 12:break S;case 11:break T;case 10:break U;case 9:break V;case 3:break W;case 2:break X;case 1:break Y;case 0:break Z;default:break u}}break p}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22692]=0;e=T(374,f|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){t[c+5|0]=e;v[22692]=0;Q(318,d+32|0,1)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break p}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;xb(d+32|0);break a}xb(d+32|0)}l=l+1|0;if(l>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Yc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));hB(a+1298292|0,b,Mg(b),4)}gb=d+272|0;return h|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(e)}S(b|0);L()}function Qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=gb-1344|0;gb=d;vc(b);f=gb-32|0;gb=f;l=d+768|0;oX(f+24|0,l);k=yb(f+24|0);h=v[f+28>>2];j=v[f+24>>2];v[f+8>>2]=j;v[f+12>>2]=h;v[f>>2]=j;v[f+4>>2]=h;h=b;cc(f+16|0,h,f);j=yb(f+16|0);if((j|0)==(k|0)){Rb(h,yb(f+24|0))}gb=f+32|0;h=(j|0)==(k|0);if(!h){nX(l)}a:{b:{c:{d:{if(!h){break d}if(!rX(d+768|0)){break d}if(!Pb(b,Qc(qX(d+768|0),jb))){break d}if(!c){e=1;break d}p=tr(d+760|0);r=1;e:{while(1){h=(e<<5)+a|0;f=h+480280|0;Ue(f);k=(d+768|0)+(e<<4)|0;u[h+480284>>1]=((w[k+78|0]<<8&65280)>>>0)/255;Ek(d+496|0,1,k- -64|0);Bc(d+112|0,d+496|0);v[22692]=0;Q(399,h+480289|0,d+112|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break c}vb(d+112|0);f:{g:{switch(w[k+79|0]){case 0:i=e+1|0;break f;case 1:v[f>>2]=1024;i=g+1|0;break f;case 2:break g;default:break e}}v[f>>2]=1024;tl(d+112|0,p,e);Af(d+112|0,1)}r=e>>>0<31;g=g+1|0;e=e+1|0;if((e|0)!=32){continue}break}Id(a,33554432);u[a+480188>>1]=i&255;e=Tb(d+112|0,3827);Eb(a+1298304|0,e);vb(e);e=Tb(d+112|0,8283);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;h:{if(w[d+847|0]){break h}g=1;while(1){if(w[((g<<4)+d|0)+847|0]!=1){break h}e=1;g=g+1|0;if((g|0)!=16){continue}break}while(1){i=((e<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}Ie(d+496|0,1,d+768|0);Bc(d+112|0,d+496|0);Eb(a+1298268|0,d+112|0);vb(d+112|0);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+806|0]|w[d+807|0]<<8)<<4&16;v[a+480196>>2]=w[d+816|0];v[a+480204>>2]=B(w[d+817|0],1e4);C=a,D=Gd(w[d+818|0],0,64)<<2,v[C+480200>>2]=D;C=a,D=Gd(w[d+819|0],4,127),v[C+480228>>2]=D;e=w[d+804|0]|w[d+805|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;dw(b,d+496|0);Qr(Sb(a+484360|0),d+496|0,w[d+800|0]|w[d+801|0]<<8,65535,255);s=c&1;if(s){xg(a+484344|0,w[d+802|0]|w[d+803|0]<<8)}if(w[d+802|0]|w[d+803|0]<<8){z=a+484344|0;while(1){e=Mg(b);n=Mg(b);ud(d+48|0,b,e-4|0);j=jc(d+112|0,d+48|0);xb(d+48|0);i:{if(!s){break i}v[22692]=0;e=W(331,z|0,m&65535,n|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){j:{if(!e){break i}o=0;k=_i(d+24|0);if(!n){break i}while(1){k:{v[22692]=0;g=T(374,j|0)|0;e=v[22692];v[22692]=0;l:{m:{if((e|0)!=1){if(g){break m}o=o+1|0;break l}break j}e=k;q=g&31;if(q>>>0<x[a+480188>>1]){e=_b(z,m);v[22692]=0;e=Wc(e,o,q);i=v[22692];v[22692]=0;if((i|0)==1){break j}}n:{if(!(g&32)){break n}v[22692]=0;R(403,d+48|0,j|0);h=v[22692];v[22692]=0;i=e;o:{p:{if((h|0)!=1){f=od(d+48|0);h=w[d+48|0];t[e|0]=h;t[e+1|0]=w[f|0];if((h|0)!=160){break p}h=255;break o}break j}if((h|0)!=255){t[e|0]=(B(h>>>4|0,12)+(h&15)|0)+13;v[22692]=0;f=PC(e);h=v[22692];v[22692]=0;if((h|0)!=1){h=0;if(!f){break o}break n}break j}h=0}t[i|0]=h}i=g&192;q:{if(!i){break q}if((i|0)==192){v[22692]=0;R(529,d+48|0,j|0);i=v[22692];v[22692]=0;r:{s:{t:{if((i|0)!=1){f=od(d+48|0);g=Te(d+48|0);i=bj(d+48|0);l=d+48|0;A=w[l|0];if((A|0)!=12){break t}v[22692]=0;t[d|0]=64;h=ac(f,d);f=v[22692];v[22692]=0;if((f|0)==1){break j}t[e+4|0]=w[h|0];h=1;break s}break j}h=w[g|0];u:{if((h|0)==12){v[22692]=0;t[d|0]=64;i=ac(i,d);g=v[22692];v[22692]=0;if((g|0)!=1){t[e+4|0]=w[i|0];h=1;break u}break j}if((A|0)==10){t[e+4|0]=(w[f|0]<<6>>>0)/255;h=2;break s}if((h|0)!=10){break r}t[e+4|0]=(w[i|0]<<6>>>0)/255;h=2}g=l;i=f}t[e+2|0]=h;h=w[g|0]}t[e+3|0]=h;t[e+5|0]=w[i|0];break q}v[22692]=0;R(403,d+48|0,j|0);i=v[22692];v[22692]=0;if((i|0)==1){break j}i=od(d+48|0);t[e+3|0]=w[d+48|0];t[e+5|0]=w[i|0]}if(w[e+3|0]){v[22692]=0;_(549,e|0);i=v[22692];v[22692]=0;if((i|0)==1){break j}}tl(d+48|0,p,q);if(!Cb(d+48|0)){break l}v[22692]=0;i=pX(e);g=v[22692];v[22692]=0;if((g|0)==1){break k}if(!i){break l}t[e+3|0]=0}if(o>>>0<n>>>0){continue}break i}break}}}e=P()|0;O()|0;xb(d+112|0);break b}xb(d+112|0);m=m+1|0;if(m>>>0<(w[d+802|0]|w[d+803|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break e}o=c&2;k=d- -64|0;i=1;h=0;while(1){h=h+1|0;n=h&65535;g=CO(a,n,0);e=gb-32|0;gb=e;l=d+112|0;bc(e+24|0,l,384);f=yb(e+24|0);c=v[e+28>>2];j=v[e+24>>2];v[e+8>>2]=j;v[e+12>>2]=c;v[e>>2]=j;v[e+4>>2]=c;c=b;cc(e+16|0,c,e);j=yb(e+16|0);if((j|0)==(f|0)){Rb(c,yb(e+24|0))}gb=e+32|0;c=(f|0)==(j|0);if(!c){Qb(l,0,384)}if(!(!c|!g)){l=i&65535;c=gb-32|0;gb=c;f=d+112|0;Ie(c,1,f);Bc(c+16|0,c);v[22692]=0;Q(301,g+492|0,c+16|0)|0;e=v[22692];v[22692]=0;v:{if((e|0)!=1){vb(c+16|0);w:{if(!(w[f+378|0]|w[f+379|0]<<8)){break w}v[c+16>>2]=120;v[c>>2]=116;if(!v[Fb(c+16|0,c)>>2]){break w}j=g+236|0;e=0;while(1){m=w[(e+f|0)+32|0];C=wd(j,e+12|0),D=l+m|0,u[C>>1]=D;v[c+16>>2]=120;v[c>>2]=116;e=e+1|0;if(e>>>0<y[Fb(c+16|0,c)>>2]){continue}break}}e=w[f+376|0]|w[f+377|0]<<8;t[g+33|0]=1;v[g>>2]=e;OC(f,g+48|0,0);OC(f,g+68|0,1);OC(f,g+88|0,2);e=w[g+100|0];if(e&1){t[g+100|0]=e|16}if(!(v[g>>2]|t[g+60|0]&1)){v[g>>2]=32767}gb=c+32|0;break v}break a}e=0;x:{if(!(w[d+490|0]|w[d+491|0]<<8)){break x}while(1){y:{ZX(b,d+48|0);z:{if((w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=808538953){break z}c=e+i|0;l=c&65535;if(l>>>0>3999){break z}u[a+480190>>1]=c;c=gb-32|0;gb=c;j=B(l,104)+a|0;m=j+484380|0;f=m;td(f,0);g=d+48|0;ii(c,1,g);Bc(c+16|0,c);v[22692]=0;Q(303,f+43|0,c+16|0)|0;p=v[22692];v[22692]=0;A:{if((p|0)!=1){vb(c+16|0);v[f>>2]=w[g+16|0]|w[g+17|0]<<8|(w[g+18|0]<<16|w[g+19|0]<<24);v[f+4>>2]=w[g+20|0]|w[g+21|0]<<8|(w[g+22|0]<<16|w[g+23|0]<<24);v[f+8>>2]=w[g+24|0]|w[g+25|0]<<8|(w[g+26|0]<<16|w[g+27|0]<<24);v[f+24>>2]=w[g+28|0]|w[g+29|0]<<8|(w[g+30|0]<<16|w[g+31|0]<<24);u[f+30>>1]=w[g+32|0]<<2;u[f+28>>1]=w[g+33|0];if(t[g+48|0]&1){u[f+34>>1]=x[f+34>>1]|2}if(w[g+48|0]&2){u[f+34>>1]=x[f+34>>1]|4}if(w[g+48|0]&4){u[f+34>>1]=x[f+34>>1]|1;v[f>>2]=v[f>>2]>>>1;v[f+4>>2]=v[f+4>>2]>>>1;v[f+8>>2]=v[f+8>>2]>>>1}if(w[g+48|0]&8){u[f+34>>1]=x[f+34>>1]|32}gb=c+32|0;break A}break a}c=gb-16|0;gb=c;PE(c+8|0,j+484423|0);Wr(d+24|0,c+8|0);gb=c+16|0;v[22692]=0;Q(301,((l<<5)+a|0)+946304|0,d+24|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break y}vb(d+24|0);if(!(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))){break z}ud(d,b,w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24));c=jc(d+24|0,d);xb(d);B:{if(!o){break B}g=Rc(d,u[j+484414>>1]&1?16:8,1,0,0);v[22692]=0;W(329,g|0,m|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break B}e=P()|0;O()|0;xb(d+24|0);break b}xb(d+24|0)}e=e+1|0;if(e>>>0<(w[d+490|0]|w[d+491|0]<<8)>>>0){continue}break x}break}e=P()|0;O()|0;vb(d+24|0);break b}i=(w[d+490|0]|w[d+491|0]<<8)+i|0}if(n>>>0<x[a+480192>>1]){continue}break}}e=!r}gb=d+1344|0;return e&1}e=P()|0;O()|0;vb(d+112|0)}S(e|0);L()}a=P()|0;O()|0;vb(c+16|0);S(a|0);L()}function lu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-32|0;gb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}l=v[b+104>>2];i=v[b+656>>2];if(!(!i|v[a+480180>>2]!=16777216)){n=v[i+44>>2]!=0}b:{if(!(!i|(c|0)>128)){k=x[wd(i+236|0,c-1|0)>>1];c:{if((k-1&65535)>>>0<=3998){l=(B(k,104)+a|0)+484380|0;break c}Db(h+16|0,a+1074312|0,43);if(!Cb(h+16|0)){break c}if(!nk(b)){break a}}k=w[lc(i+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=k;break b}k=c}if((k|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(k|0)!=255:0)){vo(a,b);if(d){break d}Db(h+16|0,a+1074312|0,100);if(!Cb(h+16|0)|!(w[a+480208|0]&4)|!w[b+789|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}Db(h+16|0,a+1074312|0,50);if(Cb(h+16|0)){break g}}v[b+688>>2]=0}Db(h+16|0,a+1074312|0,50);if(Cb(h+16|0)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Db(h+16|0,a+1074312|0,20);if(!Cb(h+16|0)){break a}t[b+797|0]=0;t[b+802|0]=0;break a}h:{i:{j:{if(n){if(d){j=w[b+797|0];if(j){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!l)){u[b+770>>1]=t[l+36|0];u[b+772>>1]=t[l+37|0]}if(l){Db(h+16|0,a+1074312|0,24);k=0;m=1;if(!Cb(h+16|0)){break h}v[b+704>>2]=v[l+24>>2];break h}k=0;break h}m=v[i+44>>2];u[h>>1]=j;u[h+14>>1]=k;v[h+16>>2]=0;k=(v[h+16>>2]+B(u[m+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+852>>2]|0;v[b+708>>2]=k;v[b+852>>2]=0-k}m=(l|0)!=0;k=1;if(Mi(b)){break h}k=a+1074312|0;Db(h+16|0,k,54);if(Cb(h+16|0)){v[b+700>>2]=0;break a}Db(h+16|0,k,39);k=(Cb(h+16|0)^-1)&d}k:{if(bp(a)){v[h+28>>2]=v[h+28>>2]+u[b+770>>1];Sd(h+28|0,12,131);break k}eV(h+28|0)}j=a+1074312|0;Db(h+16|0,j,34);d=b;l:{if(Cb(h+16|0)){c=hn(c);break l}c=v[h+28>>2]}t[d+797|0]=c;t[b+851|0]=w[b+851|0]&219|32;if(!(v[a+480180>>2]&16777250?0:k)){t[b+803|0]=0}d=Zg(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;Db(h+16|0,j,48);if(Cb(h+16|0)){AP(a,b,i,l)}m:{if(e^1|k){break m}v[b+776>>2]=0;v[b+780>>2]=0;if(!i){break m}Db(h+16|0,j,29);if(Cb(h+16|0)){t[b+798|0]=w[i+16|0]}if(!(w[i+60|0]&8)){Cj(b+724|0)}if(!(w[i+80|0]&8)){Cj(b+732|0)}if(!(w[i+100|0]&8)){Cj(b+740|0)}if(w[i+20|0]){c=ju(uo(a));o=w[i+20|0];Db(h+16|0,j,28);p=((B(c,o)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(h+16|0)){o=v[b+752>>2];break n}o=(v[b+688>>2]+1|0)/2|0}u[c+776>>1]=(B(o,p)|0)/199}o:{if(!w[i+19|0]){break o}q=b,r=(B(ju(uo(a)),w[i+19|0])<<16>>16)/32|0,u[q+778>>1]=r;Db(h+16|0,j,28);if(Cb(h+16|0)|x[b+784>>1]){break o}u[b+784>>1]=x[b+692>>1]+1}c=w[i+23|0];if(c){o=ju(uo(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[i+24|0];if(!c){break m}o=ju(uo(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!d){break q}r:{s:{t:{if(k){u:{if(!v[b+700>>2]){v[b+700>>2]=d;if(!n){break u}break t}if(n){break t}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&247;break t}v[b+700>>2]=d;if(n){break s}Db(h+16|0,j,69);if(Cb(h+16|0)){break s}Db(h,j,46);if(Cb(h)|v[a+480180>>2]==1){break s}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&247;break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=l;c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Db(h+16|0,j,96);if(!Cb(h+16|0)){break w}}if(w[b+789|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Fb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}c=x[l+34>>1];d=c&1023;n=d|v[b+88>>2]&-525056;v[b+88>>2]=n;x:{y:{if(c&8){v[b+80>>2]=v[l+12>>2];c=v[l+16>>2];v[b+88>>2]=(d&16?n|4:n&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break y}break x}if(!(d&2)){break x}v[b+80>>2]=v[l+4>>2];c=v[l+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break x}}v[b+76>>2]=c}Db(h+16|0,j,83);if(!(!Cb(h+16|0)|v[b+80>>2])){c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}z:{if(w[b+822|0]>3){break z}Db(h+16|0,j,21);c=b;A:{if(!(Cb(h+16|0)|!(v[a+480180>>2]&16777248))){d=16;if(!(v[a+480208>>2]&4)){break A}}d=32;if(v[a+480180>>2]==16){break A}if(v[a+480180>>2]&67633152){break z}d=0}t[c+819|0]=d}Db(h+16|0,j,21);if(Cb(h+16|0)|w[b+825|0]>3){break r}t[b+820|0]=0}d=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=d;d=v[b+80>>2];v[b>>2]=c;v[b+4>>2]=d}if(!k){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}if(!(w[a+480208|0]&8)|!w[b+789|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Gm(b);Db(h+16|0,j,21);if(!Cb(h+16|0)){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(w[b+789|0]|(!m|!(w[a+480208|0]&8)))){m=1;break p}if(w[b+789|0]?0:v[a+480180>>2]&1048580){break p}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}Db(h+16|0,j,40);B:{C:{D:{E:{if(Cb(h+16|0)){if(m){if(w[b+789|0]?w[a+480208|0]&8:0){break D}v[b+88>>2]=v[b+88>>2]&-4194305;break C}c=v[b+88>>2]&-4196353;break E}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;l=1;if(m){break B}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Db(h+16|0,j,23);F:{if(Cb(h+16|0)){break F}Db(h,j,22);if(Cb(h)){break F}Db(h+16|0,j,52);if(Cb(h+16|0)){break F}Db(h,j,71);if(Cb(h)){break F}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;G:{if(i){H:{I:{if(!RE(i)){if(lw(i)){break I}c=!(c>>>13|0);if(c){break H}break G}q=b,r=SE(i),t[q+838|0]=r;if(!lw(i)){break H}}q=b,r=TE(i),t[q+837|0]=r}c=1;d=w[i+25|0];if((d|0)==255){break G}t[b+845|0]=d;break G}v[b+776>>2]=0;v[b+780>>2]=0;c=!c}J:{if(w[b+837|0]>=127){Db(h+16|0,j,36);if(!Cb(h+16|0)){break J}}if(!c){break J}if((Eq(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break J}c=a+1298260|0;if(!Dd(c)|(g|0)==65535){break J}Mq(v[c>>2],g,w[b+837|0]>>>1|0,1)}l=0;if(!(w[b+89|0]&2)){break B}c=a+1298260|0;if(!Dd(c)|(g|0)==65535){break B}Db(h+16|0,j,111);if(Cb(h+16|0)){pk(v[c>>2],g);break B}Db(h+16|0,j,110);if(!Cb(h+16|0)){break B}PA(v[c>>2],g,0,1,0);break B}v[b+88>>2]=v[b+88>>2]&-4196353}l=1}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}K:{L:{if(w[a+24618|0]&16?c&1024:0){break L}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break L}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break K}}if(f){break K}v[b+700>>2]=0}if(l){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}gb=h+32|0}function M2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2491;p=he(l+136|0,l+144|0,l+104|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Kb(l+104|0);m=Kb(l+88|0);n=Kb(l+72|0);o=Kb(l+56|0);r=Kb(l+40|0);v[22692]=0;na(2494,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,m|0,n|0,o|0,l+36|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;q=v[l+36>>2];k=0;e=0;f:{while(1){v[22692]=0;c=Q(2442,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}g:{if(!c){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(kh(h,8192,c)){v[22692]=0;R(2495,l+24|0,a|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=t[l+24|0];v[22692]=0;R(61,r|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break h}}if((e|0)==3){break g}}while(1){v[22692]=0;c=Q(2442,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!c){break h}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!kh(h,8192,c)){break h}v[22692]=0;R(2495,l+24|0,a|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=t[l+24|0];v[22692]=0;R(61,r|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}q:{if(Ab(n)){if(Ab(o)){break q}}if(Ab(n)){v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(w[nc(n,0)|0]!=(c&255)){break k}v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(w[nc(o,0)|0]!=(c&255)){break h}v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(w[nc(n,0)|0]==(c&255)){v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(w[nc(o,0)|0]==(c&255)){v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|k|((e|0)==2&w[l+123|0]!=0|z))){k=0;break h}A=l,B=zd(m),v[A+16>>2]=B;c=Hd(l+24|0,l+16|0);r:{if(!e|w[(e+l|0)+119|0]>1){break r}A=l,B=ef(m),v[A+16>>2]=B;s:{if(!Gb(c,l+16|0)){break s}while(1){if(!kh(h,8192,t[v[c>>2]])){break s}Ne(c);A=l,B=ef(m),v[A+16>>2]=B;if(Gb(c,l+16|0)){continue}break}}A=l,B=zd(m),v[A+16>>2]=B;c=Yj(c,l+16|0);if(Ab(r)>>>0>=c>>>0){A=l,B=ef(r),v[A+16>>2]=B;d=ve(l+16|0,0-c|0);s=ef(r);x=zd(m);c=gb-32|0;gb=c;v[c+16>>2]=s;v[c+24>>2]=d;v[c+8>>2]=x;d=1;t:{if(!Gb(c+24|0,c+16|0)){break t}while(1){d=w[v[c+24>>2]]==w[v[c+8>>2]];if(!d){break t}Ne(c+24|0);Ne(c+8|0);if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;if(d){break r}}A=l,B=zd(m),v[A+8>>2]=B;Hd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];A=l,B=ef(m),v[A+8>>2]=B;u:{v:{w:{if(!Gb(l+16|0,l+8|0)){break w}while(1){v[22692]=0;c=Q(2442,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break v}if(!c){break w}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break v}if(w[v[l+16>>2]]!=(c&255)){break w}v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break u}Ne(l+16|0);A=l,B=ef(m),v[A+8>>2]=B;if(Gb(l+16|0,l+8|0)){continue}break}}if(!y){break h}A=l,B=ef(m),v[A+8>>2]=B;if(!Gb(l+16|0,l+8|0)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+36>>2]=q;break a}a=P()|0;O()|0;v[l+36>>2]=q;break a}c=0;x=w[l+118|0];d=b;x:{while(1){y:{v[22692]=0;b=Q(2442,a|0,l+552|0)|0;s=v[22692];v[22692]=0;if((s|0)==1){break y}if(!b){break x}v[22692]=0;s=T(2444,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}z:{if(kh(h,2048,s)){b=v[j>>2];if((b|0)==v[l+548>>2]){v[22692]=0;U(2496,i|0,j|0,l+548|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}b=v[j>>2]}v[j>>2]=b+1;t[b|0]=s;c=c+1|0;break z}if(!Ab(u)|!c|(x|0)!=(s&255)){break x}if(v[l+128>>2]==(d|0)){v[22692]=0;U(2497,p|0,l+132|0,l+128|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;d=b;c=0}v[22692]=0;T(2446,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!c|v[p>>2]==(d|0)){break j}if(v[l+128>>2]==(d|0)){v[22692]=0;U(2497,p|0,l+132|0,l+128|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;break i}t[g|0]=1;break h}b=d}A:{if((q|0)<1){break A}v[22692]=0;c=Q(2443,a|0,l+552|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}B:{if(!c){v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if(w[l+119|0]==(c&255)){break B}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}while(1){if((q|0)<1){q=0;break A}v[22692]=0;c=Q(2443,a|0,l+552|0)|0;d=v[22692];v[22692]=0;C:{if((d|0)==1){break C}D:{if(!c){v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break C}if(kh(h,2048,c)){break D}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22692]=0;U(2496,i|0,j|0,l+548|0);c=v[22692];v[22692]=0;if((c|0)==1){break C}}v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break C}d=v[j>>2];v[j>>2]=d+1;t[d|0]=c;v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;q=q-1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;if((e|0)!=4){continue}}break}v[l+36>>2]=q;E:{if(!k){break E}e=1;while(1){if(Ab(k)>>>0<=e>>>0){break E}v[22692]=0;c=Q(2443,a|0,l+552|0)|0;d=v[22692];v[22692]=0;F:{if((d|0)==1){break F}G:{if(!c){v[22692]=0;c=T(2444,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break F}if(w[nc(k,e)|0]==(c&255)){break G}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22692]=0;T(2446,a|0)|0;c=v[22692];v[22692]=0;e=e+1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[p>>2]==(b|0)){break f}a=0;v[l+24>>2]=0;gf(u,v[p>>2],b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}vb(r);vb(o);vb(n);vb(m);vb(u);Hc(p);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(r);vb(o);vb(n);vb(m);vb(u);Hc(p);S(a|0);L()}
function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-240|0;gb=e;vc(c);l=Fh(e+216|0,c);v[22692]=0;c=Q(1136,l|0,e+200|0)|0;f=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((f|0)!=1){if(!c|v[e+200>>2]!=1297239878|((w[e+208|0]|w[e+209|0]<<8|(w[e+210|0]<<16|w[e+211|0]<<24))!=1128679745?v[e+208>>2]!=1179011393:0)){break a}v[22692]=0;R(1137,e+184|0,l|0);c=v[22692];v[22692]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22692]=0;U(1138,e+160|0,e+184|0,1129270605);c=v[22692];v[22692]=0;if((c|0)==1){break p}v[22692]=0;c=Q(1139,e+160|0,e+136|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break l}if(!c){break b}h=e+136|2;if(!Yb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))){break b}if(!Ib(w[e+136|0]|w[e+137|0]<<8)){break b}if(Ib(w[e+136|0]|w[e+137|0]<<8)>>>0>2){break b}f=e+136|6;if(!Ib(w[f|0]|w[f+1|0]<<8)){break b}if(Ib(w[f|0]|w[f+1|0]<<8)>>>0>64){break b}v[e+132>>2]=1162760014;c=1;if((w[e+208|0]|w[e+209|0]<<8|(w[e+210|0]<<16|w[e+211|0]<<24))==1128679745){v[22692]=0;c=Q(790,e+160|0,e+132|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break k}if(!c){break b}c=v[e+132>>2]!=1936684916}v[22692]=0;U(1138,e+112|0,e+184|0,1397968452);g=v[22692];v[22692]=0;if((g|0)==1){break o}v[22692]=0;g=Q(1140,e+112|0,e+104|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break m}if(g){break n}break c}g=P()|0;O()|0;break d}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}i=((Ib(w[f|0]|w[f+1|0]<<8)-1|0)/8|0)-1|0;j=i<<3;f=j&31;f=Rc(e+96|0,(i>>>0<7?(j&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255,(Ib(w[e+136|0]|w[e+137|0]<<8)|0)==2?2:1,c,0);q:{c=v[e+132>>2];if((c|0)<=875981925){if((c|0)<=842230885){if((c|0)==544694642){break q}if((c|0)==842222662){break i}break h}if((c|0)==842230886){break i}if((c|0)!=875973702){break h}break i}if((c|0)<=1463897172){if((c|0)==875981926){break i}if((c|0)!=1463897153){break h}break j}if((c|0)!=1463897173){if((c|0)==2002873441){break j}if((c|0)!=2002873461){break h}}zf(f,17);Xi(f,16);break h}zf(f,1);break h}g=P()|0;O()|0;break g}g=P()|0;O()|0;break f}g=P()|0;O()|0;break d}g=P()|0;O()|0;break f}zf(f,18);Xi(f,16);break h}zf(f,3)}if(d){VQ(f)}c=Yb(w[e+104|0]|w[e+105|0]<<8|(w[e+106|0]<<16|w[e+107|0]<<24));v[22692]=0;c=Q(189,e+112|0,c|0)|0;d=v[22692];v[22692]=0;r:{if((d|0)==1){break r}if(c){c=Yb(w[e+104|0]|w[e+105|0]<<8|(w[e+106|0]<<16|w[e+107|0]<<24));v[22692]=0;Q(318,e+112|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break r}}v[22692]=0;Q(1127,a|0,b|0)|0;c=v[22692];v[22692]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)==1){break B}v[22692]=0;i=(B(b,104)+a|0)+484380|0;R(424,i|0,0);c=v[22692];v[22692]=0;if((c|0)==1){break B}n=i,o=Yb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),v[n>>2]=o;d=e+136|0;c=w[d+13|0]|(w[d+11|0]<<16|w[d+10|0]<<24|w[d+12|0]<<8);h=30-w[d+9|0]|0;C:{if(!(h&255)){d=0;break C}while(1){d=c;c=c>>>1|0;h=h-1|0;if(h&255){continue}break}}v[(B(b,104)+a|0)+484404>>2]=(d&1)+c;v[22692]=0;W(329,f|0,i|0,e+112|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break B}v[22692]=0;U(1138,e+72|0,e+184|0,1296126539);c=v[22692];v[22692]=0;if((c|0)==1){break A}v[22692]=0;c=T(275,e+72|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break z}if(!c){break t}v[22692]=0;U(1138,e+24|0,e+184|0,1229869908);c=v[22692];v[22692]=0;if((c|0)==1){break y}v[22692]=0;c=Q(1141,e+24|0,e+48|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break x}xb(e+24|0);if(!c){break t}v[22692]=0;f=T(416,e+72|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break w}d=cd(e+24|0);v[22692]=0;R(1142,d|0,f|0);c=v[22692];v[22692]=0;if((c|0)!=1){D:{if(!f){break D}h=e|6;c=0;while(1){v[22692]=0;j=Q(1143,e+72|0,e|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break v}if(!j){break D}v[22692]=0;R(1144,d|0,e|0);j=v[22692];v[22692]=0;if((j|0)==1){break v}j=w[h|0];k=w[h|0];v[22692]=0;Q(318,e+72|0,j+((k^-1)&1)|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break v}c=c+1|0;if((f|0)!=(c|0)){continue}break}}if(Ib(w[e+56|0]|w[e+57|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|8;f=Ib(w[e+56|0]|w[e+57|0]<<8);u[c>>1]=x[c>>1]&65519|((f|0)==2)<<4}if(Ib(w[e+62|0]|w[e+63|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2;f=Ib(w[e+62|0]|w[e+63|0]<<8);u[c>>1]=x[c>>1]&65531|((f|0)==2)<<2}n=e,o=Vb(d),v[n>>2]=o;n=e,o=Zb(d),v[n+16>>2]=o;if(Gb(e,e+16|0)){c=B(b,104)+a|0;h=c+484388|0;j=c+484384|0;k=c+484396|0;m=c+484392|0;f=e- -64|0;while(1){c=v[e>>2];if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+58|0]|w[e+59|0]<<8)|0)){n=m,o=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[n>>2]=o}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+60|0]|w[e+61|0]<<8)|0)){n=k,o=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[n>>2]=o}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[f|0]|w[f+1|0]<<8)|0)){n=j,o=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[n>>2]=o}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+66|0]|w[e+67|0]<<8)|0)){n=h,o=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[n>>2]=o}v[e>>2]=v[e>>2]+7;if(Gb(e,e+16|0)){continue}break}}v[22692]=0;rk(i);c=v[22692];v[22692]=0;if((c|0)!=1){break u}}break v}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;xb(e+24|0);break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;QQ(d);break s}QQ(d)}v[22692]=0;U(1138,e+24|0,e+184|0,1312902469);c=v[22692];v[22692]=0;E:{F:{if((c|0)!=1){v[22692]=0;c=T(275,e+24|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break F}G:{H:{I:{J:{if(c){v[22692]=0;c=T(193,e+24|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break F}v[22692]=0;W(472,e+24|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break J}break F}v[22692]=0;c=Q(70,e|0,18699)|0;d=v[22692];v[22692]=0;if((d|0)==1){break I}v[22692]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break H}vb(c)}b=v[a+480180>>2];v[22692]=0;U(1129,i|0,32,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break G}v[22692]=0;_h(i,a,0);a=v[22692];v[22692]=0;if((a|0)==1){break F}xb(e+24|0);xb(e+72|0);break c}g=P()|0;O()|0;break E}g=P()|0;O()|0;vb(c);break E}g=P()|0;O()|0;break E}g=P()|0;O()|0;break s}g=P()|0;O()|0}xb(e+24|0)}xb(e+72|0);break g}g=P()|0;O()|0}xb(e+112|0)}xb(e+160|0)}Ed(e+184|0)}xb(l);S(g|0);L()}xb(e+112|0)}xb(e+160|0);Ed(e+184|0)}xb(l);gb=e+240|0;return g|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}h=z[a+4268>>2];XL(a);if(h==z[a+4268>>2]){break a}Ly(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!ki(p)){break b}q=Od(p,0);x=Od(p,1);m=md(p,0);n=md(p,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}X=a+4960|0;G=a+4648|0;H=a+4672|0;T=a+4936|0;I=a+4696|0;J=a+4720|0;K=a+4744|0;L=a+4768|0;U=a+4840|0;E=a+4504|0;M=a+4528|0;V=a+4912|0;N=a+4552|0;O=a+4576|0;P=a+4600|0;Q=a+4624|0;W=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){h=z[q>>2];h=C(C(C(z[a+5008>>2]-h)*z[a+4276>>2])+h);z[a+5008>>2]=h;_=Cc(u,v[a+4880>>2]),$=h,z[_>>2]=$;h=z[x>>2];h=C(C(C(z[a+5012>>2]-h)*z[a+4276>>2])+h);z[a+5012>>2]=h;_=Cc(s,v[a+4904>>2]),$=h,z[_>>2]=$;h=Th(u,v[a+4356>>2]);f=Th(u,v[a+4360>>2]);e=Th(u,v[a+4364>>2]);g=Th(u,v[a+4368>>2]);h=C(C(C(h*C(.6800000071525574))+C(C(e+Th(u,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=h;h=C(z[Cc(W,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));_=Cc(W,v[a+4832>>2]),$=C(f-C(h*C(.6180340051651001))),z[_>>2]=$}R=z[a+4280>>2];_=a,$=C(Th(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;f=C(Th(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Cc(Q,v[a+4644>>2])>>2];y=z[a+4444>>2];g=C(z[Cc(Q,v[a+4644>>2])>>2]+C(y*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];j=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(j+l);f=C(C(i*e)+C(z[a+4440>>2]*g));_=Cc(Q,v[a+4640>>2]),$=C(e-C(i*f)),z[_>>2]=$;e=z[a+4976>>2];g=z[Cc(P,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Cc(P,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));_=Cc(P,v[a+4616>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Cc(O,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Cc(O,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));_=Cc(O,v[a+4592>>2]),$=C(e-C(g*f)),z[_>>2]=$;e=z[a+4968>>2];g=z[Cc(N,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Cc(N,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));_=Cc(N,v[a+4568>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(C(f*C(.3499999940395355))+y)+C(e*C(-.3799999952316284)))}_=Cc(V,v[a+4928>>2]),$=e,z[_>>2]=$;k=Cc(V,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Cc(M,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Cc(M,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));_=Cc(M,v[a+4544>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4960>>2];e=z[Cc(E,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Cc(E,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];A=C(C(e*g)+C(z[a+4400>>2]*f));_=Cc(E,v[a+4520>>2]),$=C(g-C(e*A)),z[_>>2]=$;z[a+5020>>2]=A;f=Th(s,v[a+4380>>2]);e=Th(s,v[a+4384>>2]);i=Th(s,v[a+4388>>2]);S=Th(s,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+Th(s,v[a+4396>>2]))*C(-.5)))+C(C(S+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Cc(U,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Cc(U,v[a+4856>>2]),$=C(e-C(f*C(.6180340051651001))),z[_>>2]=$}S=z[a+4280>>2];e=z[a+5004>>2];i=z[Cc(L,v[a+4788>>2])>>2];F=z[a+4492>>2];e=C(z[Cc(L,v[a+4788>>2])>>2]+C(F*C(e-i)));z[a+5004>>2]=e;F=z[a+4272>>2];j=C(j-l);i=C(C(F*j)+C(z[a+4488>>2]*e));_=Cc(L,v[a+4784>>2]),$=C(j-C(F*i)),z[_>>2]=$;e=z[a+5e3>>2];j=z[Cc(K,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Cc(K,v[a+4764>>2])>>2]+C(l*C(e-j)));z[a+5e3>>2]=e;j=z[a+4272>>2];e=C(C(j*i)+C(z[a+4480>>2]*e));_=Cc(K,v[a+4760>>2]),$=C(i-C(j*e)),z[_>>2]=$;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];j=z[Cc(J,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Cc(J,v[a+4740>>2])>>2]+C(l*C(g-j)));z[a+4996>>2]=g;j=z[a+4272>>2];g=C(C(j*e)+C(z[a+4472>>2]*g));_=Cc(J,v[a+4736>>2]),$=C(e-C(j*g)),z[_>>2]=$;e=z[a+4992>>2];j=z[Cc(I,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Cc(I,v[a+4716>>2])>>2]+C(l*C(e-j)));z[a+4992>>2]=e;j=z[a+4272>>2];e=C(C(j*g)+C(z[a+4464>>2]*e));_=Cc(I,v[a+4712>>2]),$=C(g-C(j*e)),z[_>>2]=$;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}Y=x+4|0;Z=q+4|0;g=C(R*h);R=C(S*f);_=Cc(T,v[a+4952>>2]),$=e,z[_>>2]=$;k=Cc(T,v[a+4956>>2]);h=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-h)*z[a+4500>>2])+h;h=z[a+4988>>2];f=z[Cc(H,v[a+4692>>2])>>2];e=z[a+4460>>2];h=C(z[Cc(H,v[a+4692>>2])>>2]+C(e*C(h-f)));z[a+4988>>2]=h;f=z[a+4272>>2];e=z[a+5032>>2];h=C(C(z[a+4456>>2]*h)+C(f*e));_=Cc(H,v[a+4688>>2]),$=C(e-C(f*h)),z[_>>2]=$;e=z[a+4284>>2];f=z[a+4984>>2];j=z[Cc(G,v[a+4668>>2])>>2];l=z[a+4452>>2];f=C(z[Cc(G,v[a+4668>>2])>>2]+C(l*C(f-j)));z[a+4984>>2]=f;j=z[a+4272>>2];f=C(C(j*h)+C(z[a+4448>>2]*f));_=Cc(G,v[a+4664>>2]),$=C(h-C(j*f)),z[_>>2]=$;z[a+5024>>2]=f;h=C(C(h-A)*C(.3799999952316284));A=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((X|0)!=(k|0)){continue}break}h=C(C(C(h+y)*e)+g);f=C(C(A*C(i+C(f*C(-.3799999952316284))))+R);e:{f:{if(w[a+4264|0]&2){q=Z;k=Y;break f}z[m>>2]=C(z[a+5036>>2]+h)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=h;if((r|0)==1){break e}r=r-1|0;q=q+8|0;n=n+4|0;m=m+4|0;k=x+8|0}x=k;z[m>>2]=h;z[n>>2]=f;n=n+4|0;m=m+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}Ei(a,b,c,md(p,0),md(p,1),d)}}function uoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=gb-208|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!Hh(b,11087)){break h}if(d){t[d|0]=1}j=a+1074312|0;qv(j);n=a+480216|0;o=a+480224|0;k=a+1074368|0;p=a+480200|0;l=a+480248|0;i:{if(!Pb(b,7)){break i}s=a+480220|0;z=a+480228|0;A=a+480232|0;C=a+484360|0;m=a+480268|0;D=a+1298280|0;while(1){d=qg(b);e=Mg(b);if((d|0)==(w[18675]|w[18676]<<8|(w[18677]<<16|w[18678]<<24))){ng(b,6);break i}if(!(d&1616928864)|d&-2139062144){break i}if(!Pb(b,e)){break i}ud(f+24|0,b,e);g=jc(f+184|0,f+24|0);xb(f+24|0);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break A}if((d|0)!=1129797166){break j}v[22692]=0;v[f+24>>2]=0;U(604,g|0,e|0,f+24|0);d=v[22692];v[22692]=0;if((d|0)==1){break x}v[a+1074304>>2]=v[f+24>>2];break j}if((d|0)==1130917459){break s}if((d|0)!=1145525806){break j}v[22692]=0;U(604,g|0,e|0,p|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}break j}if((d|0)<=1213486400){if((d|0)==1146367534){break C}if((d|0)!=1196316499|e>>>0<3){break j}v[22692]=0;R(605,f+8|0,f+184|0);d=v[22692];v[22692]=0;if((d|0)==1){break q}v[22692]=0;R(606,f+168|0,f+8|0);d=v[22692];v[22692]=0;if((d|0)==1){break p}v[22692]=0;d=W(100,f+24|0,f+168|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break o}vb(f+168|0);gc(f+8|0);v[22692]=0;e=T(193,f+184|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break m}v[22692]=0;U(607,f+24|0,l|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break m}uf(d);break j}if((d|0)==1213486401){break t}if((d|0)==1280530262){break w}if((d|0)!=1297303086){break j}qv(j);d=0;break l}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break y}if((d|0)!=1347244882){break j}v[22692]=0;U(608,g|0,e|0,m|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}if(rp(w[m|0])){break j}t[m|0]=5;break j}if((d|0)==1380340804){break B}if((d|0)==1380986414){break u}if((d|0)!=1380991534){break j}v[22692]=0;U(604,g|0,e|0,n|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}break j}if((d|0)<=1397768493){if((d|0)==1380994350){break k}if((d|0)!=1397052739|e>>>0<3){break j}v[22692]=0;d=T(287,g|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break j}e=B(d,104)+a|0;d=e+484448|0;e=e+484484|0;while(1){v[22692]=0;h=T(190,g|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break r}v[d>>2]=h;d=d+4|0;if((e|0)!=(d|0)){continue}break}break j}if((d|0)==1397768494){break v}if((d|0)==1414344238){break z}if((d|0)!=1448301654){break j}v[22692]=0;U(604,g|0,e|0,A|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}break j}v[22692]=0;U(604,g|0,e|0,f+24|0);d=v[22692];v[22692]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[22692]=0;U(604,g|0,e|0,f+24|0);d=v[22692];v[22692]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break j}e=P()|0;O()|0;break a}if(c){break j}v[22692]=0;u[f+24>>1]=0;U(609,g|0,e|0,f+24|0);d=v[22692];v[22692]=0;if((d|0)!=1){E=a,F=Gd(x[f+24>>1],x[a+480188>>1],127),u[E+480188>>1]=F;break j}e=P()|0;O()|0;break a}v[22692]=0;U(610,g|0,e|0,o|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}break j}v[22692]=0;U(611,g|0,e|0,k|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}break j}e=P()|0;O()|0;break a}v[22692]=0;v[f+24>>2]=0;U(604,g|0,e|0,f+24|0);d=v[22692];v[22692]=0;if((d|0)==1){break f}d=v[f+24>>2];if(!d){break j}v[a+1074308>>2]=d;break j}v[22692]=0;U(604,g|0,e|0,z|0);d=v[22692];v[22692]=0;if((d|0)!=1){break j}break b}if(v[a+480180>>2]==4){break j}v[22692]=0;U(609,g|0,e|0,f+24|0);d=v[22692];v[22692]=0;if((d|0)!=1){bf(Sb(C),x[f+24>>1]);break j}e=P()|0;O()|0;break a}d=Kb(f+24|0);v[22692]=0;e=T(193,f+184|0)|0;h=v[22692];v[22692]=0;D:{if((h|0)==1){break D}v[22692]=0;W(612,g|0,d|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break D}v[22692]=0;U(13,f+168|0,0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break D}Eb(D,f+168|0);vb(f+168|0);vb(d);break j}e=P()|0;O()|0;vb(d);break a}if(e&1|e>>>0>126){break j}u[f+24>>1]=(e>>>1|0)- -64;v[22692]=0;u[f+168>>1]=127;d=Pc(f+24|0,f+168|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}q=x[d>>1];if(q>>>0<65){break j}e=64;while(1){v[22692]=0;R(403,f+24|0,g|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}d=od(f+24|0);h=f+24|0;E:{if(w[h|0]==255){break E}i=w[d|0];d=(e<<5)+a|0;r=d+480284|0;u[r>>1]=128;u[d+480286>>1]=i;i=d+480280|0;v[i>>2]=0;v[i>>2]=(w[h|0]&128)<<3;d=w[h|0]&127;t[h|0]=d;if(d>>>0<65){u[r>>1]=d<<2;d=w[h|0]}if((d|0)!=100){break E}v[i>>2]=v[i>>2]|256}e=e+1|0;if((q|0)!=(e|0)){continue}break}break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break n}e=P()|0;O()|0;vb(f+168|0)}gc(f+8|0);break a}e=P()|0;O()|0;uf(d);break a}F:{G:{H:while(1){v[22692]=0;e=Q(189,f+184|0,1)|0;h=v[22692];v[22692]=0;if((h|0)==1){break G}if(!(e&d>>>0<114)){break j}v[22692]=0;h=T(374,g|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break F}e=0;while(1){I:{if(!(!(h>>>e&1)|d>>>0>113)){v[22692]=0;W(409,j|0,d|0,1)|0;i=v[22692];v[22692]=0;if((i|0)==1){break I}}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}continue H}break}break}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}v[22692]=0;U(604,g|0,e|0,s|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}}xb(f+184|0);if(Pb(b,7)){continue}break}}Ap(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(w[a+480224|0]>=3){t[o|0]=0}if(w[k|0]>=6){t[k|0]=0}tc(p,256);if(bd(l)){break h}KC(l,v[n>>2],16777216)}gb=f+208|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0}xb(f+184|0);S(e|0);L()}function xo(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;h=gb-16|0;gb=h;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;s=v[b+752>>2];i=w[b+802|0];a:{if(!i){Db(h+8|0,a+1074312|0,11);if(Cb(h+8|0)){break a}}b:{c:{if(!g){break c}if(!ue(i)){break c}d:{k=g+236|0;i=i-1|0;if(x[wd(k,i)>>1]){break d}Db(h+8|0,a+1074312|0,43);if(!Cb(h+8|0)){break d}if(Ej(g)){break d}v[b+656>>2]=g;break a}if(w[lc(g+108|0,i)|0]>120){break a}k=x[wd(k,i)>>1];k=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(i>>>0>250){break a}Db(h+8|0,a+1074312|0,43);if(Cb(h+8|0)){if(g){k=0;if(Ej(g)){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}k=0}i=v[b+104>>2];o=(i|0)!=0&(i|0)!=(k|0);j=v[b+656>>2];q=!g|v[a+480180>>2]!=16777216?q:v[g+44>>2]!=0;p=d^1;l=(g|0)!=(j|0);if((p|l|o)==1){u[b+774>>1]=0}r=!o;if(!(r?1:!(d&q)|v[b+656>>2]!=(g|0))){break a}e:{if(p|r){break e}i=a+1074312|0;Db(h+8|0,i,32);if(!(!Cb(h+8|0)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|l:1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Mi(b)){break f}}Db(h+8|0,i,79);if(!Cb(h+8|0)){break e}if(!Mi(b)){break e}}n=1}g:{if(!v[b+16>>2]|(!o|(l|!x[a+480192>>1]))){break g}Db(h+8|0,a+1074312|0,87);if(!Cb(h+8|0)){break g}n=de(b+788|0)^1|n}h:{i:{j:{k:{if(Mi(b)|!(v[a+480180>>2]&16777248)){break k}if(g){if(Ej(g)){break k}}m=1;break j}if(!(l|o)){break i}m=(g|0)!=(j|0)}if(!d){break i}Db(h+8|0,a+1074312|0,61);if(!Cb(h+8|0)){break i}i=v[b+656>>2];if(!i){l=0;i=0;j=v[b+104>>2];if(!j){break i}break h}j=v[b+104>>2];l=0;break h}v[b+656>>2]=g;l=m;j=k;i=g}l:{if(!e){break l}k=b;m:{n:{o:{if(v[a+480180>>2]&3){if(j){if(Nd(j)){break o}}if(!nk(b)){break l}}if(!j){break n}}if(u[j+34>>1]<0){break l}g=x[j+30>>1];break m}g=0;if(!i|!w[i+34|0]){break m}g=b;m=v[b+656>>2];p:{if(m){g=v[m+4>>2]<<2;break p}g=v[g+688>>2]}}v[k+688>>2]=g}if(n){if(!((j|0)!=0&o)){break a}Db(h+8|0,a+1074312|0,85);if(Cb(h+8|0)){u[b+772>>1]=t[j+37|0]}if(v[a+480180>>2]!=2){break a}if(!Nd(j)){break a}v[b+704>>2]=v[j+24>>2];break a}t[b+803|0]=0;q:{if(!i){break q}Db(h+8|0,a+1074312|0,29);if(z=0,A=(D=Cb(h+8|0),E=1,F=j,F?D:E),C=w[i+34|0]!=0|l,C?z:A){break q}t[b+798|0]=w[i+16|0]}k=i;n=64;m=b;v[b+752>>2]=64;g=j;if(g){n=x[g+32>>1];v[m+752>>2]=n}if(k){v[m+752>>2]=B(v[k+4>>2],n)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}Db(h+8|0,a+1074312|0,48);if(Cb(h+8|0)){break r}AP(a,b,i,j)}s:{t:{u:{if(!f){break u}e=a+1074312|0;Db(h+8|0,e,19);v:{w:{x:{y:{z:{A:{B:{C:{if(Cb(h+8|0)){if(!v[b+76>>2]){g=1;break B}if(!(!c|p)){g=(w[a+480208|0]&8)>>>3|0;if(g){break B}break C}g=0;if(c){break C}break B}g=1;D:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break D}g=0;if(!(w[b+89|0]&16)){break D}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|l)){break z}if(!g){break y}g=v[b+88>>2];c=g&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){g=0;break B}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|l){break z}if(!g){break y}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break v}if(c){break w}if(!(w[i+60|0]&8)){Cj(b+724|0)}if(!(w[i+80|0]&8)){Cj(b+732|0)}if(w[i+100|0]&8){break v}Cj(b+740|0);break v}if(g){break x}}if(i){if(t[i+60|0]&1){break u}Db(h+8|0,e,32);if(Cb(h+8|0)){Cj(b+724|0);break u}Gm(b);break u}g=0;if(!j){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break v}}Gm(b)}Db(h+8|0,e,21);if(Cb(h+8|0)){break u}t[b+818|0]=0;v[b+756>>2]=0}g=0;if(j){break s}if(!i){break t}g=1;if(Ej(i)){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}c=b;E:{F:{G:{H:{I:{if(!(!d|!j|v[b+104>>2]!=(j|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break I}Db(h+8|0,a+1074312|0,40);if(!Cb(h+8|0)|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;Db(h+8|0,e,18);c=b;J:{if(z=Cb(h+8|0),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(j|0)|l)){break J}}f=-768}v[c+88>>2]=f&v[b+88>>2];K:{if(!i){break K}t[b+730|0]=w[i+60|0];t[b+738|0]=w[i+80|0];t[b+746|0]=w[i+100|0];L:{if((w[i+100|0]&17)!=17){break L}Db(h+8|0,e,36);if(Cb(h+8|0)|w[b+837|0]){break L}t[b+837|0]=127}if(lw(i)){z=b,A=TE(i),t[z+837|0]=A}if(!RE(i)){break K}z=b,A=SE(i),t[z+838|0]=A}if(g){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[c+88>>2]=d&-640;if(!g){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;Db(h+8|0,c,54);if(!Cb(h+8|0)){Db(h,c,39);if(!Cb(h)){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}Db(h+8|0,a+1074312|0,100);if(!Cb(h+8|0)|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[j+30>>1];if(!(w[j+34|0]&32)){break a}Lo(b,x[j+28>>1],a);break a}v[b+104>>2]=j;v[b+76>>2]=v[j>>2];v[b+80>>2]=v[j+4>>2];v[b+84>>2]=v[j+8>>2];e=a+1074312|0;Db(h+8|0,e,83);if(!(!Cb(h+8|0)|v[b+80>>2])){v[b+84>>2]=v[j>>2]}v[b+88>>2]=v[b+88>>2]|x[j+34>>1]&1023;Db(h+8|0,e,21);if(Cb(h+8|0)){t[b+818|0]=0;v[b+756>>2]=0}c=b;N:{O:{if(q){v[b+704>>2]=v[j+24>>2];t[b+851|0]=w[b+851|0]|32;d=0;break O}if(!(v[a+480180>>2]&5?o|p:1)){break N}v[b+704>>2]=v[j+24>>2];d=t[j+37|0]}u[c+772>>1]=d}c=b;if(bp(a)){d=t[j+36|0]}else{d=0}u[c+770>>1]=d;Db(h+8|0,e,69);if(!(Cb(h+8|0)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[j+12>>2];v[b+84>>2]=v[j+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}P:{if(!(g&2)){g=v[b+76>>2];break P}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break P}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}gb=h+16|0}function Yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-208|0;gb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;VO(a+900380|0);v[22692]=0;dA(a+946304|0);d=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}Qb(g+48|0,0,160);d=YO(g+48|0);v[22692]=0;e=a+906300|0;U(1283,e|0,e+4e4|0,d|0);e=v[22692];v[22692]=0;f:{g:{h:{i:{if((e|0)!=1){wq(d);v[22692]=0;d=T(275,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}if(!d){break f}i=cd(g+48|0);e=0;if(c&16){break h}v[22692]=0;h=(c|0)!=0;e=W(1284,i|0,b|0,h|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}d=4;j:{if(e){break j}v[22692]=0;e=W(1285,i|0,b|0,h|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}d=5;if(e){break j}v[22692]=0;e=W(1286,i|0,b|0,h|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}d=6;if(e){break j}e=0;v[22692]=0;h=W(1287,i|0,b|0,h|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}d=3;if(!h){break h}}if(c){break i}f=1;break b}a=P()|0;O()|0;wq(d);break c}if(!bd(i)){uw(b,v[i>>2]+12|0)}e=d}if(c&32){break b}d=37808;k:{l:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[22692]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){if(f){break k}d=d+12|0;if((d|0)==38312){break l}continue}break}break g}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break b}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[22692]=0;R(1111,a+1298224|0,1);d=v[22692];v[22692]=0;if((d|0)!=1){Zz(i);break d}}a=P()|0;O()|0;Zz(i);break c}v[22692]=0;R(367,a|0,0);d=v[22692];v[22692]=0;if((d|0)==1){break e}v[22692]=0;R(1111,a+1298224|0,1);d=v[22692];v[22692]=0;if((d|0)==1){break e}v[a+1074304>>2]=19923014;break d}a=P()|0;O()|0;break c}d=0;m:{n:{while(1){e=(d<<5)+a|0;wg(e+480286|0,64);e=e+480284|0;if(x[e>>1]>=257){u[e>>1]=128}v[22692]=0;Vm((B(d,872)+a|0)+1074992|0,7,a,d&65535,134217728);e=v[22692];v[22692]=0;if((e|0)==1){break n}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1298260|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;o:{if(Nd(d)){v[22692]=0;_h(d,a,0);d=v[22692];v[22692]=0;if((d|0)!=1){break o}break m}h=e+484414|0;j=x[h>>1];if(j&16384){break o}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}p:{if(!(w[e+484415|0]&2)){break p}if(!qk(i)){break p}v[22692]=0;_(1289,a|0);d=v[22692];v[22692]=0;if((d|0)==1){break m}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;e=0;while(1){q:{f=v[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break q}e=v[a+480180>>2];v[22692]=0;AS(f,e);f=v[22692];v[22692]=0;e=d;if((f|0)!=1){break q}a=P()|0;O()|0;break c}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=e;d=a+480204|0;r:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break r}tc(d,65535e4)}e=v[a+480196>>2];if(!e){v[a+480196>>2]=6;e=6}f=v[a+480220>>2];d=v[a+480216>>2];if(f>>>0<d>>>0){v[a+480220>>2]=d;f=d}v[a+1074416>>2]=e;v[a+1074420>>2]=v[a+480204>>2];v[a+1074412>>2]=f;v[a+1074408>>2]=d;v[a+1074456>>2]=v[a+480200>>2];mA(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;u[a+480276>>1]=0;v[22692]=0;_(1291,a|0);d=v[22692];v[22692]=0;s:{if((d|0)==1){break s}d=a+484360|0;l=g,m=Vb(d),v[l+48>>2]=m;l=g,m=Zb(d),v[l+32>>2]=m;t:{if(Gb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[22692]=0;_(1292,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break t}e=x[d+28>>1];if(sc(d)>>>0<=e>>>0){bf(d,0)}kS(g+48|0);if(Gb(g+48|0,g+32|0)){continue}break}}d=w[a+1074368|0];v[22692]=0;R(1293,a|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break s}u:{v:{w:{x:{y:{z:{A:{B:{k=v[a+480180>>2];if(k){$t(a+8|0,uq(a));if(v[a+1074308>>2]){v[22692]=0;_(1294,a|0);d=v[22692];v[22692]=0;if((d|0)==1){break s}}f=cd(g+48|0);if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;C:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break C}v[22692]=0;Q(1295,i|0,a|0)|0;c=v[22692];v[22692]=0;D:{if((c|0)!=1){c=v[i>>2];if(!c){break D}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[22692]=0;R(i|0,c|0,e|0);c=v[22692];v[22692]=0;if((c|0)!=1){break C}}a=P()|0;O()|0;break u}e=Vb(f);h=Zb(f);c=gb-32|0;gb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;if(Gb(c+24|0,c+16|0)){while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(!e){Oe(c+24|0);if(Gb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[g+32>>2]=e;l=g,m=Zb(f),v[l+16>>2]=m;if(Gb(g+32|0,g+16|0)){break C}v[22692]=0;v[g+32>>2]=j+906316;R(1296,f|0,g+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break v}v[22692]=0;c=Q(2,g+16|0,14769)|0;e=v[22692];v[22692]=0;if((e|0)==1){break B}v[22692]=0;R(1297,g|0,i|0);e=v[22692];v[22692]=0;if((e|0)==1){break A}v[22692]=0;U(3,g+32|0,c|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break z}v[22692]=0;U(556,a|0,2,g+32|0);e=v[22692];v[22692]=0;if((e|0)==1){break y}vb(g+32|0);vb(g);vb(c)}d=d+1|0;if((d|0)!=250){continue}break}}zl(f)}f=(k|0)!=0;break a}a=P()|0;O()|0;break u}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g+32|0)}vb(g)}vb(c);break u}a=P()|0;O()|0}zl(f);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}xb(b);S(a|0);L()}Zz(i)}xb(b);gb=g+208|0;return f|0}function j6(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;k=gb-560|0;gb=k;v[k+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<-1?1:(g|0)<=-1){z=1;A=2388;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){z=1;A=2391;break a}z=e&1;A=z?2394:2389;H=!z}b:{if((g&2146435072)==2146435072){p=z+3|0;ag(a,32,c,p,e&-65537);sf(a,A,z);d=f&32;sf(a,b!=b?d?7202:11061:d?8279:11370,3);break b}x=k+16|0;c:{d:{e:{b=JI(b,k+44|0);b=b+b;if(b!=0){g=v[k+44>>2];v[k+44>>2]=g-1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}m=v[k+44>>2];n=(d|0)<0?6:d;break d}m=g-29|0;v[k+44>>2]=m;b=b*268435456;n=(d|0)<0?6:d}s=(m|0)<0?k+48|0:k+336|0;h=s;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((m|0)<1){d=m;g=h;i=s;break f}i=s;d=m;while(1){u=(d|0)<29?d:29;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=u;q=0;while(1){r=g;p=0;F=q;q=v[g>>2];l=d&31;if((d&63)>>>0>=32){G=q<<l;l=0}else{G=(1<<l)-1&q>>>32-l;l=q<<l}q=F+l|0;p=p+G|0;p=l>>>0>q>>>0?p+1|0:p;l=q;q=mqa(l,p,1e9,0);F=r;r=jqa(q,jb,1e9,0);v[F>>2]=l-r;g=g-4|0;if(i>>>0<=g>>>0){continue}break}d=q;if(!d){break g}i=i-4|0;v[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[k+44>>2]-u|0;v[k+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<=-1){u=h+1|0;E=(C|0)==102;while(1){q=(d|0)<-9?9:0-d|0;h:{if(g>>>0>i>>>0){r=1e9>>>q|0;l=-1<<q^-1;d=0;h=i;while(1){F=d;d=v[h>>2];v[h>>2]=F+(d>>>q|0);d=B(r,d&l);h=h+4|0;if(h>>>0<g>>>0){continue}break}i=v[i>>2]?i:i+4|0;if(!d){break h}v[g>>2]=d;g=g+4|0;break h}i=v[i>>2]?i:i+4|0}d=v[k+44>>2]+q|0;v[k+44>>2]=d;h=E?s:i;g=(u|0)<g-h>>2?h+(u<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=i>>>0){break i}h=B(s-i>>2,9);d=10;l=v[i>>2];if(l>>>0<10){break i}while(1){h=h+1|0;d=B(d,10);if(l>>>0>=d>>>0){continue}break}}d=(n-((C|0)==102?0:h)|0)-((C|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-s>>2,9)-9|0)){r=d+9216|0;l=(r|0)/9|0;p=((l<<2)+((m|0)<0?k+48|4:k+340|0)|0)-4096|0;d=10;r=r-B(l,9)|0;if((r|0)<=7){while(1){d=B(d,10);r=r+1|0;if((r|0)!=8){continue}break}}r=v[p>>2];l=(r>>>0)/(d>>>0)|0;u=r-B(d,l)|0;m=p+4|0;j:{if(!((m|0)==(g|0)?u:1)){break j}b=(g|0)==(m|0)?1:1.5;m=d>>>1|0;y=m>>>0>u>>>0?.5:(m|0)==(u|0)?b:1.5;b=l&1?9007199254740994:9007199254740992;if(!(w[A|0]!=45|H)){y=-y;b=-b}m=r-u|0;v[p>>2]=m;if(b+y==b){break j}d=d+m|0;v[p>>2]=d;if(d>>>0>=1e9){while(1){v[p>>2]=0;p=p-4|0;if(p>>>0<i>>>0){i=i-4|0;v[i>>2]=0}d=v[p>>2]+1|0;v[p>>2]=d;if(d>>>0>999999999){continue}break}}h=B(s-i>>2,9);d=10;m=v[i>>2];if(m>>>0<10){break j}while(1){h=h+1|0;d=B(d,10);if(m>>>0>=d>>>0){continue}break}}d=p+4|0;g=d>>>0<g>>>0?d:g}while(1){l=g;m=g>>>0<=i>>>0;if(!m){g=l-4|0;if(!v[g>>2]){continue}}break}k:{if((C|0)!=103){q=e&8;break k}g=n?n:1;d=(g|0)>(h|0)&(h|0)>-5;n=(d?h^-1:-1)+g|0;f=(d?-1:-2)+f|0;q=e&8;if(q){break k}d=-9;l:{if(m){break l}m=v[l-4>>2];d=-9;if(!m){break l}r=10;g=0;d=0;if((m>>>0)%10|0){break l}while(1){d=g;g=g+1|0;r=B(r,10);if(!((m>>>0)%(r>>>0)|0)){continue}break}d=d^-1}g=B(l-s>>2,9)-9|0;if((f&-33)==70){q=0;d=d+g|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break k}q=0;d=d+(g+h|0)|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}u=(n|q)!=0;d=a;m=c;r=f&-33;if((r|0)==70){f=(h|0)>0?h:0}else{g=h>>31;g=Wn(g+h^g,0,x);if((x-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((x-g|0)<2){continue}break}}E=g-2|0;t[E|0]=f;t[g-1|0]=(h|0)<0?45:43;f=x-E|0}p=(f+(u+(n+z|0)|0)|0)+1|0;ag(d,32,m,p,e);sf(a,A,z);ag(a,48,c,p,e^65536);m:{n:{o:{if((r|0)==70){d=k+16|8;h=k+16|9;f=i>>>0>s>>>0?s:i;i=f;while(1){g=Wn(v[i>>2],0,h);p:{if((f|0)!=(i|0)){if(k+16>>>0>=g>>>0){break p}while(1){g=g-1|0;t[g|0]=48;if(k+16>>>0<g>>>0){continue}break}break p}if((g|0)!=(h|0)){break p}t[k+24|0]=48;g=d}sf(a,g,h-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}g=0;if(!u){break n}sf(a,13818,1);if((n|0)<1|i>>>0>=l>>>0){break o}while(1){g=Wn(v[i>>2],0,h);if(g>>>0>k+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(k+16>>>0<g>>>0){continue}break}}sf(a,g,(n|0)<9?n:9);g=n-9|0;i=i+4|0;if(l>>>0<=i>>>0){break n}d=(n|0)>9;n=g;if(d){continue}break}break n}q:{if((n|0)<0){break q}f=i>>>0<l>>>0?l:i+4|0;m=k+16|9;d=k+16|8;h=i;while(1){g=Wn(v[h>>2],0,m);if((m|0)==(g|0)){t[k+24|0]=48;g=d}r:{if((h|0)!=(i|0)){if(k+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(k+16>>>0<g>>>0){continue}break}break r}sf(a,g,1);g=g+1|0;if(q?0:(n|0)<=0){break r}sf(a,13818,1)}l=g;g=m-g|0;sf(a,l,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(f>>>0<=h>>>0){break q}if((n|0)>-1){continue}break}}ag(a,48,n+18|0,18,0);sf(a,E,x-E|0);break m}g=n}ag(a,48,g+9|0,9,0)}break b}n=f&32;s=n?A+9|0:A;s:{if(d>>>0>11){break s}g=12-d|0;if(!g){break s}y=8;while(1){y=y*16;g=g-1|0;if(g){continue}break}if(w[s|0]==45){b=-(y+(-b-y));break s}b=b+y-y}g=v[k+44>>2];h=g>>31;g=Wn(h^g+h,0,x);if((x|0)==(g|0)){t[k+15|0]=48;g=k+15|0}m=z|2;h=v[k+44>>2];l=g-2|0;t[l|0]=f+15;t[g-1|0]=(h|0)<0?45:43;g=e&8;i=k+16|0;while(1){f=i;q=n;if(D(b)<2147483648){h=~~b}else{h=-2147483648}t[i|0]=q|w[h+71200|0];b=(b-+(h|0))*16;i=f+1|0;if(!(!(g?1:(d|0)>0|b!=0)|(i-(k+16|0)|0)!=1)){t[f+1|0]=46;i=f+2|0}if(b!=0){continue}break}f=!d|((i-k|0)-18|0)>=(d|0)?(x-(l+(k+16|0)|0)|0)+i|0:((d+x|0)-l|0)+2|0;p=f+m|0;ag(a,32,c,p,e);sf(a,s,m);ag(a,48,c,p,e^65536);d=i-(k+16|0)|0;sf(a,k+16|0,d);g=d;d=x-l|0;ag(a,48,f-(g+d|0)|0,0,0);sf(a,l,d)}ag(a,32,c,p,e^8192);gb=k+560|0;return((c|0)>(p|0)?c:p)|0}function gP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=C(0),M=0,N=0,O=C(0),P=0;j=gb-48|0;gb=j;m=x[a+480192>>1]?v[(B(b,872)+a|0)+1075648>>2]:m;n=a+1074312|0;f=B(b,872)+a|0;q=f+1075791|0;A=f+1075680|0;D=f+1075768|0;r=f+1075744|0;y=f+1075740|0;E=f+1075712|0;F=f+1075684|0;G=f+1075676|0;H=f+1075656|0;I=f+1075778|0;J=f+1075080|0;h=e&127;K=C(h>>>0);s=f+1075842|0;L=C(w[s|0]);f=1;while(1){e=w[d+o|0];if(e){g=e-48|0;a:{b:{c:{if((g&255)>>>0<10){break c}if((e-65&255)>>>0<=5){g=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Em(a,b,3,0);if(!e|e-251>>>0<5){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=Yw(e,50336,50368);if(!e){break g}g=kb[v[v[e>>2]+188>>2]](e,b)|0;e=(g|0)!=255;g=e?g:0;if(e|!m){break c}break d}if(m){break d}g=0;break c;case 13:g=0;if(!ue(w[q|0])){break e}g=w[q|0]-1|0;break e;case 21:Db(j+8|0,n,28);h:{if(!Cb(j+8|0)){Db(j,n,1);e=0;if(!Cb(j)){break h}}e=u[D>>1]}g=B(v[r>>2],v[y>>2]);e=B(v[a+1074456>>2],e+v[A>>2]|0);g=Mb((Ac(kqa(jqa(g,g>>31,e,e>>31),jb,1048576,0),jb)|0)/2|0,1,127);break e;case 23:v[j+8>>2]=v[F>>2]/2;v[j>>2]=127;g=v[nd(j+8|0,j)>>2];break e;case 24:v[j+8>>2]=v[G>>2]/2;v[j>>2]=127;g=v[nd(j+8|0,j)>>2];break e;case 0:g=0;if(!m){break e}e=x[m+28>>1];if(!e){break e}g=e-1>>>7&127;break e;case 1:g=0;if(!m){break e}e=x[m+28>>1];if(!e){break e}g=e-1&127;break e;case 14:g=v[H>>2]>>>8|0;break e;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[I|0]-1|0}g=e&127;break e;case 12:g=v[J>>2]>>>7&1;break e;case 15:g=0;if(!m){break e}e=w[m+30|0];if(!e){break e}g=e-1&127;break e;case 25:l=s;e=h;i:{if(!c){break i}e=h;if(t[s|0]<0){break i}j:{if(i>>>0<3){break j}k=(j+16|0)+i|0;if(w[k-3|0]!=240){break j}e=h;if(w[k-2|0]>239){break i}}p=yq(a,L,K);if(p<C(4294967296)&p>=C(0)){e=~~p>>>0;break i}e=0}g=e;t[l|0]=g;break e;case 18:e=i;k:{if(!e){e=0;break k}while(1){e=e-1|0;if(w[e+(j+16|0)|0]==240){break k}if(e){continue}break}}if(w[(j+16|0)+e|0]!=240|i-e>>>0<5){break a}g=0;e=e+5|0;if((i|0)!=(e|0)){while(1){g=w[(j+16|0)+e|0]+g|0;e=e+1|0;if((i|0)!=(e|0)){continue}break}}g=0-g&127;break e;case 20:break f;default:break a}}e=B(v[r>>2],v[y>>2]);g=e;k=e>>31;e=B(v[a+1074456>>2],v[E>>2]);g=Mb((Ac(kqa(jqa(g,k,e,e>>31),jb,67108864,0),jb)|0)/2|0,1,127)}e=((f^-1)&1)+i|0;t[e+(j+16|0)|0]=g;i=e+1|0;f=1;break b}e=m;l=a;g=0;k=b;l:{if(k>>>0>=256){break l}if(w[e+31|0]==17){e=x[(l+B(k,872)|0)+1075778>>1];g=(e?e-1|0:k)&15;break l}if(!Ej(e)){break l}g=w[e+31|0]-1&15}}e=(j+16|0)+i|0;m:{if(f&1){t[e|0]=g;break m}t[e|0]=w[e|0]<<4|g;i=i+1|0}f=(f^-1)&1}}o=o+1|0;if((o|0)!=31){continue}}break}e=((f^-1)&1)+i|0;n:{if(!e){break n}g=0;f=0;while(1){l=(j+16|0)+f|0;d=t[l|0];o:{p:{q:{if((d|0)==-16){if(e-f>>>0>=4){o=4;if((w[(f+j|0)+17|0]&254)==240){break p}}o=f;r:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break r}if(w[(j+16|0)+o|0]!=247){continue}break}d=o-f|0;o=d+1|0;if(o>>>0>=d>>>0){break p}}t[(j+16|0)+e|0]=247;e=e+1|0;o=e-f|0;break q}if((d|0)>=0){if(g&255){f=f-1|0;t[f+(j+16|0)|0]=g;break o}f=f+1|0;g=0;break o}M=j,N=US(d&255),v[M+8>>2]=N;v[j>>2]=e-f;o=v[Fb(j+8|0,j)>>2]}if(!o){break n}d=w[l|0];g=d>>>0<240?d:g}s=f;d=a;h=b;m=c;k=gb-32|0;gb=k;i=o;v[k+28>>2]=i;f=w[l|0];n=f-250|0;if(!(n>>>0>5|!(1<<n&37))){if(x[d+480188>>1]){f=0;while(1){n=(d+B(f,872)|0)+1075829|0;t[n|0]=127;t[n+1|0]=0;f=f+1|0;if(f>>>0<x[d+480188>>1]){continue}break}}f=w[l|0]}s:{t:{if((f&255)!=240){break t}n=w[l+1|0];if((n&254)!=240){break t}f=i>>>0<4;i=0;if(f){break s}r=(d+B(h,872)|0)+1074992|0;q=w[l+2|0];f=t[l+3|0];if(!(q|(n|0)==241|(f|0)<0)){l=d+B(h,872)|0;i=l+1075829|0;n=i;if(m){f=gA(yq(d,C(w[i|0]),C((f&255)>>>0)))}t[n|0]=f;t[l+1075788|0]=0;i=4;f=l+1075080|0;m=Eq(d,r,!(v[f>>2]&32768),256);if((m|0)<0|!(w[f+1|0]&2)){break s}d=d+1298260|0;if(!Dd(d)){break s}Mq(v[d>>2],h,m>>>2&255,1);break s}if(!((n|0)==241|(q|0)!=1|(f|0)<0)){h=d+B(h,872)|0;i=h+1075830|0;u:{if(!m){break u}p=yq(d,C(w[i|0]),C((f&255)>>>0));if(p<C(4294967296)&p>=C(0)){f=~~p>>>0;break u}f=0}t[i|0]=f;t[h+1075787|0]=0;Eq(d,r,!(v[h+1075080>>2]&32768),256);i=4;break s}if(!((n|0)==241|(q|0)!=2)){i=4;if((f&255)>>>0>31){break s}h=d+B(h,872)|0;t[h+1075837|0]=(f&240)>>>4;Eq(d,r,!(v[h+1075080>>2]&32768),256);break s}if(!((n|0)==241|(q|0)!=3)){i=4;h=Em(d,h,3,0);if((f|0)<0|(h+5&255)>>>0<6){break s}h=(d+B(h,160)|0)+906284|0;p=C(C(((f^127)&255)>>>0)*C(.007874015718698502));if(!m){z[h>>2]=p;break s}M=h,O=yq(d,z[h>>2],p),z[M>>2]=O;break s}if(!((n|0)!=241?q&128:1)){break s}i=4;h=Em(d,h,3,0);if((h+5&255)>>>0<6){break s}h=v[(d+B(h,160)|0)+906140>>2];if(!h|(f|0)<0){break s}l=(n|0)==241?q+128|0:q&127;p=C(C((f&255)>>>0)*C(.007874015718698502));if(!m){kb[v[v[h>>2]+44>>2]](h,l,p);break s}N=h,P=l,O=yq(d,C(kb[v[v[h>>2]+48>>2]](h,l)),p),M=v[v[h>>2]+44>>2],kb[M](N|0,P|0,C(O));break s}v:{if(h>>>0<x[d+480188>>1]){f=h+1|0;break v}f=x[(d+B(h,872)|0)+1075778>>1];if(!f){break s}}if(w[(d+B(h,872)|0)+1075083|0]&4|x[d+480188>>1]<(f&65535)>>>0){break s}f=Em(d,h,3,0);if(!f|f-251>>>0<5){break s}d=v[(d+B(f,160)|0)+906140>>2];if(!d){break s}f=w[l|0];if((f|0)==240){bc(k+16|0,zb(l),i);f=v[v[d>>2]+72>>2];h=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=h;kb[f|0](d,k)|0;break s}M=k,P=US(f),v[M+12>>2]=P;f=v[Fb(k+12|0,k+28|0)>>2];v[k+12>>2]=0;hc(k+12|0,l,f);kb[v[v[d>>2]+68>>2]](d,v[k+12>>2])|0;i=v[k+28>>2]}gb=k+32|0;f=(i?i:o)+s|0}if(e>>>0>f>>>0){continue}break}}gb=j+48|0}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-336|0;gb=d;Yc(b,60);i=15;a:{if(!Hh(b,11355)){Yc(b,124);i=31;if(!Hh(b,12478)){break a}}Id(a,536870912);u[a+480190>>1]=i;vc(b);b:{if(x[a+480190>>1]){while(1){e=Gr(b);v[(d+208|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;uh(a,1);Rb(b,4);i=Ir(b);if(i>>>0<178){break a}e=a;o=177693e5/+(i>>>0);c:{if(o<4294967296&o>=0){f=~~o>>>0;break c}f=0}v[e+480204>>2]=f;Rb(b,14);d:{e:{f:{if(x[a+480190>>1]){p=d+62|0;k=1;i=0;m=1;while(1){tV(b,d+40|0);e=v[((k<<2)+d|0)+204>>2];l=gb-16|0;gb=l;h=(B(k,104)+a|0)+484380|0;td(h,1);v[h>>2]=e;e=d+40|0;t[h+37|0]=w[e+24|0]<<4;t[l+15|0]=w[e+25|0];t[l+14|0]=64;q=h,r=w[ac(l+15|0,l+14|0)|0]<<2,u[q+30>>1]=r;f=e+26|0;g=Ib(w[f|0]|w[f+1|0]<<8);e=e+28|0;e=Ib(w[e|0]|w[e+1|0]<<8);f=v[h>>2];g:{if(!f){break g}v[h+4>>2]=g;e=(e<<1)+g|0;v[h+8>>2]=e;if(f>>>0<=g>>>0){g=f-1|0;v[h+4>>2]=g}if(e>>>0>f>>>0){v[h+8>>2]=f;e=f}if(!(e-g>>>0>3?!(e>>>0<g>>>0|e>>>0<4):0)){v[h+4>>2]=0;v[h+8>>2]=0;break g}if(e>>>0<=g>>>0){break g}u[h+34>>1]=x[h+34>>1]|2}gb=l+16|0;f=d+40|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;i=i+1|0}f=f+1|0;if((p|0)!=(f|0)){continue}break}if(i>>>0>127){break b}Jk(d+176|0,3,d+40|0);Bc(d+192|0,d+176|0);v[22692]=0;Q(301,((k<<5)+a|0)+946304|0,d+192|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}vb(d+192|0);m=m+1|0;k=m&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}e=Tb(d+40|0,11240);v[22692]=0;h=a+946336|0;f=Q(879,h|0,e|0)|0;k=v[22692];v[22692]=0;i=1;h:{i:{j:{k:{if((k|0)!=1){if(!f){v[22692]=0;f=Q(70,d+192|0,11251)|0;i=v[22692];v[22692]=0;if((i|0)==1){break k}v[22692]=0;i=Q(879,h|0,f|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break j}vb(f)}vb(e);f=0;e=d+40|0;h=mV(b,e);if(!h){QB(e)}if(!h){break a}if(!mU(d+40|0)){break a}if(c){break h}break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(f)}vb(e);break e}u[d+38>>1]=0;if(w[d+40|0]){while(1){u[d+192>>1]=w[(d+f|0)+42|0]+1;q=d,r=x[Je(d+38|0,d+192|0)>>1],u[q+38>>1]=r;f=f+1|0;if(f>>>0<w[d+40|0]){continue}break}}e=d+40|1;f=w[e|0];h=w[d+40|0];k=a+484360|0;bf(Sb(k),f>>>0<h>>>0?w[e|0]:0);Br(Sb(k),d+40|2,w[d+40|0]);if(x[a+480190>>1]==31){Rb(b,4)}k=0;v[d+32>>2]=0;v[d+28>>2]=0;v[d+24>>2]=0;t[d+23|0]=0;l=c&1;if(l){xg(a+484344|0,x[d+38>>1])}if(x[d+38>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(sh(h,k&65535,64)){break m}}Rb(b,1024);break l}while(1){p=Wc(_b(h,k),m,0);f=0;while(1){pn(d+192|0,b);e=p+B(f,6)|0;n:{o:{p:{q:{if(w[lc(d+192|0,0)|0]!=255){break q}t[(d+32|0)+f|0]=0;t[(d+24|0)+f|0]=0;g=lc(d+192|0,1);j=w[g|0];if((j|0)==252&i){t[g|0]=254;break o}switch(j-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}g=v[d+192>>2];v[d+16>>2]=g;v[d+8>>2]=g;cr(d+8|0,e);g=w[e|0];r:{if(!g){break r}t[(d+24|0)+f|0]=0;t[(d+32|0)+f|0]=g;if(g>>>0>48){break r}t[d+176|0]=8;q=d,r=w[Bf(d+23|0,d+176|0)|0],t[q+23|0]=r}s:{t:{u:{v:{w:{x:{switch(w[e+3|0]){case 1:t[e+3|0]=1;break n;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break n}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break n}t[e+5|0]=0;break t;case 3:if(w[(d+24|0)+f|0]){break u}t[e+3|0]=19;t[e+5|0]=0;break n;case 4:if(w[(d+24|0)+f|0]){break u}t[e+3|0]=19;t[e+5|0]=1;break n;case 5:if(!w[e+1|0]){break u}t[e+3|0]=13;t[d+176|0]=63;t[d+15|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);q=e,r=w[ac(d+176|0,d+15|0)|0],t[q+5|0]=r;if(!w[(d+24|0)+f|0]){break w}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break t;case 6:g=w[e+1|0];if(!g){break u}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;j=w[e+5|0];g=g>>>0<j>>>0?0:g-j|0;t[e+5|0]=g;if(!w[(d+24|0)+f|0]){break w}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break t;case 8:j=w[(d+32|0)+f|0];g=w[e+5|0];n=j+(g>>>4|0)|0;t[(d+28|0)+f|0]=n;t[e+3|0]=2;g=g&15;t[(d+24|0)+f|0]=g;q=e,r=lU(g,j,n&255),t[q+5|0]=r;break w;case 9:t[d+176|0]=8;q=d,r=w[Bf(d+23|0,d+176|0)|0],t[q+23|0]=r;break t;case 0:break v;case 7:break x;default:break t}}g=w[(d+32|0)+f|0];j=w[e+5|0];n=g-(j>>>4|0)|0;t[(d+28|0)+f|0]=n;t[e+3|0]=3;j=j&15;t[(d+24|0)+f|0]=j;q=e,r=lU(j,n&255,g),t[q+5|0]=r}if(!w[e+3|0]){break s}break n}if(!w[e+5|0]){break s}break t}t[e+5|0]=0}t[e+3|0]=0}j=w[(d+24|0)+f|0];if(!j){break n}n=(d+28|0)+f|0;g=w[n|0];if(g){t[(d+32|0)+f|0]=g;t[e|0]=g;t[e+5|0]=j;t[n|0]=0}t[e+3|0]=4;break n}t[e+3|0]=14;t[d+23|0]=9;break n}t[e+3|0]=13}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[d+38>>1]){continue}break}}y:{z:{A:{B:{if(c&2){i=x[a+480190>>1];if(!i){break A}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){Ag(Rc(d+192|0,8,1,0,0),c,b);i=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(i&65535)>>>0){continue}break}break B}i=x[a+480190>>1]}if((i&65535)!=15){break A}b=gb-16|0;gb=b;c=Tb(b,1514);Dc(d+176|0,c);vb(c);gb=b+16|0;v[22692]=0;U(461,d+192|0,d+176|0,d+23|0);b=v[22692];v[22692]=0;f=1;if((b|0)!=1){break z}a=P()|0;O()|0;Hb(d+176|0);break e}f=0;v[22692]=0;Q(2,d+192|0,9514)|0;b=v[22692];v[22692]=0;if((b|0)==1){break y}}Eb(a+1298304|0,d+192|0);vb(d+192|0);if(f){Hb(d+176|0)}Vc(a+1298316|0,x[a+480190>>1]==15?2374:12261);v[a+1298364>>2]=2;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+192|0)}S(a|0);L()}f=1;break a}f=0}gb=d+336|0;return f|0}function yK(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-48|0;gb=g;v[g+44>>2]=c;u[g+32>>1]=0;u[g+16>>1]=65535;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(At(g+44|0,g+32|0,g+16|0)){if(le(v[b+24>>2]+484344|0,c&65535)){break j}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);Bi(c,a,b);vb(b);vb(a);break i}c=_b(v[b+24>>2]+484344|0,c);if(!(v[c+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Bi(c,a,b);vb(b);vb(a);break i}if(!(x[v[b+24>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Bi(c,a,b);vb(b);vb(a);break i}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Bi(c,a,b);vb(b);vb(a);break i}e=Wc(c,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!de(e)){if(!St(e)){break n}}HO(g+16|0,v[b+24>>2],w[e|0],w[e+1|0]);v[22692]=0;R(2023,g+32|0,g+16|0);c=v[22692];v[22692]=0;b=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22692]=0;Q(70,g+32|0,13812)|0;c=v[22692];v[22692]=0;if((c|0)==1){break l}}v[22692]=0;c=de(e);d=v[22692];v[22692]=0;if((d|0)==1){break c}o:{if(c){v[22692]=0;Q(70,g|0,7192)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}break o}if(St(e)){v[22692]=0;Q(70,g|0,7502)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break o}break c}v[22692]=0;Q(70,g|0,13812)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}}Bi(a,g+32|0,g);vb(g);vb(g+32|0);if(!b){break i}vb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:b=e+1|0;p:{if(w[e+1|0]){dv(g+32|0,b);break p}Tb(g+32|0,13817)}q:{if(w[b|0]){v[22692]=0;Q(70,g+16|0,8009)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break q}break d}v[22692]=0;Q(70,g+16|0,13817)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}}Bi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 2:r:{if(zg(e)){Tb(g+32|0,14884);break r}if(w[e+2|0]){Ge(g+32|0,1,lz(v[v[b+24>>2]+8>>2],w[e+2|0]));break r}Tb(g+32|0,14884)}v[22692]=0;b=zg(e);c=v[22692];v[22692]=0;if((c|0)==1){break e}s:{if(b){v[22692]=0;Q(70,g+16|0,14884)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}break s}if(w[e+2|0]){v[22692]=0;Q(70,g+16|0,2597)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break s}break e}v[22692]=0;Q(70,g+16|0,14884)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}}Bi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 4:t:{if(zg(e)){q=g,r=Cq(e)&255,v[q>>2]=r;bC(g+32|0,g);break t}if(w[e+2|0]){dv(g+32|0,e+4|0);break t}Tb(g+32|0,13817)}v[22692]=0;b=zg(e);c=v[22692];v[22692]=0;if((c|0)==1){break f}u:{if(b){v[22692]=0;Q(70,g+16|0,2581)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}break u}if(w[e+2|0]){v[22692]=0;Q(70,g+16|0,2581)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break u}break f}v[22692]=0;Q(70,g+16|0,13817)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}}Bi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 3:v:{if(zg(e)){q=g,r=(yo(e)&3840)!=0,t[q|0]=r;i=gb-32|0;gb=i;t[i+24|0]=44;v[i+16>>2]=-1;v[i+20>>2]=0;v[i+8>>2]=1058;v[i+12>>2]=1;n=g+32|0;c=g;b=gb+-64|0;gb=b;d=b;k=i+8|0;l=v[k>>2]&2?16:10;j=gb-32|0;gb=j;f=Ge(j+16|0,1,0);w:{x:{y:{while(1){h=Jb(f);m=Jb(f);o=Ab(f);p=w[c|0];v[22692]=0;ha(91,j+8|0,h|0,m+o|0,p|0,l|0);h=v[22692];v[22692]=0;if((h|0)==1){break x}if(!v[j+12>>2]){break y}h=Ab(f);v[22692]=0;v[j+4>>2]=h;h=wf(j+4|0);m=v[22692];v[22692]=0;if((m|0)!=1){v[22692]=0;U(75,f|0,h|0,0);h=v[22692];v[22692]=0;if((h|0)!=1){continue}}break}break x}c=v[j+8>>2];l=Jb(f);v[22692]=0;R(76,f|0,c-l|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;R(77,d|0,f|0);c=v[22692];v[22692]=0;if((c|0)==1){break x}vb(f);gb=j+32|0;break w}}a=P()|0;O()|0;vb(f);S(a|0);L()}El(b+16|0,b,k);v[22692]=0;U(89,b+32|0,b+16|0,k|0);c=v[22692];v[22692]=0;z:{A:{B:{C:{D:{if((c|0)!=1){v[22692]=0;U(90,b+48|0,b+32|0,k|0);c=v[22692];v[22692]=0;if((c|0)==1){break D}v[22692]=0;R(72,n|0,b+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break C}vb(b+48|0);vb(b+32|0);vb(b+16|0);vb(b);gb=b- -64|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b+48|0)}vb(b+32|0)}vb(b+16|0);vb(b);S(a|0);L()}gb=i+32|0;break v}if(w[e+3|0]){Ge(g+32|0,1,kz(v[v[b+24>>2]+8>>2],w[e+3|0]));break v}Tb(g+32|0,13818)}v[22692]=0;b=zg(e);c=v[22692];v[22692]=0;if((c|0)==1){break g}E:{if(b){v[22692]=0;Q(70,g+16|0,9505)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}break E}if(w[e+3|0]){v[22692]=0;Q(70,g+16|0,9505)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break E}break g}v[22692]=0;Q(70,g+16|0,13818)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}}Bi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 5:F:{if(zg(e)){q=g,r=yo(e)&255,v[q>>2]=r;bC(g+32|0,g);break F}if(w[e+3|0]){dv(g+32|0,e+5|0);break F}Tb(g+32|0,13817)}v[22692]=0;b=zg(e);c=v[22692];v[22692]=0;if((c|0)==1){break h}G:{if(b){v[22692]=0;Q(70,g+16|0,8296)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}break G}if(w[e+3|0]){v[22692]=0;Q(70,g+16|0,8296)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break G}break h}v[22692]=0;Q(70,g+16|0,13817)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}}Bi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;default:break k}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);Bi(c,a,b);vb(b);vb(a)}gb=g+48|0;return}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);if(!b){break a}}vb(g+16|0)}S(c|0);L()}function wma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=gb-1824|0;gb=d;vc(b);g=gb-32|0;gb=g;j=d+1224|0;jV(g+24|0,j);i=yb(g+24|0);e=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=e;v[g>>2]=k;v[g+4>>2]=e;e=b;cc(g+16|0,e,g);k=yb(g+16|0);if((k|0)==(i|0)){Rb(e,yb(g+24|0))}gb=g+32|0;e=(i|0)==(k|0);if(!e){iV(j)}a:{if(!e){break a}if(!sV(d+1224|0)){break a}if(!XB(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;h=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=h;Id(a,1);e=a+1074312|0;Pf(e,83);Ob(e,84,1);Ob(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Yc(b,20);k=a+480188|0;h=1;g=1;while(1){i=B(h,104)+a|0;j=i+484380|0;e=((h<<5)+a|0)+946304|0;YB(b,d+16|0,j,e,1);m=v[j>>2];b:{if(!w[lc(e,0)|0]){break b}c:{if(rd(e,13820,3)){if(rd(e,13824,3)){break c}}if(w[lc(e,5)|0]==58){break b}}g=0}if(Ib(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){z=i+484384|0,A=Ib(w[d+42|0]|w[d+43|0]<<8),v[z>>2]=A;z=i+484388|0,A=Ib(w[d+42|0]|w[d+43|0]<<8)+(Ib(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[z>>2]=A;rk(j)}d:{if(Ib(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break d}}v[d+1064>>2]=5;z=d,A=v[Vo(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}f=f+m|0;h=h+1|0;if((h|0)!=16){continue}break}yV(b,d+1064|0);p=a+484360|0;Br(Sb(p),d+1064|2,128);h=0;m=xV(b,Sb(p),w[d+1064|0],f,k,0,1);e=d+1064|1;if(!(m>>>0<2?w[e|0]|w[d+1064|0]:1)){break a}if(mf(b)+65536>>>0<(m<<10)+f>>>0){break a}if(!c){h=1;break a}if(!w[e|0]){t[e|0]=120}if(!rd(d+1200|0,12077,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;r=145364549.18032786/+(240-w[e|0]|0);f:{if(r<4294967296&r>=0){e=~~r>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=g?4:5;z=d,A=v[Vo(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A;break e}v[d+16>>2]=g?1:2;z=d,A=v[Vo(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;Uj(d+1048|0,3,d+1200|0);Bc(d+16|0,d+1048|0);Eb(a+1298268|0,d+16|0);vb(d+16|0);j=0;uh(a,0);s=v[b+8>>2];u[d+1046>>1]=0;g:{if(m){while(1){f=Sb(p);z=d,A=WB(Vb(f),Zb(f),d+1046|0),v[z+16>>2]=A;z=d,A=Zb(f),v[z+1048>>2]=A;f=Gb(d+16|0,d+1048|0);rV(b,d+16|0);if(f){j=VB(d+16|0,0)+j|0;if(j>>>0>512){break g}}k=0;f=0;o=0;while(1){y=qV(d+16|0,k);h=0;while(1){e=f;l=Ri(y,h);q=w[lc(l,2)|0]&15;i=w[lc(l,3)|0];f=0;h:{if(!(e&255)|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}v[d+1196>>2]=6}i:{j:{k:{switch(q-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1?i>>>0>=32:0){break j}l=(q|0)!=1;if(!(l|!i|i>>>0>2)){v[d+1048>>2]=2;z=d,A=v[Vo(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}if(l){break i}if((i|0)!=55){if((i|0)!=71){break i}if((e|0)<3){break j}break i}if((e|0)<=2){break j}break i;case 10:v[d+1196>>2]=6;break i;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[Vo(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((q|0)!=13){break i}o=((i|k)!=0)+o|0;f=1;break i;case 14:break k;default:break i}}v[d+1048>>2]=3;z=d,A=v[Vo(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}v[d+1196>>2]=g}h=h+1|0;if((h|0)!=4){continue}break}k=k+1|0;if((k|0)!=64){continue}break}if((o-1&255)>>>0<2){v[d+1196>>2]=6}n=(o&255)+n|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(m>>>0>(f&65535)>>>0){continue}break}}if(!(v[d+1196>>2]!=6|m+32>>>0>=n>>>0)){v[d+1196>>2]=5}Yc(b,s);o=c&1;if(o){xg(a+484344|0,m)}if(m){l=a+484344|0;k=0;while(1){rV(b,d+16|0);l:{if(!o){break l}if(!sh(l,k&65535,64)){break l}v[d+1048>>2]=0;n=0;while(1){q=Wc(_b(l,k),n,0);p=qV(d+16|0,n);i=0;while(1){f=Ri(p,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=q+B(i,6)|0;cr(d+8|0,e);m:{n:{o:{p:{q:{r:{s:{t:{f=w[e+5|0];if(f){h=e+3|0;g=(d+1048|0)+i|0;j=w[e+3|0];if((j|0)!=14){break t}t[g|0]=0;break q}h=(d+1048|0)+i|0;t[h|0]=0;j=w[e+3|0];if(!j){break r}h=e+3|0;break s}g=w[g|0];if(!g){break s}u:{if(g>>>0>=16){t[e+2|0]=3;g=g>>>4|0;break u}t[e+2|0]=4}t[e+4|0]=g}v:{w:{switch(j-12|0){case 1:g=v[d+1196>>2];if((g|0)==6){break v}j=10;t[h|0]=10;break o;case 0:f=f&127;t[e+5|0]=f;j=12;break p;case 2:break q;case 3:break w;default:break p}}j=15;f=f&15;t[e+5|0]=f;break p}t[e+5|0]=0;break n}t[h|0]=0;break m}if(v[d+1196>>2]>3?f>>>0<=1:0){break n}j=10;t[h|0]=10;t[(d+1048|0)+i|0]=f}g=v[d+1196>>2]}if((g|0)>1){break n}x:{y:{z:{switch(j|0){case 0:if(f>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}t[h|0]=0;break m}t[h|0]=1;break m}g=f&15;if(g){t[h|0]=2;t[e+5|0]=g;break m}if(f>>>0<16){break m}t[h|0]=3;t[e+5|0]=f>>>4;break m}Nf(e)}i=i+1|0;if((i|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}k=k+1|0;if((m|0)!=(k|0)){continue}break}}h=18699;f=v[d+1196>>2];if(f>>>0<7){h=v[(f<<2)+33192>>2]}f=Tb(d+16|0,5422);Eb(a+1298304|0,f);vb(f);f=Tb(d+16|0,7997);Eb(a+1298316|0,f);vb(f);Vc(a+1298328|0,h);v[a+1298364>>2]=2;h=1;if(!(c&2)){break a}i=1;while(1){c=B(i,104)+a|0;f=c+484384|0;Rb(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;Rc(d+16|0,8,1,1,0);Ag(d+16|0,f,b);i=i+1|0;if((i|0)!=16){continue}break}break a}h=0}gb=d+1824|0;return h|0}function Ux(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0;h=gb-80|0;gb=h;v[h+76>>2]=b;z=h+55|0;x=h+56|0;b=0;a:{b:{c:while(1){d:{if((p|0)<0){break d}if((2147483647-p|0)<(b|0)){v[115173]=61;p=-1;break d}p=b+p|0}e:{f:{k=v[h+76>>2];b=k;i=w[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(w[b+1|0]!=37){break h}j=b+2|0;v[h+76>>2]=j;i=i+1|0;m=w[b+2|0];b=j;if((m|0)==37){continue}break}}b=i-k|0;if(a){sf(a,k,b)}if(b){continue c}q=-1;i=1;j=h;r=!Qh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(!(r|w[b+2|0]!=36)){q=t[b+1|0]-48|0;y=1;i=3}b=i+b|0;v[j+76>>2]=b;s=0;l=t[b|0];j=l-32|0;i:{if(j>>>0>31){i=b;break i}i=b;j=1<<j;if(!(j&75913)){break i}while(1){i=b+1|0;v[h+76>>2]=i;s=j|s;l=t[b+1|0];j=l-32|0;if(j>>>0>=32){break i}b=i;j=1<<j;if(j&75913){continue}break}}j:{if((l|0)==42){j=h;k:{l:{if(!Qh(t[i+1|0])){break l}b=v[h+76>>2];if(w[b+2|0]!=36){break l}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;o=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break k}if(y){break b}y=0;o=0;if(a){b=v[c>>2];v[c>>2]=b+4;o=v[b>>2]}b=v[h+76>>2]+1|0}v[j+76>>2]=b;if((o|0)>-1){break j}o=0-o|0;s=s|8192;break j}o=OI(h+76|0);if((o|0)<0){break b}b=v[h+76>>2]}m=-1;m:{if(w[b|0]!=46){break m}if(w[b+1|0]==42){n:{if(!Qh(t[b+2|0])){break n}b=v[h+76>>2];if(w[b+3|0]!=36){break n}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;m=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break m}if(y){break b}if(a){b=v[c>>2];v[c>>2]=b+4;m=v[b>>2]}else{m=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break m}v[h+76>>2]=b+1;m=OI(h+76|0);b=v[h+76>>2]}i=0;while(1){r=i;n=-1;if(t[b|0]-65>>>0>57){break a}l=b+1|0;v[h+76>>2]=l;i=t[b|0];b=l;i=w[(i+B(r,58)|0)+70671|0];if(i-1>>>0<8){continue}break}o:{p:{if((i|0)!=19){if(!i){break a}if((q|0)>=0){v[(q<<2)+e>>2]=i;b=(q<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break p}if(!a){break e}NI(h- -64|0,i,c,g);l=v[h+76>>2];break o}if((q|0)>-1){break a}}b=0;if(!a){continue c}}j=s&-65537;i=s&8192?j:s;n=0;q=2378;s=x;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{b=t[l-1|0];b=r?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break q;case 9:case 13:case 14:case 15:break r;case 27:break w;case 12:case 17:break z;case 23:break A;case 0:case 32:break B;case 24:break C;case 22:break D;case 29:break E;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break f;default:break F}}G:{switch(b-65|0){case 0:case 4:case 5:case 6:break r;case 2:break u;case 1:case 3:break f;default:break G}}if((b|0)==83){break v}break f}l=v[h+64>>2];k=v[h+68>>2];q=2378;break y}b=0;H:{switch(r&255){case 0:v[v[h+64>>2]>>2]=p;continue c;case 1:v[v[h+64>>2]>>2]=p;continue c;case 2:i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c;case 3:u[v[h+64>>2]>>1]=p;continue c;case 4:t[v[h+64>>2]]=p;continue c;case 6:v[v[h+64>>2]>>2]=p;continue c;case 7:break H;default:continue c}}i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c}m=m>>>0>8?m:8;i=i|8;b=120}j=x;C=b&32;r=v[h+68>>2];k=r;l=v[h+64>>2];if(k|l){while(1){j=j-1|0;t[j|0]=C|w[(l&15)+71200|0];D=!k&l>>>0>15|(k|0)!=0;r=k;k=k>>>4|0;l=(r&15)<<28|l>>>4;if(D){continue}break}}k=j;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break x}q=(b>>>4|0)+2378|0;n=2;break x}b=x;j=v[h+68>>2];k=j;l=v[h+64>>2];if(j|l){while(1){b=b-1|0;t[b|0]=l&7|48;r=!k&l>>>0>7|(k|0)!=0;j=k;k=j>>>3|0;l=(j&7)<<29|l>>>3;if(r){continue}break}}k=b;if(!(i&8)){break x}b=x-k|0;m=(b|0)<(m|0)?m:b+1|0;break x}b=v[h+68>>2];k=b;l=v[h+64>>2];if((b|0)<-1?1:(b|0)<=-1){k=0-(k+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=k;n=1;q=2378;break y}if(i&2048){n=1;q=2379;break y}n=i&1;q=n?2380:2378}k=Wn(l,k,x)}i=(m|0)>-1?i&-65537:i;b=v[h+68>>2];j=b;l=v[h+64>>2];if(!((l|0)!=0|(b|0)!=0|m)){m=0;k=x;break f}b=!(j|l)+(x-k|0)|0;m=(b|0)<(m|0)?m:b;break f}b=v[h+64>>2];k=b?b:14119;b=jt(k,0,m);s=b?b:k+m|0;i=j;m=b?b-k|0:m;break f}j=v[h+64>>2];if(m){break t}b=0;ag(a,32,o,0,i);break s}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];v[h+64>>2]=h+8;m=-1;j=h+8|0}b=0;I:{while(1){k=v[j>>2];if(!k){break I}k=HI(h+4|0,k);l=(k|0)<0;if(!(l|k>>>0>m-b>>>0)){j=j+4|0;b=b+k|0;if(m>>>0>b>>>0){continue}break I}break}n=-1;if(l){break a}}ag(a,32,o,b,i);if(!b){b=0;break s}j=0;l=v[h+64>>2];while(1){k=v[l>>2];if(!k){break s}k=HI(h+4|0,k);j=k+j|0;if((j|0)>(b|0)){break s}sf(a,h+4|0,k);l=l+4|0;if(b>>>0>j>>>0){continue}break}}ag(a,32,o,b,i^8192);b=(b|0)<(o|0)?o:b;continue c}b=kb[f|0](a,A[h+64>>3],o,m,i,b)|0;continue c}t[h+55|0]=v[h+64>>2];m=1;k=z;i=j;break f}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}n=p;if(a){break a}if(!y){break e}b=1;while(1){a=v[(b<<2)+e>>2];if(a){NI((b<<3)+d|0,a,c,g);n=1;b=b+1|0;if((b|0)!=10){continue}break a}break}n=1;if(b>>>0>9){break a}while(1){n=1;b=b+1|0;if((b|0)==10){break a}n=-1;if(!v[(b<<2)+e>>2]){continue}break}break a}l=s-k|0;m=(l|0)>(m|0)?l:m;j=m+n|0;b=(j|0)>(o|0)?j:o;ag(a,32,b,j,i);sf(a,q,n);ag(a,48,b,j,i^65536);ag(a,48,m,l,0);sf(a,k,l);ag(a,32,b,j,i^8192);continue}break}n=0;break a}n=-1}gb=h+80|0;return n}function fL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-448|0;gb=e;a:{if(kk(b)){break a}f=w[nl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Cl(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}Md(e+184|0);f=v[e+184>>2];Md(e+416|0);h=ml(f,v[e+420>>2],b);Md(e+184|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=uc(e+432|0,18699);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){a=ba(8)|0;v[22692]=0;c=Q(2041,e+416|0,c|0)|0;b=v[22692];v[22692]=0;f:{g:{h:{if((b|0)!=1){v[22692]=0;U(2021,e+184|0,14701,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}qc(a,e+184|0);d=0;v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break g}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}if(!d){break e}d=ba(8)|0;v[22692]=0;f=Q(2041,e+384|0,b|0)|0;b=v[22692];v[22692]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22692]=0;U(2021,e+400|0,14737,f|0);a=v[22692];v[22692]=0;if((a|0)==1){break q}v[22692]=0;R(2038,e+416|0,e+400|0);b=v[22692];v[22692]=0;a=1;if((b|0)==1){break p}v[22692]=0;c=Q(2041,e+368|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break o}v[22692]=0;U(2042,e+184|0,e+416|0,c|0);b=v[22692];v[22692]=0;a=1;if((b|0)==1){break n}qc(d,e+184|0);v[22692]=0;U(184,d|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(c)}vb(e+416|0)}vb(e+400|0)}vb(f)}if(!a){break c}da(d|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=uc(e+352|0,18699);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Gc(e+176|0,e+168|0)){a=ba(8)|0;v[22692]=0;c=Q(2041,e+416|0,c|0)|0;b=v[22692];v[22692]=0;r:{s:{t:{if((b|0)!=1){v[22692]=0;U(2021,e+184|0,14701,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break t}qc(a,e+184|0);d=0;v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break s}b=P()|0;O()|0;break r}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=uc(e+336|0,9545);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Gc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=uc(e+320|0,2693);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Gc(e- -64|0,e+56|0)){v[a+52>>2]=0;break e}v[e+312>>2]=d;v[e+316>>2]=b;f=uc(e+304|0,8529);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Gc(e+48|0,e+40|0)){v[a+52>>2]=1;break e}v[e+296>>2]=d;v[e+300>>2]=b;b=uc(e+288|0,6317);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Gc(e+32|0,e+24|0)){v[a+52>>2]=2;break e}a=ba(8)|0;v[22692]=0;c=Q(2041,e+416|0,c|0)|0;b=v[22692];v[22692]=0;u:{v:{w:{if((b|0)!=1){v[22692]=0;U(2021,e+184|0,11771,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break w}qc(a,e+184|0);d=0;v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break v}b=P()|0;O()|0;break u}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=uc(e+272|0,8766);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Gc(e+144|0,e+136|0)){break e}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=uc(e+256|0,12662);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;x:{if(Gc(e+128|0,e+120|0)){break x}v[e+248>>2]=c;v[e+252>>2]=d;b=uc(e+240|0,12667);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Gc(e+112|0,e+104|0)){break x}v[e+232>>2]=c;v[e+236>>2]=d;b=uc(e+224|0,9850);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Gc(e+96|0,e+88|0)){break x}v[e+216>>2]=c;v[e+220>>2]=d;b=uc(e+208|0,6381);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Gc(e+80|0,e+72|0)){break x}a=ba(8)|0;v[22692]=0;c=Q(70,e+184|0,8802)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break e}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=wK(v[a+56>>2]),v[i+204>>2]=j;if(!Dy(e+184|0,v[b>>2]+24648|0)){break e}Mz(v[b>>2],e+184|0)}gb=e+448|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function jJ(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),v=0,w=0,x=0,y=0,A=C(0),D=0,E=0,F=C(0),G=C(0),H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0,R=0;if((d|0)>=1){while(1){D=B(v,2304)+b|0;q=c;x=0;s=gb-128|0;while(1){k=D+(x<<2)|0;o=0;l=s;j=l;while(1){i=z[B(31-o|0,72)+k>>2];w=B(o,72)+k|0;h=z[w>>2];m=C(i+h);n=z[w+1152>>2];t=z[B(15-o|0,72)+k>>2];A=C(n+t);z[j>>2]=m+A;w=B(o,12);i=C(z[w+68276>>2]*C(h-i));h=C(z[w+68272>>2]*C(t-n));z[j+64>>2]=i+h;n=z[w+68280>>2];z[j+32>>2]=n*C(m-A);z[j+96>>2]=C(i-h)*n;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){m=z[l+28>>2];n=z[l>>2];i=C(m+n);t=z[l+16>>2];A=z[l+12>>2];h=C(t+A);F=C(i+h);G=z[l+24>>2];J=z[l+4>>2];K=C(G+J);L=z[l+20>>2];M=z[l+8>>2];N=C(L+M);O=C(K+N);z[l>>2]=F+O;z[l+16>>2]=C(F-O)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(K-N))*C(.7071067690849304));z[l+24>>2]=C(i-h)*C(1.3065630197525024);z[l+8>>2]=C(h+i)*C(.5411961078643799);h=C(J-G);F=C(M-L);G=C(C(h+F)*C(.7071067690849304));i=C(n-m);m=C(G+i);h=C(i+h);n=C(C(C(A-t)+F)+C(h*C(-.1989123672246933)));h=C(C(n*C(.3826834261417389))+h);z[l+28>>2]=C(m-h)*C(2.562915563583374);z[l+4>>2]=C(h+m)*C(.509795606136322);h=C(n+C(h*C(-.1989123672246933)));i=C(i-G);z[l+20>>2]=C(h+i)*C(.8999761939048767);z[l+12>>2]=C(i-h)*C(.601344883441925);l=l+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;i=z[s+32>>2];h=z[s+96>>2];n=z[s+64>>2];while(1){z[k>>2]=z[s+(o<<2)>>2];l=k;o=o+1|0;k=s+(o<<2)|0;m=z[k+96>>2];t=C(m+h);z[l+72>>2]=t+n;h=z[k+32>>2];z[l+144>>2]=h+i;n=z[k- -64>>2];z[l+216>>2]=n+t;k=l+288|0;i=h;h=m;if((o|0)!=7){continue}break}z[l+288>>2]=z[s+28>>2];i=z[s+124>>2];z[l+360>>2]=i+z[s+92>>2];h=z[s+60>>2];z[l+504>>2]=i;z[l+432>>2]=h;x=x+1|0;if((q|0)!=(x|0)){continue}break}v=v+1|0;if((v|0)!=(d|0)){continue}break}}I=hc(f,a,3840);P=d<<5;v=0;while(1){k=gb-32|0;gb=k;o=(v<<8)+I|0;x=(v<<2)+b|0;z[o+4080>>2]=z[x+1152>>2];l=d;f=l-1|0;w=x+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[x>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[x+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[x+4>>2];z[o+4348>>2]=z[w+4>>2];D=(B(v,P)<<1)+e|0;E=D+(f<<1)|0;nt(E,l,o+244|0);f=l<<6;nt(f+E|0,l,o+500|0);nt(D,l,o+240|0);nt(f+D|0,l,o+496|0);H=o+3840|0;q=68368;f=14;while(1){s=f;g=f<<4;j=g+H|0;p=B(31-f|0,72);m=z[p+x>>2];z[j>>2]=m;z[(g|4)+H>>2]=z[p+w>>2];p=p|4;z[(g|8)+H>>2]=z[p+x>>2];z[(g|12)+H>>2]=z[p+w>>2];p=B(f,72);r=p+76|0;z[j+256>>2]=z[r+x>>2];z[j+260>>2]=z[r+w>>2];p=p+72|0;z[j-248>>2]=z[p+x>>2];z[j-244>>2]=z[p+w>>2];i=z[q>>2];p=g+o|0;t=z[p>>2];h=z[q+4>>2];n=C(C(m*i)-C(t*h));z[k+16>>2]=n;m=C(C(t*i)+C(m*h));z[k>>2]=m;r=f<<2;f=1;while(1){g=f<<2;t=z[g+j>>2];A=z[g+p>>2];z[g+(k+16|0)>>2]=C(t*i)-C(A*h);z[g+k>>2]=C(A*i)+C(t*h);f=f+1|0;if((f|0)!=4){continue}break}j=(r<<2)+H|0;p=j-3584|0;r=j-256|0;i=z[q+12>>2];h=z[q+8>>2];f=0;while(1){g=f<<2;t=z[g+p>>2];A=z[g+r>>2];z[g+(k+16|0)>>2]=C(C(t*i)-C(A*h))+n;z[g+k>>2]=C(C(t*h)+C(A*i))+m;f=f+1|0;if((f|0)!=4){g=f<<2;n=z[g+(k+16|0)>>2];m=z[g+k>>2];continue}break}p=j-3328|0;r=j-512|0;i=z[q+20>>2];h=z[q+16>>2];f=0;while(1){g=f<<2;y=g+k|0;m=z[g+p>>2];n=z[g+r>>2];z[y>>2]=C(C(m*h)+C(n*i))+z[y>>2];g=g+(k+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=j-3072|0;r=j-768|0;i=z[q+28>>2];h=z[q+24>>2];f=0;while(1){g=f<<2;y=g+k|0;m=z[g+p>>2];n=z[g+r>>2];z[y>>2]=C(C(m*h)+C(n*i))+z[y>>2];g=g+(k+16|0)|0;z[g>>2]=C(C(m*i)-C(n*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=j-2816|0;r=j-1024|0;i=z[q+36>>2];h=z[q+32>>2];f=0;while(1){g=f<<2;y=g+k|0;m=z[g+p>>2];n=z[g+r>>2];z[y>>2]=C(C(m*h)+C(n*i))+z[y>>2];g=g+(k+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=j-2560|0;r=j-1280|0;i=z[q+44>>2];h=z[q+40>>2];f=0;while(1){g=f<<2;y=g+k|0;m=z[g+p>>2];n=z[g+r>>2];z[y>>2]=C(C(m*h)+C(n*i))+z[y>>2];g=g+(k+16|0)|0;z[g>>2]=C(C(m*i)-C(n*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=j-2304|0;r=j-1536|0;i=z[q+52>>2];h=z[q+48>>2];f=0;while(1){g=f<<2;y=g+k|0;m=z[g+p>>2];n=z[g+r>>2];z[y>>2]=C(C(m*h)+C(n*i))+z[y>>2];g=g+(k+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=j-2048|0;p=j-1792|0;i=z[q+60>>2];h=z[q+56>>2];f=0;while(1){j=f<<2;r=j+k|0;m=z[g+j>>2];n=z[j+p>>2];z[r>>2]=C(C(m*h)+C(n*i))+z[r>>2];j=j+(k+16|0)|0;z[j>>2]=C(C(m*i)-C(n*h))+z[j>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(l,15-s|0)<<1;Q=f+E|0,R=vj(z[k+20>>2]),u[Q>>1]=R;j=B(l,s+17|0)<<1;Q=j+E|0,R=vj(z[k+4>>2]),u[Q>>1]=R;Q=f+D|0,R=vj(z[k+16>>2]),u[Q>>1]=R;Q=j+D|0,R=vj(z[k>>2]),u[Q>>1]=R;f=B(l,47-s|0)<<1;Q=f+E|0,R=vj(z[k+28>>2]),u[Q>>1]=R;j=B(l,s+49|0)<<1;Q=j+E|0,R=vj(z[k+12>>2]),u[Q>>1]=R;Q=f+D|0,R=vj(z[k+24>>2]),u[Q>>1]=R;Q=j+D|0,R=vj(z[k+8>>2]),u[Q>>1]=R;f=s-1|0;q=q- -64|0;if(s){continue}break}gb=k+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+I>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}hc(a,(b<<2)+I|0,3840)}}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-160|0;gb=d;vc(c);a:{b:{c:{d:{if(!(!xr(c,d+144|0)|v[d+144>>2]!=1297239878|!((w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))!=1146437965?v[d+152>>2]==1482052408|(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))==1448293937:1))){m=Fh(d+120|0,c);v[22692]=0;R(1147,d+104|0,m|0);c=v[22692];v[22692]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((c|0)!=1){v[22692]=0;i=T(214,d+80|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break n}k=Rc(d+76|0,8,1,1,0);if((w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))!=1146437965){break j}v[22692]=0;U(1148,d+56|0,d+104|0,1296581714);c=v[22692];v[22692]=0;if((c|0)==1){break m}v[22692]=0;U(1148,d+32|0,d+104|0,1296318804);c=v[22692];v[22692]=0;if((c|0)==1){break d}qd(i,d+32|0);xb(d+32|0);v[22692]=0;g=T(1149,d+56|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}e=1;c=0;if(!g){break k}v[22692]=0;g=T(275,i|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}f=0;if(!g){break k}v[22692]=0;f=T(426,d+56|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}v[22692]=0;j=T(416,d+56|0)|0;c=v[22692];v[22692]=0;o:{if((c|0)==1){break o}v[22692]=0;Q(318,d+56|0,2)|0;c=v[22692];v[22692]=0;if((c|0)==1){break o}v[22692]=0;c=T(426,d+56|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break l}}break d}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}v[22692]=0;R(1150,d+32|0,d+56|0);g=v[22692];v[22692]=0;e=1;if((g|0)==1){break d}g=d+32|0;if(!Ib(w[g|0]|w[g+1|0]<<8)){break k}h=fc(d+32|0);l=Te(d+32|0);c=(c>>>0)/(Ib(w[g|0]|w[g+1|0]<<8)>>>0)|0;if((Ib(w[h|0]|w[h+1|0]<<8)|0)!=(Ib(w[l|0]|w[l+1|0]<<8)+1|0)){break k}g=d+38|0;if((Ib(w[h|0]|w[h+1|0]<<8)|0)==2){vp(k,2)}p:{if((j|0)!=16){if((j|0)!=8){break k}if(!Ib(w[g|0]|w[g+1|0]<<8)){zf(k,1);break p}if((Ib(w[g|0]|w[g+1|0]<<8)|0)==2){zf(k,18);break p}if((Ib(w[g|0]|w[g+1|0]<<8)|0)!=3){break k}zf(k,17);break p}if(Ib(w[g|0]|w[g+1|0]<<8)){break k}Xi(k,16)}e=0}xb(d+56|0);if(!e){break i}e=0;break e}v[22692]=0;U(1148,d+56|0,d+104|0,1447576658);c=v[22692];v[22692]=0;q:{r:{if((c|0)!=1){v[22692]=0;U(1148,d+32|0,d+104|0,1128808782);c=v[22692];v[22692]=0;if((c|0)==1){break r}v[22692]=0;U(1148,d+8|0,d+104|0,1112491097);c=v[22692];v[22692]=0;if((c|0)==1){break g}qd(i,d+8|0);xb(d+8|0);v[22692]=0;e=T(275,i|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}c=0;f=0;s:{if(!e){break s}v[22692]=0;e=T(275,d+56|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}c=0;f=0;if(!e){break s}v[22692]=0;e=Q(1151,d+56|0,d+8|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}c=0;f=0;if(!e){break s}c=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);v[22692]=0;e=T(426,d+32|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}g=(c|0)!=1482052408;if(g){Rc(d+4|0,16,1,0,0);v[d+76>>2]=v[d+4>>2]}if((e|0)==6){vp(k,3)}c=d+8|0;h=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=d+8|4;j=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=d+20|0;c=Ib(w[c|0]|w[c+1|0]<<8);f=d+24|0;n=Yb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22692]=0;l=T(193,i|0)|0;f=v[22692];v[22692]=0;o=1;if((f|0)==1){break g}f=B((e|0)==6?2:1,g?2:1);g=(h>>>0)/(f>>>0)|0;h=(j>>>0)/(f>>>0)|0;f=(l>>>0)/(f>>>0)|0}xb(d+32|0);xb(d+56|0);e=0;if(o){break h}break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break f}break g}h=0;g=0}v[22692]=0;Q(1127,a|0,b|0)|0;e=v[22692];v[22692]=0;t:{u:{v:{w:{if((e|0)!=1){v[22692]=0;j=B(b,104)+a|0;e=j+484380|0;R(424,e|0,0);l=v[22692];v[22692]=0;if((l|0)==1){break w}v[e>>2]=f;h=g+h|0;v[j+484388>>2]=h;v[j+484384>>2]=g;if(!(f>>>0<h>>>0|h>>>0<=g+4>>>0)){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]|2}f=B(b,104)+a|0;v[f+484404>>2]=c?c:22050;c=n>>>8|0;u[f+484410>>1]=c&65535?(n&16776960)>>>0>65536?256:c:256;c=v[a+480180>>2];v[22692]=0;U(1129,e|0,32,c|0);c=v[22692];v[22692]=0;x:{y:{z:{A:{if((c|0)!=1){v[22692]=0;U(1148,d+56|0,d+104|0,1312902469);c=v[22692];v[22692]=0;if((c|0)==1){break A}v[22692]=0;c=T(275,d+56|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break u}if(!c){break z}v[22692]=0;c=T(193,d+56|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break u}v[22692]=0;W(501,d+56|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break y}break u}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22692]=0;c=Q(70,d+32|0,18699)|0;f=v[22692];v[22692]=0;if((f|0)==1){break x}v[22692]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break v}vb(c)}v[22692]=0;W(329,k|0,e|0,i|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break u}v[22692]=0;_h(e,a,0);a=v[22692];v[22692]=0;if((a|0)==1){break u}xb(d+56|0);e=1;break e}e=P()|0;O()|0;break t}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(c);break t}e=P()|0;O()|0}xb(d+56|0);break c}e=P()|0;O()|0;xb(d+32|0)}xb(d+56|0);break c}xb(i);Ed(d+104|0);xb(m)}gb=d+160|0;return e|0}e=P()|0;O()|0;xb(d+56|0)}xb(i)}Ed(d+104|0)}xb(m);S(e|0);L()}function mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;d=gb-752|0;gb=d;vc(b);f=gb-32|0;gb=f;h=d+144|0;sU(f+24|0,h);i=yb(f+24|0);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;e=b;cc(f+16|0,e,f);g=yb(f+16|0);if((g|0)==(i|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){rU(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!e){break m}if(!vU(d+144|0)){break m}if(!Pb(b,Qc(uU(d+144|0),jb))){break m}if(!c){p=1;break m}Id(a,262144);Fk(d+104|0,2,d+144|0);Bc(d+24|0,d+104|0);Eb(a+1298268|0,d+24|0);vb(d+24|0);e=Tb(d+24|0,5435);Eb(a+1298304|0,e);vb(e);e=Tb(d+24|0,7349);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=Tb(e,1302);Dc(d+104|0,f);vb(f);gb=e+16|0;t[d+8|0]=w[d+174|0];e=w[d+173|0];v[22692]=0;t[d+127|0]=e;R(869,d+128|0,d+127|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;Y(372,d+24|0,d+104|0,d+8|0,d+128|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}Eb(a+1298328|0,d+24|0);vb(d+24|0);vb(d+128|0);Hb(d+104|0);v[a+480208>>2]=12;v[a+1298364>>2]=5;u[a+480188>>1]=w[d+182|0]|w[d+183|0]<<8;u[d+24>>1]=w[d+178|0]|w[d+179|0]<<8;u[d+104>>1]=3999;C=a,D=x[Pc(d+24|0,d+104|0)>>1],u[C+480190>>1]=D;EX(Sb(a+484360|0),d+240|0,w[d+176|0]|w[d+177|0]<<8);if(x[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;Ue(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}ud(d+24|0,b,B(w[d+178|0]|w[d+179|0]<<8,80));l=jc(d+104|0,d+24|0);xb(d+24|0);if(x[a+480190>>1]){i=c&2;h=d+72|0;e=0;while(1){v[22692]=0;R(870,l|0,d+24|0);f=v[22692];v[22692]=0;if((f|0)==1){break l}v[22692]=0;Fk(d+8|0,2,h);f=v[22692];v[22692]=0;n:{o:{p:{if((f|0)==1){break p}v[22692]=0;R(324,d+128|0,d+8|0);f=v[22692];v[22692]=0;if((f|0)==1){break p}v[22692]=0;e=e+1|0;Q(301,((e<<5)+a|0)+946304|0,d+128|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break o}vb(d+128|0);v[22692]=0;f=(B(e,104)+a|0)+484380|0;U(871,d+128|0,d+24|0,f|0);g=v[22692];v[22692]=0;q:{if((g|0)==1){break q}if(!i|!v[f>>2]){break n}g=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[22692]=0;g=Q(188,b|0,g|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break q}if(!g){break n}v[22692]=0;W(329,d+128|0,f|0,b|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break n}}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+128|0);break e}if(x[a+480190>>1]>e>>>0){continue}break}}p=1;r:{if(!(c&1)){break r}c=w[d+180|0]|w[d+181|0]<<8;g=0;v[22692]=0;m=a+484344|0;R(330,m|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break k}if(!(w[d+180|0]|w[d+181|0]<<8)){break r}q=d+24|4;r=d+24|2;s=d+24|5;y=d+24|3;z=d+24|1;while(1){v[22692]=0;c=W(331,m|0,g&65535,64)|0;e=v[22692];v[22692]=0;if((e|0)==1){break j}s:{if(!c){break s}c=(g<<1)+d|0;e=c+496|0;if(!(w[e|0]|w[e+1|0]<<8)){break s}c=w[c+496|0]|w[c+497|0]<<8;v[22692]=0;c=Q(188,b|0,c<<4)|0;e=v[22692];v[22692]=0;if((e|0)==1){break j}if(!c){break s}n=0;c=_b(m,g);v[22692]=0;c=Wc(c,0,0);e=v[22692];v[22692]=0;if((e|0)==1){break f}while(1){v[22692]=0;e=Q(189,b|0,1)|0;f=v[22692];v[22692]=0;t:{u:{v:{if((f|0)!=1){if(!e){break s}v[22692]=0;k=T(374,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break v}if(k){break u}n=n+1|0;c=B(x[a+480188>>1],6)+c|0;break t}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}u[d+28>>1]=0;v[d+24>>2]=0;e=k&31;i=B(e,6)+c|0;o=_i(d+24|0);h=e>>>0<x[a+480188>>1];w:{if(!(k&32)){break w}v[22692]=0;R(403,d+128|0,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break i}f=od(d+128|0);j=h?i:d+24|0;e=w[d+128|0];t[j|0]=e;t[(h?i+1|0:z)|0]=w[f|0];x:{if(e){if((e|0)==254){break x}if(e>>>0<121){break w}}e=0}t[j|0]=e}y:{if(!(k&64)){break y}v[22692]=0;R(403,d+128|0,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break h}A=od(d+128|0);e=h?i+3|0:y;f=w[d+128|0];t[e|0]=f;j=h?i+5|0:s;t[j|0]=w[A|0];z:{A:{B:{if(f>>>0<=15){v[22692]=0;Nf(h?i:o);f=v[22692];v[22692]=0;if((f|0)!=1){break B}a=P()|0;O()|0;break e}if(f>>>0>23){break z}o=e;e=w[f+33303|0];t[o|0]=e;break A}e=w[e|0]}e=e&255;if((e|0)!=23){if((e|0)!=9){break y}e=w[j|0];C:{D:{if(e>>>0>=136){f=e&127;break D}f=128;if(e>>>0<129){break C}}t[j|0]=f;e=f}t[j|0]=(B(e&127,255)>>>0)/127;break y}v[22692]=0;t[d+8|0]=64;e=ac(j,d+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){t[j|0]=w[e|0]<<1;break y}a=P()|0;O()|0;break e}t[e|0]=0}if(!(k&128)){break t}t[(h?i+2|0:r)|0]=1;v[22692]=0;e=T(374,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}t[(h?i+4|0:q)|0]=e}if(n>>>0<64){continue}break}}g=g+1|0;if(g>>>0<(w[d+180|0]|w[d+181|0]<<8)>>>0){continue}break}}xb(l)}gb=d+752|0;return p|0}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}xb(l);break a}a=P()|0;O()|0;vb(d+128|0);break b}a=P()|0;O()|0}Hb(d+104|0)}S(a|0);L()}function sma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-240|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!xr(b,d+224|0)){break h}if(!pV(d+224|0)){break h}i=oi(d+200|0);k=Kb(d+184|0);aD(d+120|0);v[22692]=0;e=Q(775,b|0,d+112|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}i:{if(!e){break i}e=d+112|4;h=Yb(Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-4|0);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=0;while(1){f=Yb(Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-8|0);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;j:{if(c){break j}f=d+112|0;if((Yb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)!=1347699796){break j}h=1;break i}f=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22692]=0;U(288,d+88|0,b|0,f|0);f=v[22692];v[22692]=0;k:{l:{m:{n:{o:{if((f|0)!=1){f=jc(d+8|0,d+88|0);xb(d+88|0);v[22692]=0;g=T(275,d+8|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break n}if(g){break o}xb(d+8|0);break k}a=P()|0;O()|0;break a}g=d+112|0;g=Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((g|0)<=1347699795){if((g|0)==1129139796){break m}if((g|0)!=1229866575){break l}v[22692]=0;l=Q(776,f|0,d+120|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break n}break l}if((g|0)!=1347699796){if((g|0)!=1447383635){break l}v[22692]=0;Q(318,d+8|0,4)|0;g=v[22692];v[22692]=0;if((g|0)==1){break n}v[22692]=0;g=T(777,f|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break n}if(!g){break l}if(Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0<7){break l}g=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22692]=0;U(778,f|0,k|0,g-6|0);f=v[22692];v[22692]=0;if((f|0)==1){break n}break l}v[22692]=0;h=W(779,a|0,f|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break l}}a=P()|0;O()|0;xb(d+8|0);break a}uw(i,f)}xb(d+8|0);v[22692]=0;f=Q(775,b|0,d+112|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}if(f){continue}}break}if(ed(k)){v[22692]=0;b=Q(2,d+8|0,12029)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}Eb(k,b);vb(b)}p:{if(!(h&l&1)){break p}b=d+162|0;b=Ib(w[b|0]|w[b+1|0]<<8);v[22692]=0;c=b&256;W(409,a+1074312|0,5,!c|0)|0;b=v[22692];v[22692]=0;q:{r:{if((b|0)!=1){b=d+158|0;if(Ib(w[b|0]|w[b+1|0]<<8)){u[d+8>>1]=64;b=Ib(w[b|0]|w[b+1|0]<<8);v[22692]=0;u[d+88>>1]=b;b=Pc(d+8|0,d+88|0);e=v[22692];v[22692]=0;if((e|0)==1){break r}v[a+480228>>2]=x[b>>1]}b=d+160|0;if(!(!Ib(w[b|0]|w[b+1|0]<<8)|!c)){m=a,n=B(Ib(w[b|0]|w[b+1|0]<<8),1e4),v[m+480204>>2]=n}if(w[d+120|0]){v[22692]=0;Ie(d+88|0,2,d+120|0);b=v[22692];v[22692]=0;if((b|0)==1){break q}v[22692]=0;R(324,d+8|0,d+88|0);b=v[22692];v[22692]=0;if((b|0)==1){break q}Eb(a+1298268|0,d+8|0);vb(d+8|0)}v[d+8>>2]=1;v[d+88>>2]=12;c=d+166|0;if(!br(c,d+8|0,d+88|0)){break p}v[d+80>>2]=31;v[d+84>>2]=1;e=d+164|0;if(!br(e,d+84|0,d+80|0)){break p}v[d+72>>2]=23;v[d+76>>2]=0;f=d+170|0;if(!br(f,d+76|0,d+72|0)){break p}v[d+64>>2]=59;v[d+68>>2]=0;g=d+172|0;if(!br(g,d+68|0,d- -64|0)){break p}v[d+56>>2]=59;v[d+60>>2]=0;j=d+174|0;if(!br(j,d+60|0,d+56|0)){break p}b=Ar(d+8|0);l=d+168|0;m=b,n=Ib(w[l|0]|w[l+1|0]<<8),v[m+20>>2]=n;m=b,n=Ib(w[c|0]|w[c+1|0]<<8)-1|0,v[m+16>>2]=n;m=b,n=Ib(w[e|0]|w[e+1|0]<<8),v[m+12>>2]=n;m=b,n=Ib(w[f|0]|w[f+1|0]<<8),v[m+8>>2]=n;m=b,n=Ib(w[g|0]|w[g+1|0]<<8),v[m+4>>2]=n;m=b,n=Ib(w[j|0]|w[j+1|0]<<8),v[m>>2]=n;v[22692]=0;R(597,a+1298368|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(h&1){v[22692]=0;b=T(275,i|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}if(b){b=Kb(d+8|0);v[22692]=0;W(413,i|0,b|0,32)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}if(ur(b,11011)){v[22692]=0;U(13,d+88|0,2,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}Eb(a+1298280|0,d+88|0);vb(d+88|0)}v[22692]=0;c=T(780,i|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!c){v[22692]=0;c=T(465,i|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}v[22692]=0;fa(471,a+1298292|0,i|0,c|0,40,0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}}vb(b)}v[22692]=0;b=Q(2,d+88|0,14606)|0;c=v[22692];v[22692]=0;if((c|0)==1){break g}v[22692]=0;U(647,d+8|0,b|0,k|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}Eb(a+1298328|0,d+8|0);vb(d+8|0);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22692]=0;a=a+1074312|0;W(409,a|0,84,1)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;W(409,a|0,83,1)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;Q(410,a|0,85)|0;a=v[22692];v[22692]=0;if((a|0)==1){break d}}vb(k);xb(i)}gb=d+240|0;return h&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b)}vb(k);xb(i);S(a|0);L()}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=gb-208|0;gb=g;vc(b);a:{b:{c:{d:{e:{if(!SC(b,g+160|0)){break e}if(!mT(g+160|0)){break e}if(!c){h=1;break e}if(!Pb(b,Qc(lT(g+160|0),jb))){break e}Id(a,128);Ie(g+144|0,2,g+175|0);Bc(g+72|0,g+144|0);Eb(a+1298268|0,g+72|0);vb(g+72|0);d=Tb(g+72|0,5585);Eb(a+1298304|0,d);vb(d);d=Tb(g+72|0,3145);Eb(a+1298316|0,d);vb(d);d=Tb(g+144|0,14618);v[22692]=0;U(940,g+72|0,d|0,v[(w[g+174|0]<<2)+33164>>2]);e=v[22692];v[22692]=0;h=1;if((e|0)==1){break b}Eb(a+1298328|0,g+72|0);vb(g+72|0);vb(d);v[a+480208>>2]=12;v[a+1298364>>2]=5;gB(a+1298292|0,b,w[g+207|0]<<5,32,0);y=a,z=Ae(b),u[y+480190>>1]=z;if(x[a+480190>>1]){j=1;while(1){f:{if(w[g+174|0]>=52){d=g+72|0;if(!kY(b,d)){cD(d)}break f}e=gb-48|0;gb=e;v[e+44>>2]=64;v[e+24>>2]=66;d=b;i=v[Fb(e+44|0,e+24|0)>>2];if(!Pb(d,i)){i=mf(d)}f=g+72|0;Av(e+24|0,f);l=vd(e+32|0,v[e+24>>2],i);m=v[l+4>>2];v[e+8>>2]=v[l>>2];v[e+12>>2]=m;cc(e+16|0,d,e+8|0);Av(e+24|0,f);Qb(v[e+24>>2]+i|0,0,66-i|0);Rb(d,v[e+44>>2]);gb=e+48|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=gb-32|0;gb=i;e=(B(h,104)+a|0)+484380|0;td(e,0);d=g+72|0;Ek(i,2,d+32|0);Bc(i+16|0,i);v[22692]=0;Q(303,e+43|0,i+16|0)|0;f=v[22692];v[22692]=0;g:{if((f|0)!=1){vb(i+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=e,z=v[Fb(i+16|0,e)>>2],v[y+16>>2]=z;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Ho(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}gb=i+32|0;break g}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}Ie(g+56|0,2,g+72|0);Bc(g+144|0,g+56|0);v[22692]=0;Q(301,((h<<5)+a|0)+946304|0,g+144|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}vb(g+144|0);j=j+1|0;h=j&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}cp(Sb(a+484360|0),b,256,255,254);h=0;d=Ae(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Ae(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(h<<5)+a|0;Ue(e+480280|0);i=e+480284|0;i:{if(w[g+174|0]>=51){e=(Ae(b)<<4|8)&248;break i}e=h&1?192:64}u[i>>1]=e;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}l=a+484344|0;xg(l,r);h=0;j=0;while(1){e=j&65535;if(!sh(l,e,64)){break e}j=j+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=_i(g+72|0);m=0;while(1){if(Pb(b,5)){j=0;h=Wc(_b(l,m),0,o&65535);while(1){s=64-j|0;n=w[g+174|0];f=gb-16|0;gb=f;p=1;d=i;q=d;e=b;k=Ae(e);if((k|0)==252){p=Ae(e);k=Ae(e)}t[q|0]=(k-1&255)>>>0<60?k+36|0:0;pn(f+8|0,e);e=od(f+8|0);k=Te(f+8|0);q=bj(f+8|0);t[d+1|0]=w[f+8|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[k|0];t[f+4|0]=w[q|0];kT(f+7|0,f+5|0,n);kT(f+6|0,f+4|0,n);k=w[f+7|0];n=(k|0)!=10;e=w[f+6|0];j:{if(!(n|(e|0)!=10)){t[f+7|0]=0;y=f,z=_l((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[y+5|0]=z;break j}k:{l:{m:{if(!n){y=f,z=_l(w[f+5|0]<<2),t[y+5|0]=z;break m}if((e|0)==10){y=f,z=_l(w[f+4|0]<<2),t[y+4|0]=z;break j}if((e|0)!=(k|0)){break m}t[f+6|0]=0;break l}if((e|0)==13){break k}if(e){break j}}if((k|0)==13){break j}}Dh(f+7|0,f+6|0);Dh(f+5|0,f+4|0)}hz(f+6|0,f+4|0,f+7|0,f+5|0);mo(f,f+7|0,f+5|0,f+6|0,f+4|0);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];gb=f+16|0;e=j+p|0;j=e>>>0>64?s:p;if(j){while(1){d=v[g+72>>2];t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=x[g+76>>1];t[h+4|0]=d;t[h+5|0]=d>>>8;h=B(x[a+480188>>1],6)+h|0;j=j-1|0;if(j){continue}break}d=e>>>0<64;j=d?e:64;if(d){continue}}break}m=m+1|0;if((r|0)!=(m|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;i=Xu(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[22692]=0;U(942,i|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)==1){a=P()|0;O()|0;Ce(i);S(a|0);L()}v[22692]=0;U(941,g+32|0,l|0,d|0);e=v[22692];v[22692]=0;h=1;if((e|0)==1){break d}Ce(g+32|0);Ce(d);if(!(c&2)|!x[a+480190>>1]){break e}j=1;while(1){c=B(j&65535,104)+a|0;Ag(Rc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);j=j+1|0;if(x[a+480190>>1]>=(j&65535)>>>0){continue}break}}gb=g+208|0;return h|0}h=P()|0;O()|0;Ce(d);break a}h=P()|0;O()|0;vb(g+144|0);break a}h=P()|0;O()|0;vb(d)}S(h|0);L()}function Fd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=gb-96|0;gb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;Kf(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;Kf(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=jqa(d,0,b,s);b=jb;G=b;e=f;A=e<<15&-32768;k=p;g=jqa(A,0,k,0);f=g+q|0;e=jb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=jqa(c,s,A,B);f=i+g|0;b=j;j=j+jb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=jqa(d,r,k,H);K=jb;p=m;f=jqa(A,B,m,0);b=f+N|0;j=jb+K|0;O=b;m=jqa(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+jb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=jqa(d,r,p,P);G=jb;f=A;I=y|65536;A=o;i=jqa(f,B,I,o);f=i+Q|0;j=jb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=jqa(C,S,k,H);i=f+B|0;o=j;f=j+jb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=jqa(c,s,D,0);c=L+i|0;s=f;j=f+jb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=jqa(p,P,C,S);e=jb;r=jqa(d,r,I,A);d=r+f|0;j=jb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=jqa(D,T,k,H);d=f+d|0;j=jb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=jqa(D,T,I,A);b=e+b|0;j=jb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=jqa(D,T,p,P);f=jb;p=jqa(C,S,I,A);b=p+k|0;j=jb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;Kf(l+48|0,u,g,h,i,j);Kf(l+32|0,d,e,b,c,j);hm(l+16|0,u,g,h,i,f);hm(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;gb=l+96|0}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-3056|0;gb=e;vc(b);f=gb-32|0;gb=f;i=e+1096|0;zD(f+24|0,i);k=yb(f+24|0);g=v[f+28>>2];l=v[f+24>>2];v[f+8>>2]=l;v[f+12>>2]=g;v[f>>2]=l;v[f+4>>2]=g;g=b;cc(f+16|0,g,f);l=yb(f+16|0);if((l|0)==(k|0)){Rb(g,yb(f+24|0))}gb=f+32|0;g=(k|0)==(l|0);if(!g){yD(i)}a:{if(!g){break a}if(!CD(e+1096|0)){break a}if(!c){d=1;break a}if(!Pb(b,Qc(1024,0))){break a}BD(b,e+576|0);BD(b,e- -64|0);while(1){g=h<<2;f=g+(e+576|0)|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>16777215){break a}g=g+(e- -64|0)|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0<3|(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0>4096){break a}if(!ns(b,((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))+(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))|0)+2978|0)){break a}h=h+1|0;if((h|0)!=128){continue}break}Id(a,2);yg(a);d=Tb(e+40|0,11092);Eb(a+1298304|0,d);vb(d);d=Tb(e+40|0,11910);Eb(a+1298316|0,d);vb(d);d=Tb(e+40|0,12580);Eb(a+1298328|0,d);vb(d);v[a+1298364>>2]=5;d=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;k=a+484360|0;bf(Sb(k),w[e+1097|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;h=B(g,104)+a|0;f=h+484380|0;td(f,2);ii(e+16|0,1,(B(d,13)+e|0)+1098|0);Bc(e+40|0,e+16|0);v[22692]=0;Q(301,((g<<5)+a|0)+946304|0,e+40|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break e}vb(e+40|0);n=f;d=(e+1096|0)+(d<<4)|0;f=d+422|0;v[n>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[h+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[h+484414>>1]=2;v[h+484388>>2]=d}v[h+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}h=0;while(1){d=h+33|0;g=(B(d,104)+a|0)+484380|0;td(g,2);ii(e+16|0,1,(B(h,13)+e|0)+2026|0);Bc(e+40|0,e+16|0);v[22692]=0;Q(301,((d<<5)+a|0)+946304|0,e+40|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}vb(e+40|0);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(h,11)|0;f=w[d+1347|0];p=lc(e+40|0,0),q=f,t[p|0]=q;f=w[d+1352|0];p=lc(e+40|0,1),q=f,t[p|0]=q;f=w[d+1348|0];p=lc(e+40|0,2),q=f,t[p|0]=q;f=w[d+1353|0];p=lc(e+40|0,3),q=f,t[p|0]=q;f=w[d+1349|0];p=lc(e+40|0,4),q=f,t[p|0]=q;f=w[d+1354|0];p=lc(e+40|0,5),q=f,t[p|0]=q;f=w[d+1350|0];p=lc(e+40|0,6),q=f,t[p|0]=q;f=w[d+1355|0];p=lc(e+40|0,7),q=f,t[p|0]=q;f=w[d+1351|0];p=lc(e+40|0,8),q=f,t[p|0]=q;f=w[d+1356|0];p=lc(e+40|0,9),q=f,t[p|0]=q;d=w[d+1346|0];p=lc(e+40|0,10),q=d,t[p|0]=q;v[e+8>>2]=v[e+48>>2];d=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=d;Jo(g,1,e);h=h+1|0;if((h|0)!=32){continue}break}Qr(Sb(k),e+2794|0,256,255,65535);l=a+484344|0;xg(l,128);n=c&1;h=0;f:{while(1){g=h<<2;d=g+(e+576|0)|0;Yc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=g+(e- -64|0)|0;ud(e+16|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));f=jc(e+40|0,e+16|0);xb(e+16|0);g:{if(!n){break g}v[22692]=0;d=W(331,l|0,h&65535,64)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!d){break g}d=0;k=_b(l,h);while(1){v[22692]=0;g=Q(189,e+40|0,1)|0;i=v[22692];v[22692]=0;h:{i:{if((i|0)!=1){if(!g){break g}v[22692]=0;g=T(374,f|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}if(g>>>0>12){break i}v[22692]=0;i=Wc(k,d,g);j=v[22692];v[22692]=0;if((j|0)==1){break c}v[22692]=0;R(403,e+16|0,f|0);j=v[22692];v[22692]=0;if((j|0)==1){break c}j=od(e+16|0);m=e+16|0;o=w[m|0];g=g>>>0>3;t[i|0]=((o&15)+(g?13:37)|0)+B(o>>>4&7,12);t[i+1|0]=((w[j|0]>>>4|0)+(g?33:1)|0)+(w[m|0]>>>3&16);AD(i,w[j|0],g);break h}break c}i=g-32|0;if((i&255)>>>0<=12){v[22692]=0;i=Wc(k,d,i&65535);j=v[22692];v[22692]=0;if((j|0)==1){break c}v[22692]=0;j=T(374,f|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break c}AD(i,j,g>>>0>35);break h}if((g|0)!=64){if((g|0)!=96){break f}if(!d){break g}v[22692]=0;d=Wc(k,d-1|0,0);g=v[22692];v[22692]=0;if((g|0)==1){break c}t[d+3|0]=14;break g}v[22692]=0;g=T(374,f|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}d=d+g|0}if(d>>>0<64){continue}break}}xb(e+40|0);h=h+1|0;if((h|0)!=128){continue}break}d=1;if(!(c&2)){break a}h=1;while(1){Ag(Rc(e+40|0,8,1,0,1),(B(h,104)+a|0)+484380|0,b);h=h+1|0;if((h|0)!=33){continue}break}break a}xb(e+40|0);d=0;break a}d=P()|0;O()|0;vb(e+40|0);break b}d=P()|0;O()|0;vb(e+40|0);break b}d=P()|0;O()|0;xb(e+40|0)}S(d|0);L()}gb=e+3056|0;return d|0}function EZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-128|0;gb=e;vc(b);a:{if(!Pr(b,8982)){break a}if(!Xv(b,e+112|0)){break a}if(!WD(e+112|0)){break a}if(!Pb(b,Qc(VD(e+112|0),jb))){break a}if(!Rb(b,w[e+121|0]|w[e+122|0]<<8)){break a}b:{if(!c){break b}Id(a,4096);v[a+480208>>2]=12;d=1;u[a+480188>>1]=(w[e+112|2]&31)+1;i=e+112|3;u[a+480190>>1]=w[i|0];uh(a,1);f=Tb(e+32|0,5608);Eb(a+1298304|0,f);vb(f);f=Tb(e+32|0,4104);Eb(a+1298316|0,f);vb(f);f=gb-16|0;gb=f;g=Tb(f,1356);Dc(e+8|0,g);vb(g);gb=f+16|0;v[22692]=0;Y(349,e+32|0,e+8|0,e+112|1,e+112|0);f=v[22692];v[22692]=0;c:{d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){Eb(a+1298328|0,e+32|0);vb(e+32|0);Hb(e+8|0);v[a+1298364>>2]=5;g=w[i|0];f=gb-16|0;gb=f;i=e+96|0;v[i>>2]=0;v[i+4>>2]=0;v[f+12>>2]=0;df(i+8|0,f+12|0,f+8|0);if(g){Vr(i,g);QE(i,g,0)}gb=f+16|0;k:{if(x[a+480190>>1]){f=1;while(1){v[22692]=0;R(350,b|0,e+32|0);g=v[22692];v[22692]=0;if((g|0)==1){break k}v[22692]=0;R(351,e+32|0,(B(d,104)+a|0)+484380|0);g=v[22692];v[22692]=0;if((g|0)==1){break k}g=w[e+48|0];pe(e+8|0,i,d-1|0);Af(e+8|0,(g&3)!=0);f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22692]=0;W(352,b|0,a+1298268|0,-1)|0;f=v[22692];v[22692]=0;d=1;l:{m:{if((f|0)!=1){if(x[a+480190>>1]){while(1){v[22692]=0;W(353,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;f=v[22692];v[22692]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[22692]=0;f=(d<<5)+a|0;Ue(f+480280|0);g=v[22692];v[22692]=0;if((g|0)==1){break e}v[22692]=0;U(355,b|0,f+480289|0,-1);f=v[22692];v[22692]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+112|4;g=w[f|0]|w[f+1|0]<<8;d=0;v[22692]=0;k=a+484344|0;R(330,k|0,g|0);g=v[22692];v[22692]=0;if((g|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){while(1){v[22692]=0;U(356,b|0,e+32|0,-1);g=v[22692];v[22692]=0;n:{o:{if((g|0)==1){break o}v[22692]=0;g=W(331,k|0,d&65535,64)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}if(!g){break n}g=_b(k,d);v[22692]=0;R(357,g|0,e+32|0);g=v[22692];v[22692]=0;if((g|0)!=1){break n}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[22692]=0;h=T(287,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}p:{if(!h){break p}v[22692]=0;d=Q(189,b|0,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}if(!d){break p}g=mc(e+32|0);v[22692]=0;W(358,b|0,g|0,h|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break h}d=Kb(e+8|0);v[22692]=0;R(60,d|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break i}m=e,n=Vb(g),v[m+56>>2]=n;m=e,n=Zb(g),v[m+88>>2]=n;if(Gb(e+56|0,e+88|0)){while(1){q:{h=w[v[e+56>>2]];if(h&128){m=e,n=ef(d),v[m+72>>2]=n;Hd(e+80|0,e+72|0);v[22692]=0;ca(359,d|0,v[e+80>>2],h&127,32)|0;h=v[22692];v[22692]=0;if((h|0)!=1){break q}break i}v[22692]=0;R(61,d|0,h<<24>>24);h=v[22692];v[22692]=0;if((h|0)!=1){break q}break i}Ne(e+56|0);if(Gb(e+56|0,e+88|0)){continue}break}}v[22692]=0;Y(360,e+56|0,5,6,d|0);h=v[22692];v[22692]=0;if((h|0)==1){break i}Eb(d,e+56|0);vb(e+56|0);h=zb(Jb(d));j=Ab(d);v[22692]=0;fa(361,a+1298292|0,h|0,j|0,76,0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break i}vb(d);gc(g)}g=Sb(a+484360|0);d=e+112|6;h=w[d|0]|w[d+1|0]<<8;d=0;v[22692]=0;fa(362,g|0,b|0,h|0,65535,65535)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}r:{s:{t:{u:{if(!(w[f|0]|w[f+1|0]<<8)){break u}g=c&1;while(1){v[22692]=0;h=Q(189,b|0,4)|0;j=v[22692];v[22692]=0;v:{if((j|0)!=1){if(h){break v}break u}b=P()|0;O()|0;break d}v[22692]=0;h=T(190,b|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break s}v[22692]=0;U(288,e+8|0,b|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break r}h=jc(e+32|0,e+8|0);xb(e+8|0);w:{if(!g){break w}v[22692]=0;j=le(k,d&65535);l=v[22692];v[22692]=0;if((l|0)==1){break t}if(!j){break w}j=_b(k,d);v[22692]=0;U(364,j|0,0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break t}}xb(e+32|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){d=1;c=1;while(1){f=B(d,104)+a|0;g=x[f+484414>>1];pe(e+32|0,i,d-1|0);d=Rc(e+8|0,g&1?16:8,1,0,Cb(e+32|0)?6:0);v[22692]=0;W(329,d|0,f+484380|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break j}c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}Ce(i);break b}b=P()|0;O()|0;xb(e+32|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Hb(e+8|0);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(d);break g}b=P()|0;O()|0}gc(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ce(i)}S(b|0);L()}d=1}gb=e+128|0;return d|0}function Apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-336|0;gb=d;vc(b);a:{if(!xr(b,d+320|0)){break a}if(!_X(d+320|0)){break a}if(v[d+320>>2]==1179472708){Rb(b,4)}if(!Jh(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}l=d+312|4;g=l;OD(b,d+120|0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Id(a,8192);e=Tb(d+32|0,3593);Eb(a+1298304|0,e);vb(e);e=Tb(d+32|0,7365);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;Fk(d+96|0,2,d+120|0);Bc(d+32|0,d+96|0);Eb(a+1298268|0,d+32|0);vb(d+32|0);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;q=a,r=x[Je(d+32|0,d+96|0)>>1],u[q+480188>>1]=r;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[ac(d+32|0,d+96|0)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+32>>2]=256/x[a+480188>>1];v[d+96>>2]=128;g=v[Fb(d+32|0,d+96|0)>>2];break b}g=w[d+165|0]&127}v[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;Ue(g+480280|0);h=d+e|0;if(w[h+168|0]<=128){u[g+480284>>1]=w[h+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}k=a+484360|0;f=Sb(k);i=d+184|0;e=gb-16|0;gb=e;v[e+12>>2]=w[d+156|0]|w[d+157|0]<<8;tc(e+12|0,128);tc(e+12|0,65535);j=x[e+12>>1];yf(f,j);if(j){h=0;while(1){g=w[h+i|0];c:{if((g|0)==255){g=65535;break c}if((g|0)!=254){break c}g=65534}q=cj(f,h),r=g,u[q>>1]=r;h=h+1|0;if((j|0)!=(h|0)){continue}break}}gb=e+16|0;if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){bf(Sb(k),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Jh(b,d+312|0)){break a}n=c&2;k=a+484344|0;o=c&1;p=d+68|0;j=0;while(1){c=l;ud(d+32|0,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));h=jc(d+96|0,d+32|0);xb(d+32|0);d:{e:{f:{if(!(!o|v[d+312>>2]!=1414807888)){v[22692]=0;m=j&65535;c=W(331,k|0,m|0,64)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}if(!c){break d}v[22692]=0;Q(318,d+96|0,2)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}Eh(d+32|0);g=0;g:{while(1){v[22692]=0;c=Q(189,d+96|0,1)|0;e=v[22692];v[22692]=0;h:{i:{if((e|0)!=1){if(!(c&g>>>0<64)){break g}v[22692]=0;e=T(374,h|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break i}if(e){break h}g=g+1|0;continue}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}c=d+32|0;j:{k:{l:{f=e&15;m:{if(f>>>0<x[a+480188>>1]){c=_b(k,m);v[22692]=0;c=Wc(c,g,f);f=v[22692];v[22692]=0;if((f|0)==1){break m}}n:{if(!(e&128)){break n}v[22692]=0;f=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break l}if(!f){break n}t[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break j}v[22692]=0;f=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){break k}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}t[c+1|0]=f}o:{p:{q:{r:{s:{t:{u:{v:{if(e&32){t[c+2|0]=1;v[22692]=0;f=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break v}t[d+16|0]=f;v[22692]=0;t[d|0]=64;f=ac(d+16|0,d);i=v[22692];v[22692]=0;if((i|0)==1){break u}t[c+4|0]=w[f|0]}if(!(e&16)){continue}v[22692]=0;R(403,d+16|0,h|0);e=v[22692];v[22692]=0;if((e|0)==1){break t}i=od(d+16|0);f=d+16|0;e=w[f|0];switch(e-17|0){case 2:break r;case 0:case 1:break s;default:break q}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}e=e&15;break p}t[f|0]=33;t[i|0]=145;e=w[f|0];break o}if(e>>>0<17){break o}e=(e&240)==32?9:-1}t[f|0]=e}t[c+3|0]=e;t[c+5|0]=w[i|0];v[22692]=0;Nf(c);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break e}j=j+1|0;break d}if(v[d+312>>2]!=1414745673){break d}if(!fi(a)){break d}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22692]=0;R(493,h|0,d+32|0);e=v[22692];v[22692]=0;w:{x:{y:{if((e|0)==1){break y}v[22692]=0;f=(B(c&65535,104)+a|0)+484380|0;R(494,d+32|0,f|0);c=v[22692];v[22692]=0;if((c|0)==1){break y}v[22692]=0;Fk(d,2,p);c=v[22692];v[22692]=0;if((c|0)==1){break x}v[22692]=0;R(324,d+16|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break x}c=x[a+480190>>1];v[22692]=0;Q(301,((c<<5)+a|0)+946304|0,d+16|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break w}vb(d+16|0);if(!n){break d}c=Rc(d+16|0,8,1,0,1);e=2;g=d+45|0;z:{if(!(w[g|0]&64)){e=0;if(!(w[g|0]&2)){break z}}zf(c,e)}if(w[g|0]&4){Xi(c,16)}v[22692]=0;W(329,d+16|0,f|0,h|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(d+16|0);break e}b=P()|0;O()|0}xb(d+96|0);S(b|0);L()}xb(d+96|0);e=1;if(Jh(b,d+312|0)){continue}break}}gb=d+336|0;return e|0}function Voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=gb-320|0;gb=d;vc(b);g=gb-32|0;gb=g;vX(g+24|0,d+96|0);i=yb(g+24|0);f=v[g+28>>2];h=v[g+24>>2];v[g+8>>2]=h;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=f;f=b;cc(g+16|0,f,g);h=yb(g+16|0);if((h|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;a:{b:{c:{d:{if((i|0)!=(h|0)){break d}if(!zX(d+96|0)){break d}if(!Pb(b,Qc(yX(d+96|0),jb))){break d}if(!c){e=1;break d}Id(a,2);yg(a);v[a+480204>>2]=455e3;v[a+480188>>2]=524296;Ob(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;Ie(d- -64|0,2,d+127|0);Bc(d+80|0,d- -64|0);Eb(a+1298268|0,d+80|0);vb(d+80|0);e:{f:{g:{h:{i:{while(1){f=(d+96|0)+B(e,19)|0;RC(d+80|0,f+63|0);Bc(d- -64|0,d+80|0);v[22692]=0;Q(399,((e<<5)+a|0)+480289|0,d- -64|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break h}vb(d- -64|0);e=e+1|0;h=B(e,104)+a|0;j=h+484380|0;td(j,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;g=d- -64|0;i=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[g+7|0]=i;t[g+8|0]=i>>>8;t[g+9|0]=i>>>16;t[g+10|0]=i>>>24;i=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24;t[g+4|0]=i;t[g+5|0]=i>>>8;t[g+6|0]=i>>>16;t[g+7|0]=i>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;Jo(j,1,d);v[h+484404>>2]=8215;Bc(d+48|0,d+80|0);v[22692]=0;Q(301,((e<<5)+a|0)+946304|0,d+48|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}vb(d+48|0);if((e|0)!=8){continue}break}o=w[d+312|0];m=o+1|0;j=a+484360|0;cp(Sb(j),b,m,65535,65535);f=mc(d+80|0);v[22692]=0;W(358,b|0,f|0,m|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}z=d,A=Vb(f),v[z+64>>2]=A;z=d,A=Zb(f),v[z+48>>2]=A;if(Gb(d- -64|0,d+48|0)){while(1){if((w[v[d- -64>>2]]-1&255)>>>0>7){break f}Ne(d- -64|0);if(Gb(d- -64|0,d+48|0)){continue}break}}z=a,A=w[kc(f,0)|0],v[z+480196>>2]=A;e=w[d+311|0];p=w[d+313|0];g=mc(d- -64|0);v[22692]=0;h=p+1|0;W(358,b|0,g|0,h|0)|0;i=v[22692];v[22692]=0;j:{if((i|0)==1){break j}v[22692]=0;i=a+484344|0;R(330,i|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break j}q=e+1|0;k:{l:{if(!(c&1)){break l}h=0;while(1){c=w[kc(g,h)|0];v[22692]=0;c=W(331,i|0,c|0,q|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break k}if(!c){break l}c=0;n=_b(i,w[kc(g,h)|0]);k=0;while(1){if(v[n+12>>2]){r=c+1|0;e=0;while(1){v[22692]=0;c=T(374,b|0)|0;l=v[22692];v[22692]=0;m:{n:{if((l|0)!=1){if(!(c&128)){break n}e=(c&127)+e|0;break m}e=P()|0;O()|0;break c}v[22692]=0;l=Wc(n,e,k&65535);s=v[22692];v[22692]=0;o:{if((s|0)!=1){p:{switch(c|0){case 0:break m;case 1:break p;default:break o}}t[l|0]=254;break m}e=P()|0;O()|0;break c}if(c>>>0>97){break m}t[l+1|0]=r;t[l|0]=c+12}e=e+1|0;if(e>>>0<y[n+12>>2]){continue}break}}e=k&65535;c=k+1|0;k=c;if(e>>>0<7){continue}break}c=(h|0)==(p|0);h=h+1|0;if(!c){continue}break}}c=0;e=0;q:{r:{s:{t:{u:{v:{w:{while(1){b=Sb(j);v[22692]=0;h=e&65535;b=Q(470,b|0,h|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break w}x:{if(!b){v[22692]=0;b=W(540,i|0,q|0,0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break v}if((b|0)==65535){break x}z=rc(Sb(j),c),A=b,u[z>>1]=A}z=d,A=Zb(_b(i,x[rc(Sb(j),c)>>1])),v[z+32>>2]=A;z=d,A=QC(d+32|0,1),v[z+48>>2]=A;b=w[kc(f,(c+1>>>0)%(m>>>0)|0)|0];if((b|0)==w[v[d+48>>2]+5|0]){break x}y:{if(w[v[d+48>>2]+3|0]!=16){break y}c=Sb(j);v[22692]=0;c=Q(541,c|0,h|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break q}if((c|0)==65535){break y}z=d,A=Zb(_b(i,c)),v[z+32>>2]=A;z=d,A=QC(d+32|0,1),v[z+48>>2]=A}t[v[d+48>>2]+3|0]=16;t[v[d+48>>2]+5|0]=b}e=e+1|0;c=e&65535;if(o>>>0>=c>>>0){continue}break}v[22692]=0;b=Q(2,d+48|0,5732)|0;c=v[22692];v[22692]=0;if((c|0)==1){break u}Eb(a+1298304|0,b);vb(b);v[22692]=0;b=Q(2,d+48|0,3141)|0;c=v[22692];v[22692]=0;if((c|0)==1){break t}Eb(a+1298316|0,b);vb(b);v[22692]=0;Uj(d+16|0,2,d+107|0);b=v[22692];v[22692]=0;if((b|0)==1){break s}v[22692]=0;R(324,d+32|0,d+16|0);b=v[22692];v[22692]=0;if((b|0)==1){break s}v[22692]=0;U(13,d+48|0,5,d+32|0);b=v[22692];v[22692]=0;e=1;if((b|0)==1){break r}Eb(a+1298328|0,d+48|0);vb(d+48|0);vb(d+32|0);v[a+1298364>>2]=5;gc(g);break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+32|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;vb(d- -64|0);break a}e=P()|0;O()|0;break b}e=0}gc(f)}gb=d+320|0;return e|0}gc(g)}gc(f)}S(e|0);L()}function bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-176|0;gb=d;vc(b);a:{if(!SC(b,d+128|0)){break a}if(!jU(d+128|0)){break a}if(!Pb(b,Qc(iU(d+128|0),jb))){break a}b:{if(!c){break b}Id(a,256);Uj(d+16|0,2,d+128|0);Bc(d+48|0,d+16|0);Eb(a+1298268|0,d+48|0);vb(d+48|0);e=Tb(d+48|0,12440);Eb(a+1298304|0,e);vb(e);e=Tb(d+48|0,7344);Eb(a+1298316|0,e);vb(e);Df(d+16|0,1380);v[22692]=0;R(371,d+112|0,d+159|0);e=v[22692];v[22692]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[22692]=0;Y(880,d+48|0,d+16|0,d+158|0,d+112|0);e=v[22692];v[22692]=0;if((e|0)==1){break g}Eb(a+1298328|0,d+48|0);vb(d+48|0);vb(d+112|0);Hb(d+16|0);v[a+1298364>>2]=5;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+160|0];if(w[d+159|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}g=(f&255?f:96)&255;e=BP(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=e;if(w[d+159|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+112|0)}Hb(d+16|0);break c}t[d+48|0]=64;p=a,q=w[ac(d+162|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;Ue(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;h:{i:{while(1){Zu(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break i}i=gb-32|0;gb=i;h=(B(f,104)+a|0)+484380|0;td(h,0);g=d+16|0;Ek(i,2,g);Bc(i+16|0,i);v[22692]=0;Q(303,h+43|0,i+16|0)|0;e=v[22692];v[22692]=0;j:{k:{if((e|0)!=1){vb(i+16|0);e=g+24|0;v[h+24>>2]=w[e|0]|w[e+1|0]<<8;t[i+16|0]=w[g+22|0];t[i|0]=64;p=h,q=w[ac(i+16|0,i)|0]<<2,u[p+30>>1]=q;e=g+16|0;v[h>>2]=w[e|0]|w[e+1|0]<<8;e=g+18|0;v[h+4>>2]=w[e|0]|w[e+1|0]<<8;e=g+20|0;j=w[e|0]|w[e+1|0]<<8;v[h+8>>2]=j;g=v[h>>2];if(g>>>0>1){break k}v[h>>2]=0;break j}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}e=v[h+4>>2];if(g>>>0<=e>>>0|e>>>0>=j>>>0|(j|0)==65535){break j}u[h+34>>1]=2;p=h,q=v[Fb(h+8|0,h)>>2],v[p+8>>2]=q}gb=i+32|0;Ek(d,2,d+16|0);Bc(d+112|0,d);v[22692]=0;Q(301,((f<<5)+a|0)+946304|0,d+112|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break h}vb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;cp(Sb(e),b,w[d+159|0]?128:64,65535,65535);e=Sb(e);p=d,q=Vb(e),v[p+16>>2]=q;p=d,q=Zb(e),v[p+112>>2]=q;if(Gb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];g=x[e>>1];l:{if(!((g|0)!=99?(g|0)!=255:0)){u[e>>1]=65535;break l}if(g>>>0>63){break i}}nf(d+16|0);if(Gb(d+16|0,d+112|0)){continue}break}}i=c&1;if(i){xg(a+484344|0,w[d+161|0])}if(w[d+161|0]){n=a+484344|0;while(1){m:{n:{if(i){if(sh(n,l&65535,64)){break n}}f=0;while(1){if((Ae(b)+5&255)>>>0>=3){Rb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}p=d,q=Vb(_b(n,l)),v[p+112>>2]=q;v[d>>2]=63;k=65535;m=0;while(1){f=0;while(1){g=f;j=0;f=0;o=0;h=0;o:{p:{q:{r:{s:{t:{e=Ae(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}t[v[d+112>>2]]=254;break o}Rr(d+16|0,b);f=w[lc(d+16|0,0)|0];o=w[lc(d+16|0,1)|0];h=w[lc(d+16|0,2)|0];j=254;if((e|0)==254){break q}j=e;if(e>>>0>95){break p}}j=(B(j>>>4|0,12)+(j&15)|0)+37|0}e=j;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=o>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(o&15)+33328|0];t[v[d+112>>2]+5|0]=h;u:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:j=v[d+112>>2];e=w[j+5|0];if(w[v[d+112>>2]+5|0]&15){t[j+5|0]=e&15;break o}t[j+5|0]=e&240;break o;case 3:t[v[d+112>>2]+5|0]=B(w[v[d+112>>2]+5|0]&240,10)|w[v[d+112>>2]+5|0]&15;v:{if((k|0)!=65535){if(w[v[d+112>>2]+5|0]){break v}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=k}k=65535}tc(d,m);break o;case 1:k=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break o;case 5:if(w[d+159|0]<=20){t[v[d+112>>2]+5|0]=w[v[d+112>>2]+5|0]%10|w[v[d+112>>2]+5|0]/10<<4}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0}Xj(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}m=m+1|0;if((m|0)!=64){continue}break}if((k|0)==65535){break m}Cm(_b(n,l),jp(Se(Be(d+16|0,12,k&255),v[d>>2])))}l=l+1|0;if(l>>>0<w[d+161|0]){continue}break}}f=1;if(!(c&2)){break a}g=Rc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;w:{if(!v[e>>2]|!x[c+484410>>1]){break w}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Yc(b,c<<4)){break w}Ag(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;vb(d+112|0)}S(f|0);L()}f=1}gb=d+176|0;return f|0}function Noa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-736|0;gb=k;a:{b:{if(d>>>0<=511){d=0;a=gb-32|0;gb=a;h=k+56|0;bc(a+24|0,h,554);i=yb(a+24|0);f=v[a+28>>2];e=v[a+24>>2];v[a+8>>2]=e;v[a+12>>2]=f;v[a>>2]=e;v[a+4>>2]=f;cc(a+16|0,b,a);f=yb(a+16|0);if((f|0)==(i|0)){Rb(b,yb(a+24|0))}gb=a+32|0;a=(f|0)==(i|0);if(!a){Qb(h,0,554)}if(!a){break b}d=gb-32|0;gb=d;c:{d:{a=k+56|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}xp(d,3,a+32|0);Bc(d+16|0,d);v[22692]=0;Q(301,c+492|0,d+16|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}vb(d+16|0);ii(d,1,a+4|0);Bc(d+16|0,d);v[22692]=0;Q(301,c+524|0,d+16|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}vb(d+16|0);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];h=c+108|0;e=c+236|0;b=0;i=a- -64|0;while(1){g=b<<1;f=w[g+i|0];g=w[i+(g|1)|0];o=wd(e,b),p=g,u[o>>1]=p;o=lc(h,b),p=(f>>>0<120?f:b)+1|0,t[o|0]=p;b=b+1|0;if((b|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;h=c+61|0;t[h|0]=w[a+18|0];e=c+62|0;t[e|0]=w[a+19|0];g=c+63|0;t[g|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];i=c+48|0;hh(i,25);b=0;while(1){f:{l=b<<1;f=w[(l+a|0)+504|0];o=Lb(i,b),p=f,u[o>>1]=p;if((f|0)==255){hh(i,b);break f}f=w[(a+(l|1)|0)+504|0];o=Lb(i,b),p=f,t[o+2|0]=p;b=b+1|0;if((b|0)!=25){continue}}break}a=w[Bf(h,e)|0];if(Nb(i)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[Bf(g,j)|0];if(Nb(i)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}gb=d+32|0;break c}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}d=554;break b}i=v[b+8>>2];f=gb-48|0;gb=f;v[f+44>>2]=674;v[f+24>>2]=674;d=b;h=v[Fb(f+44|0,f+24|0)>>2];if(!Pb(d,h)){h=mf(d)}e=k+56|0;RW(f+24|0,e);g=vd(f+32|0,v[f+24>>2],h);j=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=j;cc(f+16|0,d,f+8|0);RW(f+24|0,e);Qb(v[f+24>>2]+h|0,0,674-h|0);Rb(d,v[f+44>>2]);gb=f+48|0;f=b;h=c;d=c;l=v[a+480180>>2];a=0;g=gb-32|0;gb=g;g:{h:{j=k+56|0;e=j;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){xp(g,3,e+32|0);Bc(g+16|0,g);v[22692]=0;Q(301,d+492|0,g+16|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break h}vb(g+16|0);ii(g,1,e+4|0);Bc(g+16|0,g);v[22692]=0;Q(301,d+524|0,g+16|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break h}vb(g+16|0);v[d>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[d+4>>2]=w[e+24|0]>>>1;tc(d+4|0,64);a=w[e+25|0]&127;v[d+8>>2]=a>>>0>64?128:a<<2;t[d+15|0]=w[d+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[g+16|0]=w[e+26|0];t[g|0]=100;o=d,p=w[ac(g+16|0,g)|0],t[o+20|0]=p;t[g+16|0]=w[e+27|0];t[g|0]=64;o=d,p=w[ac(g+16|0,g)|0],t[o+19|0]=p;t[d+16|0]=w[e+17|0];t[d+17|0]=w[e+18|0];t[d+18|0]=w[e+19|0];t[d+26|0]=w[e+22|0];t[d+27|0]=w[e+23|0];am(d,w[e+58|0]&127,w[e+58|0]>>>7|0);$l(d,w[e+59|0]&127,w[e+59|0]>>>7|0);i:{j:{k:{if(!((w[e+28|0]|w[e+29|0]<<8)==514|(w[e+28|0]|w[e+29|0]<<8)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break k}}if(w[e+61|0]==255){break k}if(w[e+61|0]<=128){t[d+30|0]=w[e+61|0]}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break j}break i}a=0;if(t[e+61|0]>=0){t[d+30|0]=w[e+61|0]+1}a=t[e+62|0]>=0?w[e+62|0]+1|0:a;if(t[e+63|0]<0){break j}a=(w[e+63|0]<<7)+a|0}u[d+28>>1]=a}a=t[e+60|0];t[d+31|0]=a;if((a|0)<=-1){t[d+31|0]=0;t[d+34|0]=a^128}a=0;l=l&16777216?240:25;nw(e+304|0,d+48|0,0,l);nw(e+386|0,d+68|0,32,l);nw(e+468|0,d+88|0,32,l);t[d+100|0]=w[d+100|0]&239|w[e+468|0]>>>3&16;l=d+108|0;n=d+236|0;d=e- -64|0;while(1){m=a<<1;e=w[m+d|0];m=w[d+(m|1)|0];o=wd(n,a),p=m,u[o>>1]=p;o=lc(l,a),p=(e>>>0<120?e:a)+1|0,t[o|0]=p;a=a+1|0;if((a|0)!=120){continue}break}a=554}gb=g+32|0;break g}a=P()|0;O()|0;vb(g+16|0);S(a|0);L()}if(a){if(!((w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1297110104?(w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1481920589:0)){d=h+236|0;a=0;while(1){h=w[(a+j|0)+554|0];e=wd(d,a);u[e>>1]=x[e>>1]|h<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Yc(f,i+d|0);if(!Hh(b,11235)){break b}ud(k+8|0,b,qg(b));a=jc(k+32|0,k+8|0);xb(k+8|0);v[22692]=0;i=T(193,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;b=Q(551,a|0,11026)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}if(b){v[22692]=0;b=T(374,a|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}d=(d+i|0)+8|0;xb(a)}gb=k+736|0;return d|0}b=P()|0;O()|0;xb(a);S(b|0);L()}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-112|0;gb=f;vc(b);a:{b:{c:{d:{e:{if(WU(b,11351)){i=mc(f+96|0);j=mc(f+80|0);l=Xu(f- -64|0);v[22692]=0;R(367,a|0,32768);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;d=Q(2,f+32|0,5287)|0;h=v[22692];v[22692]=0;if((h|0)==1){break c}Eb(a+1298304|0,d);vb(d);v[22692]=0;d=Q(2,f+32|0,3149)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=2;m=a+484360|0;h=f+56|4;f:{g:{h:{i:{j:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;g=v[22692];v[22692]=0;if((g|0)==1){break i}k:{l:{m:{n:{if(!d){break n}v[22692]=0;d=Q(819,b|0,f+56|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break m}if(!d){break n}d=h;d=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[22692]=0;U(288,f+8|0,b|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break l}g=jc(f+32|0,f+8|0);xb(f+8|0);v[22692]=0;d=T(275,f+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}if(d){break k}xb(f+32|0)}if(x[a+480188>>1]){break j}h=0;break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=f+56|0;d=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if($e(i)>>>0>255){break p}v[22692]=0;R(535,i|0,g|0);d=v[22692];v[22692]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(x[a+480190>>1]|(d|0)!=1396788560){break p}v[22692]=0;U(820,g|0,l|0,a|0);d=v[22692];v[22692]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}v[22692]=0;d=T(193,f+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[22692]=0;d=T(416,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}p=a,q=Gd(d,1,255),v[p+480196>>2]=q;break p}if(x[a+480188>>1]){break p}v[22692]=0;e=T(193,f+32|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break e}d=0;if(e>>>0<8){break p}while(1){v[22692]=0;k=T(374,g|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break o}v[22692]=0;n=T(374,g|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}e=x[a+480188>>1];if(k|n){v[22692]=0;Ue(((e<<5)+a|0)+480280|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}k=x[a+480188>>1];e=k+1|0;u[a+480188>>1]=e;u[((k<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64}v[22692]=0;Ue((((e&65535)<<5)+a|0)+480280|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}e=x[a+480188>>1];u[a+480188>>1]=e+1;u[((e<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64;d=d+1|0;if((d|0)!=4){continue}break}if(c){break p}xb(f+32|0);break g}v[22692]=0;d=T(193,f+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[22692]=0;o=T(416,g|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break e}break p}d=Sb(m);v[22692]=0;e=T(193,f+32|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break e}v[22692]=0;fa(519,d|0,g|0,e|0,255,254)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break p}break e}if($e(j)>>>0>3998){break p}v[22692]=0;d=T(193,f+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}if(!d){break p}v[22692]=0;R(535,j|0,g|0);d=v[22692];v[22692]=0;if((d|0)==1){break e}}xb(f+32|0);continue}break}break e}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Sb(m);v[22692]=0;R(500,b|0,o&65535);b=v[22692];v[22692]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=$e(i);v[22692]=0;R(330,a+484344|0,b&65535);b=v[22692];v[22692]=0;if((b|0)==1){break b}if(!$e(i)){break u}b=0;while(1){d=Jg(i,d);v[22692]=0;U(821,d|0,b&65535,a|0);d=v[22692];v[22692]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if($e(i)>>>0>d>>>0){continue}break}}b=1;if(x[a+480190>>1]<2){break g}g=c&2;d=0;v:{while(1){if(!g|$e(j)>>>0<=d>>>0){break g}w:{c=(B(b,104)+a|0)+484380|0;if(v[c>>2]){h=Jg(j,d);v[22692]=0;h=T(193,h|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}tc(c,h);pe(f+32|0,l,b-1|0);h=Rc(f+8|0,8,1,1,Cb(f+32|0)?10:0);e=Jg(j,d);v[22692]=0;W(329,h|0,c|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break v}d=d+1|0}h=1;b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break f}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}h=1}Ce(l);hd(j);hd(i)}gb=f+112|0;return h|0}a=P()|0;O()|0;xb(f+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ce(l);hd(j);hd(i);S(a|0);L()}function jL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-416|0;gb=e;t[e+415|0]=c;a:{if(kk(b)){break a}f=w[nl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Cl(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}Md(e+160|0);f=v[e+160>>2];Md(e+376|0);h=ml(f,v[e+380>>2],b);Md(e+160|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=uc(e+392|0,18699);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Gc(e+8|0,e)){c=ba(8)|0;v[22692]=0;R(2040,e+376|0,e+415|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}v[22692]=0;U(2021,e+160|0,14701,e+376|0);a=v[22692];v[22692]=0;if((a|0)==1){break f}qc(c,e+160|0);a=0;v[22692]=0;U(184,c|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);break e}if(!d){break h}c=ba(8)|0;v[22692]=0;d=Q(2041,e+344|0,b|0)|0;b=v[22692];v[22692]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22692]=0;U(2021,e+360|0,14737,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break q}v[22692]=0;R(2038,e+376|0,e+360|0);b=v[22692];v[22692]=0;a=1;if((b|0)==1){break p}v[22692]=0;R(2040,e+328|0,e+415|0);a=v[22692];v[22692]=0;if((a|0)==1){break o}v[22692]=0;U(2042,e+160|0,e+376|0,e+328|0);b=v[22692];v[22692]=0;a=1;if((b|0)==1){break n}qc(c,e+160|0);v[22692]=0;U(184,c|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(e+328|0)}vb(e+376|0)}vb(e+360|0)}vb(d)}if(a){break d}break c}v[e+320>>2]=f;v[e+324>>2]=g;d=uc(e+312|0,18699);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Gc(e+152|0,e+144|0)){c=ba(8)|0;v[22692]=0;R(2040,e+376|0,e+415|0);a=v[22692];v[22692]=0;r:{s:{if((a|0)!=1){v[22692]=0;U(2021,e+160|0,14701,e+376|0);a=v[22692];v[22692]=0;if((a|0)==1){break s}qc(c,e+160|0);a=0;v[22692]=0;U(184,c|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);break r}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}vb(e+376|0);if(a){break d}break c}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=uc(e+296|0,4491);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;t:{if(!Gc(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=uc(e+280|0,4473);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Gc(e+120|0,e+112|0)){break t}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=uc(e+264|0,3988);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;u:{if(!Gc(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=uc(e+248|0,3969);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Gc(e+88|0,e+80|0)){break u}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=uc(e+232|0,4072);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Gc(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=uc(e+216|0,3153);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=uc(e+200|0,4540);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=uc(e+184|0,10668);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Gc(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;b=e;if(c){a=wK(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!Dy(e+160|0,v[d>>2]+24648|0)){break h}Mz(v[d>>2],e+160|0)}gb=e+416|0;return}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}vb(e+376|0);if(!a){break c}}da(c|0)}S(b|0)}L()}function Zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-192|0;gb=e;a:{if(!Pb(c,8)){break a}Rb(c,4);while(1){n=nv(c);if(n){break a}p=gb-288|0;gb=p;i=MR(p);f=0;g=gb-384|0;gb=g;MR(g+96|0);j=hc(i,g+96|0,282);b:{c:{d:{e:{f:{g:{h:{h=c;if(Hh(h,10927)){ng(h,4);l=Pe(g+72|0,h);v[22692]=0;i=Q(1092,l|0,j|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break e}i:{if(!i){break i}i=w[j+26|0];v[22692]=0;i=Q(189,l|0,i|0)|0;k=v[22692];v[22692]=0;if((k|0)==1){break e}if(!i){break i}k=0;j:{k:{l:{if(w[j+26|0]){while(1){v[22692]=0;i=T(309,l|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break l}t[(j+k|0)+27|0]=i;f=f+i|0;k=k+1|0;if(k>>>0<w[j+26|0]){continue}break}k=f&65535}f=0;v[22692]=0;i=Q(189,l|0,k|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break d}if(!i){break i}v[22692]=0;Q(318,l|0,k|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}ng(l,NR(j));i=Ui(g- -64|0);OA(g+96|0);v[22692]=0;R(1093,l|0,g+96|0);f=v[22692];v[22692]=0;if((f|0)==1){break k}u[g+118>>1]=0;u[g+120>>1]=0;LR(i,g+96|0,g+123|0);f=w[j+26|0];v[22692]=0;Q(318,l|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break k}f=j+27|0;LR(i,f,f+w[j+26|0]|0);v[22692]=0;U(288,g+16|0,l|0,k|0);f=v[22692];v[22692]=0;if((f|0)!=1){break j}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}k=jc(g+40|0,g+16|0);xb(g+16|0);v[22692]=0;R(749,g+16|0,k|0);f=v[22692];v[22692]=0;if((f|0)==1){break h}v[22692]=0;Ov(g+8|0,g+16|0);f=v[22692];v[22692]=0;if((f|0)==1){break g}f=i;o=g+8|0;m=v[o>>2];o=v[o+4>>2];if((m|0)!=(o|0)){while(1){JR(f,zb(w[m|0]));m=m+1|0;if((o|0)!=(m|0)){continue}break}}zc(g+16|0);xb(k);f=0;if(v[i>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break i}f=NR(j);v[22692]=0;Q(318,h|0,f|0)|0;i=v[22692];v[22692]=0;f=1;if((i|0)==1){break d}}xb(l)}gb=g+384|0;break b}f=P()|0;O()|0;break f}f=P()|0;O()|0;zc(g+16|0)}xb(k);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}xb(l);S(f|0);L()}gb=p+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|n;vc(c);m:{n:{o:{p:{q:{r:{if(n){d=qg(c);ud(e+144|0,c,mf(c));f=jc(e+168|0,e+144|0);xb(e+144|0);u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[22692]=0;R(749,e+144|0,f|0);b=v[22692];v[22692]=0;if((b|0)==1){break r}v[22692]=0;b=Td(e+144|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=v[e+144>>2];d=zb(b);i=Ti(c);v[22692]=0;i=fa(748,d|0,i|0,e+140|0,e+136|0,0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break o}v[22692]=0;Q(318,f|0,v[e+140>>2])|0;d=v[22692];v[22692]=0;if((d|0)==1){break o}if(!i){break p}h=v[e+140>>2];v[22692]=0;T(386,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break o}d=c-h|0;b=b+h|0;n=v[e+136>>2];c=0;while(1){s:{if(n){if(!d|(n|0)!=1){break q}if(y[a>>2]>c>>>0){break s}break q}if(y[a>>2]<=c>>>0){break q}}if(!Nd(a)){break q}v[e+132>>2]=0;v[e+128>>2]=0;h=zb(b);g=Ti(d);v[22692]=0;h=la(750,i|0,h|0,g|0,e+132|0,e+124|0,e+128|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break o}v[22692]=0;v[e+140>>2]=h;Q(318,f|0,h|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}j=v[e+140>>2];Zj(e+128|0,Ti(v[a>>2]-c|0));t:{if(v[e+128>>2]<1){break t}if(v[e+132>>2]!=(dd(a)|0)){break t}if(t[a+34|0]&1){h=kg(e+112|0,v[a+20>>2]+(B(dd(a),c)<<1)|0,dd(a),v[e+128>>2]);g=kg(e+96|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22692]=0;v[e+56>>2]=v[h+8>>2];l=v[h+4>>2];v[e+48>>2]=v[h>>2];v[e+52>>2]=l;v[e+40>>2]=v[g+8>>2];h=v[g+4>>2];v[e+32>>2]=v[g>>2];v[e+36>>2]=h;R(751,e+48|0,e+32|0);h=v[22692];v[22692]=0;if((h|0)!=1){break t}break o}h=kg(e+80|0,v[a+20>>2]+B(dd(a),c)|0,dd(a),v[e+128>>2]);g=kg(e- -64|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22692]=0;v[e+24>>2]=v[h+8>>2];l=v[h+4>>2];v[e+16>>2]=v[h>>2];v[e+20>>2]=l;v[e+8>>2]=v[g+8>>2];h=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=h;R(752,e+16|0,e|0);h=v[22692];v[22692]=0;if((h|0)==1){break o}}v[22692]=0;h=v[e+128>>2];n=by(i);g=v[22692];v[22692]=0;if((g|0)==1){break o}d=d-j|0;b=b+j|0;v[e+136>>2]=n;c=c+h|0;continue}}break o}Ag(b,a,c);a=1;break m}a=P()|0;O()|0;break n}v[22692]=0;cy(i);a=v[22692];v[22692]=0;if((a|0)!=1){break p}break o}a=(i|0)!=0;zc(e+144|0);xb(f);break m}a=P()|0;O()|0;zc(e+144|0)}xb(f);S(a|0);L()}gb=e+192|0;return a|0}function _la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-256|0;gb=e;vc(b);a:{if(!vY(b,e+184|0)){break a}if(!aV(e+184|0)){break a}if(!Pb(b,Qc($U(e+184|0),jb))){break a}b:{if(!c){break b}Id(a,16);Uj(e+24|0,2,e+184|4);Bc(e+48|0,e+24|0);Eb(a+1298268|0,e+48|0);vb(e+48|0);u[a+480190>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];d=Tb(e+48|0,5497);Eb(a+1298304|0,d);vb(d);d=Tb(e+48|0,7353);Eb(a+1298316|0,d);vb(d);Df(e+24|0,1320);d=e+184|3;v[e>>2]=w[d|0]>>>4;d=w[d|0];v[22692]=0;v[e+180>>2]=d&15;Y(458,e+48|0,e+24|0,e|0,e+180|0);f=v[22692];v[22692]=0;d=1;c:{d:{e:{if((f|0)!=1){Eb(a+1298328|0,e+48|0);vb(e+48|0);Hb(e+24|0);v[a+1298364>>2]=5;if(x[a+480190>>1]){f=1;while(1){uE(b,e+48|0);i=gb-16|0;gb=i;g=(B(d,104)+a|0)+484380|0;td(g,0);h=e+48|0;u[i+14>>1]=w[h+35|0]<<2;u[i+12>>1]=256;q=g,r=x[Pc(i+14|0,i+12|0)>>1],u[q+30>>1]=r;f:{if((w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24))>>>0<3){break f}v[g>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);v[g+4>>2]=w[h+26|0]|w[h+27|0]<<8|(w[h+28|0]<<16|w[h+29|0]<<24);v[i+8>>2]=w[h+30|0]|w[h+31|0]<<8|(w[h+32|0]<<16|w[h+33|0]<<24);v[i+4>>2]=1;q=g,r=v[Mc(i+8|0,i+4|0)>>2]-1|0,v[q+8>>2]=r;tc(g+8|0,v[g>>2]);g:{if(y[g+8>>2]<=v[g+4>>2]+4>>>0){v[g+4>>2]=0;v[g+8>>2]=0;break g}u[g+34>>1]=x[g+34>>1]|2}t[g+37|0]=w[h+34|0];q=g,r=Cu(0,t[h+34|0]<<4),v[q+24>>2]=r;if(!(t[h+36|0]&1)){break f}u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}gb=i+16|0;Jk(e,2,e+48|0);Bc(e+24|0,e);v[22692]=0;Q(301,((d<<5)+a|0)+946304|0,e+24|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break e}vb(e+24|0);f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){d=0;while(1){f=(d<<5)+a|0;Ue(f+480280|0);u[f+480284>>1]=(w[(e+d|0)+218|0]<<4|8)&248;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+48|0;g=gb-32|0;gb=g;d=b;h:{if(!Pb(d,128)){d=gb-16|0;gb=d;h=f+128|0;while(1){Hf(f);f=f+1|0;if((h|0)!=(f|0)){continue}break}gb=d+16|0;break h}AW(g+24|0,f);f=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=f;id(g+16|0,d,g+8|0)}gb=g+32|0;EE(Sb(a+484360|0),e+48|0,w[e+211|0]+1|0);i=w[e+216|0]?w[e+216|0]:64;ud(e,b,B(w[e+208|0]|w[e+209|0]<<8,192));k=jc(e+24|0,e);xb(e);d=c&1;if(d){f=w[e+210|0];v[22692]=0;R(330,a+484344|0,f+1|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}}i:{j:{if(!d){break j}p=a+484344|0;while(1){v[22692]=0;f=W(331,p|0,l&65535,i|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break i}d=0;if(!f){break j}while(1){v[22692]=0;f=T(287,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}n=d;k:{if(!f|f>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0){break k}d=n&65535;if(d>>>0>=x[a+480188>>1]){break k}v[22692]=0;Q(188,k|0,B(f,192)-192|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}f=_b(p,l);v[22692]=0;d=Wc(f,0,d);f=v[22692];v[22692]=0;if((f|0)==1){break d}o=0;if(!i){break k}while(1){v[22692]=0;R(715,e|0,k|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}j=od(e);m=Te(e);g=d;h=e;f=w[e|0];if(f>>>0>=4){t[d|0]=(f>>>2|0)+37;f=w[h|0]}t[g+1|0]=f<<4&48|w[j|0]>>>4;f=w[m|0];g=0;h=0;l:{m:{n:{o:{p:{q:{j=w[j|0]&15;switch(j-8|0){case 0:break n;case 6:break p;case 2:break q;default:break o}}f=f&240?f&-16:f&15;j=10;break m}j=14;m=(f+16&240)>>>4|0;if(m>>>0>8){break m}if(1<<m&435){break n}break m}g=j;h=f}j=g;f=h;if(!((g|f)&255)){break l}}t[d+5|0]=f;t[d+3|0]=j;v[22692]=0;Nf(d);f=v[22692];v[22692]=0;if((f|0)!=1){break l}break d}d=B(x[a+480188>>1],6)+d|0;o=o+1|0;if((o|0)!=(i|0)){continue}break}}d=n+1|0;if((n&65535)>>>0<31){continue}break}d=w[e+210|0]>l>>>0;l=l+1|0;if(d){continue}break}}if(w[e+212|0]|w[e+213|0]<<8){d=w[e+212|0]|w[e+213|0]<<8;v[22692]=0;fa(471,a+1298292|0,b|0,d|0,39,1)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;f=Rc(e,u[c+484414>>1]&1?16:8,1,0,1);v[22692]=0;W(329,f|0,c+484380|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;xb(k);break b}break d}d=P()|0;O()|0;Hb(e+24|0);break c}d=P()|0;O()|0;vb(e+24|0);break c}d=P()|0;O()|0;xb(k)}S(d|0);L()}d=1}gb=e+256|0;return d|0}function yP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=gb-16|0;gb=i;a:{if(!ue(d&255)){break a}j=(B(b,872)+a|0)+1074992|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(nk(j)){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;f=e+1075012|0;e=e+1075016|0;if(!(v[f>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1298260|0;if(!Dd(c)){break c}Ni(v[c>>2],b,0);break a}c=kA(a,b);if((c|0)==65535){break a}l=B(c,872);c=a+1074992|0;a=l+c|0;iu(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;To(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[f>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;m=v[e+1075096>>2];c=x[a+480192>>1]<c>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}h=d-1|0;c=x[wd(g+236|0,h)>>1];f=a+1074312|0;Db(i+8|0,f,104);e:{if(Cb(i+8|0)){Db(i,f,34);if(Cb(i)){break e}}d=w[lc(g+108|0,h)|0]}if((c-1&65535)>>>0<=3998){m=(B(c,104)+a|0)+484380|0;break d}Db(i+8|0,f,43);if(!Cb(i+8|0)){break d}if(!Ej(g)){break a}}if(w[e+1075081|0]&4){break a}f=a+1298260|0;n=a+1074312|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)?x[a+480188>>1]>c>>>0:0){break f}e=B(c,872)+a|0;if((b|0)!=(c|0)?x[e+1075778>>1]!=(q|0):0){break f}p=e+1075648|0;h=v[p>>2];if(!h){break f}k=e+1074992|0;g:{h:{i:{j:{k:{l:{m:{switch(w[h+17|0]-1|0){case 0:if(!d){break f}l=w[e+1075789|0]==(d|0)&(g|0)==(h|0);o=l;if(!g){break l}if(l){break i}break f;case 1:if(!m|v[e+1075096>>2]!=(m|0)){break f}if((g|0)==(h|0)){break g}Db(i+8|0,n,104);if(!Cb(i+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}o=(g|0)==(h|0)}if(o){break g}break f}if(!g){break f}l=w[g+34|0];if(!l){break f}if((l|0)==w[h+34|0]){break h}break f}if((g|0)!=(h|0)){break f}}if(!w[g+34|0]){break g}}if(!w[e+1075789|0]|w[h+18|0]>2){break g}Db(i+8|0,n,34);Fm(a,c&65535,HS(k,Cb(i+8|0))+255|0,0);t[e+1075792|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:vo(a,k);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break n}if(!Dd(f)){break n}Ni(v[f>>2],c&65535,1);break n;case 1:vo(a,k);if(!(w[e+1075081|0]&2)){break n}if(!Dd(f)){break n}pk(v[f>>2],c&65535);break n;case 2:break o;default:break n}}k=e+1075080|0;h=v[k>>2];v[k>>2]=h|4096;if(!(h&512)){break n}if(!Dd(f)){break n}Db(i+8|0,n,105);if(Cb(i+8|0)){break n}pk(v[f>>2],c&65535)}if(v[e+1075680>>2]){break f}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}c=0;e=0;p:{if(!nk(j)){break p}if(!ue(w[(B(b,872)+a|0)+1075789|0])){break p}q:{d=Em(a,b,2,1);if(d-251>>>0<5){break q}if(!d){break p}e=v[(B(d,160)+a|0)+906140>>2];if(!e){break q}Db(i+8|0,n,34);c=(s=e,y=HS(j,Cb(i+8|0)),z=b,r=v[v[e>>2]+100>>2],kb[r](s|0,y|0,z|0)|0);break p}e=0}if(!(r=1,z=Mi(j),y=c,y?r:z)){break a}g=kA(a,b);if((g|0)==65535){break a}h=B(g,872)+a|0;d=h+1075080|0;m=h+1074992|0;r:{if(!(w[h+1075081|0]&2)){break r}if(!Dd(f)){break r}Ni(v[f>>2],g,1)}iu(m,j);v[d>>2]=v[d>>2]&-917505;t[h+1075823|0]=0;k=x[a+480188>>1];t[h+1075797|0]=0;u[h+1075778>>1]=b>>>0<k>>>0?b+1|0:0;s:{if(!((e|0)!=0&c)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}Fm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:vo(a,m);if(!(w[d+1|0]&2)){break t}if(!Dd(f)){break t}pk(v[f>>2],b);Db(i+8|0,n,105);if(!Cb(i+8|0)){break t}RA(v[f>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Dd(f)){break t}Ni(v[f>>2],b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Dd(f)){break t}Db(i+8|0,n,105);e=Cb(i+8|0);c=v[f>>2];if(e){RA(c,b,g);break t}pk(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}if(!Dd(f)){break t}RA(v[f>>2],b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}gb=i+16|0}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-112|0;gb=e;h=a+140|0;Mm(e+88|0,h,1296125513);v[22692]=0;f=T(275,e+88|0)|0;g=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((g|0)!=1){if(f){f=Kb(e+32|0);v[22692]=0;g=T(193,e+88|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break o}v[22692]=0;U(1423,e+88|0,f|0,g|0);g=v[22692];v[22692]=0;if((g|0)==1){break o}g=x[a+174>>1];v[22692]=0;Y(1424,e+72|0,g|0,8,f|0);g=v[22692];v[22692]=0;if((g|0)==1){break n}v[22692]=0;U(9,e+8|0,c|0,e+72|0);c=v[22692];v[22692]=0;if((c|0)==1){break m}v[22692]=0;Q(301,d|0,e+8|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break l}vb(e+8|0);vb(e+72|0);vb(f)}if(w[a+176|0]){v[22692]=0;R(1425,e+32|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}v[22692]=0;Q(303,b+43|0,e+32|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break h}vb(e+32|0)}v[22692]=0;U(1414,e+32|0,h|0,1413894985);c=v[22692];v[22692]=0;if((c|0)==1){break g}v[22692]=0;h=T(1426,e+32|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}xb(e+32|0);c=a+40|0;vc(c);v[22692]=0;f=Q(1427,c|0,e+32|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!f){break d}f=e+60|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<2){break e}v[22692]=0;f=Q(1428,c|0,e+8|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}if(!f){break e}f=v[b>>2];v[22692]=0;pz(e+8|0,b+12|0,b+16|0,f,b+34|0,8,16,h);f=v[22692];v[22692]=0;if((f|0)!=1){break e}break b}c=P()|0;O()|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;vb(e+8|0)}vb(e+72|0)}vb(f);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;xb(e+32|0);break a}v[22692]=0;c=Q(1428,c|0,e+8|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(c){c=v[b>>2];v[22692]=0;pz(e+8|0,b+4|0,b+8|0,c,b+34|0,2,4,h);c=v[22692];v[22692]=0;if((c|0)==1){break b}}c=e+44|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+42|0]=c&128?0:c+1|0;v[22692]=0;rk(b);c=v[22692];v[22692]=0;if((c|0)==1){break b}}p:{q:{r:{s:{t:{if(w[b+42|0]){break t}v[22692]=0;c=a+60|0;f=Q(858,c|0,7)|0;h=v[22692];v[22692]=0;if((h|0)==1){break c}if(!f){break t}vc(c);v[22692]=0;c=Q(1430,c|0,e+8|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break s}if(!c){break t}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22692]=0;g=a+120|0;c=T(275,g|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}if(!c){break p}c=0;v[22692]=0;f=T(190,g|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break q}v[e+72>>2]=f;i=b+68|0;tc(e+72|0,9);if(!v[e+72>>2]){f=0;break r}h=e+8|4;while(1){u:{v[22692]=0;R(1431,g|0,e+8|0);f=v[22692];v[22692]=0;if((f|0)==1){break u}f=h;v[((c<<2)+b|0)+68>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);c=c+1|0;f=v[e+72>>2];if(c>>>0<f>>>0){continue}break r}break}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}v[22692]=0;KB(i+(f<<2)|0,i+36|0,36520);c=v[22692];v[22692]=0;if((c|0)!=1){break p}}c=P()|0;O()|0;break a}a=a+80|0;vc(a);v[22692]=0;c=Q(1433,a|0,e+8|0)|0;f=v[22692];v[22692]=0;v:{w:{x:{y:{z:{if((f|0)==1){break z}if(!c){break w}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|4;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22692]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22692];v[22692]=0;if((f|0)==1){break v}u[b+28>>1]=x[c>>1];c=e+8|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22692]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22692];v[22692]=0;if((f|0)==1){break y}u[b+30>>1]=x[c>>1];c=e+16|0;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22692]=0;u[e+6>>1]=64;c=Pc(e+72|0,e+6|0);f=v[22692];v[22692]=0;if((f|0)==1){break x}u[b+32>>1]=x[c>>1];t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22692]=0;c=Q(189,a|0,32)|0;f=v[22692];v[22692]=0;if((f|0)==1){break z}if(!c){break w}v[22692]=0;W(1434,a|0,d|0,32)|0;c=v[22692];v[22692]=0;if((c|0)==1){break z}v[22692]=0;c=T(465,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break z}v[22692]=0;U(1435,a|0,b+43|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){break w}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}xb(e+88|0);gb=e+112|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}xb(e+88|0);S(c|0);L()}function HO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;a:{b:{if(!ue(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}e=v[d+44>>2];if(!e){break b}u[i+14>>1]=c-61;d=gb-80|0;gb=d;c=u[e+28>>1];g=i+14|0;b=u[g>>1];f=e+4|0;Nb(f);c:{d:{if((b|0)>=(c|0)){if((b|0)<=(x[e+28>>1]+Nb(f)<<16)-65536>>16){break d}}Kb(a);break c}e:{b=x[e+30>>1];if(!b){b=e+52|0;k=d,l=$y(b,g),v[k+56>>2]=l;k=d,l=Ah(b),v[k+40>>2]=l;if(!mg(d+56|0,d+40|0)){break e}eg(a,te(d+56|0)+4|0);break c}c=ko(u[g>>1],b<<16>>16);u[d+78>>1]=c;b=Kb(a);a=e+52|0;k=d,l=$y(a,d+78|0),v[k+72>>2]=l;k=d,l=Ah(a),v[k+56>>2]=l;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(mg(d+72|0,d+56|0)){a=te(d+72|0);v[22692]=0;Q(154,b|0,a+4|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break v}a=u[e+30>>1];c=u[g>>1];v[22692]=0;k=d,l=_y(c,a)+5|0,v[k+40>>2]=l;R(151,d+56|0,d+40|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}v[22692]=0;Q(113,b|0,d+56|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){vb(d+56|0);break c}a=P()|0;O()|0;vb(d+56|0);break f}if(u[e+30>>1]>26){break s}v[22692]=0;c=W(708,d+40|0,1,(c<<24)+1090519040>>24)|0;a=v[22692];v[22692]=0;if((a|0)==1){break u}v[22692]=0;U(13,d+56|0,0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break t}Eb(b,d+56|0);vb(d+56|0);vb(c);v[22692]=0;Q(152,b|0,11794)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break r}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22692]=0;a=(c<<16>>16)/16|0;v[d+36>>2]=c-(a<<4)<<16>>16;R(1488,d+40|0,d+36|0);f=v[22692];v[22692]=0;if((f|0)==1){break q}v[22692]=0;v[d+20>>2]=(a<<16>>16)%16;R(1488,d+24|0,d+20|0);a=v[22692];v[22692]=0;if((a|0)==1){break p}v[22692]=0;U(3,d+56|0,d+40|0,d+24|0);a=v[22692];v[22692]=0;if((a|0)==1){break o}Eb(b,d+56|0);vb(d+56|0);vb(d+24|0);vb(d+40|0);if(c<<16>>16<256){break r}v[22692]=0;U(9,d+8|0,0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break m}v[22692]=0;_S(d+40|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break l}v[22692]=0;U(13,d+56|0,0,d+40|0);a=v[22692];v[22692]=0;if((a|0)==1){break k}Eb(b,d+56|0);vb(d+56|0);vb(d+40|0);vb(d+8|0)}a=u[e+30>>1];c=u[g>>1];v[22692]=0;k=d,l=_y(c,a)+5|0,v[k+40>>2]=l;R(151,d+56|0,d+40|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}v[22692]=0;Q(113,b|0,d+56|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break h}vb(d+56|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(d+24|0)}vb(d+40|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+40|0)}vb(d+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+56|0);break f}a=P()|0;O()|0}vb(b);S(a|0);L()}b=a;a=gb-16|0;gb=a;c=a;f=gb-32|0;gb=f;e=Ge(f+16|0,1,0);NP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);w:{x:{if(v[f+12>>2]){while(1){h=Ab(e);v[22692]=0;v[f+4>>2]=h;h=wf(f+4|0);j=v[22692];v[22692]=0;if((j|0)==1){break x}v[22692]=0;U(75,e|0,h|0,0);h=v[22692];v[22692]=0;if((h|0)==1){break x}NP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);if(v[f+12>>2]){continue}break}}g=v[f+8>>2];h=Jb(e);v[22692]=0;R(76,e|0,g-h|0);g=v[22692];v[22692]=0;if((g|0)==1){break x}v[22692]=0;R(86,c|0,e|0);c=v[22692];v[22692]=0;if((c|0)!=1){break w}}a=P()|0;O()|0;vb(e);S(a|0);L()}vb(e);gb=f+32|0;v[22692]=0;R(85,b|0,a|0);b=v[22692];v[22692]=0;y:{if((b|0)!=1){vb(a);gb=a+16|0;break y}b=P()|0;O()|0;vb(a);S(b|0);L()}}gb=d+80|0;break a}e=v[b>>2];b=gb-32|0;gb=b;d=gb-16|0;gb=d;t[d+15|0]=c;t[d+14|0]=251;t[d+13|0]=255;f=Bv(d+15|0,d+14|0,d+13|0);gb=d+16|0;z:{if(f){v[b+16>>2]=v[9584];d=v[9583];v[b+8>>2]=v[9582];v[b+12>>2]=d;d=v[9581];v[b>>2]=v[9580];v[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break z}if(ue(c)){d=Kb(b);v[22692]=0;f=c-1|0;c=(f<<16>>16)/12|0;e=Q(1307,d|0,e+(f-B(c,12)<<16>>16<<2)|0)|0;f=v[22692];v[22692]=0;A:{if((f|0)==1){break A}v[22692]=0;c=Q(1308,e|0,c+48&65535)|0;e=v[22692];v[22692]=0;if((e|0)==1){break A}v[22692]=0;Q(4,a|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break A}vb(d);break z}a=P()|0;O()|0;vb(d);S(a|0);L()}if(!c){Tb(a,13812);break z}Tb(a,11765)}gb=b+32|0}gb=i+16|0}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-144|0;gb=e;d=-1;a:{b:{c:{d:{if(!xl(v[v[b>>2]-12>>2]+b|0)){b=Am(e+40|0,b);v[22692]=0;d=Q(616,e+24|0,11205)|0;f=v[22692];v[22692]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){v[22692]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(617,b|0,d|0,e+16|0);f=v[22692];v[22692]=0;if((f|0)==1){break E}Hb(d);t[e+15|0]=0;v[22692]=0;d=Q(616,e+24|0,11893)|0;f=v[22692];v[22692]=0;if((f|0)==1){break D}v[22692]=0;W(618,b|0,e+15|0,d|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break C}Hb(d);v[22692]=0;f=w[e+15|0];d=Q(616,e+24|0,12881)|0;g=v[22692];v[22692]=0;if((g|0)==1){break B}v[22692]=0;f=f?0:c;Y(1491,b|0,a+40|0,d|0,f|0);c=v[22692];v[22692]=0;if((c|0)==1){break A}Hb(d);u[e+12>>1]=65535;v[22692]=0;c=Q(616,e+24|0,12562)|0;d=v[22692];v[22692]=0;if((d|0)==1){break z}v[22692]=0;W(1081,b|0,e+12|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break y}Hb(c);u[e+10>>1]=0;v[22692]=0;c=Q(616,e+24|0,12455)|0;d=v[22692];v[22692]=0;if((d|0)==1){break x}v[22692]=0;W(1081,b|0,e+10|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break w}Hb(c);u[a>>1]=x[e+10>>1];v[22692]=0;c=Q(616,e+24|0,12192)|0;d=v[22692];v[22692]=0;if((d|0)==1){break v}v[22692]=0;Y(1492,b|0,a+52|0,c|0,f|0);d=v[22692];v[22692]=0;if((d|0)==1){break u}Hb(c);v[22692]=0;c=Q(616,e+24|0,12133)|0;d=v[22692];v[22692]=0;if((d|0)==1){break t}v[22692]=0;W(1463,b|0,a+36|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break s}Hb(c);v[22692]=0;c=Q(616,e+24|0,12564)|0;d=v[22692];v[22692]=0;if((d|0)==1){break r}v[22692]=0;f=a+4|0;U(1493,b|0,f|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break q}Hb(c);v[22692]=0;c=Q(616,e+24|0,12457)|0;d=v[22692];v[22692]=0;if((d|0)==1){break p}v[22692]=0;g=a+28|0;U(1494,b|0,g|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break o}Hb(c);v[22692]=0;c=Q(616,e+24|0,12293)|0;d=v[22692];v[22692]=0;if((d|0)==1){break n}v[22692]=0;U(1494,b|0,a+30|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break m}Hb(c);v[22692]=0;c=Q(616,e+24|0,12157)|0;d=v[22692];v[22692]=0;if((d|0)==1){break l}v[22692]=0;U(1495,b|0,a+32|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break k}Hb(c);u[e+8>>1]=0;v[22692]=0;c=Q(616,e+24|0,12112)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;W(1081,b|0,e+8|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break j}Hb(c);d=-1;if(v[b>>2]&1073741824){break e}c=u[g>>1];if((c|0)<-300|(c|0)>=301){break e}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break e}i=e,j=Ti(v[a+36>>2]),v[i+24>>2]=j;v[22692]=0;v[e+16>>2]=0;c=Wj(e+24|0,e+16|0,49640);h=v[22692];v[22692]=0;if((h|0)==1){break c}v[a+36>>2]=v[c>>2];if(Nb(f)>>>0>32767){break e}switch(x[a>>1]-1|0){case 2:break i;case 0:break h;default:break g}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;Hb(c);break a}c=u[e+8>>1];if((c|0)<1){break e}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];f=x[a+28>>1];u[e+16>>1]=f;v[22692]=0;u[e+18>>1]=(c+f|0)-1;a=ca(1496,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}c=u[e+8>>1];if((c|0)<1){break e}z[e+24>>2]=z[a+32>>2];h=x[a+28>>1];u[e+16>>1]=h;v[22692]=0;u[e+18>>1]=(c+h|0)-1;a=fa(1497,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}v[22692]=0;_(1498,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}}d=1}dh(b)}gb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}dh(b);S(a|0);L()}function HL(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;m=gb-48|0;gb=m;v[m+44>>2]=0;if(i?1:d|g|h){k=g?m+44|0:0;a:{if(!k){break a}j=v[k>>2];if(!j){break a}Xb(j);v[k>>2]=0}v[22692]=0;X(2011);j=v[22692];v[22692]=0;b:{c:{if((j|0)==1){l=Ta(89088,54704,54760,54920,89264,89368,89316,89208,89196,89512,89480,89448,89436,89064,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(89088)|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=277;if((k|0)==1){break e}break b}if((ea(54704)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=358;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(54760)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=359;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(54920)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=357;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89264)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=300;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89368)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=299;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89316)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=298;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89208)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=297;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89196)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=296;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89512)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=289;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89480)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=288;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89448)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=287;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}if((ea(89436)|0)==(n|0)){j=Z(l|0)|0;v[22692]=0;R(2012,k|0,j|0);k=v[22692];v[22692]=0;j=286;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break d}o=ea(89064)|0;j=257;l=Z(l|0)|0;if((n|0)!=(o|0)){break b}v[22692]=0;R(2012,k|0,l|0);k=v[22692];v[22692]=0;j=267;if((k|0)!=1){break b}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break d}break c}j=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break c}}V(0)|0;O()|0;Bb()}L()}S(j|0);L()}$()}l=!g;if(d){k=kb[d|0](j,e)|0}else{k=3}if(!(l|!(k&2))){v[g+16>>2]=j;l=v[m+44>>2];f:{if(l){l=je(l);break f}l=je(18699)}v[g+20>>2]=l}if(h){v[h>>2]=j}if(i){g=v[m+44>>2];g:{if(g){g=je(g);break g}g=je(18699)}v[i>>2]=g}g=v[m+44>>2];if(g){Xb(g);v[m+44>>2]=0}h:{if(!(k&1)){break h}v[22692]=0;R(1896,m+32|0,a|0);g=v[22692];v[22692]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22692]=0;R(1897,f|0,m+32|0);g=v[22692];v[22692]=0;if((g|0)!=1){break k}break j}g=Jb(m+32|0);if(b){v[22692]=0;R(b|0,g|0,c|0);g=v[22692];v[22692]=0;if((g|0)==1){break j}break k}Gt(g,m)}vb(m+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;vb(m+32|0)}Z(g|0)|0;v[m+28>>2]=f;v[m+24>>2]=e;v[m+20>>2]=d;v[m+16>>2]=c;v[m+12>>2]=b;v[m+8>>2]=a?a:18699;v[m+4>>2]=246;v[m>>2]=6285;RI(14915,m);it(90072);$()}gb=m+48|0}function eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=gb-128|0;gb=d;h=-1;a:{b:{c:{d:{if(!Xf(v[v[b>>2]-12>>2]+b|0)){break d}re(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];cm(d+104|0);dl(b,d+104|0,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=oh(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;ek(b,d+8|0);break d}u[d+86>>1]=0;_f(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}cm(d+78|0);dl(b,d+78|0,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;_f(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Kb(d+112|0);v[22692]=0;f=W(648,b|0,e|0,65535)|0;i=v[22692];v[22692]=0;if((i|0)==1){break b}if(!f){break j}v[22692]=0;U(13,d- -64|0,c|0,e|0);f=v[22692];v[22692]=0;if((f|0)!=1){break k}break b}e=Kb(d+112|0);v[22692]=0;f=W(650,b|0,e|0,255)|0;i=v[22692];v[22692]=0;if((i|0)==1){break c}if(!f){break i}v[22692]=0;U(13,d- -64|0,c|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break c}}Eb(a+40|0,d- -64|0);vb(d- -64|0);vb(e);u[d+62>>1]=0;_f(b,d+62|0);u[d+60>>1]=0;_f(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Ak(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=Fv(e);u[d+58>>1]=e;break l}_f(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Kb(d+112|0);v[22692]=0;u[d+40>>1]=0;Q(1499,b|0,d+40|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[22692]=0;g=W(648,b|0,e|0,65535)|0;j=v[22692];v[22692]=0;if((j|0)==1){break g}if(g){break q}break e}v[22692]=0;g=W(650,b|0,e|0,255)|0;j=v[22692];v[22692]=0;if((j|0)==1){break g}if(!g){break e}}v[22692]=0;U(13,d- -64|0,c|0,e|0);g=v[22692];v[22692]=0;if((g|0)==1){break p}v[22692]=0;g=Q(1500,i|0,d+40|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break o}Eb(g,d- -64|0);vb(d- -64|0);vb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}cm(d- -64|0);dl(b,d- -64|0,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(gN(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d- -64|0);break f}if(!fN(b,c)){break d}}e=a+16|0;r:{if(u[d+86>>1]<=2){if(gN(b,e)){break r}break d}if(!fN(b,e)){break d}}l=a,m=Nb(e),v[l+36>>2]=m;u[d+56>>1]=0;_f(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e+200&65535)>>>0>400){break d}u[d+54>>1]=0;_f(b,d+54|0);e=u[d+54>>1];u[a+30>>1]=e;if((e|0)<0){break d}v[d+48>>2]=0;hq(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}cm(d+40|0);dl(b,d+40|0,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}if(Nb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?u[a+30>>1]>0&z[a+32>>2]>C(0):1)){break d}s:{switch(b-1|0){case 0:case 2:if(Nb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=Ti(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[Wj(d+112|0,d+32|0,49640)>>2],v[l+36>>2]=m;iq(a);h=1;if(x[a>>1]!=3){break d}if((lN(Nb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=mc(d+112|0);b=0;if(u[a+30>>1]>0){while(1){h=Lb(c,b-u[a+28>>1]|0);v[22692]=0;R(1501,e|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break h}b=b+1|0;if((b|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;l=d,m=(Nb(c)+b|0)-1|0,u[l+34>>1]=m;v[22692]=0;u[d+30>>1]=0;fa(1497,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[22692];v[22692]=0;h=1;if((a|0)!=1){Lc(e);break d}break h}vb(e);break d}vb(e);break d}b=P()|0;O()|0;Lc(e);break a}b=P()|0;O()|0}vb(e);break a}vb(e)}gb=d+128|0;return h|0}b=P()|0;O()|0;vb(e);break a}b=P()|0;O()|0;vb(e)}S(b|0);L()}function Xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-976|0;gb=e;vc(b);f=gb-32|0;gb=f;j=e+872|0;DX(f+24|0,j);h=yb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;cc(f+16|0,d,f);i=yb(f+16|0);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){CX(j)}a:{if(!d){break a}if(!GX(e+872|0)){break a}if(!Pb(b,Qc(FX(e+872|0),jb))){break a}b:{if(!c){break b}Id(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Ob(a+1074312|0,7,1);d=Tb(e+96|0,5342);Eb(a+1298304|0,d);vb(d);d=Tb(e+96|0,6028);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;TC(e+16|0,2,e+872|4);Bc(e+96|0,e+16|0);Eb(a+1298268|0,e+96|0);vb(e+96|0);while(1){d=(g<<5)+a|0;f=d+480280|0;Ue(f);h=f;f=(e+872|0)+g|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;g=g+1|0;if((g|0)!=16){continue}break}if(w[e+968|0]|w[e+969|0]<<8){gB(a+1298292|0,b,w[e+968|0]|w[e+969|0]<<8,132,0)}g=0;f=gb-32|0;gb=f;j=e+96|0;bc(f+24|0,j,771);h=yb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;cc(f+16|0,d,f);i=yb(f+16|0);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){Qb(j,0,771)}if(!d){break a}d=a+484360|0;EX(Sb(d),e+96|0,w[e+353|0]);bf(Sb(d),w[e+354|0]);Yc(b,w[e+919|0]|w[e+920|0]<<8);i=a+484344|0;r=c&1;f=0;c:{d:{while(1){d=(f<<1)+e|0;if(w[d+355|0]|w[d+356|0]<<8){ud(e+72|0,b,w[d+355|0]|w[d+356|0]<<8);p=jc(e+16|0,e+72|0);xb(e+72|0);d=w[d+355|0]|w[d+356|0]<<8;j=(d-2|0)/64|0;e:{if(!r){break e}v[22692]=0;g=W(331,i|0,f&65535,j|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!g){break e}v[22692]=0;m=T(374,p|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}v[22692]=0;Q(318,e+16|0,1)|0;g=v[22692];v[22692]=0;if((g|0)==1){break d}if(d>>>0>=66){s=j>>>0>1?j:1;l=0;while(1){d=_b(i,f);v[22692]=0;n=Rf(d,l);d=v[22692];v[22692]=0;g=0;if((d|0)==1){break d}f:{while(1){g:{v[22692]=0;R(529,e+72|0,p|0);d=v[22692];v[22692]=0;if((d|0)==1){break g}h=od(e+72|0);d=Te(e+72|0);o=bj(e+72|0);k=w[e+72|0];if((k-1&255)>>>0<=71){q=B(g,6)+n|0;t[q|0]=k+36;t[q+1|0]=w[h|0]+1}if((w[d|0]-1&255)>>>0<=15){h=B(g,6)+n|0;t[h+2|0]=1;t[h+4|0]=((w[d|0]<<6)+-64>>>0)/15}d=B(g,6)+n|0;k=w[o|0];h=k&15;t[d+5|0]=h;h:{i:{switch((w[o|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=h<<2;break h;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=h<<3;break h;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=h|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[o|0]>>>4|0)+28592|0];g=g+1|0;if((g|0)!=16){continue}break f}break}break d}l=l+1|0;if((s|0)!=(l|0)){continue}break}}d=_b(i,f);v[22692]=0;g=Be(e+72|0,14,0);h=v[22692];v[22692]=0;if((h|0)==1){break d}g=Gh(Se(g,m?j-2>>>0>m>>>0?m+1|0:-1:-1));v[22692]=0;Q(431,d|0,g|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}}xb(e+16|0)}f=f+1|0;if((f|0)!=256){continue}break}g=1;if(!(c&2)){break a}QY(b,e- -64|0);g=0;while(1){j:{k:{if(!(w[e- -64+(g>>>3)|0]>>>(g&7)&1)){g=g+1|0;break k}if(!SC(b,e+16|0)){break b}g=g+1|0;u[a+480190>>1]=g;Ie(e,1,e+16|0);Bc(e+72|0,e);c=x[a+480190>>1];v[22692]=0;Q(301,((c<<5)+a|0)+946304|0,e+72|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break j}vb(e+72|0);f=(B(g,104)+a|0)+484380|0;d=f;td(d,0);c=e+16|0;v[d>>2]=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d+4>>2]=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}if(!(!(w[c+47|0]&8)|y[d+8>>2]<=y[d+4>>2])){u[d+34>>1]=x[d+34>>1]|2}Rc(e+72|0,t[e+62|0]&1?16:8,1,0,0);Ag(e+72|0,f,b)}if((g|0)!=64){continue}break b}break}g=P()|0;O()|0;vb(e+72|0);break c}g=P()|0;O()|0;xb(e+16|0)}S(g|0);L()}g=1}gb=e+976|0;return g|0}function II(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=gb-560|0;gb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+B(s,-24)|0;n=v[(e<<2)+71232>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=s-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+71248>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=l-24|0;i=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;while(1){f=A[(g<<3)+h>>3];c=0;i=g;o=(g|0)<1;if(!o){while(1){k=(h+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;a:{if(D(f)<2147483648){j=~~f;break a}j=-2147483648}f=+(j|0);m=m+f*-16777216;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}v[k>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=aj(f,q);f=f+H(f*.125)*-8;c:{if(D(f)<2147483648){k=~~f;break c}k=-2147483648}f=f-+(k|0);d:{e:{f:{u=(q|0)<1;g:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;v[r+476>>2]=i;k=c+k|0;j=i>>y;break g}if(q){break f}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<1){break d}break e}j=2;if(f>=.5){break e}j=0;break d}c=0;i=0;if(!o){while(1){r=(h+480|0)+(c<<2)|0;o=v[r>>2];w=16777215;h:{i:{if(i){break i}w=16777216;if(o){break i}i=0;break h}v[r>>2]=w-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}j:{if(u){break j}c=8388607;k:{switch(z|0){case 1:c=4194303;break;case 0:break k;default:break j}}o=(g<<2)+h|0;v[o+476>>2]=v[o+476>>2]&c}k=k+1|0;if((j|0)!=2){break d}f=1-f;j=2;if(!i){break d}f=f-aj(1,q)}l:{m:{if(f==0){i=0;c=g;if((n|0)>=(c|0)){break l}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break l}l=q;while(1){l=l-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break m}f=aj(f,24-l|0);n:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=q}v[(h+480|0)+(g<<2)>>2]=c}f=aj(1,l);if((g|0)>=0){c=g;while(1){A[(c<<3)+h>>3]=f*+v[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){q:{f=f+A[(c<<3)+74016>>3]*A[(a+c<<3)+h>>3];if((c|0)>=(n|0)){break q}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<1){break u}d=(h+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;a=c-1|0;e=(h+160|0)+(a<<3)|0;x=A[e>>3];f=f+x;A[(h+160|0)+(c<<3)>>3]=m+(x-f);A[e>>3]=f;e=(c|0)>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;a=c-1|0;d=(h+160|0)+(a<<3)|0;p=A[d>>3];f=f+p;A[(h+160|0)+(c<<3)>>3]=m+(p-f);A[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break s}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}gb=h+560|0;return k&7}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(s+g<<2)+71248>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}}function R2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb+-64|0;gb=h;v[h+56>>2]=b;v[e>>2]=0;Fc(h,d);v[22692]=0;i=T(2464,h|0)|0;j=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h);S(a|0);L()}VG(a,f+24|0,h+56|0,c,e,i);break b}UG(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=ck(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}a=e;b=kj(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[20871];v[h+24>>2]=v[20870];v[h+28>>2]=g;g=v[20869];v[h+16>>2]=v[20868];v[h+20>>2]=g;g=v[20867];v[h+8>>2]=v[20866];v[h+12>>2]=g;g=v[20865];v[h>>2]=v[20864];v[h+4>>2]=g;k=h,l=ck(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20879];v[h+24>>2]=v[20878];v[h+28>>2]=g;g=v[20877];v[h+16>>2]=v[20876];v[h+20>>2]=g;g=v[20875];v[h+8>>2]=v[20874];v[h+12>>2]=g;g=v[20873];v[h>>2]=v[20872];v[h+4>>2]=g;k=h,l=ck(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=kj(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=kj(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=kj(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=kj(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=kj(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+56|0;H:{if(!pm(b,a+8|0)){break H}while(1){if(!cl(i,8192,om(b))){break H}nm(b);if(pm(b,a+8|0)){continue}break}}if(bl(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+56|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Js(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=hc(h,83520,44);k=g,l=ck(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20896];g=v[20895];v[h+8>>2]=v[20894];v[h+12>>2]=g;g=v[20893];v[h>>2]=v[20892];v[h+4>>2]=g;k=h,l=ck(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=kj(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[20907];v[h+24>>2]=v[20906];v[h+28>>2]=g;g=v[20905];v[h+16>>2]=v[20904];v[h+20>>2]=g;g=v[20903];v[h+8>>2]=v[20902];v[h+12>>2]=g;g=v[20901];v[h>>2]=v[20900];v[h+4>>2]=g;k=h,l=ck(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=kj(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=ck(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}TG(f+20|0,h+56|0,c,e,i);break b}a=kj(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(bl(c,a+8|0)){break M}b=4;if((Kn(i,om(c))|0)!=37){break M}b=2;if(!bl(nm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+56>>2]}gb=h- -64|0;return a|0}function V8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-128|0;gb=e;a:{if(ed(b)){break a}f=w[lL(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Ls(e+112|0,b,0,Ab(b)-1|0);Eb(b,e+112|0);vb(e+112|0)}Md(e+112|0);f=v[e+112>>2];Md(e+96|0);f=kL(f,v[e+100>>2],b);Md(e+112|0);b:{c:{d:{e:{if((f|0)==v[e+116>>2]){if(oe(b,18699)){a=ba(8)|0;v[22692]=0;U(2037,e+112|0,14701,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}qc(a,e+112|0);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+112|0);break c}if(!d){break e}a=ba(8)|0;v[22692]=0;U(2037,e+80|0,14737,b|0);b=v[22692];v[22692]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[22692]=0;R(2038,e+96|0,e+80|0);b=v[22692];v[22692]=0;if((b|0)==1){break j}v[22692]=0;U(710,e+112|0,e+96|0,c|0);b=v[22692];v[22692]=0;d=1;if((b|0)==1){break i}qc(a,e+112|0);v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+112|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}vb(e+96|0)}vb(e+80|0);if(!d){break c}}da(a|0);break c}k:{switch(v[f+4>>2]){case 0:Bg(e+72|0,b);b=gb-192|0;gb=b;Yf(b+16|0,c);v[22692]=0;R(99,b+32|0,b+16|0);c=v[22692];v[22692]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22692]=0;c=W(100,b+48|0,b+32|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break p}vb(b+32|0);vb(b+16|0);f=v[v[c>>2]-12>>2];v[22692]=0;g=ga(79)|0;h=v[22692];v[22692]=0;if((h|0)==1){break n}v[22692]=0;U(80,b+8|0,f+(b+48|0)|0,g|0);f=v[22692];v[22692]=0;if((f|0)==1){break n}Wb(b+8|0);v[22692]=0;f=Q(2039,c|0,b+32|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break n}g=v[v[f>>2]-12>>2];v[22692]=0;f=xl(f+g|0);g=v[22692];v[22692]=0;if((g|0)==1){break n}g=w[b+32|0];uf(c);gb=b+192|0;b=(f^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break m}a=P()|0;O()|0;uf(c)}S(a|0);L()}c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;jL(a,e,b,d);break e;case 1:Bg(e- -64|0,b);b=gb-192|0;gb=b;Yf(b+16|0,c);v[22692]=0;R(99,b+32|0,b+16|0);c=v[22692];v[22692]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[22692]=0;c=W(100,b+48|0,b+32|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break u}vb(b+32|0);vb(b+16|0);f=v[v[c>>2]-12>>2];v[22692]=0;g=ga(79)|0;h=v[22692];v[22692]=0;if((h|0)==1){break s}v[22692]=0;U(80,b+8|0,f+(b+48|0)|0,g|0);f=v[22692];v[22692]=0;if((f|0)==1){break s}Wb(b+8|0);v[22692]=0;f=Q(110,c|0,b+32|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break s}g=v[v[f>>2]-12>>2];v[22692]=0;f=xl(f+g|0);g=v[22692];v[22692]=0;if((g|0)==1){break s}g=v[b+32>>2];h=v[b+36>>2];uf(c);gb=b+192|0;b=f?0:g;c=f?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;uf(c)}S(a|0);L()}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;hL(a,e+8|0,b,c,d);break e;case 2:Bg(e+56|0,b);b=gb-192|0;gb=b;Yf(b+16|0,c);v[22692]=0;R(99,b+32|0,b+16|0);c=v[22692];v[22692]=0;v:{w:{x:{y:{z:{if((c|0)!=1){v[22692]=0;c=W(100,b+48|0,b+32|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break z}vb(b+32|0);vb(b+16|0);f=v[v[c>>2]-12>>2];v[22692]=0;g=ga(79)|0;h=v[22692];v[22692]=0;if((h|0)==1){break x}v[22692]=0;U(80,b+8|0,f+(b+48|0)|0,g|0);f=v[22692];v[22692]=0;if((f|0)==1){break x}Wb(b+8|0);v[22692]=0;f=Q(111,c|0,b+32|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break x}g=v[v[f>>2]-12>>2];v[22692]=0;f=xl(f+g|0);g=v[22692];v[22692]=0;if((g|0)==1){break x}i=A[b+32>>3];uf(c);gb=b+192|0;i=f?0:i;break v}a=P()|0;O()|0;break y}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break w}a=P()|0;O()|0;uf(c)}S(a|0);L()}b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;gL(a,e+16|0,i,d);break e;case 3:break k;default:break e}}Bg(e+48|0,b);Bg(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;fL(a,e+32|0,e+24|0,d)}gb=e+128|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Co(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-112|0;gb=d;p=LA(a);q=Qi(p);f=q;c=a;e=Ec(c);a:{if(f>>>0>e>>>0){m=gb-32|0;gb=m;b:{i=f-e|0;c:{if(i>>>0<=(v[wb(c)>>2]-v[c+4>>2]|0)/12>>>0){f=gb-16|0;gb=f;i=Ip(f,c,i);h=v[i+4>>2];e=v[i+8>>2];if((h|0)!=(e|0)){while(1){wb(c);eR(h);h=h+12|0;v[i+4>>2]=h;if((e|0)!=(h|0)){continue}break}}$b(i);gb=f+16|0;break c}e=wb(c);j=Ou(m+8|0,FB(c,Ec(c)+i|0),Ec(c),e);v[22692]=0;R(1119,j|0,i|0);e=v[22692];v[22692]=0;if((e|0)==1){break b}Vp(c);wb(c);f=j+4|0;l=f;k=v[c+4>>2];e=v[c>>2];if((k|0)!=(e|0)){i=v[l>>2];while(1){k=k-12|0;JB(i-12|0,k);i=v[l>>2]-12|0;v[l>>2]=i;if((e|0)!=(k|0)){continue}break}}wc(c,f);wc(c+4|0,j+8|0);wc(wb(c),dc(j));v[j>>2]=v[j+4>>2];Pw(c,Ec(c));fR(j)}gb=m+32|0;break a}a=P()|0;O()|0;fR(j);S(a|0);L()}if(e>>>0>f>>>0){f=v[c>>2]+B(f,12)|0;Ec(c);jR(c,f);gR(c)}}if(b){c=a+12|0;Gq(c,Yd(c));r=wb(c),s=0,v[r>>2]=s;r=c,s=fc(c),v[r>>2]=s;r=fc(c),s=0,v[r>>2]=s;v[a+28>>2]=0}n=mc(d+96|0);c=v[a+24>>2];v[22692]=0;e=jq(c+484344|0);c=v[22692];v[22692]=0;d:{e:{f:{g:{if((c|0)==1){break g}v[22692]=0;j=W(788,d+80|0,e|0,36508)|0;c=v[22692];v[22692]=0;if((c|0)==1){break g}h=0;u[d+78>>1]=0;if(q){o=a+12|0;while(1){l=x[rc(p,h&65535)>>1];c=uR(a,l);v[d+72>>2]=c;f=Ad(a,x[d+78>>1]);h:{if(b){v[22692]=0;t[d+32|0]=0;U(1113,f|0,c|0,d+32|0);c=v[22692];v[22692]=0;if((c|0)!=1){break h}g=P()|0;O()|0;break e}v[22692]=0;U(942,f|0,c|0,0);c=v[22692];v[22692]=0;if((c|0)==1){break f}}v[22692]=0;e=Q(470,p|0,x[d+78>>1])|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}i:{if(!e){break i}g=0;g=b?g:v[f+4>>2];v[22692]=0;v[d+32>>2]=g;e=Fb(d+32|0,d+72|0);c=v[22692];v[22692]=0;j:{k:{if((c|0)!=1){v[d+68>>2]=v[e>>2];i=Ah(o);if(x[rc(j,l)>>1]!=65535){e=sR(o,Nm(d+32|0,rc(j,l),d+68|0));v[d+64>>2]=e;r=d,s=Ah(o),v[r+8>>2]=s;f=d;l:{if(mg(d- -64|0,d+8|0)){c=sR(o,Nm(d+32|0,rc(j,l),d+72|0));break l}c=Ah(o)}v[f+56>>2]=c;v[d+48>>2]=e;if(!mg(d+48|0,d+56|0)){break i}while(1){m:{f=cd(d+32|0);c=rg(te(d+48|0)+8|0);v[22692]=0;R(1114,f|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break m}nB(d+16|0,i);c=Nm(d+8|0,d+78|0,te(d+48|0)+4|0);v[22692]=0;e=ca(1115,o|0,v[d+16>>2],c|0,f|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}v[d+24>>2]=e;rR(d+24|0);i=v[d+24>>2];Hq(f);if(mg(rR(d+48|0),d+56|0)){continue}break i}break}g=P()|0;O()|0;Hq(f);break e}f=_b(v[a+24>>2]+484344|0,l);v[22692]=0;e=Ji(f);c=v[22692];v[22692]=0;n:{o:{if((c|0)!=1){v[22692]=0;t[d+32|0]=0;U(1117,n|0,e|0,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break o}k=v[d+72>>2];if((k|0)!=v[d+68>>2]){break n}break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}p:while(1){q:{h=0;v[22692]=0;k=k-1|0;v[d+64>>2]=k;g=Rf(f,k);c=v[22692];v[22692]=0;m=1;if((c|0)==1){break k}while(1){r:{v[22692]=0;e=Ji(f);c=v[22692];v[22692]=0;s:{if((c|0)!=1){if(m>>>0<16?e>>>0>h>>>0:0){break s}if(m>>>0>1){e=cd(d+32|0);v[22692]=0;R(1114,e|0,m|0);c=v[22692];v[22692]=0;if((c|0)==1){break r}nB(d,i);c=Nm(d+8|0,d+78|0,d- -64|0);v[22692]=0;i=ca(1115,o|0,v[d>>2],c|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}Hq(e)}if(v[d+68>>2]==(k|0)){break j}continue p}g=P()|0;O()|0;break e}e=w[kc(n,h)|0];t:{u:{v:{switch(w[g+3|0]-19|0){case 1:c=w[g+5|0];if((c&240)==176){break u}break t;case 0:break v;default:break t}}c=w[g+5|0];if((c&240)!=96){break t}}r=kc(n,h),s=c&15,t[r|0]=s;if(!w[kc(n,h)|0]){break t}e=w[kc(n,h)|0]}m=B(e?e+1|0:1,m);g=g+6|0;h=h+1|0;continue}break}}break}g=P()|0;O()|0;Hq(e);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}if(k){break i}c=x[d+78>>1];r=rc(j,l),s=c,u[r>>1]=s}h=x[d+78>>1]+1|0;u[d+78>>1]=h;if((h&65535)>>>0<q>>>0){continue}break}}We(j);gc(n);gb=d+112|0;return}g=P()|0;O()|0;break d}g=P()|0;O()|0}We(j)}gc(n);S(g|0);L()}function ne(a,b){var c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),n=C(0),o=0,r=0,s=C(0),t=C(0),u=C(0);i=C(1);a:{b:{c:{k=(p(b),j(2));d=k&2147483647;d:{if(!d){break d}h=(p(a),j(2));if((h|0)==1065353216){break d}e=h&2147483647;c=C(a+b);if(!(d>>>0<2139095041?e>>>0<=2139095040:0)){break a}e:{f:{if((h|0)>-1){break f}o=2;if(d>>>0>1266679807){break e}if(d>>>0<1065353216){break f}g=150-(d>>>23|0)|0;r=d>>>g|0;o=0;if((d|0)!=r<<g){break e}o=2-(r&1)|0;break e}o=0}g=o;g:{if((d|0)!=1065353216){if((d|0)!=2139095040){break g}if((e|0)==1065353216){break d}c=(k|0)>-1?b:C(0);if(e>>>0>=1065353217){break a}c=(k|0)>-1?C(0):C(-b);break a}c=(k|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((k|0)==1073741824){break a}c=C(K(a));if(!((k|0)!=1056964608|(h|0)<0)){break a}f=C(D(a));if(e?(h&1073741823)!=1065353216:0){break b}i=(k|0)<0?C(C(1)/f):f;if((h|0)>-1){break d}if(g|e-1065353216){break c}a=C(i-i);i=C(a/a)}c=i;break a}c=(g|0)==1?C(-i):i;break a}h:{if((h|0)>-1){break h}i:{switch(g|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}i=C(-1)}j:{if(d>>>0>=1291845633){c=(k|0)<0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0<=1065353207){break a}c=(k|0)>0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0>=1065353224){break a}a=C(f+C(-1));c=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));f=c;a=C(a*C(1.44268798828125));c=(l(2,(p(C(c+a)),j(2))&-4096),q());f=C(f-C(c-a));break j}d=e>>>0<8388608;e=d?(p(C(f*C(16777216))),j(2)):e;h=e&8388607;g=h|1065353216;d=(e>>23)+(d?-151:-127)|0;e=0;k:{if(h>>>0<1885298){break k}if(h>>>0<6140887){e=1;break k}g=h|1056964608;d=d+1|0}h=e<<2;a=z[h+90032>>2];n=(l(2,g),q());m=C(C(1)/C(a+n));s=C(n-a);f=C(s*m);c=(l(2,(p(f),j(2))&-4096),q());t=C(c*c);u=m;m=(l(2,((g>>>1&536866816)+(e<<21)|0)+541065216|0),q());n=C(u*C(C(s-C(m*c))-C(C(n-C(m-a))*c)));a=C(f*f);m=C(C(n*C(f+c))+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(t+C(3))+m)),j(2))&-4096),q());f=C(C(n*a)+C(f*C(m-C(C(a+C(-3))-t))));c=C(c*a);a=(l(2,(p(C(f+c)),j(2))&-4096),q());n=z[h+90048>>2];f=C(z[h+90040>>2]+C(C(C(f-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(a*C(.9619140625));m=C(d|0);c=(l(2,(p(C(C(n+C(f+a))+m)),j(2))&-4096),q());f=C(f-C(C(C(c-m)-n)-a))}l:{m:{n=(l(2,k&-4096),q());a=C(c*n);b=C(C(f*b)+C(C(b-n)*c));c=C(a+b);g=(p(c),j(2));if((g|0)>=1124073473){break m}e=1124073472;n:{o:{if((g|0)==1124073472){if(!(C(b+C(4.299566569443414e-8))>C(c-a))){break o}break m}e=g&2147483647;if(!(!(b<=C(c-a))|(g|0)!=-1021968384)|e>>>0>=1125515265){break l}d=0;if(e>>>0<1056964609){break n}}k=(8388608>>>(e>>>23|0)-126|0)+g|0;e=k>>>23&255;d=(k&8388607|8388608)>>>150-e|0;d=(g|0)<0?0-d|0:d;a=C(a-(l(2,k&-8388608>>e-127),q()));g=(p(C(b+a)),j(2))}c=(l(2,g&-32768),q());f=C(c*C(.693145751953125));c=C(C(c*C(14286065379565116e-22))+C(C(b-C(c-a))*C(.6931471824645996)));a=C(f+c);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));m=C(C(a*b)/C(b+C(-2)));b=C(c-C(a-f));a=C(C(a-C(m-C(b+C(a*b))))+C(1));g=(p(a),j(2))+(d<<23)|0;p:{if((g|0)<=8388607){a=KI(a,d);break p}a=(l(2,g),q())}c=C(i*a);break a}c=C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function Y2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=b;v[e>>2]=0;Fc(h+8|0,d);v[22692]=0;i=T(21,h+8|0)|0;j=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h+8|0);S(a|0);L()}YG(a,f+24|0,h+24|0,c,e,i);break b}XG(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=dk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}a=e;b=lj(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=dk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=dk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=lj(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=lj(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=lj(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=lj(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=lj(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+24|0;H:{if(!gk(b,a+8|0)){break H}while(1){if(!kh(i,8192,gl(b))){break H}fl(b);if(gk(b,a+8|0)){continue}break}}if(fk(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+24|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ks(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[83444]|w[83445]<<8|(w[83446]<<16|w[83447]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);v[h+8>>2]=w[83437]|w[83438]<<8|(w[83439]<<16|w[83440]<<24);v[h+12>>2]=g;k=h,l=dk(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[83452];v[h+8>>2]=w[83448]|w[83449]<<8|(w[83450]<<16|w[83451]<<24);k=h,l=dk(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=lj(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=dk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=lj(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=dk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}WG(f+20|0,h+24|0,c,e,i);break b}a=lj(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(fk(c,a+8|0)){break M}b=4;if((Ln(i,gl(c))|0)!=37){break M}b=2;if(!fk(fl(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+24>>2]}gb=h+32|0;return a|0}function iha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-11360|0;gb=g;vc(c);a:{b:{if(!Pb(c,4)){break b}c:{while(1){d:{d=g+16|0;f=gb-32|0;gb=f;h=c;e:{if(!Pb(c,3)){i=gb-16|0;gb=i;k=d+3|0;while(1){Hf(d);d=d+1|0;if((k|0)!=(d|0)){continue}break}gb=i+16|0;break e}bY(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;id(f+16|0,h,f+8|0)}gb=f+32|0;f:{if(!rd(g+16|0,12162,3)){d=g+4648|0;f=gb-32|0;gb=f;g:{if(!Pb(c,7)){h=gb-16|0;gb=h;i=d+7|0;while(1){Hf(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}gb=h+16|0;break g}mn(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;id(f+16|0,h,f+8|0)}gb=f+32|0;f=3;d=0;while(1){h=w[(g+4648|0)+f|0];if(h&128){break c}d=h|d<<7;f=f+1|0;if((f|0)!=7){continue}break}Rb(c,d);break f}h:{if(rd(g+16|0,11381,3)){break h}if(!wV(c,10831)){break h}Rb(c,qg(c)+16|0);break f}if(!rd(g+16|0,36511,3)){break f}if(!rd(g+16|0,36515,3)){break f}if(w[g+16|0]){break d}ng(c,2)}if(Pb(c,4)){continue}break b}break}if(RS(g+16|0)){break b}}f=0;break a}vc(c);FC(g+11336|0,c);k=v[g+11336>>2];v[22692]=0;c=Td(g+11336|0);d=v[22692];v[22692]=0;i:{j:{k:{l:{if((d|0)!=1){c=zb(c);j=mc(g+11320|0);Qb(g+4648|0,0,6668);v[22692]=0;ot(g+4648|0);d=v[22692];v[22692]=0;if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;h=0;d=0;while(1){f=Ac(k,l);v[22692]=0;m=fa(1124,g+4648|0,c|0,f|0,g+16|0,g+4624|0)|0;f=v[22692];v[22692]=0;m:{n:{if((f|0)!=1){if((m|0)<0){break k}f=v[g+4624>>2];if((f|0)<0){break k}n=(m|0)<1;if(!(f?1:n)|!(f|m)){break k}if((f|0)<1){break m}i=v[g+4636>>2];if((i|0)!=(h|0)?h:0){break k}f=v[g+4632>>2];if((f|0)!=(d|0)?d:0){break k}if((i|0)<1|f-1>>>0>1){break l}v[g+12>>2]=0;d=Ac(k,l);v[22692]=0;v[g+8>>2]=d;d=Wj(g+4624|0,g+12|0,g+8|0);h=v[22692];v[22692]=0;o:{if((h|0)!=1){d=v[d>>2];v[g+12>>2]=0;h=Ac(k,l);v[22692]=0;v[g+8>>2]=h;h=Wj(g+4624|0,g+12|0,g+8|0);o=v[22692];v[22692]=0;if((o|0)==1){break o}c=c+d|0;d=k;h=v[h>>2];k=d-h|0;l=l-((h>>31)+(d>>>0<h>>>0)|0)|0;if(n){break n}v[22692]=0;U(1126,j|0,g+16|0,(g+16|0)+(B(f,m)<<1)|0);d=v[22692];v[22692]=0;if((d|0)!=1){break n}d=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break j}Z(d|0)|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;h=i;d=f;if((c|0)!=1){break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}h=i;d=f}if((sc(j)>>>0)/(d>>>0)>>>0>268435456){break k}if((l|0)>0?1:(l|0)>=0?k:0){continue}break}break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break i}h=i;d=f}f=0;p:{q:{r:{s:{t:{if(!h|!d){break t}if(bd(j)){break t}if((sc(j)>>>0)/(d>>>0)>>>0>268435456){break t}v[22692]=0;Q(1127,a|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break p}if(!e){v[22692]=0;c=Q(70,g+16|0,18699)|0;f=v[22692];v[22692]=0;if((f|0)==1){break s}v[22692]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break r}vb(c);v[22692]=0;c=B(b,104)+a|0;R(424,c+484380|0,0);f=v[22692];v[22692]=0;if((f|0)==1){break p}v[c+484404>>2]=h}h=B(b,104)+a|0;c=h+484380|0;p=c,q=(sc(j)>>>0)/(d>>>0)|0,v[p>>2]=q;f=h+484414|0;h=x[f>>1];u[f>>1]=(d|0)==2?h|65:h&65470|1;v[22692]=0;T(386,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break p}if(Nd(c)){d=Vb(j);h=Zb(j);b=v[(B(b,104)+a|0)+484400>>2];v[22692]=0;W(1128,d|0,h|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break p}}if(!e){b=v[a+480180>>2];v[22692]=0;U(1129,c|0,32,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break q}v[22692]=0;_h(c,a,0);a=v[22692];v[22692]=0;if((a|0)==1){break p}}f=Nd(c)}We(j);zc(g+11336|0);break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;vb(c);break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}We(j)}zc(g+11336|0);S(d|0);L()}gb=g+11360|0;return f|0}function b_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-576|0;gb=e;vc(b);f=gb-32|0;gb=f;h=e+72|0;AE(f+24|0,h);g=yb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;cc(f+16|0,d,f);i=yb(f+16|0);if((i|0)==(g|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(i|0);if(!d){zE(h)}a:{if(!d){break a}if(!GE(e+72|0)){break a}b:{if(!c){break b}if(!Pb(b,Qc(FE(e+72|0),jb))){break a}Id(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;f=1;Ob(a+1074312|0,7,1);d=Tb(e+40|0,11807);Eb(a+1298304|0,d);vb(d);d=Tb(e+40|0,11840);Eb(a+1298316|0,d);vb(d);Vc(a+1298328|0,x[e+72>>1]==26217?11807:11835);v[a+1298364>>2]=5;d=w[e+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){i=1;while(1){h=gb-32|0;gb=h;g=e+40|0;bc(h+24|0,g,25);k=yb(h+24|0);d=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=d;v[h>>2]=j;v[h+4>>2]=d;d=b;cc(h+16|0,d,h);j=yb(h+16|0);if((j|0)==(k|0)){Rb(d,yb(h+24|0))}gb=h+32|0;if((k|0)!=(j|0)){t[g|0]=0;t[g+1|0]=0;t[g+2|0]=0;t[g+3|0]=0;t[g+4|0]=0;t[g+5|0]=0;t[g+6|0]=0;t[g+7|0]=0;t[g+24|0]=0;t[g+16|0]=0;t[g+17|0]=0;t[g+18|0]=0;t[g+19|0]=0;t[g+20|0]=0;t[g+21|0]=0;t[g+22|0]=0;t[g+23|0]=0;t[g+8|0]=0;t[g+9|0]=0;t[g+10|0]=0;t[g+11|0]=0;t[g+12|0]=0;t[g+13|0]=0;t[g+14|0]=0;t[g+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}d=(B(f,104)+a|0)+484380|0;td(d,0);v[d+24>>2]=8363;v[d>>2]=w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24);v[d+4>>2]=w[e+57|0]|w[e+58|0]<<8|(w[e+59|0]<<16|w[e+60|0]<<24);g=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);g=g>>>0>y[d>>2]?v[d+4>>2]?g:0:g;v[d+8>>2]=g;if(g){u[d+34>>1]=2;rk(d)}ii(e+8|0,2,e+40|0);Bc(e+24|0,e+8|0);v[22692]=0;Q(301,((f<<5)+a|0)+946304|0,e+24|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break e}vb(e+24|0);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}d=e+72|2;Ve(e+24|0,3,d,36);Bc(e+40|0,e+24|0);Eb(a+1298268|0,e+40|0);vb(e+40|0);f=0;PS(a+1298292|0,zb(d),108,36,0);d=a+484360|0;EE(Sb(d),e+185|0,128);if(x[rc(Sb(d),w[e+184|0])>>1]<w[e+183|0]){break d}break c}a=P()|0;O()|0;vb(e+24|0);S(a|0);L()}bf(Sb(d),w[e+184|0])}while(1){d=(f<<5)+a|0;Ue(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;xg(h,w[e+183|0]);n=1;if(w[e+183|0]){o=c&1;g=0;while(1){f:{g:{if(o){if(sh(h,g&65535,64)){break g}}Rb(b,1536);break f}v[e+24>>2]=-1;v[e+28>>2]=-1;j=0;while(1){f=Rf(_b(h,g),j);k=0;while(1){Rr(e+40|0,b);d=od(e+40|0);l=Te(e+40|0);i=w[d|0];d=w[e+40|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+k|0]=255;d=w[e+40|0]}if((d&255)!=255){t[f+2|0]=1;t[f+4|0]=(((i&15)<<6|8)>>>0)/15}m=(e+24|0)+k|0;h:{i:{i=w[l|0];j:{if((i|0)!=255){t[m|0]=i;d=i&15;if(d|(i|0)==48){break j}break i}i=w[m|0];if((i|0)==255){break h}d=i&15}t[f+5|0]=d;k:{if(i<<24>>24<0){break k}l=i>>>4|0;t[f+3|0]=w[l+28376|0];l:{switch(l-3|0){case 0:t[f+5|0]=d|32;break i;case 1:t[f+5|0]=B(d,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(i&15){case 0:t[f+5|0]=79;break h;case 1:break m;default:break k}}t[f+5|0]=244;break h}t[f+3|0]=0;break h}t[m|0]=255}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}j=j+1|0;if((j|0)!=64){continue}break}d=(e+72|0)+g|0;f=d;if(w[d+369|0]<63){Cm(_b(h,g),Gh(Se(Be(e+40|0,14,0),w[f+369|0])))}Cm(_b(h,g),Gh(Be(e+40|0,16,w[d+241|0])))}g=g+1|0;if(g>>>0<w[e+183|0]){continue}break}}if(!(c&2)){break a}f=1;c=Rc(e+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){Ag(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=1}gb=e+576|0;return n|0}function gL(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=gb-256|0;gb=e;A[e+248>>3]=c;a:{if(kk(b)){break a}f=w[nl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Cl(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}Md(e+216|0);f=v[e+216>>2];Md(e+200|0);h=ml(f,v[e+204>>2],b);Md(e+216|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=uc(e+232|0,18699);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){d=ba(8)|0;v[22692]=0;R(2044,e+200|0,e+248|0);a=v[22692];v[22692]=0;f:{g:{h:{if((a|0)!=1){v[22692]=0;U(2021,e+216|0,14701,e+200|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}qc(d,e+216|0);a=0;v[22692]=0;U(184,d|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break c}}da(d|0);break c}if(!d){break e}d=ba(8)|0;v[22692]=0;f=Q(2041,e+168|0,b|0)|0;b=v[22692];v[22692]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22692]=0;U(2021,e+184|0,14737,f|0);a=v[22692];v[22692]=0;if((a|0)==1){break q}v[22692]=0;R(2038,e+200|0,e+184|0);b=v[22692];v[22692]=0;a=1;if((b|0)==1){break p}v[22692]=0;R(2044,e+152|0,e+248|0);a=v[22692];v[22692]=0;if((a|0)==1){break o}v[22692]=0;U(2042,e+216|0,e+200|0,e+152|0);b=v[22692];v[22692]=0;a=1;if((b|0)==1){break n}qc(d,e+216|0);v[22692]=0;U(184,d|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(e+152|0)}vb(e+200|0)}vb(e+184|0)}vb(f)}if(!a){break c}da(d|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=uc(e+136|0,18699);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Gc(e+80|0,e+72|0)){d=ba(8)|0;v[22692]=0;R(2044,e+200|0,e+248|0);a=v[22692];v[22692]=0;r:{s:{t:{if((a|0)!=1){v[22692]=0;U(2021,e+216|0,14701,e+200|0);a=v[22692];v[22692]=0;if((a|0)==1){break t}qc(d,e+216|0);a=0;v[22692]=0;U(184,d|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break c}}da(d|0);break c}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=uc(e+120|0,4808);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Gc(e- -64|0,e+56|0)){if(!w[a+28|0]){break e}if(c<=4?c<=0:1){a=ba(8)|0;v[22692]=0;d=Q(70,e+216|0,4903)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}qc(a,d);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=xh(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;tq(v[a>>2]);break e}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=uc(e+104|0,4860);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Gc(e+48|0,e+40|0)){if(!w[a+28|0]){break e}if(c<=4?c<=0:1){a=ba(8)|0;v[22692]=0;d=Q(70,e+216|0,4924)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,d);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=P()|0;O()|0;da(a|0);break c}b=xh(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;tq(v[a>>2]);break e}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=uc(e+88|0,4878);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Gc(e+32|0,e+24|0)){break e}b=Io(c*65536);v[v[a+24>>2]+480236>>2]=b}gb=e+256|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0;e=gb-48|0;gb=e;a:{b:{c:{d:{if(!c){break d}A=e,B=Ae(a),t[A+32|0]=B;k=e+32|0;d=b;e:{if(y[d+4>>2]<y[wb(d)>>2]){h=gb-16|0;gb=h;f=zi(h,d,1);wb(d);Bd(v[f+4>>2],k);v[f+4>>2]=v[f+4>>2]+1;$b(f);gb=h+16|0;break e}f=gb-32|0;gb=f;h=wb(d);h=Yg(f+8|0,nh(d,pc(d)+1|0),pc(d),h);Bd(v[h+8>>2],k);v[h+8>>2]=v[h+8>>2]+1;v[22692]=0;R(296,d|0,h|0);d=v[22692];v[22692]=0;f:{if((d|0)!=1){be(h);gb=f+32|0;break f}a=P()|0;O()|0;be(h);S(a|0);L()}}h=c-1|0;if(!h){break c}while(1){g:{h:{c=i<<1;i=c&254;i:{if(!i){if(!kf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0<256){break i}break h}if((c&65535)>>>0>255){break h}}if(!kf(a,e+32|0)){break d}g=e+32|0;c=b;j:{if(v[c+4>>2]!=v[wb(c)>>2]){jM(c,g);break j}k=gb-32|0;gb=k;f=wb(c);j=Yg(k+8|0,nh(c,pc(c)+1|0),pc(c),f);d=v[j+8>>2];v[22692]=0;kl(f,d,g);d=v[22692];v[22692]=0;k:{if((d|0)==1){break a}v[j+8>>2]=v[j+8>>2]+1;v[22692]=0;R(296,c|0,j|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}be(j);gb=k+32|0;break k}}h=h-1|0;break g}d=1;while(1){l:{m:{n:{c=i<<1&254;o:{if(c){g=i>>>0>127}else{if(!kf(a,e+32|0)){break o}f=w[e+32|0]<<1|1;c=f&255;g=f>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break m}if(kf(a,e+32|0)){break n}}i=0;break l}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break l}if(c>>>0>127){continue}}break}p:{if((d|0)<=2){f=0;g=d-2|0;break p}c=kf(a,e+32|0);if(!c){break d}c=c?(w[e+32|0]|d<<8)-768|0:s;f=((c|0)>1279?2:1)+((c|0)>31999)|0;s=c^-1;g=0}c=i<<1&254;if(c){d=i>>>0>127}else{if(!kf(a,e+32|0)){break d}d=w[e+32|0]<<1|1;c=d&255;d=d>>>0>255}k=h;i=c<<1&254;if(i){c=c>>>0>127}else{if(!kf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(g<<2|(d?2:0));if(!c){d=1;while(1){q:{r:{s:{c=i<<1&254;t:{if(c){g=i>>>0>127}else{if(!kf(a,e+32|0)){break t}g=w[e+32|0]<<1|1;c=g&255;g=g>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break r}if(kf(a,e+32|0)){break s}}i=0;break q}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break q}if(c>>>0>127){continue}}break}c=d+2|0}g=k;k=c+f|0;d=0;if(g>>>0<k>>>0|(k|0)<1|(s|0)>-1){break b}d=0;if((0-pc(b)|0)>(s|0)){break b}A=e,B=Zb(b),v[A+32>>2]=B;Hd(e+40|0,e+32|0);t[e+24|0]=0;m=e+24|0;n=gb-32|0;gb=n;v[n+24>>2]=v[e+40>>2];c=b;d=v[c>>2];A=n,B=Vb(c),v[A>>2]=B;d=Yj(n+24|0,n)+d|0;u:{g=k;f=v[wb(c)>>2];l=v[c+4>>2];v:{if(g>>>0<=f-l>>>0){f=g;j=l-d|0;if(f>>>0>j>>>0){wn(c,g-j|0,m);f=j;if(!f){break v}}x=gb-16|0;gb=x;o=c;r=l;j=d;q=v[c+4>>2];p=(q-(d+g|0)|0)+d|0;z=zi(x,c,l-p|0);if(l>>>0>p>>>0){u=v[z+4>>2];l=p;while(1){wb(o);Bd(u,l);u=u+1|0;v[z+4>>2]=u;l=l+1|0;if(r>>>0>l>>>0){continue}break}}$b(z);wr(j,p,q);gb=x+16|0;li(d,f,d>>>0<=m>>>0?m>>>0<y[c+4>>2]?g+m|0:m:m);break v}f=wb(c);j=Yg(n,nh(c,pc(c)+g|0),d-v[c>>2]|0,f);v[22692]=0;U(633,j|0,g|0,m|0);f=v[22692];v[22692]=0;if((f|0)==1){break a}o=c;rt(c);r=j;f=v[j+4>>2];g=d;p=j+4|0;wk(wb(c),v[c>>2],d,p);wb(c);l=j+8|0;q=l;d=v[c+4>>2];if((g|0)!=(d|0)){c=v[q>>2];while(1){Bd(c,g);c=v[q>>2]+1|0;v[q>>2]=c;g=g+1|0;if((d|0)!=(g|0)){continue}break}}xc(o,p);xc(o+4|0,l);xc(wb(o),dc(r));v[r>>2]=v[r+4>>2];pt(o,pc(o));d=f;be(j)}Fg(d);gb=n+32|0;break u}A=e,B=Zb(b),v[A+16>>2]=B;A=e,B=LV(e+16|0,k),v[A+24>>2]=B;A=e,B=ve(e+24|0,s),v[A+32>>2]=B;A=e,B=Zb(b),v[A+16>>2]=B;A=e,B=LV(e+16|0,k),v[A+24>>2]=B;c=k;while(1){A=e,B=KV(e+32|0),v[A+16>>2]=B;d=w[v[e+16>>2]];A=e,B=KV(e+24|0),v[A+8>>2]=B;t[v[e+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}h=h-k|0}if(h){continue}break}break c}d=0;break b}d=1}gb=e+48|0;return d|0}a=P()|0;O()|0;be(j);S(a|0);L()}function T7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-352|0;gb=d;a:{if(kk(b)){break a}e=w[nl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Cl(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}Md(d+320|0);e=v[d+320>>2];Md(d+304|0);e=ml(e,v[d+308>>2],b);Md(d+320|0);b:{c:{d:{e:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=uc(d+336|0,18699);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22692]=0;c=Q(70,d+320|0,7706)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;if(!c){break e}c=ba(8)|0;v[22692]=0;e=Q(2041,d+304|0,b|0)|0;a=v[22692];v[22692]=0;f:{g:{h:{if((a|0)!=1){v[22692]=0;U(2021,d+320|0,14737,e|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}qc(c,d+320|0);a=0;v[22692]=0;U(184,c|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+320|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e);if(!a){break c}}da(c|0);break c}if(v[e+4>>2]){a=ba(8)|0;v[22692]=0;c=Q(70,d+320|0,8828)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=uc(d+288|0,18699);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Gc(d+152|0,d+144|0)){a=ba(8)|0;v[22692]=0;c=Q(70,d+320|0,7706)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=uc(d+272|0,4491);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;i:{if(!Gc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=uc(d+256|0,4473);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Gc(d+120|0,d+112|0)){break i}}e=w[a+60|0]!=0;break e}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=uc(d+240|0,3988);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;j:{if(!Gc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=uc(d+224|0,3969);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Gc(d+88|0,d+80|0)){break j}}e=w[a+61|0]!=0;break e}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=uc(d+208|0,4072);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break e}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=uc(d+192|0,3153);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break e}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=uc(d+176|0,4540);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break e}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=uc(d+160|0,10668);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Gc(d+24|0,d+16|0)){break e}e=v[v[a+24>>2]+24668>>2]!=0}gb=d+352|0;return e|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function rP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;h=a+1074376|0;f=B(b,872);d=(h+f|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+f|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(Gj(d)){a=B(b,872)+a|0;u[a+1075764>>1]=e-8;a=a+1075843|0;t[a|0]=w[a|0]|32;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=e<<28>>24;c=x[(e<<1)+39712>>1];v[b+1075696>>2]=c;d=b+1075692|0;if(!v[d>>2]){break a}k=d,l=Zg(a,w[b+1075789|0],e<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){t[(B(b,872)+a|0)+1075814|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){t[(B(b,872)+a|0)+1075817|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1298260|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,872)+a|0;c:{if((i|0)!=x[c+1075778>>1]){break c}d:{e:{switch(j|0){case 0:vo(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!Dd(d)){break d}pk(v[d>>2],e&65535);break d;case 1:f=c+1075080|0;h=v[f>>2];v[f>>2]=h|4096;if(!(h&512)){break d}if(!Dd(d)){break d}pk(v[d>>2],e&65535);break d;default:break e}}v[c+1075688>>2]=0;f=c+1075080|0;h=v[f>>2];v[f>>2]=h|4096;if(!(h&512)){break d}if(!Dd(d)){break d}Ni(v[d>>2],e&65535,1)}h=v[c+1075648>>2];if(!h){break c}f=w[h+34|0];if(!f){break c}f=v[(B(f,160)+a|0)+906140>>2];if(!f){break c}kb[v[v[f>>2]+92>>2]](f,h,w[c+1075789|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}cB(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Im(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=de(d+788|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=d;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=e;Db(g+8|0,a+1074312|0,35);if(Cb(g+8|0)){break a}if(!de(c+1075780|0)){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}mu(a,h,d,e);break a;case 11:i:{if(e){break i}e=1;if(v[a+480180>>2]&16777248){break i}e=0;if(v[a+480180>>2]==2){break a}}Db(g+8|0,a+1074312|0,30);c=a;if(Cb(g+8|0)){a=1}else{a=v[a+480180>>2]==2}jA(c,b,e,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=e}gb=g+16|0}function moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-288|0;gb=e;d=e+128|0;g=gb-48|0;gb=g;FC(g+24|0,b);v[22692]=0;Kr(g+16|0,g+24|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}v[22692]=0;b=v[g+20>>2];v[g+8>>2]=v[g+16>>2];v[g+12>>2]=b;R(635,d|0,g+8|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}zc(g+24|0);gb=g+48|0;break a}a=P()|0;O()|0;zc(g+24|0);S(a|0);L()}v[22692]=0;R(606,e+24|0,e+128|0);b=v[22692];v[22692]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((b|0)!=1){v[22692]=0;g=W(100,e+144|0,e+24|0,8)|0;b=v[22692];v[22692]=0;if((b|0)==1){break D}vb(e+24|0);gc(e+128|0);if(c>>>0<2189){break i}v[22692]=0;b=Q(615,e+24|0,g|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break e}v[22692]=0;c=Q(616,e+8|0,7348)|0;d=v[22692];v[22692]=0;if((d|0)==1){break B}v[22692]=0;v[e>>2]=19923014;v[e+4>>2]=0;U(617,b|0,c|0,e|0);d=v[22692];v[22692]=0;if((d|0)==1){break A}Hb(c);t[e|0]=0;v[22692]=0;c=Q(616,e+8|0,8234)|0;d=v[22692];v[22692]=0;if((d|0)==1){break k}d=0;v[22692]=0;W(618,b|0,e|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break z}Hb(c);if(!w[e|0]){v[22692]=0;d=Ck(a);c=v[22692];v[22692]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[22692]=0;c=Q(616,e+8|0,12881)|0;h=v[22692];v[22692]=0;if((h|0)==1){break x}v[22692]=0;Y(620,b|0,f|0,c|0,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break w}Hb(c);v[22692]=0;c=Q(616,e+8|0,12562)|0;f=v[22692];v[22692]=0;if((f|0)==1){break v}v[22692]=0;Y(621,b|0,a|0,c|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break u}Hb(c);v[22692]=0;c=Q(616,e+8|0,12455)|0;d=v[22692];v[22692]=0;if((d|0)==1){break t}v[22692]=0;d=a+484360|0;U(622,b|0,d|0,c|0);f=v[22692];v[22692]=0;if((f|0)==1){break s}Hb(c);v[22692]=0;c=Q(616,e+8|0,28854)|0;f=v[22692];v[22692]=0;if((f|0)==1){break r}v[22692]=0;U(623,b|0,a+484344|0,c|0);f=v[22692];v[22692]=0;if((f|0)==1){break q}Hb(c);v[22692]=0;f=Ck(a);c=v[22692];v[22692]=0;if((c|0)==1){break p}v[22692]=0;c=Q(616,e+8|0,28860)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}v[22692]=0;Y(624,b|0,d|0,c|0,f|0);d=v[22692];v[22692]=0;if((d|0)==1){break n}Hb(c);if(v[b>>2]&1073741824){v[22692]=0;c=Q(2,e+8|0,13355)|0;d=v[22692];v[22692]=0;if((d|0)==1){break m}v[22692]=0;U(556,a|0,1,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break l}vb(c)}dh(b);break h}a=P()|0;O()|0;break C}a=P()|0;O()|0;vb(e+24|0)}gc(e+128|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0}dh(b);break d}b=Kb(e+24|0);d=v[a+4>>2];v[22692]=0;f=Ck(a);h=v[22692];v[22692]=0;if((h|0)==1){break g}v[22692]=0;d=ca(625,d|0,g|0,b|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}E:{if((d|0)!=1){v[22692]=0;c=Q(2,e+8|0,13661)|0;d=v[22692];v[22692]=0;F:{if((d|0)!=1){v[22692]=0;U(556,a|0,1,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break F}vb(c);break E}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22692]=0;d=Ck(a);f=v[22692];v[22692]=0;if((f|0)==1){break g}v[22692]=0;Y(626,g|0,a|0,d|0,c>>>0<2188|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}}vb(b)}uf(g);gb=e+288|0;return}a=P()|0;O()|0}vb(b);break d}a=P()|0;O()|0}uf(g)}S(a|0);L()}function vg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=gb-112|0;gb=k;l=h;o=i&2147483647;m=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(m|0)==-1;r=d;p=(c|0)==(m|0)&b>>>0>j>>>0|c>>>0>m>>>0;n=d+p|0;m=e&2147483647;j=m;j=n>>>0<p>>>0?j+1|0:j;p=n-1|0;a:{b:{j=j-(n>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;n=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(n|0)!=-1;p=(g|0)==(n|0)&f>>>0>j>>>0|g>>>0>n>>>0;n=p+l|0;j=o;j=n>>>0<p>>>0?j+1|0:j;p=n;n=n-1|0;j=j-(p>>>0<1)|0;if((n|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(n|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(m|0)==2147418112?!(b|c):m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|m))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}q=(l|0)==(r|0)&(m|0)==(o|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:(m|0)==(o|0)&l>>>0>r>>>0|m>>>0<o>>>0;j=q;n=j?f:b;o=j?g:c;l=j?i:e;r=l;m=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|m);i=d<<6;l=E(d?n:m)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;Kf(k+96|0,n,o,m,j,d-15|0);m=v[k+104>>2];n=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Kf(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=m;d=j<<3|b>>>29;m=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}Kf(k- -64|0,b,c,h,i,128-d|0);hm(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=m;p=s|524288;b=n;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1?1:(q|0)<=-1){o=e;b=c-e|0;m=h;n=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=n-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<m>>>0)+i|0)|0)-(e>>>0>n>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;Kf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;l=l+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}e=0;e:{if((l|0)>0){e=l;break e}Kf(k+16|0,b,c,h,i,l+127|0);hm(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2]}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;f:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;gb=k+112|0}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-176|0;gb=e;re(e+160|0,b);m=a;l=c;g=d;i=gb-48|0;gb=i;v[i+44>>2]=0;f=b;Ak(f,i+44|0);a:{b:{c:{if(v[i+44>>2]!=(tn(11327)|0)){break c}v[i+40>>2]=0;h=gb-16|0;gb=h;v[h+12>>2]=0;wj(h,f,h+12|0,4);yb(h);v[h>>2]=v[h+12>>2];v[i+40>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);gb=h+16|0;h=-1;j=v[i+40>>2];if(j-1>>>0>1){break c}d:{e:{f:{if((j|0)<=1){j=Kb(i+24|0);v[22692]=0;k=W(648,f|0,j|0,256)|0;n=v[22692];v[22692]=0;if((n|0)==1){break b}if(!k){break e}v[22692]=0;U(13,i+8|0,g|0,j|0);k=v[22692];v[22692]=0;if((k|0)!=1){break f}break b}j=Kb(i+24|0);v[22692]=0;k=W(650,f|0,j|0,255)|0;n=v[22692];v[22692]=0;if((n|0)==1){break b}if(!k){break d}v[22692]=0;U(13,i+8|0,g|0,j|0);k=v[22692];v[22692]=0;if((k|0)==1){break b}}Eb(l,i+8|0);vb(i+8|0);vb(j);l=0;u[i+8>>1]=0;_f(f,i+8|0);v[i+24>>2]=0;Ak(f,i+24|0);j=v[i+24>>2];if(j>>>0>50){break c}if(j){while(1){if(!XM(m,f,g)){break c}l=l+1|0;if(l>>>0<y[i+24>>2]){continue}break}}v[i+24>>2]=0;Ak(f,i+24|0);h=v[i+24>>2]==(tn(11365)|0)?1:-1;break c}vb(j);break c}vb(j)}gb=i+48|0;f=h;break a}a=P()|0;O()|0;vb(j);S(a|0);L()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!f){go(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;ek(b,e);b=Am(e+56|0,b);v[22692]=0;f=Q(616,e+40|0,11453)|0;g=v[22692];v[22692]=0;if((g|0)==1){break h}v[22692]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(617,b|0,f|0,e+32|0);g=v[22692];v[22692]=0;if((g|0)==1){break i}Hb(f);t[e+31|0]=0;v[22692]=0;f=Q(616,e+40|0,11893)|0;g=v[22692];v[22692]=0;if((g|0)==1){break j}v[22692]=0;W(618,b|0,e+31|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break k}Hb(f);v[22692]=0;f=w[e+31|0];g=T(1505,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break l}v[22692]=0;h=T(1506,b|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break m}v[e+32>>2]=h;v[e+24>>2]=g;if(Gb(e+24|0,e+32|0)){f=f?0:d;while(1){u[e+22>>1]=65535;v[22692]=0;d=Q(616,e+40|0,12881)|0;g=v[22692];v[22692]=0;if((g|0)==1){break p}v[22692]=0;g=W(1507,b|0,e+24|0,d|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}Hb(d);s:{if(!g){v[22692]=0;Y(1508,b|0,e+24|0,c|0,f|0);d=v[22692];v[22692]=0;if((d|0)==1){break n}break s}v[22692]=0;d=Q(616,e+40|0,12562)|0;g=v[22692];v[22692]=0;t:{u:{if((g|0)!=1){v[22692]=0;g=W(1507,b|0,e+24|0,d|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break u}Hb(d);if(g){break t}v[22692]=0;U(1509,b|0,e+24|0,e+22|0);d=v[22692];v[22692]=0;if((d|0)!=1){break s}break n}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}v[22692]=0;d=Q(616,e+40|0,12455)|0;g=v[22692];v[22692]=0;if((g|0)==1){break r}v[22692]=0;g=W(1507,b|0,e+24|0,d|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break q}Hb(d);if(g){break s}v[22692]=0;Y(1510,b|0,e+24|0,a|0,f|0);d=v[22692];v[22692]=0;if((d|0)==1){break n}}Ro(e+24|0);if(Gb(e+24|0,e+32|0)){continue}break}}a=v[b>>2];dh(b);f=a&1073741824?-1:1}gb=e+176|0;return f|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0}dh(b);S(a|0);L()}function y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-160|0;gb=d;vc(b);os(a);f=gb-32|0;gb=f;h=d+120|0;jF(f+24|0,h);g=yb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;cc(f+16|0,e,f);i=yb(f+16|0);if((i|0)==(g|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){kF(h)}a:{if(!e){break a}if(!TN(d+120|0)){break a}g=b;i=0;k=Mf(10389);if(k){p=v[g+8>>2];if(Yc(g,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){b:{if(!(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))){break b}while(1){if(!Pb(g,5)){break b}c:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((Ki(g)|0)<1){break c}}i=0;f=1;while(1){e=Ae(g);if(e){q=Vq(e<<24>>24);m=i>>>0>=k>>>0;h=m&f;e=h;d:{if(m){break d}e=h;if(!(f&1)){break d}e=w[i+10389|0]==(q&255)}f=e;i=i+1|0;continue}break}Rb(g,4);l=(i|0)==(k|0)?f?1:l:l}n=n+1|0;if(n>>>0<(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0){continue}break}}i=l&1}Yc(g,p)}if(!i){break a}if(!Pb(b,SN(d+120|0))){break a}if(!c){j=1;break a}f=gb-16|0;gb=f;c=b;e=d+120|0;Yc(c,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));g=mc(d+104|0);h=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[22692]=0;R(1405,g|0,h|0);h=v[22692];v[22692]=0;e:{f:{g:{if((h|0)!=1){h:{i:{j:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break j}while(1){v[22692]=0;h=Q(189,c|0,5)|0;i=v[22692];v[22692]=0;if((i|0)==1){break g}if(!h){break j}h=w[e+4|0]|w[e+5|0]<<8;v[22692]=0;U(1406,f|0,c|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break i}v[22692]=0;R(1407,g|0,f|0);h=v[22692];v[22692]=0;if((h|0)==1){break h}vb(f);o=o+1|0;if(o>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}gb=f+16|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(f);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}yd(g);S(a|0);L()}v[22692]=0;Y(273,d+88|0,b|0,d+120|0,d+104|0);c=v[22692];v[22692]=0;k:{l:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22692]=0;Q(188,b|0,c|0)|0;c=v[22692];v[22692]=0;m:{if((c|0)!=1){if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break k}e=d+36|0;n:{o:{p:{q:{while(1){v[22692]=0;c=Q(189,b|0,8)|0;f=v[22692];v[22692]=0;r:{if((f|0)!=1){if(c){break r}break k}b=P()|0;O()|0;break m}v[22692]=0;ka(274,d- -64|0,b|0,d+120|0,d+88|0,d+104|0,10389);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;f=d- -64|0;c=T(275,f|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break q}if(c){v[22692]=0;c=T(276,d+24|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break p}g=v[d+84>>2];s:{if((g|0)<0){break s}if(Ec(d+104|0)>>>0<=g>>>0){break s}g=Ad(d+104|0,v[d+84>>2]);v[22692]=0;U(13,d+8|0,2,g|0);g=v[22692];v[22692]=0;if((g|0)==1){break o}Eb(d+24|0,d+8|0);vb(d+8|0)}uw(e,f);v[22692]=0;R(277,a|0,c|0);f=v[22692];v[22692]=0;if((f|0)==1){break o}Bw(c)}xb(d- -64|0);j=j+1|0;if(j>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break k}break}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break n}b=P()|0;O()|0;Bw(c)}xb(d- -64|0);break m}b=P()|0;O()|0}Lc(d+88|0);break l}b=P()|0;O()|0}yd(d+104|0);S(b|0);L()}j=bd(a)^1;Lc(d+88|0);yd(d+104|0)}gb=d+160|0;return j|0}function H1(){var a=0,b=0,c=0;Xd(465776);v[116444]=83640;v[22692]=0;X(2510);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22692]=0;Q(70,465968,11457)|0;a=v[22692];v[22692]=0;if((a|0)==1){break e}Pd(465792);Xd(465456);v[116364]=84964;v[22692]=0;X(2511);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465464);v[116366]=84996;v[22692]=0;X(2512);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465472);v[116368]=83660;t[465484]=0;v[116370]=0;b=465480,c=Tp(),v[b>>2]=c;v[22692]=0;X(2513);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465488);v[116372]=84144;v[22692]=0;X(2514);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465496);v[116374]=84292;v[22692]=0;X(2515);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;X(2516);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;X(2517);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465520);v[116380]=84440;v[22692]=0;X(2518);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465528);v[116382]=84556;v[22692]=0;X(2519);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465536);u[232772]=11310;v[116384]=83760;Kb(465548);v[22692]=0;X(2520);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465568);v[116394]=46;v[116395]=44;v[116392]=83800;Kb(465584);v[22692]=0;X(2521);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465600);v[116400]=85028;v[22692]=0;X(2522);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465608);v[116402]=85272;v[22692]=0;X(2523);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465616);v[116404]=85484;v[22692]=0;X(2524);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465624);v[116406]=85716;v[22692]=0;X(2525);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465632);v[116408]=86700;v[22692]=0;X(2526);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465640);v[116410]=86848;v[22692]=0;X(2527);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465648);v[116412]=86964;v[22692]=0;X(2528);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465656);v[116414]=87080;v[22692]=0;X(2529);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465664);v[116416]=87196;v[22692]=0;X(2530);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465672);v[116418]=87360;v[22692]=0;X(2531);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465680);v[116420]=87524;v[22692]=0;X(2532);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465688);v[116422]=87688;v[22692]=0;X(2533);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465696);v[116426]=88944;v[116426]=85964;v[116424]=85916;v[22692]=0;X(2534);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465712);v[116430]=88980;v[116430]=86228;v[116428]=86180;v[22692]=0;X(2535);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;X(2536);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;X(2537);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;X(2538);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;X(2539);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465760);v[116440]=87852;v[22692]=0;X(2540);a=v[22692];v[22692]=0;if((a|0)==1){break d}Xd(465768);v[116442]=87972;v[22692]=0;X(2541);a=v[22692];v[22692]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(465968)}fx(465792)}S(a|0);L()}v[116042]=465776}function Gka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=gb-4144|0;gb=f;a:{b:{if(!Ib(w[a+14|0]|w[a+15|0]<<8)){break b}i=a;if(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0>20|x[b+480190>>1]<=w[a+23|0]){break b}td(d,32);u[d+34>>1]=1;a=a+20|0;sd(f+24|0,a,a+80|0);LT(f+4136|0,f+24|0,Ib(w[i+14|0]|w[i+15|0]<<8));a=Ml(b,w[Lb(f+4136|0,0)+3|0]+1|0);v[f+24>>2]=1;n=1/+y[Mc(a+24|0,f+24|0)>>2];g=f+24|0;j=f+4136|0;if(c){a=Zq(f+4136|0)}else{a=1}LT(g,j,a);a=v[f+24>>2];g=v[f+28>>2];if((a|0)!=(g|0)){while(1){if(!(t[a+1|0]<0|x[b+480190>>1]<=w[a+3|0])){j=Ml(b,w[a+3|0]+1|0);h=v[j>>2];k=t[a+1|0];l=Lb(f+4136|0,0);s=d,z=xh(n*+(h>>>0)*+y[j+24>>2]*Cg(+(k-t[l+1|0]|0)*-.08333333333333333))+v[d>>2]|0,v[s>>2]=z}a=a+4|0;if((g|0)!=(a|0)){continue}break}}q=Um(d);if(q){j=(e<<12>>>0)/1e4|0;a=Zq(f+4136|0);k=f+4120|0;e=rh(k);c:{if(!a){break c}v[22692]=0;R(933,k|0,a|0);g=v[22692];v[22692]=0;if((g|0)!=1){v[22692]=0;R(934,k|0,a|0);a=v[22692];v[22692]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;zB(e);S(a|0);L()}d:{if(!Zq(f+4136|0)){break d}a=0;while(1){e:{h=Lb(f+4136|0,a);g=KT(k,a);if(!(t[h+1|0]<0|x[b+480190>>1]<=w[h+3|0])){e=0;e=w[h+2|0]<242|w[h+2|0]>247?e:w[w[h+2|0]+33102|0];l=Ml(b,w[h+3|0]+1|0);h=t[h+1|0];m=Lb(f+4136|0,0);o=v[l+24>>2];m=t[m+1|0];v[22692]=0;h=Oa(928,+(n*+(o>>>0)*Cg(+(h-m|0)*.08333333333333333+ +(e<<24>>24)*.010416666666666666)))|0;e=O()|0;m=h|0;o=v[22692];v[22692]=0;h=g;f:{g:{if((o|0)!=1){v[g+8>>2]=m;v[g+12>>2]=e;v[g+16>>2]=v[l+20>>2];e=v[l>>2];v[g+76>>2]=e;v[g+88>>2]=x[l+34>>1]&1023;if(!c){break g}v[g+664>>2]=r;p=CB(g+8|0);v[22692]=0;e=xh(+(e>>>0)/p);l=v[22692];v[22692]=0;if((l|0)==1){break e}r=e+r|0;e=j;break f}break a}e=(j>>>0)/(Ib(w[i+14|0]|w[i+15|0]<<8)>>>0)|0}v[h+20>>2]=e;v[g+24>>2]=e}a=a+1|0;if(Zq(f+4136|0)>>>0>a>>>0){continue}break d}break}break a}a=v[d>>2];if(a){h=b+24648|0;c=0;while(1){Qb(f+24|0,0,4096);v[f+16>>2]=512;v[22692]=0;v[f+8>>2]=a-c;a=Fb(f+16|0,f+8|0);b=v[22692];v[22692]=0;h:{i:{if((b|0)!=1){g=v[a>>2];s=f,z=Vb(k),v[s+16>>2]=z;s=f,z=Zb(k),v[s+8>>2]=z;if(Gb(f+16|0,f+8|0)){break i}break h}break a}while(1){j:{a=v[f+16>>2];if(!v[a+16>>2]){break j}b=v[a+664>>2];if(b>>>0>=g>>>0){v[a+664>>2]=b-g;break j}e=v[a+88>>2];v[f+4>>2]=g-b;b=v[a+76>>2];n=CB(a);p=CB(a+8|0);v[22692]=0;b=xh((+(b>>>0)-n)/p);i=v[22692];v[22692]=0;if((i|0)==1){break a}v[22692]=0;v[f>>2]=b;b=Fb(f+4|0,f);i=v[22692];v[22692]=0;if((i|0)==1){break a}b=v[b>>2];i=v[a+664>>2];v[22692]=0;Y(v[((e&1|(e&64?18:16))<<2)+33680>>2],a|0,h|0,(f+24|0)+(i<<3)|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break j}v[a+16>>2]=0;break j}break a}v[f+16>>2]=v[f+16>>2]+872;if(Gb(f+16|0,f+8|0)){continue}break}}e=v[d+20>>2]+(c<<1)|0;j=f+24|0;b=gb-16|0;gb=b;v[b+12>>2]=g;tc(b+12|0,512);a=v[b+12>>2];v[b+12>>2]=a-1;if(a){while(1){a=e;i=gd(v[j>>2]+2048|0,12);if((i|0)<-32768){i=-32768}u[a>>1]=(i|0)>32767?32767:i;a=v[b+12>>2];v[b+12>>2]=a-1;j=j+8|0;e=e+2|0;if(a){continue}break}}gb=b+16|0;a=v[d>>2];c=c+g|0;if(a>>>0>c>>>0){continue}break}}zB(k)}j=(q|0)!=0}gb=f+4144|0;return j|0}a=P()|0;O()|0;zB(k);S(a|0);L()}function _N(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(b){h=a+327720|0;c=gb-400|0;gb=c;IR(c+384|0,8);v[22692]=0;ta(1095,c+368|0,9);g=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((g|0)!=1){v[22692]=0;g=Q(1096,c+352|0,14)|0;e=v[22692];v[22692]=0;if((e|0)==1){break l}v[22692]=0;R(1097,c+384|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break k}v[22692]=0;R(1097,c+368|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break k}HR(c+280|0,4900);HR(c+208|0,32e3);DR(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22692]=0;e=Q(1098,c+104|0,c+384|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break j}wu(c+120|0,c+280|0,e);Lf(e);v[22692]=0;e=Q(1098,c+72|0,c+368|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break i}wu(c+88|0,c+208|0,e);Lf(e);v[22692]=0;e=Q(1098,c+40|0,c+120|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break h}wu(c+56|0,c+136|0,e);Lf(e);v[22692]=0;e=Q(1098,c+8|0,c+88|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break g}wu(c+24|0,c+136|0,e);Lf(e);Lq(c+120|0);Lq(c+56|0);Lq(c+88|0);Lq(c+24|0);Lq(c+368|0);Kq(c+120|0,Dj(h,0));Kq(c+56|0,Dj(h,1));Kq(c+88|0,Dj(h,2));Kq(c+24|0,Dj(h,3));Kq(c+368|0,Dj(h,4));Lf(c+24|0);Lf(c+56|0);Lf(c+88|0);Lf(c+120|0);Jq(g);Lf(c+368|0);Lf(c+384|0);gb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Lf(c+56|0)}Lf(c+88|0)}Lf(c+120|0)}Jq(g)}Lf(c+368|0)}Lf(c+384|0);S(a|0);L()}zz(a+131112|0,9.6377,.97);zz(a+196648|0,8.5,.5);zz(a+262184|0,2.7625,.425)}g=a+368680|0;if(!(r=0,s=ZN(g,a),t=b,t?r:s)){i=a+24|0;o=A[a+8>>3];c=w[a+16|0];e=gb+-64|0;gb=e;while(1){p=+(k-4096|0)*.0001220703125;l=0;b=0;while(1){j=o;h=c;f=1;m=e+(b<<3)|0;d=+(b|0)-p;n=d+-3.5;if(!(D(n)<1e-8)){m:{n:{switch(h|0){case 0:f=.5-Ke(d*.8975979010256552)*.5;break m;case 1:f=Ke(d*.8975979010256552)*-.46+.54;break m;case 2:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.5+.42+f*.08;break m;case 3:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49364+.44959+f*.05677;break m;case 4:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49755+.42323+f*.07922;break m;case 5:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.48829+.35875+f*.14128+Ke(d*2.6927937030769655)*-.01168;break m;case 6:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49703+.40217+f*.09392+Ke(d*2.6927937030769655)*-.00183;break m;case 7:break n;default:break m}}f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49804+.40243+f*.09831+Ke(d*2.6927937030769655)*-.00122}d=n*3.141592653589793;j=qi(d*j)/d}j=j*f;A[m>>3]=j;l=j+l;b=b+1|0;if((b|0)!=8){continue}break}j=1/l;m=k<<3;b=0;while(1){q=i+(b+m<<1)|0;d=G(F(H(A[e+(b<<3)>>3]*32768*j+.5),32768),-32768);o:{if(D(d)<2147483648){h=~~d;break o}h=-2147483648}u[q>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}gb=e- -64|0;b=v[a+20>>2];v[g+16>>2]=v[a+16>>2];v[g+20>>2]=b;b=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=b;b=v[a+4>>2];v[g>>2]=v[a>>2];v[g+4>>2]=b}}function XL(a){var b=0,c=C(0),d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=C(0),q=0,r=C(0),s=C(0),u=0,w=0,x=C(0);k=gb-16|0;gb=k;u=a,w=Fj(C(z[a+4256>>2]*C(3))),v[u+4264>>2]=w;u=a,x=C(vf(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[u+4268>>2]=x;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);u=k,x=ne(C(10),C(C(WL(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[k+8>>2]=1065353216;u=a,x=C(z[zm(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=x;e=a;c=ne(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(c!=C(1)){d=Lp(C(C(VL(a)*C(6.2831854820251465))/z[a+4268>>2]));i=C(c+c);f=C(c*c);c=C(c*C(8));c=zo(C(C(C(C(d*i)+C(-2))+C(K(C(C(C(f*C(-4))+c)+C(C(C(C(f*C(4))*d)-c)*d)))))/C(i+C(-2))),C(0),C(1))}else{c=C(0)}z[e+4276>>2]=c;j=gb-16|0;gb=j;e=a;c=z[a+4268>>2];d=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;b=a;i=z[Sy(j+12|0,j+8|0)>>2];f=C(c*C(C(d+C(.007000000216066837))+i));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}v[b+4352>>2]=g;b=1;while(1){l=((B(b&1,24)+e|0)+(b<<1&-4)|0)+4352|0;f=C(C(C(z[(b<<2)+52720>>2]*i)+d)*c);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}v[l>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}z[j+12>>2]=C(C(z[e+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[j+8>>2]=1065353216;d=C(z[zm(j+12|0,j+8|0)>>2]*c);b=0;while(1){g=(b<<2)+e|0;q=g+4316|0;o=b+o|0;i=C(ne(C(.9300000071525574),C(o|0))*d);f=C(i*C(.07500000298023224));c:{if(C(D(f))<C(2147483648)){l=~~f;break c}l=-2147483648}v[q>>2]=l;l=g+4292|0;i=C(i*C(.06700000166893005));d:{if(C(D(i))<C(2147483648)){g=~~i;break d}g=-2147483648}v[l>>2]=g;b=b+1|0;if((b|0)!=6){continue}break}g=e+4348|0;d=C(c*C(.0035299998708069324));e:{if(C(D(d))<C(2147483648)){b=~~d;break e}b=-2147483648}v[g>>2]=b;g=e+4344|0;d=C(c*C(.0032500000670552254));f:{if(C(D(d))<C(2147483648)){b=~~d;break f}b=-2147483648}v[g>>2]=b;g=e+4340|0;c=C(c*C(.009999999776482582));g:{if(C(D(c))<C(2147483648)){b=~~c;break g}b=-2147483648}v[g>>2]=b;b=0;while(1){YL((B(b,24)+e|0)+4504|0,v[((b<<2)+e|0)+4292>>2]);b=b+1|0;if((b|0)!=15){continue}break}gb=j+16|0;b=gb-16|0;gb=b;d=ph(a,5);f=ph(a,11);c=C(d*ph(a,4));i=C(C(c*C(.03999999910593033))+C(d*C(.02250000089406967)));d=C(f*ph(a,10));f=C(C(d*C(.03999999910593033))+C(f*C(.02250000089406967)));if(t[a+4264|0]&1){h=ph(e,3);m=ph(e,9);h=C(h*c);c=C(ph(e,2)*h);i=C(C(C(h*C(.12250000238418579))+i)+C(c*C(.1444000005722046)));h=C(m*d);d=C(ph(e,8)*h);f=C(C(C(h*C(.12250000238418579))+f)+C(d*C(.1444000005722046)))}ph(e,12);h=z[e+4496>>2];m=ph(e,1);n=ph(e,7);r=ph(e,0);s=ph(e,6);u=b,x=ne(C(10),C(C(WL(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[b+8>>2]=1065353216;p=z[zm(b+12|0,b+8|0)>>2];h=C(h*h);d=C(n*C(h*d));n=C(s*d);c=C(m*C(h*c));h=C(r*c);m=C(C(C(n+h)*C(-.5))+C(1));z[e+4284>>2]=p*C(K(C(m/C(C(C(h+d)*C(.1444000005722046))+i))));z[e+4288>>2]=p*C(K(C(m/C(C(C(n+c)*C(.1444000005722046))+f))));gb=b+16|0;t[a+5046|0]=0;gb=k+16|0}function _pa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-736|0;gb=e;vc(b);g=gb-32|0;gb=g;j=e+120|0;zY(g+24|0,j);i=yb(g+24|0);f=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=k;v[g+4>>2]=f;f=b;cc(g+16|0,f,g);k=yb(g+16|0);if((k|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(k|0);if(!f){yY(j)}a:{if(!f){break a}if(!BY(e+120|0)){break a}b:{if(!c){break b}Id(a,67108864);yg(a);d=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Tb(e,5297);Eb(a+1298304|0,d);vb(d);d=Tb(e,8012);Eb(a+1298316|0,d);vb(d);Df(e+96|0,1283);v[e+72>>2]=w[e+144|0]>>>4;d=w[e+144|0];v[22692]=0;v[e+116>>2]=d&15;Y(458,e|0,e+96|0,e+72|0,e+116|0);d=v[22692];v[22692]=0;c:{d:{if((d|0)!=1){Eb(a+1298328|0,e);vb(e);Hb(e+96|0);v[a+1298364>>2]=2;Br(Sb(a+484360|0),e+168|0,w[e+167|0]+1|0);while(1){d=h+1|0;g=B(d,104)+a|0;i=g+484380|0;td(i,1);f=(e+120|0)+(h<<2)|0;o=i,p=Yb(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[o>>2]=p;j=Yb(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=j;o=g+484388|0,p=Yb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))+j|0,v[o>>2]=p;if(Yb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))){f=g+484414|0;u[f>>1]=x[f>>1]|2}rk(i);h=(e+120|0)+h|0;t[e|0]=w[h+548|0];t[e+96|0]=64;o=g+484410|0,p=w[ac(e,e+96|0)|0]<<2,u[o>>1]=p;t[g+484417|0]=w[h+579|0]<<4;h=d;if((d|0)!=31){continue}break}Kv(b,a+1298268|0,32);d=1;while(1){AY(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){xg(a+484344|0,w[e+166|0]+1|0)}j=a+484344|0;d=0;e:{while(1){f=d;g=oi(e+96|0);f:{if(w[e+146|0]){v[22692]=0;d=T(416,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break e}v[22692]=0;U(288,e+72|0,b|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break e}break f}d=x[a+480188>>1];v[22692]=0;U(288,e+72|0,b|0,d<<8);d=v[22692];v[22692]=0;if((d|0)==1){break d}}qd(g,jc(e,e+72|0));xb(e);xb(e+72|0);g:{if(!k){break g}v[22692]=0;d=W(331,j|0,f&65535,64)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!d){break g}if(!w[e+146|0]){h=0;if(!x[a+480188>>1]){break g}while(1){d=0;while(1){i=_b(j,f);v[22692]=0;i=Wc(i,d,h&65535);l=v[22692];v[22692]=0;if((l|0)==1){break d}v[22692]=0;R(459,g|0,i|0);i=v[22692];v[22692]=0;if((i|0)==1){break d}d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break g}i=0;v[22692]=0;R(460,g|0,e|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}while(1){d=_b(j,f);v[22692]=0;l=Rf(d,i);d=v[22692];v[22692]=0;if((d|0)==1){break d}if(x[a+480188>>1]){m=e+i|0;d=128;h=0;while(1){h:{if(!(w[m|0]&d)){break h}v[22692]=0;R(459,g|0,l+B(h,6)|0);n=v[22692];v[22692]=0;if((n|0)!=1){break h}break d}d=d>>>1|0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}d=f+1|0;xb(e+96|0);if(f>>>0<w[e+166|0]){continue}break}d=1;if(!(c&2)){break a}c=Rc(e,8,1,1,0);while(1){Ag(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}break d}d=P()|0;O()|0;Hb(e+96|0);break c}d=P()|0;O()|0;xb(e+96|0)}S(d|0);L()}d=1}gb=e+736|0;return d|0}function Xb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116503]){break a}a=a+b|0;if(v[116504]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=465996,j=v[116499]&nqa(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+466300|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=466e3,j=v[116500]&nqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116501]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116505]==(f|0)){v[116505]=d;a=v[116502]+a|0;v[116502]=a;v[d+4>>2]=a|1;if(v[116504]!=(d|0)){break a}v[116501]=0;v[116504]=0;return}if(v[116504]==(f|0)){v[116504]=d;a=v[116501]+a|0;v[116501]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=465996,j=v[116499]&nqa(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+466300|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=466e3,j=v[116500]&nqa(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116504]!=(d|0)){break f}v[116501]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+466036|0;c=v[116499];a=1<<a;k:{if(!(c&a)){v[116499]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+466300|0;l:{m:{c=v[116500];b=1<<e;n:{if(!(c&b)){v[116500]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116507]-1|0;v[116507]=a?a:-1}}function dX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-128|0;gb=g;j=Bk(g+112|0);a:{b:{c:{if(d){v[22692]=0;U(640,a|0,j|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}break b}v[22692]=0;U(641,a|0,j|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}}k=mc(g+96|0);if(x[b+480192>>1]){d=1;c=1;while(1){v[22692]=0;u[g+94>>1]=0;Q(642,a|0,g+94|0)|0;f=v[22692];v[22692]=0;d:{e:{f:{if((f|0)!=1){l=gb-16|0;gb=l;p=l+8|0;i=gb-16|0;gb=i;f=j;m=f;o=g+94|0;q=o;e=Yd(f);h=fc(f);n=gb-16|0;gb=n;if(e){wb(m);while(1){m=DC(e+16|0,q);h=m?h:e;e=v[(m?4:0)+e>>2];if(e){continue}break}}e=v[yc(n+8|0,h)>>2];gb=n+16|0;v[i+8>>2]=e;r=i,s=zh(f),v[r>>2]=s;g:{if(Rl(i+8|0,i)){if(!EC(wb(f),o,te(i+8|0))){break g}}e=zh(f)}gb=i+16|0;f=v[yc(p,e)>>2];gb=l+16|0;v[g+88>>2]=f;i=((d<<2)+b|0)+900380|0;if(!v[i>>2]){break d}r=g,s=Ah(j),v[r+72>>2]=s;if(mg(g+88|0,g+72|0)){d=te(g+88|0);v[22692]=0;d=Q(4,g+72|0,d+4|0)|0;f=v[22692];v[22692]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)!=1){v[22692]=0;f=Q(2,g+56|0,13828)|0;e=v[22692];v[22692]=0;if((e|0)==1){break i}e=sr(d,f);vb(f);if(e){break r}f=v[b+4>>2];v[22692]=0;f=Q(643,f|0,d|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break x}v[v[i>>2]+44>>2]=f;if(!v[v[i>>2]+44>>2]){break y}break e}b=P()|0;O()|0;break f}v[22692]=0;f=Q(2,g+56|0,10699)|0;e=v[22692];v[22692]=0;if((e|0)==1){break w}z:{A:{if(sr(d,f)){vb(f);break A}v[22692]=0;e=Q(2,g+40|0,10911)|0;h=v[22692];v[22692]=0;if((h|0)==1){break v}h=sr(d,e);vb(e);vb(f);if(!h){break z}}v[22692]=0;f=T(644,d|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break u}v[g+56>>2]=f;f=v[b+4>>2];ni(g+32|0,g+56|0);v[22692]=0;f=Q(645,f|0,v[g+32>>2])|0;e=v[22692];v[22692]=0;if((e|0)==1){break t}Hg(g+56|0);if(f){break e}}h=Vb(k);l=Zb(k);f=d;e=gb-16|0;gb=e;v[e>>2]=l;v[e+8>>2]=h;if(Gb(e+8|0,e)){while(1){if(!sr(v[e+8>>2],f)){pr(e+8|0);if(Gb(e+8|0,e)){continue}}break}h=v[e+8>>2]}gb=e+16|0;v[g+56>>2]=h;r=g,s=Zb(k),v[r+40>>2]=s;if(Gb(g+56|0,g+40|0)){break r}v[22692]=0;R(646,k|0,d|0);f=v[22692];v[22692]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(f);break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;Hg(g+56|0);break h}v[22692]=0;f=Q(2,g+16|0,14530)|0;e=v[22692];v[22692]=0;if((e|0)==1){break q}v[22692]=0;U(647,g+40|0,f|0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break p}v[22692]=0;e=Q(2,g|0,13404)|0;h=v[22692];v[22692]=0;if((h|0)==1){break o}v[22692]=0;U(3,g+56|0,g+40|0,e|0);h=v[22692];v[22692]=0;if((h|0)==1){break n}v[22692]=0;U(556,b|0,2,g+56|0);h=v[22692];v[22692]=0;if((h|0)==1){break m}vb(g+56|0);vb(e);vb(g+40|0);vb(f)}v[v[i>>2]+44>>2]=0;break e}b=P()|0;O()|0;break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(g+56|0)}vb(e)}vb(g+40|0)}vb(f);break h}b=P()|0;O()|0}vb(d);break f}if(!v[i>>2]){break d}v[v[i>>2]+44>>2]=0;break d}b=P()|0;O()|0}mm(k);break a}vb(d)}c=c+1|0;d=c&65535;if(d>>>0<=x[b+480192>>1]){continue}break}}mm(k);_W(j);gb=g+128|0;return}b=P()|0;O()|0}_W(j);S(b|0);L()}function hA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;f=gb-16|0;gb=f;i=B(b,872)+a|0;l=i+1075800|0;j=w[l|0];k=a+1074312|0;Db(f+8|0,k,23);h=c&15;a:{b:{c:{if(Cb(f+8|0)){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[l|0]=h;break c}e=w[l|0];if(e){g=e-1|0;t[l|0]=g;e=0;if(g&255){break c}}t[l|0]=h;e=1;break c}Db(f+8|0,k,52);g=c&256;if(!(!Cb(f+8|0)|!g)){d:{if(!(w[a+480209|0]&16)){break d}e=B(b,872)+a|0;if(w[e+1075781|0]){j=PC(e+1075780|0)?1:j}if(w[e+1075782|0]!=1){break d}if(w[(B(b,872)+a|0)+1075784|0]){break b}}e=0;if((j&255)>>>0<h>>>0){break c}if(w[a+480209|0]&16){if(de((B(b,872)+a|0)+1075780|0)){break c}}j=0;e=1;break c}if(v[a+480180>>2]&16777250){e=j&255;if(e){e=(e>>>0)%((h?h:1)>>>0)|0}else{e=1}e=!e;j=j+1|0;break c}if(v[a+480180>>2]==1){g=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!g){if(de((B(b,872)+a|0)+1075780|0)){break a}}e=h?!((g>>>0)%(h>>>0)|0):e;break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(h|0)&(h|0)!=0;break c}e:{f:{g:{h:{i:{if(g){e=B(b,872)+a|0;if(w[e+1075782|0]==1){h=(w[e+1075785|0]>15)+h|0}h=h?h:1;break i}if(w[a+480209|0]&16){break f}h=h?h:1;if(v[a+1074416>>2]){break h}}e=0;break g}e=!(y[a+1074392>>2]%(h>>>0)|0)}j=j+1|0;break e}j=v[a+480180>>2]&1048580?0:j}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!g?v[a+1074392>>2]:1)|(j&255)<(h|0))){e=1}Db(f+8|0,k,52);if(!Cb(f+8|0)|c){break c}e=!v[a+1074392>>2]}h=i+1074992|0;i=(B(b,872)+a|0)+1075068|0;j:{if(v[i>>2]){break j}Db(f+8|0,k,38);if(!Cb(f+8|0)){break j}if(!nk(h)){break a}}Db(f+8|0,k,106);if(u=0,z=Cb(f+8|0),A=v[(B(b,872)+a|0)+1075688>>2],A?u:z){break a}if(e){g=B(b,872)+a|0;o=g+1075680|0;v[f+4>>2]=v[o>>2];e=c>>>4&15;if(e){Db(f+8|0,k,52);k:{if(u=Cb(f+8|0),z=0,A=w[(B(b,872)+a|0)+1075782|0]==1,A?u:z){break k}if(!(16191>>>e&1)){v[f+4>>2]=B(v[f+4>>2],t[e+40128|0])>>4;break k}v[f+4>>2]=v[f+4>>2]+(t[e+40144|0]<<2)}Sd(f+4|0,0,256);e=(B(b,872)+a|0)+1075080|0;v[e>>2]=v[e>>2]|2097152}p=g+1075692|0;q=v[p>>2];e=w[g+1075794|0];l:{if(!v[i>>2]|(e-1&255)>>>0>119){break l}if(!(!(w[(B(b,872)+a|0)+1075081|0]&2)|v[a+480180>>2]!=2)){Db(f+8|0,k,108);if(!Cb(f+8|0)){break l}}yP(a,b,0,e,1)}g=0;m:{if(!(v[a+480180>>2]&1048580)){break m}i=w[(B(b,872)+a|0)+1075781|0];g=(c|0)<256;if(!i|(c|0)>255){break m}xo(a,h,i,0,0,1);g=1}i=B(b,872)+a|0;m=i+1075652|0;r=v[m>>2];v[m>>2]=0;n=i+1075080|0;s=v[n>>2];Db(f+8|0,k,23);lu(a,h,e,Cb(f+8|0),g,0,b);if(!w[i+1075781|0]){v[m>>2]=r}if(!(!(s&4096)|v[a+480180>>2]!=4)){v[n>>2]=v[n>>2]|4096}g=i+1075780|0;v[o>>2]=v[f+4>>2];if(x[a+480192>>1]){t[g|0]=e;hO(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[g|0]|!q))){v[p>>2]=q}e=v[a+480180>>2];Db(f+8|0,k,23);if(Cb(f+8|0)){v[h>>2]=0;v[h+4>>2]=0}e=e&16777250;n:{if((d|0)<1){break n}g=(B(b,872)+a|0)+1075096|0;i=d-1|0;if((i|0)>9){break n}g=v[g>>2];if(!g){break n}o:{if(!i){b=v[(B(b,872)+a|0)+1075656>>2];break o}i=(B(b,872)+a|0)+1075656|0;b=v[(g+(d<<2)|0)+60>>2];v[i>>2]=b}Hm(a,h,b)}j=e?j:0}Db(f+8|0,k,52);a=Cb(f+8|0);Db(f+8|0,k,23);if(Cb(f+8|0)){break a}j=(a&(c&256)>>>8)+j|0}t[l|0]=j}gb=f+16|0}function hL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-224|0;gb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(kk(b)){break a}g=w[nl(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Cl(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}Md(f+184|0);g=v[f+184>>2];Md(f+168|0);i=ml(g,v[f+172>>2],b);Md(f+184|0);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=uc(f+200|0,18699);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Gc(f+16|0,f+8|0)){a=ba(8)|0;v[22692]=0;R(2043,f+168|0,f+216|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(2021,f+184|0,14701,f+168|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}qc(a,f+184|0);e=0;v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);break e}if(!e){break h}a=ba(8)|0;v[22692]=0;c=Q(2041,f+136|0,b|0)|0;b=v[22692];v[22692]=0;e=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22692]=0;U(2021,f+152|0,14737,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break q}v[22692]=0;R(2038,f+168|0,f+152|0);b=v[22692];v[22692]=0;if((b|0)==1){break p}v[22692]=0;R(2043,f+120|0,f+216|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}v[22692]=0;U(2042,f+184|0,f+168|0,f+120|0);b=v[22692];v[22692]=0;if((b|0)==1){break n}qc(a,f+184|0);v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);e=0;break m}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}vb(f+120|0)}vb(f+168|0)}vb(f+152|0)}vb(c)}if(e){break d}break c}v[f+112>>2]=g;v[f+116>>2]=h;e=uc(f+104|0,18699);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Gc(f- -64|0,f+56|0)){a=ba(8)|0;v[22692]=0;R(2043,f+168|0,f+216|0);b=v[22692];v[22692]=0;r:{s:{if((b|0)!=1){v[22692]=0;U(2021,f+184|0,14701,f+168|0);b=v[22692];v[22692]=0;if((b|0)==1){break s}qc(a,f+184|0);e=0;v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);break r}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}vb(f+168|0);if(e){break d}break c}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=uc(f+88|0,8161);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Gc(f+48|0,f+40|0)){WK(a,Ac(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=uc(f+72|0,5743);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Gc(f+32|0,f+24|0)){break h}b=CA(c,d);c=gb-16|0;gb=c;a=v[a+32>>2];b=b>>>0<4?b:1;t:{if((xy(a)|0)==(b|0)){d=a+120|0;Ai(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[14906];v[a+8>>2]=v[14905];v[a+12>>2]=e;e=v[14904];v[a>>2]=v[14903];v[a+4>>2]=e;kb[v[Rh(a,Xg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break t}uK(a,b,vK(a))}gb=c+16|0}gb=f+224|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}vb(f+168|0);if(!e){break c}}da(a|0)}S(b|0)}L()}function fga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=49408;v[a+4>>2]=0;v[a>>2]=38416;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Sq(a+24604|0);_O(a+24648|0,0);b=a+393352|0;v[b>>2]=8;v[b+4>>2]=0;c=b+4109|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;v[b+4104>>2]=0;v[b+4108>>2]=0;v[b+4120>>2]=0;v[b+4124>>2]=0;u[b+4128>>1]=0;Qb(b+4132|0,0,40);LS(b+8|0,1024);Qb(b+4172|0,0,49824);Qb(b+53996|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Ao(a+480248|0);v[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){v[22692]=0;c=ZO(c);e=v[22692];v[22692]=0;if((e|0)==1){break k}c=c+32|0;if((b|0)!=(c|0)){continue}break}e=a+484344|0;cd(e);v[e+12>>2]=a;v[22692]=0;l=Q(1268,a+484360|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break j}b=a+900380|0;c=a+484380|0;while(1){v[22692]=0;c=Q(890,c|0,0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}c=c+104|0;if((b|0)!=(c|0)){continue}break}v[22692]=0;T(1269,a+901404|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}c=a+946300|0;f=a+906300|0;b=f;while(1){b=YO(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;d=a+1074304|0;g=a+946304|0;b=g;while(1){v[22692]=0;b=Qq(b);h=v[22692];v[22692]=0;if((h|0)==1){break g}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;fA(a+1074312|0);v[22692]=0;b=ga(1270)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}v[22692]=0;b=T(1271,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}v[a+1074328>>2]=b;v[22692]=0;eO(a+1074332|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;T(1273,a+1074376|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;d=W(1234,a+1298224|0,a|0,255)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}h=wh(a+1298260|0);b=gb-16|0;gb=b;v[b+12>>2]=0;i=a+1298264|0;sq(i,b+12|0);gb=b+16|0;m=Kb(a+1298268|0);n=Kb(a+1298280|0);j=a+1298292|0;Kb(j);o=XO(a+1298304|0);p=cd(a+1298368|0);t[a+1298380|0]=0;b=a+1298384|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298424>>2]=0;vq(a+12|0);Po(a+8204|0);v[22692]=0;Po(a+12300|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[a+480216>>2]=4;v[a+480220>>2]=16;b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;VO(a+900380|0);v[22692]=0;dA(g);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;b=T(1276,12)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;eh(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;eA(p);eu(o);vb(j);vb(n);vb(m);du(i);cu(h);zq(d)}while(1){c=wq(c-160|0);if((f|0)!=(c|0)){continue}break}}Bu(l)}cA(e)}Lc(k);S(b|0);L()}function RL(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);QP(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=vf(v[a+16>>2]);o=ne(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));b=C(C(c*C(6.2831854820251465))/C(d>>>0));c=oG(b);r=Lp(b);s=a;t=c;k=C(C(C(b*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());c=C(((d|0)<=22?C(C(C(1)-g)+C(c-e)):C(C(c-C(e+g))+C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+71216>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=KI(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(b*o);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function P8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;v[d+184>>2]=c;a:{b:{c:{d:{if(!(b<.8)){v[22692]=0;c=ga(2054)|0;e=v[22692];v[22692]=0;e:{f:{g:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22692]=0;c=T(2055,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}v[d+72>>2]=c;fo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=Pe(d+160|0,a);v[22692]=0;e=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=e;v[d- -64>>2]=v[a+16>>2];e=v[a+4>>2];v[d+48>>2]=v[a>>2];v[d+52>>2]=e;a=W(2045,c|0,d+48|0,15)|0;c=v[22692];v[22692]=0;if((c|0)==1){break g}if(a){a=v[d+88>>2];v[22692]=0;T(1277,a|0)|0;a=v[22692];v[22692]=0;f=1;if((a|0)==1){break g}}Ci(d+72|0);Di(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ci(d+72|0);break e}c=V(0)|0;O()|0}Di(d+88|0);break d}if(!(b<.6)){v[22692]=0;c=ga(2054)|0;e=v[22692];v[22692]=0;h:{i:{j:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22692]=0;c=T(2055,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break i}v[d+72>>2]=c;fo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=Pe(d+136|0,a);v[22692]=0;e=v[a+12>>2];v[d+32>>2]=v[a+8>>2];v[d+36>>2]=e;v[d+40>>2]=v[a+16>>2];e=v[a+4>>2];v[d+24>>2]=v[a>>2];v[d+28>>2]=e;a=W(2045,c|0,d+24|0,2)|0;c=v[22692];v[22692]=0;if((c|0)==1){break j}if(a){a=v[d+88>>2];v[22692]=0;T(1277,a|0)|0;a=v[22692];v[22692]=0;f=.8;if((a|0)==1){break j}}Ci(d+72|0);Di(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ci(d+72|0);break h}c=V(0)|0;O()|0}Di(d+88|0);break d}f=.2;if(!(b<.2)){v[22692]=0;c=ga(2054)|0;e=v[22692];v[22692]=0;k:{l:{m:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22692]=0;c=T(2055,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break l}v[d+72>>2]=c;fo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=Pe(d+112|0,a);v[22692]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;v[d+16>>2]=v[a+16>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2045,c|0,d|0,0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}f=0;if(a){a=v[d+88>>2];v[22692]=0;T(1277,a|0)|0;a=v[22692];v[22692]=0;f=.6;if((a|0)==1){break m}}Ci(d+72|0);Di(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ci(d+72|0);break k}c=V(0)|0;O()|0}Di(d+88|0);break d}if(b<.1){break c}v[22692]=0;U(747,d+88|0,a|0,2048);c=v[22692];v[22692]=0;n:{o:{p:{if((c|0)!=1){v[22692]=0;c=Td(d+88|0);e=v[22692];v[22692]=0;if((e|0)==1){break o}e=v[d+88>>2];v[22692]=0;a=T(193,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break o}v[22692]=0;a=lG(2056,3,0,c,e,a,0);c=v[22692];v[22692]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+59632>>3];zc(d+88|0);break c}c=V(0)|0;O()|0;break d}a=ba(8)|0;v[22692]=0;e=Q(70,d+72|0,18699)|0;c=v[22692];v[22692]=0;if((c|0)!=1){qc(a,e);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;vb(e);break n}c=V(0)|0;O()|0;da(a|0);break n}c=V(0)|0;O()|0}zc(d+88|0)}Z(c|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;f=0;if((a|0)==1){break a}}cg(d+184|0);gb=d+192|0;return+f}L()}a=P()|0;O()|0;cg(d+184|0);S(a|0);L()}function xs(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116504]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=465996,j=v[116499]&nqa(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+466300|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=466e3,j=v[116500]&nqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116501]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116505]==(f|0)){v[116505]=a;b=v[116502]+b|0;v[116502]=b;v[a+4>>2]=b|1;if(v[116504]!=(a|0)){break a}v[116501]=0;v[116504]=0;return}if(v[116504]==(f|0)){v[116504]=a;b=v[116501]+b|0;v[116501]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=465996,j=v[116499]&nqa(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+466300|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=466e3,j=v[116500]&nqa(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116504]!=(a|0)){break g}v[116501]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+466036|0;d=v[116499];b=1<<b;l:{if(!(d&b)){v[116499]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+466300|0;m:{d=v[116500];c=1<<e;n:{if(!(d&c)){v[116500]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function qO(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){rq(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;IO(a)}pO(a+24648|0);s=v[a+24620>>2];g=gb-144|0;gb=g;f=a+393352|0;c=v[f+4>>2];if(c>>>0>=29){v[f+4>>2]=0;c=0}j=B(c,44)+53280|0;if(!(b?0:(j|0)==v[f+4112>>2])){v[f+4112>>2]=j;r=C(s>>>0);h=r;c=g+8|0;d=v[j+24>>2];v[c>>2]=d;e=v[j+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[j+4>>2];m=(d|0)>(e|0)?d:e;if((m|0)<=-601){i=e;e=m+600|0;v[c+4>>2]=i-e;v[c>>2]=d-e}e=c;k=C(z[j+36>>2]*C(79.30999755859375));a:{if(C(D(k))<C(2147483648)){d=~~k;break a}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(z[j+32>>2]*C(117.9612045288086))+C(4915.05029296875));b:{if(C(D(k))<C(2147483648)){e=~~k;break b}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;m=0;k=z[j+8>>2];e=c;o=C(C(F(z[j+20>>2],C(.10000000149011612)))*h);c:{if(C(D(o))<C(2147483648)){d=~~o;break c}d=-2147483648}i=(d|0)<96;p=i?96:d;l=(p|0)>7500;o=C(z[j+28>>2]*h);d:{if(C(D(o))<C(2147483648)){n=~~o;break d}n=-2147483648}d=(n+(i?d-96|0:0)|0)+(l?p-7500|0:0)|0;i=(d|0)<128;n=i?128:d;t=(n|0)>3800;w=t?3800:n;v[e+24>>2]=w;i=i?d-128|0:0;e=c;h=C(k*h);e:{if(C(D(h))<C(2147483648)){d=~~h;break e}d=-2147483648}i=(d+i|0)+(t?n-3800|0:0)|0;v[e+32>>2]=i;p=l?7500:p;while(1){d=B(m,12);e=d+c|0;u[e+42>>1]=x[d+54570>>1];u[e+36>>1]=x[d+54564>>1];l=d+54566|0;l=x[l>>1]|x[l+2>>1]<<16;u[e+38>>1]=l;u[e+40>>1]=l>>>16;v[e+44>>2]=p+((B(v[d+54560>>2],w)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}e=c;h=C(i|0);k=C(ne(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/h))*C(32768));f:{if(C(D(k))<C(2147483648)){d=~~k;break f}d=-2147483648}v[e+12>>2]=d;h=C(z[j+12>>2]*h);A=c,E=ne(C(.0010000000474974513),h>C(4720)?C(C(4720)/h):C(1)),z[A+28>>2]=E;v[f+4124>>2]=v[g+40>>2];c=JL(KL(v[g+16>>2]),r);u[f+4190>>1]=c;u[f+4188>>1]=c;c=x[g+24>>1]<<1;u[f+4198>>1]=c;u[f+4196>>1]=c;while(1){c=(q<<4)+f|0;d=(g+8|0)+B(q,12)|0;e=v[d+44>>2];v[c+4204>>2]=e;v[c+4208>>2]=e;u[c+4212>>1]=x[d+36>>1];u[c+4214>>1]=x[d+42>>1];u[c+4216>>1]=x[d+40>>1];u[c+4218>>1]=x[d+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+53996>>2]=v[g+32>>2];e=f+4184|0;c=v[g+12>>2];if((c|0)>-9e3){c=IL(c)}else{c=0}v[e>>2]=c;e=f+54052|0;c=v[g+8>>2];if((c|0)>=-8999){c=IL(c)}else{c=0}v[e>>2]=c;c=v[g+28>>2];d=f+54036|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+54010>>1]=c;u[f+54008>>1]=c;u[f+54006>>1]=c;u[f+54004>>1]=c;v[g+4>>2]=v[g+20>>2];Sd(g+4|0,0,32752);c=x[g+4>>1];u[f+54018>>1]=c;d=f+54014|0;u[d>>1]=0;u[d+2>>1]=0;u[f+54012>>1]=c;h=z[g+36>>2];A=g,G=JL(C(h*h),r),v[A>>2]=G;Sd(g,256,32512);c=x[g>>1];u[f+54026>>1]=c;d=f+54022|0;u[d>>1]=0;u[d+2>>1]=0;u[f+54020>>1]=c}if(b){v[f+4120>>2]=0;ML(f)}b=B(s,5);if(b>>>0>y[f+4124>>2]){v[f+4124>>2]=b}gb=g+144|0;b=a+1298260|0;if(Dd(b)){QR(v[b>>2],v[a+24620>>2])}}function u_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-32|0;gb=e;v[e+28>>2]=b;a:{b:{if((d|0)<1){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Fb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;It(c,v[Fb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){c:{f=ih(e+8|0,a);b=ih(e+8|0,a+4|0);i=ih(e+8|0,a+5|0);r=e,s=ih(e+8|0,a+6|0)<<8|ih(e+8|0,a+7|0),v[r+24>>2]=s;b=i|b<<8;p=a+8|0;d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break d}a=ba(8)|0;v[22692]=0;T(283,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}break b}while(1){r=e,s=ih(e+8|0,i+p|0),t[r+20|0]=s;fq(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break d;case 1:break e;default:break c}}Zj(e+24|0,d);i=v[e+24>>2];m=ih(e+8|0,a+10|0);t[e+20|0]=m;fq(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break d}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=og(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!og(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!og(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!og(h,a,1,e+8|0)){break n}f=og(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;f=((k<<3)+f|0)-17|0;if((f|0)<=-1){a=ba(8)|0;v[22692]=0;T(283,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}break b}if(f>>>0>=56){a=ba(8)|0;v[22692]=0;T(283,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}break b}k=w[f+28320|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];o:{if((g|0)<1){break o}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=ih(f,g);m=m-((ih(f,g+1|0)<<8|q<<16|ih(f,g+2|0))<<(b-(l<<3)|0)+8>>32-k)|0;t[e+20|0]=m;fq(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if((a|0)<1){break o}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}p:{q:{r:{a=f+1|0;if(!og(h,a,1,e+8|0)){f=2;break r}a=f+2|0;if(!og(h,a,1,e+8|0)){f=4;break r}a=f+3|0;if(!og(h,a,1,e+8|0)){f=6;break r}a=f+5|0;if(!og(h,f+4|0,1,e+8|0)){b=f+8|0;a=og(h,a,3,e+8|0)+8|0;break p}b=f+10|0;f=16;a=og(h,a,5,e+8|0);break q}b=a+2|0;a=og(h,a+1|0,1,e+8|0)}a=a+f|0}s:{if(og(h,b,1,e+8|0)){f=-256;g=12;break s}b=b+1|0;g=og(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=og(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=(j|0)>0?j-1|0:0}f=pc(c)+((l^-1)+f|0)|0;if(f>>>0<pc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<1|(g|0)<=0){break g}while(1){m=w[kc(c,f)|0];t[e+20|0]=m;fq(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if((a|0)<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}a=ba(8)|0;v[22692]=0;T(283,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break b}break a}n=n-(n>>3)|0;if((g|0)>0){continue}break}}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=bd(c)^1}gb=e+32|0;return a|0}b=P()|0;O()|0;da(a|0);S(b|0);L()}ia(a|0,28288,204);L()}function Hfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=gb-144|0;gb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){oz(a+96|0,c);v[22692]=0;c=Q(2,a+80|0,14837)|0;d=v[22692];v[22692]=0;if((d|0)==1){break E}v[22692]=0;U(3,a+112|0,a+96|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break D}v[22692]=0;d=Q(4,a+48|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break C}v[22692]=0;e=Q(2,a+32|0,16642)|0;f=v[22692];v[22692]=0;if((f|0)==1){break B}v[22692]=0;U(5,a- -64|0,d|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break A}v[22692]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[22692];v[22692]=0;if((f|0)==1){break z}vb(a- -64|0);vb(e);vb(d);vb(a+112|0);vb(c);vb(a+96|0);c=v[b>>2];v[22692]=0;U(6,a+112|0,1,(c?c:18699)|0);c=v[22692];v[22692]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22692]=0;U(6,a+96|0,1,(c?c:18699)|0);c=v[22692];v[22692]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22692]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[22692];v[22692]=0;if((b|0)==1){break r}v[22692]=0;b=Q(8,463368,14716)|0;c=v[22692];v[22692]=0;if((c|0)==1){break q}v[22692]=0;U(9,a- -64|0,0,a+112|0);c=v[22692];v[22692]=0;if((c|0)==1){break p}v[22692]=0;b=Q(10,b|0,a- -64|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break o}v[22692]=0;b=Q(8,b|0,14490)|0;c=v[22692];v[22692]=0;if((c|0)==1){break o}v[22692]=0;U(9,a+32|0,0,a+80|0);c=v[22692];v[22692]=0;if((c|0)==1){break n}v[22692]=0;b=Q(10,b|0,a+32|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}v[22692]=0;b=Q(8,b|0,14487)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}v[22692]=0;b=Q(8,b|0,14837)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}v[22692]=0;U(9,a+16|0,0,a+128|0);c=v[22692];v[22692]=0;if((c|0)==1){break l}v[22692]=0;b=Q(10,b|0,a+16|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break k}v[22692]=0;b=Q(8,b|0,10725)|0;c=v[22692];v[22692]=0;if((c|0)==1){break k}v[22692]=0;U(9,a|0,0,a+96|0);c=v[22692];v[22692]=0;if((c|0)==1){break j}v[22692]=0;b=Q(10,b|0,a|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break i}v[22692]=0;b=Q(8,b|0,10723)|0;c=v[22692];v[22692]=0;if((c|0)==1){break i}v[22692]=0;Q(11,b|0,12)|0;b=v[22692];v[22692]=0;if((b|0)==1){break i}vb(a);vb(a+16|0);vb(a+32|0);vb(a- -64|0);vb(a+80|0);vb(a+96|0);vb(a+112|0);vb(a+128|0)}gb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a- -64|0)}vb(e)}vb(d)}vb(a+112|0)}vb(c)}vb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a)}vb(a+16|0)}vb(a+32|0)}vb(a- -64|0)}vb(a+80|0)}vb(a+96|0)}vb(a+112|0)}vb(a+128|0)}S(b|0);L()}function Xm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-96|0;gb=c;g=mc(a);v[22692]=0;e=T(426,b|0)|0;a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)==1){break e}v[22692]=0;a=Q(189,b|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break e}if(a){break d}v[22692]=0;a=T(465,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break e}v[22692]=0;Q(318,b|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[22692]=0;U(288,c+48|0,b|0,e|0);b=v[22692];v[22692]=0;a=c;f:{g:{h:{i:{if((b|0)!=1){f=jc(c+72|0,c+48|0);xb(c+48|0);if(e>>>0<10){break g}v[22692]=0;b=T(924,f|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!b){break g}v[22692]=0;b=T(426,f|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}v[c+44>>2]=b;v[c+40>>2]=e-10;b=v[c+40>>2];if(b>>>0>25264513){break i}b=B(b,170);break h}a=P()|0;O()|0;break a}b=-1}v[a+40>>2]=b;tc(c+44|0,b);v[22692]=0;R(440,g|0,v[c+44>>2]);a=v[22692];v[22692]=0;if((a|0)==1){break b}e=v[c+44>>2];b=0;while(1){j:{v[22692]=0;a=T(925,f|0)|0;d=v[22692];v[22692]=0;k:{l:{m:{n:{if((d|0)!=1){if(a){break j}v[22692]=0;a=T(701,f|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}switch(a|0){case 3:break k;case 2:break l;case 1:break m;case 0:break n;default:break j}}break b}v[22692]=0;a=T(374,f|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(a>>>0>e>>>0){break j}v[22692]=0;d=Q(189,f|0,a|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break b}if(!d){break j}v[22692]=0;Vd(c+48|0,g);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;Y(926,c+24|0,c+48|0,b|0,a|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;U(629,c+16|0,f|0,c+8|0);d=v[22692];v[22692]=0;if((d|0)!=1){e=e-a|0;b=a+b|0;continue}break b}v[22692]=0;a=T(374,f|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}d=a<<2;if(d>>>0>e>>>0){break j}v[22692]=0;h=Q(927,f|0,c+32|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break b}if(!h){break j}e=e-d|0;if(!a){continue}while(1){d=fc(c+32|0);j=c,k=Vb(g),v[j+48>>2]=k;Lu(c+32|0,d,ve(c+48|0,b));b=b+4|0;a=a-1|0;if(a&255){continue}break}continue}if(e>>>0<8){break j}v[22692]=0;a=Q(927,f|0,c+32|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!a){break j}a=fc(c+32|0);j=c,k=Vb(g),v[j+48>>2]=k;Lu(c+32|0,a,ve(c+48|0,b));a=fc(c+32|0);j=c,k=Vb(g),v[j+16>>2]=k;j=c,k=ve(c+16|0,b),v[j+48>>2]=k;Lu(c+32|0,a,ve(c+48|0,4));e=e-8|0;b=b+8|0;continue}v[22692]=0;a=T(374,f|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(a>>>0>e>>>0){break j}e=e-a|0;b=a+b|0;continue}break}if(!e){break f}a=mc(c+48|0);xc(a,g);xc(a+4|0,g+4|0);xc(wb(a),wb(g));wb(a);wb(g);gc(a);break f}v[22692]=0;W(503,f|0,g|0,e|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}}xb(f)}gb=c+96|0;return}a=P()|0;O()|0;xb(f)}gc(g);S(a|0);L()}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-96|0;gb=d;a:{b:{c:{d:{if(w[a|0]==23){e=t[a+1|0];f=d,g=tA(c,+w[a+2|0]*41.666666666666664),t[f+8|0]=g;v[d+80>>2]=127;v[d+64>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[nd(d+80|0,d- -64|0)>>2],t[f+95|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Df(d- -64|0,12673);v[22692]=0;R(729,d+48|0,d+8|0);a=v[22692];v[22692]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[22692]=0;R(729,d+32|0,d+95|0);a=v[22692];v[22692]=0;if((a|0)==1){break k}v[22692]=0;Y(730,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break j}v[22692]=0;R(444,d+16|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}v[22692]=0;Q(401,d+16|0,d+80|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break i}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;case 1:Df(d- -64|0,12613);v[22692]=0;R(729,d+48|0,d+8|0);a=v[22692];v[22692]=0;l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22692]=0;R(729,d+32|0,d+95|0);a=v[22692];v[22692]=0;if((a|0)==1){break q}v[22692]=0;Y(730,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22692];v[22692]=0;if((a|0)==1){break p}v[22692]=0;R(444,d+16|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break o}v[22692]=0;Q(401,d+16|0,d+80|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break o}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;default:break e}}a=Tb(d+80|0,12700);v[22692]=0;R(444,d- -64|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;Q(401,d- -64|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}vb(a);break b}if(w[a|0]==24){t[d+95|0]=t[a+1|0]<=4?w[a+1|0]:0;t[d+31|0]=t[a+2|0]>=0?w[a+2|0]:127;t[d+30|0]=t[a+3|0]>=0?w[a+3|0]:127;a=gb-16|0;gb=a;c=Tb(a,1157);Dc(d- -64|0,c);vb(c);gb=a+16|0;v[22692]=0;R(729,d+48|0,d+95|0);a=v[22692];v[22692]=0;r:{s:{t:{u:{v:{w:{x:{y:{if((a|0)!=1){v[22692]=0;R(729,d+32|0,d+31|0);a=v[22692];v[22692]=0;if((a|0)==1){break y}v[22692]=0;R(729,d+16|0,d+30|0);a=v[22692];v[22692]=0;if((a|0)==1){break x}v[22692]=0;ha(931,d+80|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22692];v[22692]=0;if((a|0)==1){break w}v[22692]=0;R(444,d+8|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break v}v[22692]=0;Q(401,d+8|0,d+80|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break v}vb(d+80|0);vb(d+16|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;break u}b=P()|0;O()|0;vb(d+80|0)}vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c}a=0;break a}b=P()|0;O()|0;vb(a)}S(b|0);L()}a=1}gb=d+96|0;return a|0}function Hy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-96|0;gb=e;a:{b:{c:{if(j=1,k=ld(a,11),l=v[a+4>>2],l?j:k){g=v[a+28>>2];b=e;d=v[a+12>>2];f=v[a+64>>2];c=f+v[a+8>>2]|0;d=oh(b+80|0,c,c>>>0<f>>>0?d+1|0:d);c=v[d+12>>2];v[b+32>>2]=v[d+8>>2];v[b+36>>2]=c;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;ek(g,e+24|0);b=v[a+28>>2];if(xl(v[v[b>>2]-12>>2]+b|0)){qh(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=g;c=tf(b);d:{if(d>>>0>c>>>0){f=gb-32|0;gb=f;e:{c=d-c|0;f:{if(c>>>0<=v[wb(b)>>2]-v[b+4>>2]>>4>>>0){h=gb-16|0;gb=h;c=Zp(h,b,c);d=v[c+4>>2];i=v[c+8>>2];if((d|0)!=(i|0)){while(1){wb(b);WH(d);d=d+16|0;v[c+4>>2]=d;if((d|0)!=(i|0)){continue}break}}$b(c);gb=h+16|0;break f}d=wb(b);d=SI(f+8|0,Wx(b,tf(b)+c|0),tf(b),d);v[22692]=0;PI(d,c);c=v[22692];v[22692]=0;if((c|0)==1){break e}Jx(b);wb(b);c=d+4|0;hl(v[b>>2],v[b+4>>2],c);wc(b,c);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];bI(b,tf(b));MI(d)}gb=f+32|0;break d}a=P()|0;O()|0;MI(d);S(a|0);L()}if(c>>>0>d>>>0){d=v[b>>2]+(d<<4)|0;tf(b);GI(b,d);vi(b);tf(b)}}h=a+32|0;It(h,v[a+92>>2]<<2);if(v[a+92>>2]){c=0;while(1){b=v[a+28>>2];if(xl(v[v[b>>2]-12>>2]+b|0)){qh(a,1073741828);break a}b=x[a+16>>1];u[e+78>>1]=b;if((b|0)==65535){Iy(v[a+28>>2],e+78|0);b=x[e+78>>1]}f=pc(h);v[e+72>>2]=f;g:{if(!b){break g}d=b;f=v[e+72>>2];if(b>>>0>-1-f>>>0){break g}Gy(h,d+f|0);dl(v[a+28>>2],kc(h,v[e+72>>2]),d);f=v[e+72>>2]}j=Tc(g,c),k=b,u[j+12>>1]=k;j=Tc(g,c),k=f,v[j>>2]=k;if(ld(a,6)){rl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break c}j=Tc(g,c),k=v[e+56>>2],v[j+4>>2]=k}b=v[a+4>>2];h:{if(b){j=Tc(g,c),k=b,v[j+8>>2]=k;break h}if(!ld(a,7)){break h}rl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break b}j=Tc(g,c),k=v[e+56>>2],v[j+8>>2]=k}i:{if(v[Tc(g,c)+8>>2]==-1){break i}if(ld(a,6)){break i}if(c){b=Tc(g,c-1|0);b=v[b+8>>2]+v[b+4>>2]|0}else{b=0}j=Tc(g,c),k=b,v[j+4>>2]=k}if(ld(a,8)){u[e+56>>1]=0;Iy(v[a+28>>2],e+56|0);b=ld(a,9);qm(v[a+28>>2],x[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<y[a+92>>2]){continue}break}}re(e+56|0,v[a+28>>2]);b=v[e+68>>2];v[a+72>>2]=v[e+64>>2];v[a+76>>2]=b}sl(a,4,1);g=v[a+76>>2];f=v[a+88>>2];c=f+v[a+8>>2]|0;d=v[a+12>>2];d=c>>>0<f>>>0?d+1|0:d;b=c;c=(f|0)==v[a+64>>2];f=c?v[a+72>>2]:b;v[a+80>>2]=f;b=c?g:d;v[a+84>>2]=b;d=v[a+28>>2];b=oh(e+40|0,f,b);c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;ek(d,e+8|0);if(ld(a,6)){break a}if(!(j=1,k=ld(a,7),l=v[a+4>>2],l?j:k)){break a}b=v[a+92>>2];if(!b){break a}d=a+44|0;c=v[a+80>>2];a=v[a+8>>2];c=c-a|0;a=0;while(1){g=Tc(d,a);v[g+4>>2]=c+v[g+4>>2];a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}qh(a,1073741829);break a}qh(a,1073741829)}gb=e+96|0}function Gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-48|0;gb=c;if(gi(b)){h=Ji(b);j=v[b+12>>2];f=c+32|0;e=Gg(f);a:{d=h;if(!d){break a}v[22692]=0;R(613,f|0,d|0);g=v[22692];v[22692]=0;if((g|0)!=1){v[22692]=0;BN(f,d);d=v[22692];v[22692]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;pv(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[22692]=0;d=Xf(a+d|0);e=v[22692];v[22692]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[22692]=0;t[c+31|0]=0;Q(1468,a|0,c+31|0)|0;d=v[22692];v[22692]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[22692]=0;Q(1468,a|0,c+30|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;Eh(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[22692]=0;g=Wc(b,i,d);e=v[22692];v[22692]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[22692]=0;Q(1468,a|0,c+29|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=$c(f,d),m=e,t[l|0]=m}l=g,m=w[$c(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[22692]=0;Q(1468,a|0,c+29|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=$c(f,d),m=e,t[l+1|0]=m}l=g,m=w[$c(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[22692]=0;Q(1468,a|0,c+29|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=$c(f,d),m=e,t[l+2|0]=m}l=g,m=w[$c(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[22692]=0;Q(1468,a|0,c+29|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=$c(f,d),m=e,t[l+4|0]=m}l=g,m=w[$c(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[22692]=0;Q(1468,a|0,c+29|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=$c(f,d),m=e,t[l+3|0]=m}l=g,m=w[$c(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[22692]=0;Q(1468,a|0,c+29|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=$c(f,d),m=e,t[l+5|0]=m}l=g,m=w[$c(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[22692]=0;Q(1468,a|0,c+15|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){d=w[c+15|0];v[22692]=0;W(1469,a|0,d|0,-1)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;dn(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}dn(f)}gb=c+48|0}function uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;e=gb-560|0;gb=e;a:{if(!Yc(b,1464)){break a}if(!ap(b,e+556|0)){break a}Id(a,1);d=a+1074312|0;Pf(d,83);Ob(d,84,1);Ob(d,85,1);b:{if(ke(e+556|0,33186)){d=Tb(e+32|0,5562);Eb(a+1298304|0,d);vb(d);d=Tb(e+32|0,11968);Eb(a+1298316|0,d);vb(d);d=Tb(e+32|0,12033);Eb(a+1298328|0,d);break b}if(!ke(e+556|0,12608)){break a}d=Tb(e+32|0,5720);Eb(a+1298304|0,d);vb(d);d=Tb(e+32|0,9470);Eb(a+1298316|0,d);vb(d);d=Tb(e+32|0,12525);Eb(a+1298328|0,d)}vb(d);v[a+1298364>>2]=2;d=0;Yc(b,0);LC(b,a+1298268|0,20);u[a+480190>>1]=31;f=1;while(1){d=YB(b,e+32|0,(B(f,104)+a|0)+484380|0,((f<<5)+a|0)+946304|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}bw(e+552|0,b);m=od(e+552|0);i=e+552|0;if(w[i|0]>128){break a}g=e+32|0;f=gb-32|0;gb=f;d=b;c:{if(!Pb(d,512)){hV(g);break c}Lv(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;id(f+16|0,d,f+8|0)}gb=f+32|0;d=e+544|0;f=e+32|0;g=w[m|0];d:{while(1){if(g>>>0>=w[f|0]){f=f+1|0;if((d|0)!=(f|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;uh(a,0);n=a+484360|0;yf(Sb(n),w[i|0]);u[e+30>>1]=0;j=a+484344|0;xg(j,w[i|0]);if(w[i|0]){g=0;while(1){s=rc(Sb(n),g),x=g,u[s>>1]=x;if(sh(j,g&65535,64)){p=g<<2;h=0;while(1){Yc(b,(w[e+32+(h+p)|0]<<8)+1468|0);f=Wc(_b(j,g),0,h&65535);d=0;while(1){av(b,f);e:{f:{l=w[f+3|0];g:{if((l|0)!=14){if(!l){if(w[f+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[f+5|0]<=15){break f}}t[f+3|0]=0;break e}Nf(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=e,x=Vb(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){f=d;h:{if(w[v[e+24>>2]+3|0]!=17?w[v[e+24>>2]+3|0]!=16:0){break h}t[v[e+24>>2]+3|0]=16;k=0;if(w[v[e+24>>2]+5|0]<16){break h}if(!(!(w[v[e+24>>2]+5|0]&15)|(w[v[e+24>>2]+5|0]&15)==(w[v[e+24>>2]+5|0]>>>4|0))){q=w[v[e+24>>2]+5|0]>>>4|0;r=w[v[e+24>>2]+5|0]&15;k=1}d=v[e+24>>2];t[d+5|0]=w[d+5|0]>>>4}Xj(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}t[e+31|0]=r;t[e+30|0]=q;d=k&255;if(d){Cm(_b(j,g),Se(Be(e+8|0,16,w[(e+d|0)+29|0]),h));d=k+1|0;k=(d&255)==3?1:d}else{k=0}h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Yc(b,(w[m|0]<<8)+1468|0);f=1;while(1){c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){Ag(Rc(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}gb=e+560|0;return o|0}function R7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-192|0;gb=d;a:{if(kk(b)){break a}e=w[nl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Cl(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}Md(d+160|0);e=v[d+160>>2];Md(d+144|0);e=ml(e,v[d+148>>2],b);Md(d+160|0);b:{c:{d:{e:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=uc(d+176|0,18699);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22692]=0;c=Q(70,d+160|0,7706)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}f=0;if(!c){break e}a=ba(8)|0;v[22692]=0;e=Q(2041,d+144|0,b|0)|0;b=v[22692];v[22692]=0;f:{g:{h:{if((b|0)!=1){v[22692]=0;U(2021,d+160|0,14737,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}qc(a,d+160|0);c=0;v[22692]=0;U(184,a|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+160|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}vb(e);if(!c){break c}}da(a|0);break c}if(v[e+4>>2]!=2){a=ba(8)|0;v[22692]=0;c=Q(70,d+160|0,8828)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=uc(d+128|0,18699);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){a=ba(8)|0;v[22692]=0;c=Q(70,d+160|0,7706)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=uc(d+112|0,4808);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,4860);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=uc(d+80|0,4878);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Gc(d+24|0,d+16|0)){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}gb=d+192|0;return+f}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function bna(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[ac(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[ac(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=bn(+(bW(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[ac(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[ac(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=ac(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[ac(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[ac(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[ac(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[ac(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[ac(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=44;h=a,i=_l(Qc(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=ei(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){Nf(a);break a}t[a+3|0]=0}gb=f+16|0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-192|0;gb=d;g=d+176|0;eL(g);v[g>>2]=55108;cd(g+4|0);h=a;fo(v[a+24>>2],g);e=w[a+62|0];f=w[a+61|0];j=w[a+60|0];k=v[a+24>>2];b=Pe(d+152|0,b);v[22692]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=f?b&14:b;b=W(2045,k|0,d|0,(e?b&3:b)|0)|0;e=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)==1){break p}if(!b){b=ba(8)|0;v[22692]=0;c=Q(70,d+136|0,9218)|0;a=v[22692];v[22692]=0;if((a|0)!=1){qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;da(b|0);break b}if(!w[a+63|0]){v[22692]=0;R(2046,a|0,a+36|0);b=v[22692];v[22692]=0;if((b|0)==1){break p}}t[a+28|0]=1;fo(v[h+24>>2],v[a+4>>2]);v[22692]=0;R(2047,d+136|0,g|0);b=v[22692];v[22692]=0;if((b|0)==1){break o}l=d,m=Vb(d+136|0),v[l+128>>2]=m;l=d,m=Zb(d+136|0),v[l+120>>2]=m;if(Gb(d+128|0,d+120|0)){h=a+68|0;while(1){b=v[d+128>>2];e=v[b>>2];v[22692]=0;f=e;e=b+4|0;U(2048,a|0,f|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}b=v[b>>2];v[22692]=0;R(2049,d+56|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;R(2023,d+72|0,d+56|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;b=Q(70,d+40|0,14837)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}v[22692]=0;U(2042,d+88|0,d+72|0,b|0);f=v[22692];v[22692]=0;if((f|0)==1){break k}v[22692]=0;U(710,d+104|0,d+88|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break m}v[22692]=0;R(1407,h|0,d+104|0);e=v[22692];v[22692]=0;if((e|0)==1){break n}vb(d+104|0);vb(d+88|0);vb(b);vb(d+72|0);vb(d+56|0);Ro(d+128|0);if(Gb(d+128|0,d+120|0)){continue}break}}l=d,m=lr(c),v[l+104>>2]=m;l=d,m=Ah(c),v[l+88>>2]=m;q:{while(1){v[22692]=0;b=mg(d+104|0,d+88|0);c=v[22692];v[22692]=0;r:{if((c|0)!=1){if(b){break r}Ft(d+136|0);Dt(g);gb=d+192|0;return}a=P()|0;O()|0;break c}v[22692]=0;c=te(d+104|0);b=v[22692];v[22692]=0;s:{if((b|0)==1){break s}v[22692]=0;b=Q(69,d+24|0,c|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break s}v[22692]=0;Y(1984,a|0,b|0,c+12|0,0);c=v[22692];v[22692]=0;if((c|0)==1){break q}vb(b);Oj(d+104|0);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(b);break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+104|0);break l}a=P()|0;O()|0}vb(d+88|0);break j}a=P()|0;O()|0}vb(b);break h}a=P()|0;O()|0}vb(d+72|0);break f}a=P()|0;O()|0}vb(d+56|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Ft(d+136|0)}Dt(g);S(a|0)}L()}function _Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-384|0;gb=e;vc(b);f=gb-32|0;gb=f;j=e+344|0;jE(f+24|0,j);g=yb(f+24|0);d=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=d;v[f>>2]=h;v[f+4>>2]=d;d=b;cc(f+16|0,d,f);h=yb(f+16|0);if((h|0)==(g|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(h|0);if(!d){iE(j)}a:{b:{if(!d){break b}if(!wE(e+344|0)){break b}if(!Pb(b,Qc(vE(e+344|0),jb))){break b}c:{if(!c){break c}Id(a,2097152);yg(a);i=1;uh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[e+376|0];v[a+480204>>2]=B(w[e+377|0],1e4);u[a+480190>>1]=w[e+378|0];if(w[e+381|0]<w[e+380|0]){bf(Sb(a+484360|0),w[e+381|0])}d=Tb(e+80|0,3573);Eb(a+1298304|0,d);vb(d);d=Tb(e+80|0,8291);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;dw(b,e+80|0);Qr(Sb(a+484360|0),e+80|0,w[e+380|0],65535,65535);if(x[a+480190>>1]){j=1;while(1){uE(b,e+40|0);h=gb-16|0;gb=h;g=(B(i,104)+a|0)+484380|0;td(g,0);k=e+40|0;t[g+37|0]=w[k+22|0]<<4;t[h+15|0]=w[k+23|0];t[h+14|0]=64;m=g,n=w[ac(h+15|0,h+14|0)|0]<<2,u[m+30>>1]=n;t[g+36|0]=w[k+24|0];d=k+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=k+33|0;d:{if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}gb=h+16|0;Jk(e+8|0,2,e+40|0);Bc(e+24|0,e+8|0);v[22692]=0;Q(301,((i<<5)+a|0)+946304|0,e+24|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}vb(e+24|0);j=j+1|0;i=j&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Rb(b,B(64-w[e+378|0]|0,37));f=a+484344|0;xg(f,w[e+379|0]);if(w[e+379|0]){i=c&1;j=0;while(1){e:{f:{if(i){if(sh(f,j&65535,64)){break f}}Rb(b,2048);break e}d=_b(f,j);m=e,n=Vb(d),v[m+40>>2]=n;m=e,n=Zb(d),v[m+24>>2]=n;if(!Gb(e+40|0,e+24|0)){break e}while(1){d=v[e+40>>2];pn(e+8|0,b);g=od(e+8|0);h=Te(e+8|0);k=bj(e+8|0);l=w[e+8|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[g|0];t[d+3|0]=w[h|0];t[d+5|0]=w[k|0];Nf(d);Xj(e+40|0);if(Gb(e+40|0,e+24|0)){continue}break}}j=j+1|0;if(j>>>0<w[e+379|0]){continue}break}}if(!(c&2)){break c}i=1;c=Rc(e+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){Ag(c,(B(i&65535,104)+a|0)+484380|0,b);i=i+1|0;if(x[a+480190>>1]>=(i&65535)>>>0){continue}break}}i=1}gb=e+384|0;return i|0}a=P()|0;O()|0;vb(e+24|0);S(a|0);L()}function lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0;f=gb-32|0;gb=f;p=a+4|0;o=v[p>>2];n=a+20|0;s=v[xe(n,b)>>2];a:{if(s+1>>>0<2){break a}h=(B(b,872)+o|0)+616|0;if(!Mi(h)){if(!w[xe(n,b)+4|0]){break a}}i=B(b,872)+o|0;if(!v[i+720>>2]){break a}A=v[(v[i+704>>2]&2?i+700|0:i+692|0)>>2];g=v[i+696>>2];j=v[i+700>>2];Db(f,v[a>>2]+1074312|0,31);u=Cb(f);y=i+1362|0;l=w[y|0];z=i+624|0;e=sw(z,c);k=jb;m=k;v[f+24>>2]=e;v[f+28>>2]=k;if(w[i+704|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+m|0)}k=j-g|0;D=k<<1;e=B(b,872)+o|0;E=e+1316|0;m=e+1467|0;F=(l&17)!=1;b:{while(1){c:{if(d>>>0>q>>>0){g=(w[y|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=Wc(_b(v[a>>2]+484344|0,x[v[p>>2]+70>>1]),v[v[p>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){rA(f,v[a>>2],e,0);l=Te(f);to(v[a>>2],h,x[f>>1]);g=1;if(w[l|0]){break c}}g=1;d:{switch(j-4|0){case 0:to(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}to(v[a>>2],h,0)}v[f+20>>2]=v[E>>2];if(u){Xt(v[a>>2],h)}if(!F){mO(v[a>>2],h,f+20|0);g=1}if(!u){Xt(v[a>>2],h)}v[f+16>>2]=0;nO(h,f+16|0);e:{f:{if(w[i+705|0]&2){break f}g:{if(!g){if(!w[xe(n,b)+4|0]){break g}}if(w[m|0]&48){GS(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&32?-33:-17)&e}Kz(f,v[a>>2],h,v[f+20>>2],0);g=v[f+4>>2];e=z;v[e>>2]=v[f>>2];v[e+4>>2]=g;G=xe(n,b),H=0,t[G+4|0]=H;e=sw(e,c);g=jb;j=g;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+704|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+j|0)}Ub(h,f+24|0);g=v[h+4>>2];j=g;l=v[h>>2];if(A>>>0>g>>>0){break f}e=v[i+704>>2];if(!(e&2)){break e}if(e&4){r=v[i+696>>2];l=r;e=l;if((e|0)>(j|0)?1:0){v[f>>2]=0;v[f+4>>2]=l<<1;G=h,H=Pg(f,h),v[G>>2]=H;v[h+4>>2]=jb;v[i+704>>2]=v[i+704>>2]^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;r=v[i+696>>2];g=v[h+4>>2]}Db(f,v[a>>2]+1074312|0,33);e=(g-r>>>0)%(D-Cb(f)>>>0)|0;h:{if(e>>>0>=k>>>0){v[h+4>>2]=v[i+700>>2]+(k-e|0);g=v[i+704>>2];if(!(g&128)){break h}break f}v[h+4>>2]=e+v[i+696>>2];g=v[i+704>>2];if(!(g&128)){break f}}v[i+704>>2]=g^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;break f}j=v[i+700>>2];if(j+k>>>0<=g>>>0){g=j+((g-j>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=l;v[h+4>>2]=e}q=q+1|0;if((s|0)!=(q|0)){continue}break b}break}dB(h);v[(B(b,872)+o|0)+1324>>2]=0}G=xe(n,b),H=0,v[G>>2]=H}gb=f+32|0}function mG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;g=gb-48|0;gb=g;o(+a);d=j(1)|0;f=j(0)|0;a:{b:{e=d;d=e;h=e&2147483647;c:{if(h>>>0<=1074752122){if((d&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;e=h>>>20|0;f=(e-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(f){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;f=e;o(+a);e=j(1)|0;j(0)|0;if((f-(e>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(h>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,f|0);l(1,e&1048575|1096810496);a=+n();d=0;f=1;while(1){m=(g+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=f&1;f=0;if(m){continue}break}A[g+32>>3]=a;e:{if(a!=0){d=2;break e}f=1;while(1){d=f;f=d-1|0;if(A[(g+16|0)+(d<<3)>>3]==0){continue}break}}d=II(g+16|0,g,(h>>>20|0)-1046|0,d+1|0,1);a=A[g>>3];if((e|0)<-1?1:(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}gb=g+48|0;return d}function g3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;n=Fx(g);o=lx(g);Tg(l,o);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22692]=0;g=Q(2486,n|0,g<<24>>24)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22692]=0;j=Q(2486,n|0,48)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=t[h+1|0];v[22692]=0;j=Q(2486,n|0,j|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=h+2|0;if(j>>>0>=c>>>0){g=j;break d}h=g+h|0;g=j;e:{while(1){i=t[g|0];v[22692]=0;k=ga(2460)|0;m=v[22692];v[22692]=0;if((m|0)==1){break e}v[22692]=0;i=vx(i,k);k=v[22692];v[22692]=0;if((k|0)==1){break e}if(!i){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}j=g+h|0;g=h;while(1){i=t[g|0];v[22692]=0;ga(2460)|0;k=v[22692];v[22692]=0;if((k|0)==1){break a}v[22692]=0;i=Qh(i);k=v[22692];v[22692]=0;if((k|0)==1){break a}if(!i){break f}g=g+1|0;if((j|0)!=(g|0)){continue}break}g=j}j=h}g:{if(ed(l)){h=v[f>>2];v[22692]=0;Y(2476,n|0,j|0,g|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-j<<2);break g}im(j,g);v[22692]=0;p=T(2474,o|0)|0;h=v[22692];v[22692]=0;h:{i:{if((h|0)!=1){if(g>>>0>j>>>0){break i}h=v[f>>2];break h}break a}h=j;i=0;k=0;j:{while(1){k:{if(t[nc(l,i)|0]<1){break k}if(t[nc(l,i)|0]!=(k|0)){break k}k=v[f>>2];v[f>>2]=k+4;v[k>>2]=p;i=(Ab(l)-1>>>0>i>>>0)+i|0;k=0}m=t[h|0];v[22692]=0;q=Q(2486,n|0,m|0)|0;m=v[22692];v[22692]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;k=k+1|0;h=h+1|0;if((h|0)==(g|0)){break j}continue}break}break a}h=m+4|0}hx((j-a<<2)+d|0,h)}l:{if(c>>>0<=g>>>0){h=v[f>>2];break l}while(1){h=w[g|0];if((h|0)==46){v[22692]=0;j=T(2477,o|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}i=v[f>>2];h=i+4|0;v[f>>2]=h;v[i>>2]=j;g=g+1|0;break l}v[22692]=0;j=Q(2486,n|0,h<<24>>24)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;g=g+1|0;if((g|0)!=(c|0)){continue}break}h=h+4|0;g=c}v[22692]=0;Y(2476,n|0,g|0,c|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g<<2)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-320|0;gb=d;e=gb-16|0;gb=e;v[a>>2]=0;f=a+32|0;It(f,32);t[e+15|0]=0;fq(f,e+15|0);gb=e+16|0;e=v[a+28>>2];a:{if(!Xf(v[v[e>>2]-12>>2]+e|0)){qh(a,1073741825);break a}re(d+56|0,v[a+28>>2]);e=v[d+68>>2];v[a+8>>2]=v[d+64>>2];v[a+12>>2]=e;f=d+56|0;v[f>>2]=3;g=v[a+28>>2];h=d+16|0;e=0;if(v[f>>2]){while(1){Wh(g,e+h|0);e=e+1|0;if(e>>>0<y[f>>2]){continue}break}}if(rd(d+16|0,27232,3)){qh(a,1073741827);break a}e=0;t[d+319|0]=0;Wh(v[a+28>>2],d+319|0);Qb(d+56|0,0,256);g=w[d+319|0];b:{if(!g){f=d+56|0;break b}f=d+56|0;dl(v[a+28>>2],f,g);e=w[d+319|0]}g=b;b=io(d+16|0,f,e);e=Ky(g,b);Hb(b);if(!e){qh(a,1073741830)}if(w[a+3|0]&64){break a}Wh(v[a+28>>2],d+55|0);e=w[d+55|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(Aj(e,6)){sl(a,9,1)}v[d+48>>2]=0;wL(v[a+28>>2],d+48|0);b=v[d+48>>2];t[d+47|0]=0;if(b>>>0>=2){Wh(v[a+28>>2],d+55|0);f=w[d+55|0];if(!f){Wh(v[a+28>>2],d+47|0);f=w[d+55|0]}qm(v[a+28>>2],b+(f&255?-1:-2)|0,-1)}v[d+32>>2]=0;v[d+36>>2]=0;c:{if(!Aj(e,4)){break c}rl(v[a+28>>2],d+32|0);b=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break c}qh(a,536871424)}if(Aj(e,5)){Wh(v[a+28>>2],d+55|0);qm(v[a+28>>2],w[d+55|0],-1)}d:{if(!Aj(w[d+47|0],0)){break d}Wh(v[a+28>>2],d+55|0);b=w[d+55|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break d}qh(a,536871168)}v[a+4>>2]=0;b=1;if(Aj(w[d+47|0],1)){wL(v[a+28>>2],a+4|0)}sl(a,6,Aj(e,2));sl(a,7,Aj(e,3));sl(a,5,x[a+16>>1]!=0);sl(a,8,Aj(e,7));e:{if(ld(a,5)){break e}if(ld(a,6)){break e}if(ld(a,7)){break e}b=ld(a,8)}sl(a,11,b);ld(a,11);b=w[d+47|0];if(Aj(b,2)){u[d+16>>1]=0;Iy(v[a+28>>2],d+16|0);qm(v[a+28>>2],B(x[d+16>>1],ld(a,9)?2:1),-1);b=w[d+47|0]}if(Aj(b,3)){qm(v[a+28>>2],5,-1)}rl(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){qh(a,1073741831);break a}v[a+92>>2]=b;if(!b){qh(a,536871040)}f:{if(!ld(a,11)){break f}rl(v[a+28>>2],d+32|0);b=v[d+36>>2];if((b|0)==2147483647|b>>>0<2147483647){break f}qh(a,1073741829);break a}re(d,v[a+28>>2]);UL(d+16|0,d,v[a+8>>2],v[a+12>>2]);b=v[d+28>>2];e=v[d+24>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){qh(a,1073741832);break a}v[a+88>>2]=e;i=a,j=v[(ld(a,11)?d+32|0:a+88|0)>>2],v[i+64>>2]=j;if(!ld(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}sl(a,10,1)}gb=d+320|0}function TU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=me(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=gb-16|0;gb=b;d=Mj(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[nd(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}g=c;d=(d|0)/32|0;c=d<<2;vh(g,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}me(a,f);gb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=me(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=gb-16|0;gb=f;d=Mj(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;b=v[nd(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;d=v[g+4>>2];h=v[v[e+24>>2]>>2];j=v[e+28>>2];v[f+8>>2]=b;k=32-d|0;v[f+4>>2]=k;l=Fb(f+8|0,f+4|0);i=v[g>>2];j=h&(-1<<j&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=nd(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}me(a,g);gb=f+16|0}gb=e+80|0}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-48|0;gb=l;f=v[a+4>>2];e=me(l+40|0,b);i=me(l+32|0,c);d=gb-16|0;gb=d;e=SU(me(d+8|0,e),me(d,i));gb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}i=v[a>>2];v[(d>>>0<33?i:i+(e>>>3&536870908)|0)>>2]=0}d=me(l+24|0,b);c=me(l+16|0,c);tp(l+8|0,a,f);b=l;i=gb-48|0;gb=i;a=l+8|0;c:{if(v[d+4>>2]==v[a+4>>2]){d=me(i+40|0,d);c=me(i+32|0,c);f=me(i+24|0,a);a=gb-16|0;gb=a;c=Mj(c,d);v[a+12>>2]=c;d:{if((c|0)<1){break d}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[nd(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;vh(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break d}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];j=d;n=v[d>>2];d=-1>>>32-e|0;v[j>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}me(b,f);gb=a+16|0;break c}e=me(i+16|0,d);c=me(i+8|0,c);d=me(i,a);f=gb-16|0;gb=f;a=Mj(c,e);v[f+12>>2]=a;e:{if((a|0)<1){break e}c=v[e+4>>2];f:{if(!c){c=v[d+4>>2];break f}c=32-c|0;v[f+8>>2]=c;a=v[nd(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;g=v[d+4>>2];k=v[v[e>>2]>>2];j=v[e+4>>2];v[f+8>>2]=a;m=32-g|0;v[f+4>>2]=m;n=Fb(f+8|0,f+4|0);h=v[d>>2];k=k&(-1<<j&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];j=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=j|v[h>>2]&(-1<<c&-1>>>m-g^-1);j=c+g|0;c=j&31;v[d+4>>2]=c;h=h+(j>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;j=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=j&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break e}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=nd(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];j=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=j|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break e}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}me(b,d);gb=f+16|0}gb=i+48|0;gb=l+48|0}function q3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;m=sD(g);q=px(g);Tg(l,q);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22692]=0;g=Q(22,m|0,g<<24>>24)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22692]=0;i=Q(22,m|0,48)|0;j=v[22692];v[22692]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=t[h+1|0];v[22692]=0;i=Q(22,m|0,i|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=h+2|0;if(i>>>0>=c>>>0){g=i;break d}h=g+h|0;g=i;e:{while(1){j=t[g|0];v[22692]=0;k=ga(2460)|0;n=v[22692];v[22692]=0;if((n|0)==1){break e}v[22692]=0;j=vx(j,k);k=v[22692];v[22692]=0;if((k|0)==1){break e}if(!j){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}i=g+h|0;g=h;while(1){j=t[g|0];v[22692]=0;ga(2460)|0;k=v[22692];v[22692]=0;if((k|0)==1){break a}v[22692]=0;j=Qh(j);k=v[22692];v[22692]=0;if((k|0)==1){break a}if(!j){break f}g=g+1|0;if((i|0)!=(g|0)){continue}break}g=i}i=h}g:{if(ed(l)){h=v[f>>2];v[22692]=0;Y(2456,m|0,i|0,g|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break g}im(i,g);v[22692]=0;j=T(2448,q|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}if(g>>>0>i>>>0){h=i;while(1){h:{if(t[nc(l,p)|0]<1){break h}if(t[nc(l,p)|0]!=(o|0)){break h}o=v[f>>2];v[f>>2]=o+1;t[o|0]=j;p=(Ab(l)-1>>>0>p>>>0)+p|0;o=0}k=t[h|0];v[22692]=0;k=Q(22,m|0,k|0)|0;n=v[22692];v[22692]=0;if((n|0)==1){break a}n=v[f>>2];v[f>>2]=n+1;t[n|0]=k;o=o+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}}im((i-a|0)+d|0,v[f>>2])}i:{if(c>>>0<=g>>>0){break i}while(1){h=w[g|0];if((h|0)==46){v[22692]=0;h=T(2457,q|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;break i}v[22692]=0;h=Q(22,m|0,h<<24>>24)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=c}h=v[f>>2];v[22692]=0;Y(2456,m|0,g|0,c|0,h|0);h=v[22692];v[22692]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g|0)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function Epa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-48|0;gb=d;a:{b:{c:{d:{g=a+24|0;e:{if(Dd(g)){break e}f=a+4|0;i=Ab(f);a=gb-48|0;gb=a;c=a+40|0;b=c;v[b>>2]=-1;v[b+4>>2]=-1;v[22692]=0;b=jG(2274);e=v[22692];v[22692]=0;if((e|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;j=b,k=jqa(v[a+16>>2],v[a+20>>2],1e3,0),v[j>>2]=k;v[b+4>>2]=jb;e=Ql(b+8|0,b);h=v[e+4>>2];gb=b+16|0;v[a+24>>2]=v[e>>2];v[a+28>>2]=h;b=GC(v[a+24>>2],v[a+28>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;cX(c,a+24|0,wb(a+24|0));v[22692]=0;b=jG(2275);e=v[22692];v[22692]=0;if((e|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;e=v[a+20>>2];v[b>>2]=v[a+16>>2];v[b+4>>2]=e;e=Ql(b+8|0,b);h=v[e+4>>2];gb=b+16|0;v[a+24>>2]=v[e>>2];v[a+28>>2]=h;b=GC(v[a+24>>2],v[a+28>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;cX(c,a+24|0,wb(a+24|0));e=v[c>>2];c=v[c+4>>2];gb=a+48|0;if(i){b=mc(d+32|0);v[22692]=0;v[d+16>>2]=c;R(40,b|0,d+16|0);a=v[22692];v[22692]=0;f:{g:{h:{if((a|0)!=1){v[22692]=0;v[d+16>>2]=e;R(40,b|0,d+16|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}if(Ab(f)){a=0;while(1){c=w[nc(f,a)|0];v[22692]=0;v[d+16>>2]=c;R(40,b|0,d+16|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}a=a+1|0;if(Ab(f)>>>0>a>>>0){continue}break}}a=Vb(b);c=Zb(b);v[22692]=0;c=W(41,d+16|0,a|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break g}v[22692]=0;a=T(42,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}v[d+8>>2]=a;NC(g,d+8|0);fn(d+8|0);Lc(c);Lc(b);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Lc(c);break b}jb=e;v[d+16>>2]=c;v[d+20>>2]=jb;b=d+32|0;a=mc(b);v[22692]=0;U(49,b|0,d+16|0,d+24|0);c=v[22692];v[22692]=0;if((c|0)==1){b=P()|0;O()|0;Lc(a);S(b|0);L()}v[22692]=0;a=T(42,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}v[d+8>>2]=a;NC(g,d+8|0);fn(d+8|0);Lc(b)}gb=d+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(b);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-160|0;gb=d;a:{if(kk(b)){break a}e=w[nl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Cl(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}Md(d+128|0);e=v[d+128>>2];Md(d+112|0);e=ml(e,v[d+116>>2],b);Md(d+128|0);b:{c:{d:{e:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=uc(d+144|0,18699);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22692]=0;c=Q(70,d+128|0,7706)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;f=0;if(!c){break e}c=ba(8)|0;v[22692]=0;e=Q(2041,d+112|0,b|0)|0;a=v[22692];v[22692]=0;f:{g:{h:{if((a|0)!=1){v[22692]=0;U(2021,d+128|0,14737,e|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}qc(c,d+128|0);a=0;v[22692]=0;U(184,c|0,54920,1920);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+128|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e);if(!a){break c}}da(c|0);break c}if(v[e+4>>2]!=1){a=ba(8)|0;v[22692]=0;c=Q(70,d+128|0,8828)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,18699);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){a=ba(8)|0;v[22692]=0;c=Q(70,d+128|0,7706)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=uc(d+80|0,8161);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break e}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=uc(d- -64|0,5743);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Gc(d+24|0,d+16|0)){break e}e=xy(v[a+32>>2]);f=0}a=f;gb=d+160|0;jb=a;return e|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-1184|0;gb=d;vc(b);a:{if(!Ow(b,d+1160|0)){break a}if(!JN(d+1160|0)){break a}e=d+1168|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(em(b)|0)){break a}f=d+1176|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=(mf(b)|0)){break a}if(!c){g=1;break a}Qb(d+1104|0,0,56);e=d+1104|0;i=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;h=v[e+32>>2];if(!h){v[e+32>>2]=2265;h=2265}if(!v[e+36>>2]){v[e+36>>2]=2266}h=kb[h|0](v[e+40>>2],1,43784)|0;i=-4;if(!h){break b}v[e+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;i=0}if(i){break a}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+1100>>2]=e;g=d+1180|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=(g|0)!=0;h=jX(d+1088|0,g);c:{d:{e:{f:{g:{h:{i:{j:{if(!e|!g){break j}while(1){v[22692]=0;v[d+48>>2]=1024;e=Fb(d+48|0,d+1100|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}e=v[e>>2];f=vd(d+56|0,d- -64|0,e);v[22692]=0;i=v[f+4>>2];v[d+24>>2]=v[f>>2];v[d+28>>2]=i;U(199,d+48|0,b|0,d+24|0);f=v[22692];v[22692]=0;if((f|0)==1){break h}v[22692]=0;j=oJ(j,d- -64|0,e);f=v[22692];v[22692]=0;if((f|0)==1){break i}v[d+1120>>2]=g;v[d+1108>>2]=e;v[d+1104>>2]=d- -64;f=v[h>>2];v[22692]=0;v[d+1116>>2]=f+k;l=Q(1455,d+1104|0,0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}i=v[d+1100>>2]-e|0;v[d+1100>>2]=i;e=v[d+1120>>2];f=(e|0)!=0;if(!i|!e){break j}k=(g+k|0)-e|0;g=e;if((l|0)!=1){continue}break}}v[22692]=0;T(1456,d+1104|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}g=0;b=d+1172|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|f|(l|0)!=1)){v[22692]=0;Vd(d+40|0,h);b=v[22692];v[22692]=0;if((b|0)==1){break f}b=Ud(d+32|0);v[22692]=0;g=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=g;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=W(724,d- -64|0,d+16|0,d+8|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}v[22692]=0;g=W(1368,a|0,b|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break e}xb(b)}gc(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;xb(b);break c}a=P()|0;O()|0}gc(h);S(a|0);L()}gb=d+1184|0;return g|0}function mR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-96|0;gb=f;t[f+95|0]=d;n=LA(a);o=Qi(n);u[b>>1]=0;a:{if(o){while(1){b:{if(!Go(n,j&65535)){break b}j=x[b>>1];if(Ec(a)>>>0<=j>>>0){v[c>>2]=0;a=1;break a}m=Ad(a,x[b>>1]);uk(f+72|0,m);Ll(f- -64|0,m);j=v[f+76>>2];v[f+32>>2]=v[f+72>>2];v[f+36>>2]=j;j=v[f+68>>2];v[f+24>>2]=v[f+64>>2];v[f+28>>2]=j;l=f+80|0;e=f+32|0;i=f+24|0;j=gb-32|0;gb=j;c:{if(w[f+95|0]){g=v[e+4>>2];v[j+24>>2]=v[e>>2];v[j+28>>2]=g;e=Mj(i,e);i=v[j+28>>2];v[j+8>>2]=v[j+24>>2];v[j+12>>2]=i;i=gb-16|0;gb=i;v[i+12>>2]=e;h=j+8|0;g=v[h+4>>2];d:{if(g){v[i+8>>2]=32-g;e=Fb(i+8|0,i+12|0);k=v[h>>2];e=v[e>>2];g=v[k>>2]&(-1<<g&-1>>>v[i+8>>2]-e);if(g){sd(l,k,iqa(g));break d}g=v[i+12>>2];if((g|0)==(e|0)){YQ(l,h,e);break d}e=g-e|0;v[i+12>>2]=e;v[h>>2]=k+4}if(e>>>0>=32){g=v[h>>2];while(1){k=v[g>>2];if(k){sd(l,g,iqa(k));break d}g=g+4|0;v[h>>2]=g;e=e-32|0;v[i+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){g=v[h>>2];break e}g=v[h>>2];h=v[g>>2]&-1>>>32-e;if(!h){break e}sd(l,g,iqa(h));break d}sd(l,g,e)}gb=i+16|0;break c}g=v[e+4>>2];v[j+16>>2]=v[e>>2];v[j+20>>2]=g;e=Mj(i,e);i=v[j+20>>2];v[j>>2]=v[j+16>>2];v[j+4>>2]=i;g=gb-16|0;gb=g;v[g+12>>2]=e;i=j;h=v[i+4>>2];f:{if(h){v[g+8>>2]=32-h;e=v[Fb(g+8|0,g+12|0)>>2];k=-1<<h&-1>>>v[g+8>>2]-e;h=v[i>>2];k=k&(v[h>>2]^-1);if(k){sd(l,h,iqa(k));break f}k=v[g+12>>2];if((k|0)==(e|0)){YQ(l,i,e);break f}e=k-e|0;v[g+12>>2]=e;v[i>>2]=h+4}if(e>>>0>=32){h=v[i>>2];while(1){k=v[h>>2];if((k|0)!=-1){sd(l,h,iqa(k^-1));break f}h=h+4|0;v[i>>2]=h;e=e-32|0;v[g+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){h=v[i>>2];break g}h=v[i>>2];i=(v[h>>2]^-1)&-1>>>32-e;if(!i){break g}sd(l,h,iqa(i));break f}sd(l,h,e)}gb=g+16|0}gb=j+32|0;if(d){Ll(f+56|0,m);if(!lR(f+80|0,f+56|0)){break b}v[c>>2]=0;a=1;break a}Ll(f+56|0,m);if(lR(f+80|0,f+56|0)^1){uk(f+48|0,m);a=v[f+84>>2];b=v[f+80>>2];v[f+40>>2]=b;v[f+44>>2]=a;d=v[f+52>>2];v[f+16>>2]=v[f+48>>2];v[f+20>>2]=d;v[f+8>>2]=b;v[f+12>>2]=a;p=c,q=yU(f+16|0,f+8|0),v[p>>2]=q;a=1;break a}if(y[m+4>>2]>=y[_b(v[a+24>>2]+484344|0,x[rc(n,x[b>>1])>>1])+12>>2]){break b}v[c>>2]=v[m+4>>2];a=1;break a}j=x[b>>1]+1|0;u[b>>1]=j;if((j&65535)>>>0<o>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}gb=f+96|0;return a|0}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;v[22692]=0;e=T(780,a|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){a:{b:{if(e){break b}v[22692]=0;e=T(374,a|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}i=Gd(e+1|0,1,1024);v[22692]=0;k=d+484344|0;e=W(331,k|0,b|0,i|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}if(!e){break b}d=x[d+480188>>1];if(!d|!i){break b}l=d-1|0;while(1){v[22692]=0;d=Q(189,a|0,1)|0;e=v[22692];v[22692]=0;c:{d:{if((e|0)!=1){if(!d){break b}v[22692]=0;f=T(374,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}if(f){break d}j=j+1|0;break c}break a}d=_b(k,b);u[h+14>>1]=f&31;v[22692]=0;u[h+12>>1]=l;e=Pc(h+14|0,h+12|0);g=v[22692];v[22692]=0;if((g|0)==1){break a}e=x[e>>1];v[22692]=0;d=Wc(d,j,e);e=v[22692];v[22692]=0;if((e|0)==1){break a}if(!(f&224)){break c}e:{if(!(f&128)){break e}v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}t[d+5|0]=e;v[22692]=0;e=T(374,a|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+49008|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Gd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){n=d,o=ei(e<<1),t[n+5|0]=o;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[22692]=0;Tt(d);e=v[22692];v[22692]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}m=d;e=w[d+5|0];g=e&240;h:{if((g|0)==16){g=2}else{if((g|0)!=32){break h}g=3}t[m+3|0]=g}t[d+5|0]=e&15|224;break e}t[d+3|0]=0}i:{if(!(f&64)){break i}v[22692]=0;R(403,h+8|0,a|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}e=od(h+8|0);t[d+1|0]=w[h+8|0];e=w[e|0];t[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break i}}t[d|0]=g}if(!(f&32)){break c}t[d+2|0]=1;v[22692]=0;e=T(374,a|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}t[d+4|0]=e;if(!c){break c}t[d+4|0]=(e<<6>>>0)/127}if(i>>>0>j>>>0){continue}break}}xb(a);gb=h+16|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;a:{if(kk(c)){break a}f=w[nl(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Cl(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}Md(e+128|0);f=v[e+128>>2];Md(e+112|0);h=ml(f,v[e+116>>2],c);Md(e+128|0);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=uc(e+144|0,18699);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Gc(e+8|0,e)){a=ba(8)|0;v[22692]=0;b=Q(70,e+128|0,7706)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(d){a=ba(8)|0;v[22692]=0;b=Q(2041,e+112|0,c|0)|0;c=v[22692];v[22692]=0;f:{g:{h:{if((c|0)!=1){v[22692]=0;U(2021,e+128|0,14737,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break h}qc(a,e+128|0);d=0;v[22692]=0;U(184,a|0,54920,1920);c=v[22692];v[22692]=0;if((c|0)!=1){break b}c=P()|0;O()|0;vb(e+128|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}vb(b);if(!d){break c}}da(a|0);break c}Kb(a);break e}v[e+104>>2]=f;v[e+108>>2]=g;d=uc(e+96|0,18699);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){a=ba(8)|0;v[22692]=0;b=Q(70,e+128|0,7706)|0;c=v[22692];v[22692]=0;if((c|0)!=1){qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}c=P()|0;O()|0;da(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=uc(e+80|0,9545);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){i:{switch(v[b+52>>2]){case 0:Tb(a,2693);break e;case 1:Tb(a,8529);break e;case 2:Tb(a,6317);break e;default:break i}}Kb(a);break e}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=uc(e- -64|0,8766);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Gc(e+24|0,e+16|0)){j:{switch(v[b+56>>2]){case 0:Tb(a,12662);break e;case 1:Tb(a,12667);break e;case 2:Tb(a,9850);break e;case 3:Tb(a,6381);break e;default:break j}}Kb(a);break e}Kb(a)}gb=e+160|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function uZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=gb-32|0;gb=f;j=_i(f+24|0);if(v[a+12>>2]){q=b^1;r=j+3|0;s=j+5|0;x=j+4|0;z=j+2|0;A=j+1|0;C=f+16|5;D=f+16|3;while(1){E=Rf(a,n);while(1){a:{if(!Pb(c,1)){break a}k=Ae(c);if((k|0)==255){break a}h=k&31;d=Ji(a)>>>0>h>>>0;h=B(h,6)+E|0;if(k&64){l=1}else{e=Ae(c);i=e<<24>>24;g=255;b:{c:{d:{e=e&127;switch(e|0){case 0:break b;case 1:break c;default:break d}}if(!(e>>>0>121|q)){g=e-1|0;break c}if((e-12&255)>>>0>96|b){break b}g=e+13|0}t[(d?h:f+24|0)|0]=g}F=d?h+1|0:A,G=Ae(c),t[F|0]=G;l=(i|0)<0}if(l){p=d?h:j;g=d?h+3|0:r;e=d?h+5|0:s;o=d?h+4|0:x;m=d?h+2|0:z;h=d?h:f+24|0;while(1){d=h;v[f+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[f+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Ae(c);l=d&128;i=d&63;e:{if(d&64){t[m|0]=1;t[o|0]=i;break e}d=Ae(c);t[e|0]=d;f:{g:{if(i>>>0<=15){t[g|0]=i;Nf(p);h:{i:{j:{d=w[g|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[e|0]=B(w[e|0]&15,17);break f}t[g|0]=0;t[m|0]=1;v[f+12>>2]=w[e|0]+1>>>1;v[f+8>>2]=64;F=o,G=v[nd(f+12|0,f+8|0)>>2],t[F|0]=G;break f}if((d|0)!=19){break f}if(w[e|0]==128){break g}Tt(p);break f}if(i>>>0>44){break f}t[g|0]=w[i+28432|0];k:{switch(i-16|0){case 0:if(d>>>0>1){break g}t[e|0]=d|158;break f;case 1:case 2:t[f+12|0]=15;F=e,G=w[ac(f+12|0,e)|0]|224,t[F|0]=G;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=d+1;F=e,G=v[nd(f+12|0,f+8|0)>>2]/2|240,t[F|0]=G;break f;case 14:l:{m:{n:{o:{p:{i=d>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[e|0]=d|240;break f}t[g|0]=3;t[e|0]=d|240;break f}t[g|0]=11;t[e|0]=(d<<3&120)+8|15;break f}t[g|0]=11;t[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=d+1>>>1;v[f+8>>2]=64;F=e,G=v[nd(f+12|0,f+8|0)>>2],t[F|0]=G;break f}t[g|0]=0}hz(g,e,D,C);if(no(w[f+19|0])>>>0<=no(w[g|0])>>>0){break e}q:{if(w[m|0]){break q}if(!iz(g,e,1)){break q}t[m|0]=w[g|0];t[o|0]=w[e|0]}t[g|0]=w[f+19|0];t[e|0]=w[f+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}gb=f+32|0}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[22692]=0;X(2011);c=v[22692];v[22692]=0;a:{b:{if((c|0)==1){c=Sa(54920,89088,89064,0)|0;c:{d:{e:{d=O()|0;if((d|0)==(ea(54920)|0)){c=Z(c|0)|0;v[22692]=0;Q(1901,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;Q(1901,a|0,14837)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;Q(1901,a|0,14813)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22692]=0;Q(1901,a|0,(b?b:18699)|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(89088)|0)==(d|0)){c=Z(c|0)|0;v[22692]=0;Q(1901,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;Q(1901,a|0,14837)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;Q(1901,a|0,14788)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22692]=0;Q(1901,a|0,(b?b:18699)|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(89064)|0;c=Z(c|0)|0;g:{if((d|0)==(e|0)){v[22692]=0;Q(1901,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;Q(1901,a|0,14837)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;Q(1901,a|0,14804)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22692]=0;Q(1901,a|0,(b?b:18699)|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22692]=0;Q(1901,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;Q(1901,a|0,14837)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;Q(1901,a|0,10988)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Bb()}L()}return}vb(a);S(b|0);L()}function qpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=gb-1120|0;gb=d;v[d+1116>>2]=c;j=eD(d+56|0,b);v[22692]=0;p=hp(j);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){f=mc(a);v[22692]=0;a=T(465,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break h}v[d+16>>2]=a;v[22692]=0;v[d+48>>2]=85899345;a=Fb(d+16|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break g}a=v[a>>2];v[22692]=0;v[d+32>>2]=B(a,50);a=Fb(d+1116|0,d+32|0);c=v[22692];v[22692]=0;if((c|0)==1){break g}a=v[a>>2];v[22692]=0;R(497,f|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}v[22692]=0;e=T(510,d+32|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}c=0;v[22692]=0;g=Q(511,d+16|0,8192)|0;a=v[22692];v[22692]=0;if((a|0)==1){break e}while(1){s=Lb(e,c),z=8192,u[s>>1]=z;s=Lb(e,c),z=c,t[s+2|0]=z;c=c+1|0;if((c|0)!=256){continue}break}m=9;break d}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}i:{j:while(1){a=0;n=257;while(1){q=m&255;k:{while(1){i=n&65535;while(1){v[22692]=0;h=Q(198,j|0,q|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break i}k=h&65535;if((k|0)==257|i>>>0<k>>>0){break k}if(pc(f)>>>0>=y[d+1116>>2]){break k}if((k|0)==256){m=9;continue j}c=i>>>0>k>>>0?h:a;l=8192;while(1){c=c&65535;r=w[Lb(e,c)+2|0];l=l-1|0;o=l&65535;s=kc(g,o),z=r,t[s|0]=z;c=x[Lb(e,c)>>1];if(c>>>0<8192){continue}break}s=d,z=Zb(f),v[s+48>>2]=z;Hd(d+8|0,d+48|0);s=d,z=Vb(g),v[s>>2]=z;c=ve(d,o);l=Zb(g);v[22692]=0;Y(498,f|0,v[d+8>>2],c|0,l|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}l:{if((i|0)!=(k|0)){break l}c=kc(g,o);v[22692]=0;R(512,f|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break l}break i}if(i>>>0>=8192){a=h;continue}if(pc(f)>>>0>=y[d+1116>>2]){continue}break}c=kc(g,o);s=Lb(e,i),z=w[c|0],t[s+2|0]=z;s=Lb(e,i),z=a,u[s>>1]=z;c=n+1|0;n=8192;a=h;h=c&65535;if((h|0)==8192){continue}break}m=((h|0)==1<<q)+m|0;n=c;continue}break}break}v[22692]=0;a=hp(j);c=v[22692];v[22692]=0;m:{if((c|0)!=1){v[22692]=0;Q(188,b|0,((a-p|0)+3&-4)+p|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break m}}break i}gc(g);$C(e);xb(j);gb=d+1120|0;return}c=P()|0;O()|0;gc(g)}$C(e)}gc(f)}xb(j);S(c|0);L()}function uu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-48|0;gb=f;v[f+32>>2]=c;u[f+38>>1]=b;g=LA(a);a:{if(sc(g)>>>0<=b>>>0){break a}if(uR(a,x[rc(g,b)>>1])>>>0<=c>>>0){break a}b:{if(Ec(a)>>>0>b>>>0){if(y[Ad(a,b)+4>>2]>c>>>0){break b}}Co(a,0);if(Ec(a)>>>0<=b>>>0){break a}}c=x[v[a+24>>2]+480188>>1];b=v[d>>2];v[f+16>>2]=b;v[f+20>>2]=b+B(c,872);d=f+24|0;b=d;v[b>>2]=-2078137563;v[b+4>>2]=-873292572;g=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;c=f+16|0;if(wR(c)){while(1){b=w[KT(c,h)+841|0];k=b^jqa(g^h,e^j,435,256);b=!b;g=(o=g,p=jqa(k,jb,435,256),q=b,q?o:p);e=b?e:jb;b=h+1|0;j=b>>>0<1?j+1|0:j;h=b;if(!j&wR(c)>>>0>b>>>0){continue}break}}v[d>>2]=g;v[d+4>>2]=e;j=Nm(f+16|0,f+38|0,f+32|0);e=gb-16|0;gb=e;c=e+8|0;h=gb-16|0;gb=h;k=a+12|0;g=k;b=Yd(g);b=dR(g,j,b,fc(g));v[h+8>>2]=b;o=h,p=zh(g),v[o>>2]=p;c:{if(Rl(h+8|0,h)){if(!Fl(wb(g),j,te(h+8|0))){break c}}b=zh(g)}gb=h+16|0;b=v[yc(c,b)>>2];gb=e+16|0;v[f+8>>2]=b;o=f,p=Ah(k),v[o+16>>2]=p;b=0;if(mg(f+8|0,f+16|0)){b=bd(te(f+8|0)+8|0)^1}m=v[d>>2]!=-2078137563|v[d+4>>2]!=-873292572;pe(f+16|0,Ad(a,x[f+38>>1]),v[f+32>>2]);n=1;g=b|m;j=Cb(f+16|0)^1;if(!(j?1:g)){break a}if(b){h=te(f+8|0)+8|0;l=Vb(h);e=Zb(h);c=d;i=gb-16|0;gb=i;v[i>>2]=e;v[i+8>>2]=l;if(Gb(i+8|0,i)){while(1){e=v[i+8>>2];if(v[e>>2]!=v[c>>2]|v[e+4>>2]!=v[c+4>>2]){vu(i+8|0);if(Gb(i+8|0,i)){continue}}break}l=v[i+8>>2]}gb=i+16|0;v[f+16>>2]=l;o=f,p=Zb(h),v[o+40>>2]=p;if(Gb(f+16|0,f+40|0)){break a}}if(m){v[a+28>>2]=v[a+28>>2]+1}if(g){if(!(b|j)){d:{e=nR(k,Nm(f+16|0,f+38|0,f+32|0));if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=$Q(b,e);wb(e);_Q(v[c+4>>2]);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break d}c=gb-32|0;gb=c;b=wb(e);b=KA(c+8|0,fs(e,qf(e)+1|0),qf(e),b);_Q(v[b+8>>2]);v[b+8>>2]=v[b+8>>2]+8;JA(e,b);IA(b);gb=c+32|0}}e=nR(k,Nm(f+16|0,f+38|0,f+32|0));e:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=$Q(b,e);wb(e);ZQ(v[c+4>>2],d);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break e}c=gb-32|0;gb=c;b=wb(e);b=KA(c+8|0,fs(e,qf(e)+1|0),qf(e),b);ZQ(v[b+8>>2],d);v[b+8>>2]=v[b+8>>2]+8;JA(e,b);IA(b);gb=c+32|0}}pe(f+16|0,Ad(a,x[f+38>>1]),v[f+32>>2]);Af(f+16|0,1);n=0}gb=f+48|0;return n|0}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=gb-112|0;gb=c;e=gb-32|0;gb=e;h=b+16|0;AW(e+24|0,h);f=yb(e+24|0);d=v[e+28>>2];g=v[e+24>>2];v[e+8>>2]=g;v[e+12>>2]=d;v[e>>2]=g;v[e+4>>2]=d;d=a;cc(e+16|0,a,e);g=yb(e+16|0);if((f|0)==(g|0)){Rb(d,yb(e+24|0))}gb=e+32|0;if((f|0)!=(g|0)){Qb(h,0,128)}bX(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;ud(c- -64|0,a,qg(a));e=jc(c+88|0,c- -64|0);xb(c- -64|0);v[22692]=0;d=T(465,e|0)|0;f=v[22692];v[22692]=0;a:{b:{if((f|0)==1){break b}v[22692]=0;f=b+4|0;R(440,f|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;Vd(c+56|0,f);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;d=v[c+60>>2];v[c>>2]=v[c+56>>2];v[c+4>>2]=d;U(629,c- -64|0,e|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;d=T(190,a|0)|0;f=v[22692];v[22692]=0;c:{if((f|0)==1){break c}v[22692]=0;U(288,c+32|0,a|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}d=jc(c- -64|0,c+32|0);xb(c+32|0);v[22692]=0;a=T(275,d|0)|0;f=v[22692];v[22692]=0;d:{if((f|0)!=1){e:{f:{g:{if(!a){break g}while(1){v[22692]=0;a=Q(189,d|0,5)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}if(!a){break g}v[22692]=0;Q(630,d|0,c+28|0)|0;a=v[22692];v[22692]=0;h:{if((a|0)!=1){a=4;if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1414682436|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1196380752){break h}v[22692]=0;a=T(190,d|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22692]=0;U(288,c+8|0,d|0,a|0);a=v[22692];v[22692]=0;i:{j:{if((a|0)!=1){a=jc(c+32|0,c+8|0);xb(c+8|0);if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1414682436){break j}v[22692]=0;i=C(Ba(631,a|0));a=v[22692];v[22692]=0;if((a|0)==1){break e}z[b+144>>2]=i;break i}a=P()|0;O()|0;break d}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1196380752){break i}v[22692]=0;a=T(190,a|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break e}v[b+148>>2]=a}xb(c+32|0);continue}}xb(d);xb(e);gb=c+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0;xb(c+32|0);break d}a=P()|0;O()|0}xb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(e);S(a|0);L()}function N9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{k=Rp(1,32);d:{e:{if(!k){a=ba(4)|0;gm(a);v[22692]=0;U(184,a|0,89088,1912);a=v[22692];v[22692]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1903;d=tu(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22692]=0;c=Q(70,j+48|0,c|0)|0;f=v[22692];v[22692]=0;i:{if((f|0)!=1){v[22692]=0;f=Q(1913,d|0,c|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break i}v[22692]=0;Q(415,f|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22692]=0;c=Q(70,j+48|0,c|0)|0;e=v[22692];v[22692]=0;j:{if((e|0)!=1){v[22692]=0;R(1914,d|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22692]=0;a=T(1276,96)|0;i=v[22692];v[22692]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22692]=0;b=Q(1915,k|0,k+4|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break m}v[j+48>>2]=b;b=v[eq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22692]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ca(1989,a|0,j+8|0,b|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break l}v[k+28>>2]=a;zj(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Dl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;zj(j+48|0)}Xb(a)}Dl(d);Z(i|0)|0;v[22692]=0;Y(1895,8584,k|0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){a=v[k+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break b}}Z(i|0)|0;k=0;v[22692]=0;Y(1895,8584,0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=j+80|0;return k|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=d;k=dg(a,c);re(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(ld(a,5)){break a}}f=v[h+24>>2];d=gb-160|0;gb=d;i=Am(d+56|0,v[a+28>>2]);v[22692]=0;g=Q(616,d+40|0,34088)|0;e=v[22692];v[22692]=0;b:{c:{d:{e:{if((e|0)!=1){v[22692]=0;v[d+24>>2]=19923014;v[d+28>>2]=0;U(617,i|0,g|0,d+24|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}Hb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}t[d+39|0]=0;v[22692]=0;g=Q(616,d+40|0,2597)|0;e=v[22692];v[22692]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[22692]=0;W(618,i|0,d+39|0,g|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break q}Hb(g);g=Kb(d+40|0);v[22692]=0;e=Q(616,d+24|0,7318)|0;j=v[22692];v[22692]=0;if((j|0)==1){break p}v[22692]=0;U(1080,i|0,g|0,e|0);j=v[22692];v[22692]=0;if((j|0)==1){break o}Hb(e);v[22692]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break n}v[22692]=0;R(418,b|0,d+24|0);e=v[22692];v[22692]=0;if((e|0)==1){break m}vb(d+24|0);u[d+22>>1]=0;v[22692]=0;e=Q(616,d+24|0,7995)|0;f=v[22692];v[22692]=0;if((f|0)==1){break g}v[22692]=0;W(1081,i|0,d+22|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break l}Hb(e);wg(d+22|0,4e3);v[22692]=0;e=Q(616,d+24|0,10697)|0;f=v[22692];v[22692]=0;if((f|0)==1){break k}f=v[yc(d+16|0,x[d+22>>1])>>2];v[22692]=0;Y(1082,i|0,b|0,e|0,f|0);f=v[22692];v[22692]=0;if((f|0)==1){break j}Hb(e);u[d+14>>1]=65535;v[22692]=0;e=Q(616,d+24|0,6080)|0;f=v[22692];v[22692]=0;if((f|0)==1){break i}v[22692]=0;f=W(1081,i|0,d+14|0,e|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Hb(e);if(!((f|0)==1|j>>>0<=l>>>0)){bf(b,x[d+14>>1])}vb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+24|0);break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0}vb(g)}dh(i);S(a|0);L()}dh(i);gb=d+160|0}Wf(a,k,c,h+16|0);gb=h+32|0}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=C(0),k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,t=0,u=0,x=C(0),y=0,A=0,B=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=C(0);a:{if(!v[a+4316>>2]){break a}k=a+44|0;if(!ki(k)){break a}p=Od(k,0);q=Od(k,1);r=md(k,0);s=md(k,1);H=kb[v[v[a>>2]+192>>2]](a)|0;e=C(kb[v[v[a>>2]+200>>2]](a));B=C(kb[v[v[a>>2]+188>>2]](a));t=kb[v[v[a>>2]+212>>2]](a)|0;b:{if(!d){break b}u=a+4276|0;l=a+4264|0;h=w[a+4260|0];E=h?u:l;F=a+4300|0;G=a+4288|0;x=C(e*C(.009999999776482582));I=t&1;m=v[a+4256>>2];n=v[a+4312>>2];y=d;while(1){j=z[q>>2];i=z[p>>2];f=jo(a,m+n|0);m=jo(a,n);c:{if(h){n=v[a+4328>>2];J=Ri(G,n),K=i,z[J>>2]=K;J=Ri(F,n),K=j,z[J>>2]=K;e=z[Lb(l,f)>>2];J=Lb(l,m),K=C(C(e*x)+i),z[J>>2]=K;e=C(C(z[Lb(u,f)>>2]*x)+j);h=u;break c}e=C(C(z[Lb(l,f)>>2]*x)+C(C(j+i)*C(.5)));h=l}J=Lb(h,m),K=e,z[J>>2]=K;d:{if(H){g=z[a+4244>>2];e=C(z[a+4236>>2]+g);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(g<=C(1))){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break d}g=z[a+4244>>2];o=z[a+4240>>2];e=C(C(g*o)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(o-C(e*g));z[a+4240>>2]=g}if(w[a+4260|0]){f=(v[a+4328>>2]+2|0)%3|0;i=z[Ri(G,f)>>2];j=z[Ri(F,f)>>2]}o=z[Lb(l,jo(a,v[a+4320>>2]+v[a+4312>>2]|0))>>2];J=r,K=C(C(C(C(o-i)+C(C(C(z[Lb(l,jo(a,(v[a+4312>>2]+v[a+4320>>2]|0)+4096|0))>>2]-o)*C(.000244140625))*C(v[a+4320>>2]&4095)))*B)+i),z[J>>2]=K;i=z[Lb(E,jo(a,v[a+4324>>2]+v[a+4312>>2]|0))>>2];J=s,K=C(C(C(C(i-j)+C(C(C(z[Lb(E,jo(a,(v[a+4312>>2]+v[a+4324>>2]|0)+4096|0))>>2]-i)*C(.000244140625))*C(v[a+4324>>2]&4095)))*B)+j),z[J>>2]=K;f=v[a+4328>>2];v[a+4328>>2]=((f|0)<1?f+3|0:f)-1;f=v[a+4312>>2];n=(((f|0)>0?0:v[a+4316>>2]<<12)+f|0)-4096|0;v[a+4312>>2]=n;A=a;m=v[a+4256>>2];f=m;j=z[a+4248>>2];i=C(j*(I?g:e));e:{if(C(D(i))<C(2147483648)){h=~~i;break e}h=-2147483648}v[A+4324>>2]=f+(t>>>0>1?h:0-h|0);f=t>>>0<4;A=a;e=C(j*e);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[A+4320>>2]=(f?h:0-h|0)+m;y=y-1|0;if(!y){break b}q=q+4|0;p=p+4|0;r=r+4|0;s=s+4|0;h=w[a+4260|0];continue}}Ei(a,b,c,md(k,0),md(k,1),d)}}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=jg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Kd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=gg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Mb(q,-16777216,16776704);p=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=jqa(l,s,f,f>>31);l=jb;p=jqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Ly(a){a=a|0;var b=0,c=0,d=C(0),e=0;Qb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22692]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ha(1822,e|0,67,5,c|0,b|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22692]=0;ha(1822,a+4528|0,62,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22692]=0;ha(1822,a+4552|0,53,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22692]=0;ha(1822,a+4576|0,43,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22692]=0;ha(1822,a+4600|0,32,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22692]=0;ha(1822,a+4624|0,22,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22692]=0;ha(1822,a+4648|0,75,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22692]=0;ha(1822,a+4672|0,69,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22692]=0;ha(1822,a+4696|0,60,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22692]=0;ha(1822,a+4720|0,48,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22692]=0;ha(1822,a+4744|0,36,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22692]=0;ha(1822,a+4768|0,25,5,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;ha(1822,a+4792|0,0,0,0,0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22692]=0;ha(1822,a+4816|0,3,0,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22692]=0;ha(1822,a+4840|0,3,0,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;ha(1822,a+4864|0,407,1,c|0,0);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;ha(1822,a+4888|0,400,1,c|0,0);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;ha(1822,a+4912|0,10,0,c|0,-1);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;ha(1822,a+4936|0,10,0,c|0,-1);c=v[22692];v[22692]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(89088)|0;if((O()|0)==(ea(89088)|0)){Z(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function DE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=gb-128|0;gb=j;a:{b:{c:{if(!ln(f,g,h,i,0,0,0,0)){break c}m=f;n=g;l=h;o=i&65535;k=i>>>16&32767;d:{e:{if((k|0)!=32767){p=4;if(k){break e}m=l|m|(n|o)?3:2;break d}p=!(l|m|(n|o))}m=p}if(!m){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}Fd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];XE(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=o<<16;p=d;q=l|e&65535;m=q;n=h;q=i>>>16&32767;k=i&65535|q<<16;if((ln(b,c,p,m,f,g,h,k)|0)<=0){if(ln(b,c,p,m,f,g,n,k)){h=b;i=c;break a}Fd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Fd(j+96|0,b,c,p,m,0,0,0,1081540608);h=v[j+108>>2];m=h;p=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Fd(j+80|0,f,g,n,k,0,0,0,1081540608);f=v[j+92>>2];k=f;n=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((o|0)>(q|0)){while(1){k=p;l=n;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0?1:(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){Fd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;p=k<<1|i>>>31;break f}l=m<<1|p>>>31;p=p<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}l=p;q=l-n|0;n=m-((l>>>0<n>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=n-(l>>>0>q>>>0)|0;n=q-l|0;g:{if((k|0)<0){n=p;k=m;break g}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|n|(i|k)){break g}Fd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=n;k=k<<1|b>>>31;n=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Fd(j- -64|0,h,i,n,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=n;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;gb=j+128|0}function Cm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;a:{b:{if(bd(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=Ji(a)>>>0;f=x[b+8>>1];if((f|0)!=65535?c:0){break b}g=f;if((g&65535)==65535){f=Ji(a)-1|0;g=0}e=Wc(a,v[b+4>>2],g&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=f&65535;if(l>>>0<(g&65535)>>>0){break d}j=w[b+10|0];c=g;d=e;while(1){e:{if(!k){if((j|0)!=w[d+3|0]){break e}break c}if((j|0)==w[d+2|0]){break c}}d=d+6|0;c=c+1|0;if((c&65535)>>>0<=l>>>0){continue}break}}j=f&65535;if(j>>>0>=(g&65535)>>>0){c=g;d=e;while(1){f:{if(!k){if(w[d+3|0]){break f}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break c}if(w[d+2|0]){break f}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break c}d=d+6|0;c=c+1|0;if(j>>>0>=(c&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[lo(a)+480180>>2]&2;c=w[b+12|0];h:{if(c&4){break h}d=f&65535;if(d>>>0<(g&65535)>>>0){break h}while(1){i:{j:{switch(w[e+3|0]-9|0){case 4:if(!mz(v[lo(a)+8>>2],1)){break i}d=1;t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+3|0]=w[b+10|0];t[e+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(i){c=w[e+5|0];if(c>>>0>128){break i}t[e+2|0]=2;t[e+3|0]=w[b+10|0];a=1;break k}t[e+2|0]=2;t[e+3|0]=w[b+10|0];c=w[e+5|0];a=2}t[e+4|0]=a+(c&255)>>>a;t[e+5|0]=w[b+11|0];break c}e=e+6|0;g=g+1|0;if(d>>>0>=(g&65535)>>>0){continue}break}c=w[b+12|0]}g=b;l:{m:{if(c&4){d=w[b+11|0];e=13;n:{switch(w[b+10|0]-1|0){case 1:d=_l(B(i?2:4,d));c=w[b+12|0];e=9;break;case 0:break n;default:break l}}t[b+11|0]=d;t[b+10|0]=e;c=c&254;break m}f=w[b+11|0];t[h+14|0]=f;e=b;d=w[b+10|0];o:{if(!(!i|(d|0)!=9)){if(f>>>0>128){break l}d=2;f=(f&254)>>>1|0;break o}t[h+15|0]=d;p:{if(iz(h+15|0,h+14|0,1)){d=w[h+15|0];if(d){break p}}c=w[b+12|0];break l}c=w[b+12|0];f=w[h+14|0]}t[e+11|0]=f;t[b+10|0]=d;c=c&254}t[g+12|0]=c}d=1;if(c&1){break g}t[b+12|0]=c^4;if(Cm(a,b)){break a}}q:{r:{c=v[b>>2];if((c|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){break r}c=v[b>>2]}if((c|0)!=2){break b}d=0;c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1;break q}v[b+4>>2]=v[b+4>>2]+1}t[b+12|0]=w[b+12|0]|1;d=Cm(a,b);break a}d=1;break a}d=0}gb=h+16|0;return d|0}function AL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{d:{e:{f:{k=Rp(1,28);if(!k){a=ba(4)|0;gm(a);v[22692]=0;U(184,a|0,89088,1912);a=v[22692];v[22692]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1903;d=tu(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22692]=0;c=Q(70,j+48|0,c|0)|0;f=v[22692];v[22692]=0;j:{if((f|0)!=1){v[22692]=0;f=Q(1913,d|0,c|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break j}v[22692]=0;Q(415,f|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22692]=0;c=Q(70,j+48|0,c|0)|0;e=v[22692];v[22692]=0;k:{if((e|0)!=1){v[22692]=0;R(1914,d|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22692]=0;a=T(1276,80)|0;i=v[22692];v[22692]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22692]=0;b=Q(1915,k|0,k+4|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[eq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22692]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ca(1916,a|0,j+8|0,b|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break m}v[k+24>>2]=a;zj(j+48|0);Dl(d);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;zj(j+48|0)}Xb(a)}Dl(d);Z(i|0)|0;v[22692]=0;Y(1895,12270,k|0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Xb(Bt(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);break d}i=V(0)|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22692]=0;Y(1895,12270,0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=j+80|0;return i|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;a:{b:{c:{h=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?h>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?h>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?h>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?h>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=h;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(j>>>16&65520)+r|0;j=u[e+14>>1];h=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];p=u[e+6>>1];t=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];i=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],w)+B(u[b+(e|-12)>>1],x)|0)+B(u[b+(e|-4)>>1],t)|0)+B(u[b+e>>1],p)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(h,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(i<<2)|0;j=v[k>>2];h=v[a+60>>2];l=h;e=(g+32|0)+(i<<3)|0;q=v[e>>2];b=Mb(q,-16777216,16776704);i=v[a+64>>2];f=Mb(v[e+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=jqa(l,p,h,h>>31);l=jb;p=h;h=jqa(i,i>>31,b,b>>31);i=p+h|0;b=jb+l|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=v[a+68>>2];i=jqa(i,i>>31,f,f>>31);f=h+i|0;b=jb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Jc(f,b,24);v[e+4>>2]=q;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[e>>2]=b-(f&j);i=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=g+48|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=jg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=(((i&2147483647)<<1|g>>>31)&-2)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Kd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Jd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=gg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Mb(q,-16777216,16776704);p=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=jqa(l,s,f,f>>31);l=jb;p=jqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function _h(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;a:{if(!Nd(a)){break a}rk(a);if(c){c=b;n=gb-16|0;gb=n;f=a;if(Nd(a)){e=x[f+34>>1];o=v[f+4>>2];h=v[f+8>>2];m=v[f>>2];r=!(e&2)|(o>>>0>=h>>>0|h>>>0>m>>>0);p=v[f+12>>2];g=v[f+16>>2];s=!(e&8)|(p>>>0>=g>>>0|g>>>0>m>>>0);z=c+1298224|0;d=c+1074992|0;j=e&4;l=e&16;while(1){b:{if((f|0)!=v[d+104>>2]){break b}c=v[d+76>>2];if(!c){break b}c:{d:{i=d;e:{f:{if(s){break f}k=v[d+88>>2];if(k&2048){break f}v[d+84>>2]=g;v[d+80>>2]=p;e=l;c=g;break e}if(r){break d}v[d+84>>2]=h;v[d+80>>2]=o;k=v[d+88>>2];e=j;c=h}v[i+76>>2]=c;i=k|2;q=d+88|0;k=(e|0)!=0;e=1;break c}q=d+88|0;i=v[d+88>>2]&-3;k=0;e=0}i=i&-5|(e?k?4:0:0);v[d+88>>2]=i;if(y[d+4>>2]>c>>>0){i=i&-129;v[d+88>>2]=i;c=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=c}if(!k){v[q>>2]=i&-129}if(e){break b}v[d+76>>2]=m}d=d+872|0;if((z|0)!=(d|0)){continue}break}}gb=n+16|0}if((fj(a)|0)==2){d=0;f=gb+-64|0;gb=f;e=dd(a);h=v[a+20>>2];g=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){j=B(d,e);l=B(e,d^-1);c=0;while(1){u[g+(c+j<<1)>>1]=x[g+(c-e<<1)>>1];u[h+(c+l<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){j=v[a+8>>2];g=v[a+4>>2];Db(f+32|0,b+1074312|0,33);uS(f+40|0,d,h+(B(e,g)<<1)|0,j-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Db(f+32|0,b+1074312|0,33);uS(f+8|0,d+(e<<7)|0,h+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}gb=f- -64|0;return}if((fj(a)|0)!=1){break a}d=0;f=gb+-64|0;gb=f;e=dd(a);h=v[a+20>>2];g=h+B(e,v[a>>2])|0;while(1){if(e){j=B(d,e);l=B(e,d^-1);c=0;while(1){t[g+(c+j|0)|0]=w[g+(c-e|0)|0];t[h+(c+l|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){j=v[a+8>>2];g=v[a+4>>2];Db(f+32|0,b+1074312|0,33);tS(f+40|0,d,h+B(e,g)|0,j-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Db(f+32|0,b+1074312|0,33);tS(f+8|0,d+(e<<6)|0,h+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}gb=f- -64|0}}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;d=gb-48|0;gb=d;e=FR(d+32|0,1<<v[b+12>>2]);if(qf(a)){while(1){f=A[xe(a,c)>>3];ER(Tc(e,c),f);c=c+1|0;if(qf(a)>>>0>c>>>0){continue}break}}v[22692]=0;vz(b,e);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}w=d,x=Vb(e),v[w>>2]=x;w=d,x=Zb(e),v[w+24>>2]=x;if(Gb(d,d+24|0)){while(1){c=v[d>>2];t=c;f=A[c+8>>3];i=gb-32|0;gb=i;o(+A[c>>3]);c=j(1)|0;g=j(0)|0;o(+f);k=j(1)|0;q=j(0)|0;p=c&2147483647;h=p;k=k&2147483647;r=(h|0)==(k|0)&g>>>0<q>>>0|h>>>0<k>>>0;c=r?g:q;h=r?h:k;r=h;l(0,c|0);l(1,h|0);f=+n();h=h>>>20|0;b:{if((h|0)==2047){break b}u=g;g=(k|0)==(p|0)&g>>>0>q>>>0|k>>>0<p>>>0;l(0,(g?u:q)|0);g=g?p:k;l(1,g|0);m=+n();p=!(c|r);c=g>>>20|0;if(!(p|(c|0)==2047)){if((c-h|0)>=65){f=m+f;break b}c:{if(c>>>0>=1534){f=f*1.90109156629516e-211;m=m*1.90109156629516e-211;s=5.260135901548374e210;break c}s=1;if(h>>>0>572){break c}f=f*5.260135901548374e210;m=m*5.260135901548374e210;s=1.90109156629516e-211}LI(i+24|0,i+16|0,m);LI(i+8|0,i,f);f=s*K(A[i>>3]+A[i+16>>3]+A[i+8>>3]+A[i+24>>3]);break b}f=m}gb=i+32|0;ER(t,Op(f));Ro(d);if(Gb(d,d+24|0)){continue}break}}v[22692]=0;tz(b,e);c=v[22692];v[22692]=0;if((c|0)==1){break a}v[22692]=0;sz(e);c=v[22692];v[22692]=0;if((c|0)==1){break a}if(tf(e)>>>0>3){c=1;while(1){NA(Tc(e,c),2);NA(Tc(e,(tf(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<tf(e)>>>1>>>0){continue}break}}v[22692]=0;vz(b,e);c=v[22692];v[22692]=0;if((c|0)==1){break a}w=d,x=Vb(e),v[w+24>>2]=x;w=d,x=Zb(e),v[w+16>>2]=x;d:{if(Gb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[22692]=0;MA(d,c);g=v[22692];v[22692]=0;if((g|0)==1){break d}g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;Ro(d+24|0);if(Gb(d+24|0,d+16|0)){continue}break}}v[22692]=0;tz(b,e);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;sz(e);b=v[22692];v[22692]=0;if((b|0)==1){break a}if(qf(a)){c=0;while(1){f=A[Tc(e,c)>>3];w=xe(a,c),y=f,A[w>>3]=y;c=c+1|0;if(qf(a)>>>0>c>>>0){continue}break}}Jq(e);gb=d+48|0;return}}a=P()|0;O()|0;Jq(e);S(a|0);L()}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];h=v[a+44>>2];v[f+32>>2]=h;m=v[a+48>>2];v[f+36>>2]=m;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){i=(((i&2147483647)<<1|j>>>31)&-2)+s|0;b=(j>>>16&65520)+r|0;e=u[b+14>>1];j=u[b+12>>1];g=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];p=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];h=0;m=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[i+(b|-4)|0],w)+B(t[i+(b|-6)|0],x)|0)+B(t[i+(b|-2)|0],p)|0)+B(t[b+i|0],q)|0)+B(t[i+(b|2)|0],l)|0)+B(t[i+(b|4)|0],g)|0)+B(j,t[i+(b|6)|0])|0)+B(e,t[i+(b|8)|0])<<8)/32768;y=k&1;k=0;b=1;if(y){continue}break}while(1){k=(f+8|0)+(h<<2)|0;j=v[k>>2];g=v[a+60>>2];l=g;i=(f+32|0)+(h<<3)|0;q=v[i>>2];b=Mb(q,-16777216,16776704);h=v[a+64>>2];e=Mb(v[i+4>>2],-16777216,16776704);p=g>>31;j=j<<8;g=j;g=jqa(l,p,g,g>>31);l=jb;p=g;g=jqa(h,h>>31,b,b>>31);h=p+g|0;b=jb+l|0;b=h>>>0<g>>>0?b+1|0:b;g=h;h=v[a+68>>2];h=jqa(h,h>>31,e,e>>31);e=g+h|0;b=jb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Jc(e,b,24);v[i+4>>2]=q;e=v[a+72>>2];v[k>>2]=(b|0)/256;v[i>>2]=b-(e&j);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;e=o>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];i=v[f+28>>2];continue}break}j=v[f+24>>2];i=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];m=v[f+36>>2];h=v[f+32>>2];break e}b=n>>12;e=o>>12}v[a+40>>2]=n;v[a+20>>2]=e;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=i;gb=f+48|0}function tz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c=gb-208|0;gb=c;i=1;j=v[a+12>>2];k=1<<j;l=2;g=j;if(g>>>0>=2){f=k;while(1){h=f>>>2|0;if(f>>>0>=4){q=B(i,3);r=i<<1;s=h>>>0>1?h:1;g=0;while(1){UN(c+192|0,Tc(a,g<<1));UN(c+176|0,Tc(a,g));Li(c+160|0,c+176|0,c+192|0);f=g<<l;p=i+f|0;if(f>>>0<p>>>0){while(1){d=Tc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;m=f+i|0;d=Tc(b,m);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;n=f+r|0;d=Tc(b,n);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;o=f+q|0;d=Tc(b,o);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;yl(c+80|0,c+144|0,c+128|0);Bj(c- -64|0,c+144|0,c+128|0);yl(c+48|0,c+112|0,c+96|0);Bj(c+16|0,c+112|0,c+96|0);Li(c+32|0,48192,c+16|0);yl(c+16|0,c+80|0,c+48|0);d=Tc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;yl(c,c- -64|0,c+32|0);Li(c+16|0,c+192|0,c);m=Tc(b,m);d=m;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Bj(c,c+80|0,c+48|0);Li(c+16|0,c+176|0,c);n=Tc(b,n);d=n;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Bj(c,c- -64|0,c+32|0);Li(c+16|0,c+160|0,c);o=Tc(b,o);d=o;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((p|0)!=(f|0)){continue}break}}g=g+1|0;if((s|0)!=(g|0)){continue}break}g=v[a+12>>2]}i=i<<2;f=h;l=l+2|0;if(l>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!j)){g=k>>>1|0;j=g>>>0>1?g:1;f=0;while(1){k=f+g|0;h=Tc(b,k);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;Bj(c+176|0,Tc(b,f),c+192|0);h=Tc(b,k);a=v[c+188>>2];v[h+8>>2]=v[c+184>>2];v[h+12>>2]=a;a=v[c+180>>2];v[h>>2]=v[c+176>>2];v[h+4>>2]=a;uz(Tc(b,f),c+192|0);f=f+1|0;if((j|0)!=(f|0)){continue}break}}gb=c+208|0}function Il(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22692]=0;R(60,a|0,d|0);d=v[22692];v[22692]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=v[sk(c,b)>>2];f:{if(d>>>0<=127){v[22692]=0;R(61,a|0,d<<24>>24);d=v[22692];v[22692]=0;if((d|0)!=1){break f}break e}v[22692]=0;R(61,a|0,63);d=v[22692];v[22692]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22692]=0;R(60,a|0,d|0);d=v[22692];v[22692]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=v[sk(c,b)>>2];i:{if(d>>>0<=255){v[22692]=0;R(61,a|0,d<<24>>24);d=v[22692];v[22692]=0;if((d|0)!=1){break i}break h}v[22692]=0;R(61,a|0,63);d=v[22692];v[22692]=0;if((d|0)==1){break h}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Uq(a,c,20880);return;case 5:Uq(a,c,21904);return;case 4:Uq(a,c,22928);return;case 6:Uq(a,c,23952);return;default:a=ba(8)|0;v[22692]=0;Q(59,a|0,8253)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;da(a|0);S(b|0);L();case 0:break c}}e=gb-16|0;gb=e;f=Kb(a);j:{k:{if(Ab(c)){while(1){a=v[sk(c,h)>>2];l:{if(a>>>0>=2097152){v[22692]=0;R(61,f|0,63);a=v[22692];v[22692]=0;if((a|0)!=1){break l}break k}d=0;m:{n:{while(1){g=a&63;t[(e+10|0)+d|0]=g;if(a>>>0<64){break n}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break m}o:{if(!d){v[22692]=0;R(61,f|0,t[e+10|0]);break o}b=d+1|0;if((b|0)!=2){break m}d=1;b=2;if((g|0)!=1){break m}v[22692]=0;R(61,f|0,t[e+10|0]|64)}a=v[22692];v[22692]=0;if((a|0)!=1){break l}break k}g=(-1<<b^-1)<<7-d;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){p:{if((a|0)==(b|0)){a=w[j|0];v[22692]=0;R(61,f|0,(a|g)<<24>>24);i=v[22692];v[22692]=0;a=d;if((i|0)!=1){break p}break k}v[22692]=0;a=a-1|0;R(61,f|0,t[a+(e+10|0)|0]|-128);i=v[22692];v[22692]=0;if((i|0)==1){break k}}if(a){continue}break}}h=h+1|0;if(Ab(c)>>>0>h>>>0){continue}break}}gb=e+16|0;break j}a=P()|0;O()|0;vb(f);S(a|0);L()}return}ia(a|0,89208,24);L()}b=P()|0;O()|0;vb(a);S(b|0);L()}function t2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-1072|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+956>>2]=a+960;j=Nx(a+960|0,100,8299,a+16|0);v[a+48>>2]=2440;o=he(a+536|0,0,a+48|0);v[a+48>>2]=2440;m=he(a+528|0,0,a+48|0);l=a+544|0;a:{b:{c:{if(j>>>0>=100){v[22692]=0;j=ga(2460)|0;l=v[22692];v[22692]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22692]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ca(2479,a+956|0,j|0,8299,a|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if((j|0)==-1){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+956>>2]);Ee(m,Cd(j<<2));if(qk(m)){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[22692]=0;Fc(a+520|0,d);f=v[22692];v[22692]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22692]=0;q=T(2464,a+520|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break j}v[22692]=0;f=v[a+956>>2];Y(2476,q|0,f|0,f+j|0,l|0);f=v[22692];v[22692]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+956>>2]]==45:p;h=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[22692]=0;na(2508,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,f|0,g|0,a+452|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}v[a+36>>2]=2440;c=he(a+40|0,0,a+36|0);i=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){k=(Ab(g)+(j-n<<1|1)|0)+Ab(f)|0;break k}k=(Ab(g)+Ab(f)|0)+2|0}k=k+n|0;if(k>>>0<101){break h}Ee(c,Cd(k<<2));i=v[c>>2];if(i){break h}v[22692]=0;X(2441);b=v[22692];v[22692]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[22692]=0;qa(2509,i|0,a+36|0,a+32|0,k|0,l|0,(j<<2)+l|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,f|0,g|0,n|0);j=v[22692];v[22692]=0;if((j|0)!=1){v[22692]=0;b=la(2489,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}Ic(g);Ic(f);vb(h)}Wb(a+520|0);break a}Hc(c);Ic(g);Ic(f);vb(h);Wb(a+520|0);Hc(m);Hc(o);gb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Hc(m);Hc(o);S(j|0);L()}function rx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[22597]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Mf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}h=e+1|0;f=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}h=e+2|0;f=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76784>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76784>>2];f=1;continue}h=w[e|0];f=h>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{i=e+1|0;f=h-128|g<<6;h=i;v:{if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=e+2|0;f=h|f<<6;h=i;if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[115173]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[115173]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function _z(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-160|0;gb=h;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!c){break i}d=v[c+4>>2];if(!d&y[c>>2]>=yb(b)>>>0|d){break i}b=ba(8)|0;v[22692]=0;Q(126,b|0,18699)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break h}a=P()|0;O()|0;da(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[22692]=0;T(1278,b|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break g}a=P()|0;O()|0;da(b|0);break a}d=v[b+4>>2];g=v[b>>2];v[h>>2]=g;v[h+4>>2]=d;v[h+128>>2]=g;v[h+132>>2]=d;g=gb-16|0;gb=g;d=v[h+4>>2];e=v[h>>2];v[g>>2]=e;v[g+4>>2]=d;v[g+8>>2]=e;v[g+12>>2]=d;d=gb-32|0;gb=d;e=v[g+4>>2];f=v[g>>2];v[d+8>>2]=f;v[d+12>>2]=e;v[d+16>>2]=f;v[d+20>>2]=e;Sh(d+24|0,d+8|0);e=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=e;e=gb-16|0;gb=e;f=v[d+4>>2];i=v[d>>2];v[e>>2]=i;v[e+4>>2]=f;v[e+8>>2]=i;v[e+12>>2]=f;f=gb-16|0;gb=f;i=v[e+4>>2];k=v[e>>2];v[f>>2]=k;v[f+4>>2]=i;v[f+8>>2]=k;v[f+12>>2]=i;i=h+136|0;SF(i,f);gb=f+16|0;gb=e+16|0;v[i+12>>2]=0;gb=d+32|0;gb=g+16|0;j:{k:{if(a&2){d=Cn(h+104|0,i);v[22692]=0;g=Q(1279,d|0,c|0)|0;e=v[22692];v[22692]=0;d=1;if((e|0)==1){break j}if((g|0)==1){break k}e=Cn(h+80|0,i);v[22692]=0;e=Q(1280,e|0,c|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break f}k=(e|0)==1;if(k){break k}f=Cn(h+56|0,i);v[22692]=0;f=Q(1281,f|0,c|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break e}l=(f|0)==1;if(l){break k}j=Cn(h+32|0,i);v[22692]=0;j=Q(1282,j|0,c|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break d}if((j|0)==1){break k}d=(g|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(j|0)==-1?-1:l?d:(f|0)==-1?-1:d}if(a&1){a=37808;while(1){d=v[a>>2];if(d){g=Cn(h+8|0,i);v[22692]=0;g=Q(d|0,g|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}d=1;if((g|0)==1){break k}j=(g|0)==-1?-1:j}a=a+12|0;if((a|0)!=38312){continue}break}}if(c){d=0;if((j|0)!=-1){break k}d=Qc(v[c>>2],v[c+4>>2])>>>0>yb(b)>>>0?-1:0;break k}d=0;if((j|0)!=-1){break k}d=yb(b)>>>0>2047?1:-1}gb=h+160|0;return d}a=P()|0;break b}ia(b|0,89368,24);L()}ia(b|0,89264,24);L()}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0}O()|0}S(a|0);L()}function y2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-464|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+348>>2]=a+352;j=Nx(a+352|0,100,8299,a+16|0);v[a+48>>2]=2440;o=he(a+232|0,0,a+48|0);v[a+48>>2]=2440;m=he(a+224|0,0,a+48|0);l=a+240|0;a:{b:{c:{if(j>>>0>=100){v[22692]=0;j=ga(2460)|0;l=v[22692];v[22692]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22692]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ca(2479,a+348|0,j|0,8299,a|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if((j|0)==-1){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+348>>2]);Ee(m,Cd(j));if(qk(m)){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[22692]=0;Fc(a+216|0,d);f=v[22692];v[22692]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22692]=0;q=T(21,a+216|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break j}v[22692]=0;f=v[a+348>>2];Y(2456,q|0,f|0,f+j|0,l|0);f=v[22692];v[22692]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+348>>2]]==45:p;h=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[22692]=0;na(2506,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,f|0,g|0,a+156|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}v[a+36>>2]=2440;c=he(a+40|0,0,a+36|0);i=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){k=(Ab(g)+(j-n<<1|1)|0)+Ab(f)|0;break k}k=(Ab(g)+Ab(f)|0)+2|0}k=k+n|0;if(k>>>0<101){break h}Ee(c,Cd(k));i=v[c>>2];if(i){break h}v[22692]=0;X(2441);b=v[22692];v[22692]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[22692]=0;qa(2507,i|0,a+36|0,a+32|0,k|0,l|0,j+l|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],h|0,f|0,g|0,n|0);j=v[22692];v[22692]=0;if((j|0)!=1){v[22692]=0;b=la(17,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}vb(g);vb(f);vb(h)}Wb(a+216|0);break a}Hc(c);vb(g);vb(f);vb(h);Wb(a+216|0);Hc(m);Hc(o);gb=a+464|0;return b|0}L()}j=P()|0;O()|0}Hc(m);Hc(o);S(j|0);L()}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=jg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Kd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=gg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Mb(o,-16777216,16776704);n=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=jqa(m,s,f,f>>31);m=jb;n=jqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function nma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=a;d=w[b+2|0];e=d-16|0;a:{b:{if((e&255)>>>0<=128){t[a+2|0]=1;d=(e&254)>>>1|0;break b}c:{switch((d+96&240)>>>4|0){case 0:t[a+2|0]=4;d=d&15;break b;case 1:t[a+2|0]=3;d=d&15;break b;case 2:t[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;d=d&15}t[c+4|0]=d}d=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=w[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}t[a+2|0]=15;c=w[b+6|0];t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;g=a,h=w[ac(b+5|0,f+15|0)|0]|208,t[g+5|0]=h;break d}c=w[b+6|0];e=w[b+5|0];if(!(c|e)){break d}t[a+5|0]=e;t[a+3|0]=c;Nf(a);d=w[b+6|0]==15;break d}t[a+3|0]=2;g=a,h=ei(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=3;g=a,h=ei(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=4;g=a,h=ei(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=5;t[a+5|0]=w[b+6|0]&240|w[b+5|0]>>>4;break d}c=w[b+5|0];if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((w[b+6|0]-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=w[b+6|0]>>>1;break d}c=w[b+6|0];if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=w[b+5|0]&15;break d}t[a+3|0]=w[b+6|0];t[a+5|0]=w[b+5|0];Pu(a,1);d=(w[a+3|0]&254)==16;break d}t[a+3|0]=18;t[a+5|0]=w[b+5|0];break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1;break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=w[b+6|0]>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}gb=f+16|0;return d|0}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb+-64|0;gb=d;u[d+62>>1]=c;wg(d+62|0,32);f=mc(a);v[22692]=0;R(705,f|0,x[d+62>>1]);a=v[22692];v[22692]=0;a:{if((a|0)!=1){b:{if(!x[d+62>>1]){break b}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;c:{d:{if((a&65535)>>>0<4e3){break d}u[d+24>>1]=1;e:{if(!x[b+480190>>1]){break e}while(1){f:{if(Nd(Ml(b,x[d+24>>1]))){break f}i=d,j=WB(Vb(f),Zb(f),d+24|0),v[i+48>>2]=j;i=d,j=Zb(f),v[i+40>>2]=j;if(Gb(d+48|0,d+40|0)){break f}u[d+60>>1]=x[d+24>>1];c=1;if(!x[b+480192>>1]){break e}while(1){a=v[(((c&65535)<<2)+b|0)+900380>>2];g:{if(!a){break g}a=a+236|0;e=Eu(a);if((a|0)==(e|0)){break g}while(1){if(x[a>>1]==x[d+60>>1]){u[a>>1]=0}a=a+2|0;if((e|0)!=(a|0)){continue}break}}c=c+1|0;if(x[b+480192>>1]>=(c&65535)>>>0){continue}break}break e}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break d}c=Xu(d+48|0);v[22692]=0;a=Q(964,b|0,c|0)|0;e=v[22692];v[22692]=0;h:{i:{if((e|0)==1){break i}j:{if(a){v[22692]=0;Q(965,b|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break i}e=1;if(!x[b+480192>>1]){break j}while(1){a=v[(((e&65535)<<2)+b|0)+900380>>2];k:{if(!a){break k}a=a+236|0;g=Eu(a);if((a|0)==(g|0)){break k}while(1){l:{if(y[c+4>>2]<=x[a>>1]){break l}pe(d+40|0,c,x[a>>1]);if(Cb(d+40|0)){break l}u[a>>1]=0}a=a+2|0;if((g|0)!=(a|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break j}Ce(c);break b}uk(d+24|0,c);kB(d+32|0,d+24|0,1);Ll(d+16|0,c);v[22692]=0;t[d+15|0]=0;aT(d+40|0,d+32|0,d+16|0,d+15|0);a=v[22692];v[22692]=0;if((a|0)!=1){break h}}a=P()|0;O()|0;Ce(c);break a}uk(d,c);i=d,j=Mj(d+40|0,d),u[i+60>>1]=j;Ce(c);if(x[d+60>>1]>=4e3){break c}}v[22692]=0;R(383,f|0,d+60|0);a=v[22692];v[22692]=0;if((a|0)!=1){if(x[b+480190>>1]>=x[d+60>>1]){break c}u[b+480190>>1]=x[d+60>>1];break c}a=P()|0;O()|0;break a}h=h+1|0;if(x[d+62>>1]>(h&65535)>>>0){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0}We(f);S(a|0);L()}function M9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{j=Rp(1,32);d:{e:{if(!j){a=ba(4)|0;gm(a);v[22692]=0;U(184,a|0,89088,1912);a=v[22692];v[22692]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1903;d=tu(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22692]=0;c=Q(70,k+16|0,c|0)|0;f=v[22692];v[22692]=0;i:{if((f|0)!=1){v[22692]=0;f=Q(1913,d|0,c|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break i}v[22692]=0;Q(415,f|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22692]=0;c=Q(70,k+16|0,c|0)|0;e=v[22692];v[22692]=0;j:{if((e|0)!=1){v[22692]=0;R(1914,d|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22692]=0;c=T(1276,96)|0;e=v[22692];v[22692]=0;k:{l:{m:{if((e|0)!=1){v[22692]=0;e=Q(1915,j|0,j+4|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[eq(k+8|0,k+16|0)>>2];v[22692]=0;fa(1990,c|0,a|0,b|0,e|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break l}v[j+28>>2]=c;zj(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Dl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;zj(k+16|0)}Xb(c)}Dl(d);Z(i|0)|0;v[22692]=0;Y(1895,2069,j|0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[22692]=0;Y(1895,2069,0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=k+48|0;return j|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function E8(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;e=gb-16|0;gb=e;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!((a|0)>-1?a>>>0>=8388608:0)){g=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}g=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));f=C(k*k);m=C(f*f);g=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());f=C(C(C(g-c)-i)+C(k*C(i+C(C(f*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}g=c}f=C(g*C(2e3));if(!(C(D(f))<C(2147483648))){break c}a=~~f;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=gb-16|0;gb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){e=ba(8)|0;v[22692]=0;b=Q(70,b|0,2219)|0;a=v[22692];v[22692]=0;if((a|0)==1){break k}qc(e,b);v[22692]=0;U(184,e|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break i}a=P()|0;O()|0;vb(b);break j}gb=b+16|0;a=v[(a<<24>>24<<2)+59656>>2];break h}a=P()|0;O()|0;da(e|0)}S(a|0)}L()}break b;case 3:v[e>>2]=0;d=gb-80|0;gb=d;a=v[a+24>>2]+24604|0;v[d+40>>2]=v[a+32>>2];v[d>>2]=v[a+36>>2];b=v[Gf(d+40|0,d)>>2];o=e;l:{if(v[a+32>>2]==v[Sq(d+40|0)+32>>2]){h=-1;if(v[a+36>>2]==v[Sq(d)+36>>2]){break l}}h=0;if((b|0)<1){break l}h=(b+500>>>0)/1e3|0}v[o>>2]=h;gb=d+80|0;a=v[e>>2];break b;default:break d}}d=ba(8)|0;v[22692]=0;b=Q(70,e|0,7609)|0;a=v[22692];v[22692]=0;m:{if((a|0)!=1){qc(d,b);v[22692]=0;U(184,d|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break m}a=P()|0;O()|0;da(d|0)}S(a|0);L()}a=-2147483648}gb=e+16|0;return a|0}L()}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;a:{b:{c:{i=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?i>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?i>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?i>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){m=1;e=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];i=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];t=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];k=0;b=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((((B(u[e+(h|-8)>>1],w)+B(u[e+(h|-12)>>1],x)|0)+B(u[e+(h|-4)>>1],t)|0)+B(u[e+h>>1],o)|0)+B(u[e+(h|4)>>1],l)|0)+B(u[e+(h|8)>>1],n)|0)+B(u[e+(h|12)>>1],i)|0)+B(j,u[e+(h|16)>>1])|0)/32768;h=b;b=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];i=v[a+60>>2];n=i;h=(f+32|0)+(k<<3)|0;k=v[h>>2];b=Mb(k,-16777216,16776704);l=v[a+64>>2];e=Mb(v[h+4>>2],-16777216,16776704);o=i>>31;i=g<<8;g=i;g=jqa(n,o,g,g>>31);n=jb;l=jqa(l,l>>31,b,b>>31);g=l+g|0;b=jb+n|0;b=g>>>0<l>>>0?b+1|0:b;o=g;g=v[a+68>>2];g=jqa(g,g>>31,e,e>>31);e=o+g|0;b=jb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Jc(e,b,24);v[h+4>>2]=k;e=v[a+72>>2];v[j>>2]=(b|0)/256;v[h>>2]=b-(e&i);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=jg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=(((i&2147483647)<<1|g>>>31)&-2)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Kd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Jd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=gg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Mb(o,-16777216,16776704);n=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=jqa(m,s,f,f>>31);m=jb;n=jqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Ei(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=C(0),n=0,o=C(0),p=0;if(!(kb[v[v[a>>2]+136>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((kb[v[v[a>>2]+152>>2]](a)|0)<1){break a}if(!AM(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}m=z[a+4196>>2];k=C(m*k);j=C(m*j);l=a+44|0;n=Od(l,0);l=Od(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;k=z[g+n>>2];h=b+g|0;m=z[h>>2];p=h;h=c+g|0;z[p>>2]=C(z[d+g>>2]*j)-C(z[h>>2]+z[g+l>>2]);z[h>>2]=C(z[e+g>>2]*j)-C(k+m);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+n>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+n>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+n>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+n>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=AM(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;m=C(z[d+g>>2]-z[g+n>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(m*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(m*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(kb[v[v[a>>2]+136>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+n>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(ki(m)){A=Od(m,0);B=Od(m,1);D=md(m,0);E=md(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];r=r&1023;I=(r<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;Ei(a,b,c,md(m,0),md(m,1),d)}}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){e=(((g&2147483647)<<1|j>>>31)&-2)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];k=0;m=1;i=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],x)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],w)|0)+B(t[b+e|0],o)|0)+B(t[e+(b|2)|0],l)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],h)|0)+B(j,t[e+(b|8)|0])<<8)/32768;g=i;i=0;b=1;if(g){continue}break}while(1){j=(f+8|0)+(k<<2)|0;e=v[j>>2];h=v[a+60>>2];n=h;i=(f+32|0)+(k<<3)|0;k=v[i>>2];b=Mb(k,-16777216,16776704);l=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);o=h>>31;h=e<<8;e=h;e=jqa(n,o,e,e>>31);n=jb;l=jqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+n|0;b=e>>>0<l>>>0?b+1|0:b;o=e;e=v[a+68>>2];e=jqa(e,e>>31,g,g>>31);g=o+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=k;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&h);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function Qp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Cd(b)}if(b>>>0>=4294967232){v[115173]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116619]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;xs(c,b);return a}if(v[116505]==(f|0)){c=c+v[116502]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116502]=c;v[116505]=b;return a}if(v[116504]==(f|0)){c=c+v[116501]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116504]=d;v[116501]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=465996,o=v[116499]&nqa(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+466300|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=466e3,o=v[116500]&nqa(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;xs(b,l);return a}c=Cd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;hc(c,a,b>>>0>d>>>0?d:b);Xb(a);a=c}return a}function vz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=gb-208|0;gb=c;f=1;e=v[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;k=i>>>0>1?i:1;e=0;while(1){d=e+i|0;f=Tc(b,d);j=v[f+12>>2];v[c+200>>2]=v[f+8>>2];v[c+204>>2]=j;j=v[f+4>>2];v[c+192>>2]=v[f>>2];v[c+196>>2]=j;Bj(c+176|0,Tc(b,e),c+192|0);f=Tc(b,d);d=f;j=v[c+188>>2];v[d+8>>2]=v[c+184>>2];v[d+12>>2]=j;d=v[c+180>>2];v[f>>2]=v[c+176>>2];v[f+4>>2]=d;uz(Tc(b,e),c+192|0);e=e+1|0;if((k|0)!=(e|0)){continue}break}e=v[a+12>>2];f=2;h=h>>>3|0}else{h=h>>>2|0}k=e&-2;if(k){while(1){if(f){o=B(h,3);p=h<<1;i=0;while(1){e=Tc(a,i<<1);d=v[e+12>>2];v[c+200>>2]=v[e+8>>2];v[c+204>>2]=d;d=v[e+4>>2];v[c+192>>2]=v[e>>2];v[c+196>>2]=d;e=Tc(a,i);d=v[e+12>>2];v[c+184>>2]=v[e+8>>2];v[c+188>>2]=d;d=v[e+4>>2];v[c+176>>2]=v[e>>2];v[c+180>>2]=d;Li(c+160|0,c+176|0,c+192|0);e=i<<k;j=h+e|0;if(e>>>0<j>>>0){while(1){d=Tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+h|0;Li(c+128|0,c+192|0,Tc(b,g));l=e+p|0;Li(c+112|0,c+176|0,Tc(b,l));n=e+o|0;Li(c+96|0,c+160|0,Tc(b,n));yl(c+80|0,c+144|0,c+112|0);Bj(c- -64|0,c+144|0,c+112|0);yl(c+48|0,c+128|0,c+96|0);Om(c+16|0,-A[6024],-A[6025]);Bj(c,c+128|0,c+96|0);Li(c+32|0,c+16|0,c);yl(c+16|0,c+80|0,c+48|0);d=Tc(b,e);m=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=m;m=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=m;Bj(c+16|0,c+80|0,c+48|0);d=Tc(b,g);m=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=m;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;yl(c+16|0,c- -64|0,c+32|0);d=Tc(b,l);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;Bj(c+16|0,c- -64|0,c+32|0);d=Tc(b,n);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((j|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(f|0)){continue}break}}h=h>>>2|0;f=f<<2;k=k-2|0;if(k){continue}break}}gb=c+208|0}function zL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{d:{e:{f:{j=Rp(1,28);if(!j){a=ba(4)|0;gm(a);v[22692]=0;U(184,a|0,89088,1912);a=v[22692];v[22692]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1903;d=tu(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22692]=0;c=Q(70,k+16|0,c|0)|0;f=v[22692];v[22692]=0;j:{if((f|0)!=1){v[22692]=0;f=Q(1913,d|0,c|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break j}v[22692]=0;Q(415,f|0,e|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22692]=0;c=Q(70,k+16|0,c|0)|0;e=v[22692];v[22692]=0;k:{if((e|0)!=1){v[22692]=0;R(1914,d|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22692]=0;c=T(1276,80)|0;e=v[22692];v[22692]=0;l:{m:{n:{if((e|0)!=1){v[22692]=0;e=Q(1915,j|0,j+4|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[eq(k+8|0,k+16|0)>>2];v[22692]=0;fa(1917,c|0,a|0,b|0,e|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break m}v[j+24>>2]=c;zj(k+16|0);Dl(d);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;zj(k+16|0)}Xb(c)}Dl(d);Z(i|0)|0;v[22692]=0;Y(1895,12226,j|0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Xb(Bt(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);break d}i=V(0)|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22692]=0;Y(1895,12226,0,g|0,h|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=k+48|0;return i|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function TS(a){a=a|0;var b=0,c=0,d=0,e=0;Qb(a,0,288);iB(a+288|0);Po(a+800|0);t[a+2|0]=w[11380];b=w[11378]|w[11379]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[11458];b=w[11456]|w[11457]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[2591]|w[2592]<<8|(w[2593]<<16|w[2594]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[2588]|w[2589]<<8|(w[2590]<<16|w[2591]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[12772]|w[12773]<<8|(w[12774]<<16|w[12775]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[12775]|w[12776]<<8|(w[12777]<<16|w[12778]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[6380];b=w[6376]|w[6377]<<8|(w[6378]<<16|w[6379]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;b=gb-32|0;gb=b;c=Tb(b+16|0,2028);v[22692]=0;R(444,b+8|0,a+288|0);d=v[22692];v[22692]=0;a:{b:{if((d|0)==1){break b}v[22692]=0;Q(401,b+8|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}vb(c);gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}d=a+800|0;b=0;a=gb+-64|0;gb=a;c:{d:{e:{while(1){v[a+60>>2]=b<<3;f:{if(b>>>0<=15){Df(a+32|0,1193);v[22692]=0;R(442,a+16|0,a+60|0);c=v[22692];v[22692]=0;g:{h:{i:{j:{if((c|0)!=1){v[22692]=0;U(443,a+48|0,a+32|0,a+16|0);c=v[22692];v[22692]=0;if((c|0)==1){break j}v[22692]=0;R(444,a+8|0,d+(b<<5)|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}v[22692]=0;Q(401,a+8|0,a+48|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break i}vb(a+48|0);vb(a+16|0);Hb(a+32|0);break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a+48|0)}vb(a+16|0)}Hb(a+32|0);break d}c=Tb(a+48|0,18699);v[22692]=0;R(444,a+32|0,d+(b<<5)|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}v[22692]=0;Q(401,a+32|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}vb(c)}b=b+1|0;if((b|0)!=128){continue}break}gb=a- -64|0;break c}b=P()|0;O()|0;vb(c)}S(b|0);L()}}function tk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22692]=0;R(62,a|0,d|0);d=v[22692];v[22692]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=t[nc(c,b)|0];f:{if((d|0)>=0){v[22692]=0;R(63,a|0,d&255);d=v[22692];v[22692]=0;if((d|0)!=1){break f}break e}v[22692]=0;R(63,a|0,65533);d=v[22692];v[22692]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22692]=0;R(62,a|0,d|0);d=v[22692];v[22692]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=w[nc(c,b)|0];v[22692]=0;R(63,a|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break h}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Tq(a,c,20880);return;case 5:Tq(a,c,21904);return;case 4:Tq(a,c,22928);return;case 6:Tq(a,c,23952);return;default:a=ba(8)|0;v[22692]=0;Q(59,a|0,8253)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=P()|0;O()|0;da(a|0);S(b|0);L();case 0:break c}}d=gb-16|0;gb=d;e=Kb(a);f=d,g=zd(c),v[f+8>>2]=g;f=d,g=ef(c),v[f>>2]=g;i:{j:{k:{if(!Gb(d+8|0,d)){break k}c=0;a=0;while(1){b=w[v[d+8>>2]];l:{if(!c){if(!(b&128)){c=0;v[22692]=0;R(63,e|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break l}break j}if((b&224)==192){a=b&31;c=1;break l}if((b&240)==224){a=b&15;c=2;break l}if((b&248)==240){a=b&7;c=3;break l}a=0;v[22692]=0;R(63,e|0,65533);b=v[22692];v[22692]=0;c=0;if((b|0)==1){break j}break l}if((b&192)!=128){v[22692]=0;R(63,e|0,65533);a=v[22692];v[22692]=0;if((a|0)==1){break j}a=b&63;c=-1;break l}b=b&63|a<<6;c=c-1|0;if(c){a=b;break l}a=0;v[22692]=0;R(63,e|0,b|0);b=v[22692];v[22692]=0;c=0;if((b|0)==1){break j}}Ne(d+8|0);if(Gb(d+8|0,d)){continue}break}if(!c){break k}v[22692]=0;R(63,e|0,65533);a=v[22692];v[22692]=0;if((a|0)!=1){break k}break j}gb=d+16|0;break i}a=P()|0;O()|0;Ic(e);S(a|0);L()}return}ia(a|0,89208,24);L()}b=P()|0;O()|0;Ic(a);S(b|0);L()}function U7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-96|0;gb=e;a:{if(ed(c)){break a}f=w[lL(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Ls(e+80|0,c,0,Ab(c)-1|0);Eb(c,e+80|0);vb(e+80|0)}Md(e+80|0);f=v[e+80>>2];Md(e+72|0);g=kL(f,v[e+76>>2],c);Md(e+80|0);b:{c:{d:{e:{f:{if(v[e+84>>2]==(g|0)){if(oe(c,18699)){a=ba(8)|0;v[22692]=0;b=Q(70,e+80|0,7706)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(!d){break f}a=ba(8)|0;v[22692]=0;U(2037,e+80|0,14737,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,e+80|0);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+80|0);break c}c=P()|0;O()|0;da(a|0);break c}f=Kb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Bg(e- -64|0,c);v[22692]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(1980,b|0,e+8|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;t[e+72|0]=b;R(2040,a|0,e+72|0);a=v[22692];v[22692]=0;if((a|0)!=1){break g}}break i;case 1:Bg(e+56|0,c);v[22692]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=kG(b,e+16|0,d);c=jb;d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2043,a|0,e+72|0);a=v[22692];v[22692]=0;if((a|0)!=1){break g}}break i;case 2:Bg(e+48|0,c);v[22692]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(1982,b|0,e+24|0,d|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;A[e+72>>3]=h;R(2044,a|0,e+72|0);a=v[22692];v[22692]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Bg(e+40|0,c);v[22692]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;Y(1983,a|0,b|0,e+32|0,d|0);a=v[22692];v[22692]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;vb(f);break c}Dc(a,f)}vb(f);break e}Kb(a)}gb=e+96|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;t=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){s=(g+8|0)+(f<<2)|0;f=f<<1;v[s>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],q)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],w)+B(u[e+(f|-12)>>1],x)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],m)|0)/2|0)|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Mb(q,-16777216,16776704);m=v[a+64>>2];i=Mb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=jqa(l,r,h,h>>31);l=jb;m=jqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=jqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=e+o|0;l=o>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}l=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;u[c+62>>1]=b;e=Qi(a);b=e;f=c+48|0;g=Gg(f);a:{if(!b){break a}v[22692]=0;R(806,f|0,b|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;R(1074,f|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$r(g);S(a|0);L()}b:{c:{if(!e){break c}b=0;while(1){i=rc(f,b),j=b-d|0,u[i>>1]=j;v[22692]=0;g=Q(1073,a|0,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}if(!(d&65535)){break c}e=Vb(a);d=Zb(a);b=gb-32|0;gb=b;v[b+16>>2]=d;i=b,j=WB(e,d,c+62|0),v[i+24>>2]=j;d:{if(!Gb(b+24|0,b+16|0)){break d}v[b+8>>2]=v[b+24>>2];if(!Gb(nf(b+8|0),b+16|0)){break d}while(1){if(x[v[b+8>>2]>>1]!=x[c+62>>1]){u[v[b+24>>2]>>1]=x[v[b+8>>2]>>1];nf(b+24|0)}if(Gb(nf(b+8|0),b+16|0)){continue}break}}gb=b+32|0;v[c+32>>2]=v[b+24>>2];b=Hd(c+40|0,c+32|0);i=c,j=Zb(a),v[i+16>>2]=j;e=Hd(c+24|0,c+16|0);b=v[b>>2];d=gb-32|0;gb=d;v[d+16>>2]=v[e>>2];v[d+24>>2]=b;b=a;e=v[b>>2];i=d,j=Vb(b),v[i+8>>2]=j;e=e+(np(d+24|0,d+8|0)<<1)|0;if(Gb(d+24|0,d+16|0)){rn(b,Qg(e+(np(d+16|0,d+24|0)<<1)|0,v[b+4>>2],e))}Fg(e);gb=d+32|0;i=c,j=Vb(a),v[i+32>>2]=j;i=c,j=Zb(a),v[i+16>>2]=j;if(Gb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[22692]=0;d=le(d+484344|0,b);e=v[22692];v[22692]=0;if((e|0)==1){break b}e:{if(!d){break e}b=_b(v[a+24>>2]+484344|0,b);i=c,j=Vb(b),v[i+8>>2]=j;i=c,j=Zb(b),v[i>>2]=j;if(!Gb(c+8|0,c)){break e}while(1){b=v[c+8>>2];f:{if(w[b+3|0]!=12){break f}d=w[b+5|0];if(sc(f)>>>0<=d>>>0){break f}i=b,j=w[rc(f,w[b+5|0])|0],t[i+5|0]=j}Xj(c+8|0);if(Gb(c+8|0,c)){continue}break}}nf(c+32|0);if(Gb(c+32|0,c+16|0)){continue}break}}b=x[a+28>>1];if(sc(f)>>>0<=b>>>0){break c}i=a,j=x[rc(f,x[a+28>>1])>>1],u[i+28>>1]=j}We(f);gb=c- -64|0;return}a=P()|0;O()|0;We(f);S(a|0);L()}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+s|0;n=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],q)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],w)+B(t[e+(f|-6)|0],x)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],m)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Mb(q,-16777216,16776704);m=v[a+64>>2];i=Mb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=jqa(l,r,h,h>>31);l=jb;m=jqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=jqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;l=p>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);o=e+o|0;f=o>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}f=o>>12;l=p>>12}v[a+40>>2]=o;v[a+20>>2]=l;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function e3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-432|0;gb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Hs(i+424|1,11118,v[c+4>>2]);v[i+380>>2]=i+384;a=we();a:{if(m){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;j=i- -64|0;v[j>>2]=e;v[j+4>>2]=f;v[i+48>>2]=k;a=Ff(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Ff(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2440;k=he(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22692]=0;a=ga(2460)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[22692]=0;a=ca(2479,i+380|0,a|0,i+424|0,i|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break e}break c}v[22692]=0;a=ga(2460)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22692]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ca(2479,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)==1){break c}break d}Ee(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=Sg(j,f,c);v[i+116>>2]=2440;e=he(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=Cd(a<<3);if(!a){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+380>>2]}v[22692]=0;Fc(i+104|0,c);h=v[22692];v[22692]=0;h:{i:{if((h|0)!=1){v[22692]=0;ja(2488,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22692];v[22692]=0;if((f|0)==1){break i}Wb(i+104|0);v[22692]=0;a=la(2489,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}Hc(e);Hc(k);gb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function p3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-256|0;gb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Hs(i+248|1,11118,v[c+4>>2]);v[i+204>>2]=i+208;a=we();a:{if(m){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;j=i- -64|0;v[j>>2]=e;v[j+4>>2]=f;v[i+48>>2]=k;a=Ff(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Ff(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2440;k=he(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22692]=0;a=ga(2460)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[22692]=0;a=ca(2479,i+204|0,a|0,i+248|0,i|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){break e}break c}v[22692]=0;a=ga(2460)|0;j=v[22692];v[22692]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22692]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ca(2479,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)==1){break c}break d}Ee(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=Sg(j,f,c);v[i+116>>2]=2440;e=he(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=Cd(a<<1);if(!a){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+204>>2]}v[22692]=0;Fc(i+104|0,c);h=v[22692];v[22692]=0;h:{i:{if((h|0)!=1){v[22692]=0;ja(2480,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22692];v[22692]=0;if((f|0)==1){break i}Wb(i+104|0);v[22692]=0;a=la(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}Hc(e);Hc(k);gb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function ig(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>=1){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+34688>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+34688>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+34688>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+34688>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+34688>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+34688>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+34176>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function t6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=nJ(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=nJ(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;hc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;hc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}gb=e+16|0;return g|0}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb+-64|0;gb=f;k=c+484344|0;xg(k,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){h=v[a+8>>2];e=qg(a);Rb(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Ae(a)+1|0;break b}c=Mg(a)}d=Mg(a);Yc(a,e+h|0);ud(f+16|0,a,d);h=jc(f+40|0,f+16|0);xb(f+16|0);v[22692]=0;c=W(331,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break a}c:{if(!c|!d){break c}c=_b(k,j);l=f,m=Vb(c),v[l+16>>2]=m;l=f,m=Zb(c),v[l+8>>2]=m;if(!Gb(f+16|0,f+8|0)){break c}while(1){d=v[f+16>>2];v[22692]=0;c=T(374,h|0)|0;e=v[22692];v[22692]=0;d:{e:{f:{if((e|0)!=1){if(!(c&128)){break f}if(c&1){v[22692]=0;e=T(374,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}t[d|0]=e}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[22692]=0;e=T(374,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}t[d+1|0]=e}e=0;if(c&4){v[22692]=0;e=T(374,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}}if(c&8){v[22692]=0;g=T(374,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}t[d+3|0]=g}if(c&16){v[22692]=0;c=T(374,h|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}t[d+5|0]=c}c=d;g:{h:{g=w[d|0];if(!g){break h}i=255;if((g|0)==97){break g}if(g>>>0>96){break h}i=g+12|0;break g}i=0}t[c|0]=i;i:{if(w[d+5|0]|w[d+3|0]){v[22692]=0;Nf(d);c=v[22692];v[22692]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=e-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(e>>>0<96){break j}c=e&15;t[d+4|0]=c;e=e-96>>4;t[d+2|0]=w[e+33423|0];if((e|0)!=6){break j}t[d+4|0]=c<<2}Xj(f+16|0);if(Gb(f+16|0,f+8|0)){continue}break}}xb(f+40|0);j=j+1|0;if(j>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}gb=f- -64|0;return}a=P()|0;O()|0;xb(f+40|0);S(a|0);L()}function Cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-32|0;gb=h;l=h,m=Yq(b),v[l+16>>2]=m;e=gb-32|0;gb=e;c=b;d=a;b=Yd(d);g=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(Gu(c,d)){if(!v[b>>2]){break b}g=b;break e}if(!Gu(d,c)){break c}g=b+4|0;if(!v[b+4>>2]){break d}b=g;g=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=g;break a}v[e+28>>2]=b;b=g;break a}b=fc(d)}v[e+28>>2]=b}g=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=gb-16|0;gb=j;b=fc(a);k=Pj(e+8|0,Nc(48,4),Qj(j+8|0,b));b=v[k>>2];i=gb-16|0;gb=i;v[i+8>>2]=v[h+16>>2];c=v[i+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+14|0]=f;t[b+15|0]=f>>>8;t[b+16|0]=f>>>16;t[b+17|0]=f>>>24;t[b+18|0]=d;t[b+19|0]=d>>>8;t[b+20|0]=d>>>16;t[b+21|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);f=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+38|0]=f;t[b+39|0]=f>>>8;t[b+40|0]=f>>>16;t[b+41|0]=f>>>24;t[b+42|0]=d;t[b+43|0]=d>>>8;t[b+44|0]=d>>>16;t[b+45|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);f=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+30|0]=f;t[b+31|0]=f>>>8;t[b+32|0]=f>>>16;t[b+33|0]=f>>>24;t[b+34|0]=d;t[b+35|0]=d>>>8;t[b+36|0]=d>>>16;t[b+37|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+22|0]=c;t[b+23|0]=c>>>8;t[b+24|0]=c>>>16;t[b+25|0]=c>>>24;t[b+26|0]=d;t[b+27|0]=d>>>8;t[b+28|0]=d>>>16;t[b+29|0]=d>>>24;u[b+46>>1]=0;gb=i+16|0;l=fc(k),m=1,t[l+4|0]=m;gb=j+16|0;zk(a,v[e+28>>2],g,v[e+8>>2]);b=ce(e+8|0);t[e+27|0]=1;g=e+8|0;c=g;a=v[c>>2];v[c>>2]=0;if(a){fc(g);if(a){sT(a)}}}Rj(h+24|0,yc(e+8|0,b),e+27|0);gb=e+32|0;a=Pl(h+24|0);gb=h+32|0;return a+32|0}function lk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{if(!v[c>>2]|!d){break a}j=c;f=v[c>>2]+B(d,20)|0;b:{c:{if(v[a+480180>>2]==64){break c}f=v[c>>2]+((B(d,36318)|0)/1024|0)|0;if(v[a+480180>>2]==512){break c}d:{e:{f:{f=v[a+480208>>2];if(f&16){if(v[a+480180>>2]!=4){break f}f=v[a+480208>>2]}if(f&16){break d}Db(i,a+1074312|0,7);if(!Cb(i)){break d}f=v[c>>2];if((d|0)>-1){break e}g=jqa(f,0,14317456,0);h=jb;f=jqa(f,0,0-d|0,0)+14317456|0;d=jb;f=hP(mqa(g,h,f,f>>>0<14317456?d+1|0:d),jb);break c}k=v[c>>2];f=d>>31;v[i+12>>2]=f+d^f;tc(i+12|0,1020);h=v[i+12>>2];f=c;l=f;g=v[f>>2];m=g;n=g>>31;g:{if((d|0)>=1){if(h>>>0<=15){g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h<<2)+(f?43440:43504)>>2];break g}g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h>>>2<<2)+(f?43568:44592)>>2];break g}if(h>>>0<=15){g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h<<2)+(f?43504:43440)>>2];break g}g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h>>>2<<2)+(f?44592:43568)>>2]}h=jqa(m,n,h,h>>31)+32768|0;f=jb;f=Ac(kqa(h,h>>>0<32768?f+1|0:f,65536,0),jb);v[l>>2]=f;if((f|0)!=(k|0)){break b}Db(i,a+1074312|0,7);h=Cb(i);f=v[c>>2];if(!(h^(d|0)>0)){d=(f|0)==2147483647;f=v[c>>2];if(d){break b}f=f+1|0;break c}if((f|0)<2){break b}f=f-1|0;break c}d=jqa(f,f>>31,d,0);h=jb;g=h;if((g|0)>0?1:(g|0)>=0?d>>>0>=14317456:0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=hP(mqa(jqa(f,0,14317456,0),jb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),jb);break c}f=v[c>>2]-d|0}v[j>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=i+16|0}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;m=gb-16|0;gb=m;n=c;k=d;f=gb-32|0;gb=f;l=f+28|0;g=f+24|0;i=c;e=gb-32|0;gb=e;v[e+24>>2]=b;a:{b:{c:{d:{h=a;if(!Zo(e+24|0,yc(e+16|0,zh(h)))){j=wb(h);if(!Fl(j,i,te(e+24|0))){break d}}v[e+16>>2]=b;if(!Zo(e+16|0,yc(e+8|0,lC(h)))){o=wb(h);j=e+16|0;p=j;c=v[j>>2];g=v[c>>2];e:{if(g){c=g;while(1){g=c;c=v[c+4>>2];if(c){continue}break}break e}if(lg(c)){while(1){c=v[c+8>>2];if(lg(c)){continue}break}}g=v[c+8>>2]}v[p>>2]=g;if(!Fl(o,te(j),i)){break c}}if(!v[b>>2]){v[l>>2]=b;break a}b=v[e+16>>2];v[l>>2]=b;b=b+4|0;break a}if(!Fl(j,te(e+24|0),i)){break b}c=gb-16|0;gb=c;v[c+8>>2]=b;Oj(c+8|0);gb=c+16|0;c=v[c+8>>2];v[e+16>>2]=c;if(!Zo(e+16|0,yc(e+8|0,zh(h)))){if(!Fl(j,i,te(e+16|0))){break c}}if(!v[v[e+24>>2]+4>>2]){v[l>>2]=b;b=b+4|0;break a}v[l>>2]=c;b=c;break a}b=bR(h,l,i);break a}v[l>>2]=b;v[g>>2]=b;b=g}gb=e+32|0;c=b;b=v[b>>2];t[f+23|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);h=Pj(f+8|0,aR(),Qj(i+8|0,b));b=v[h>>2];v[22692]=0;b=b+16|0;g=v[22692];v[22692]=0;f:{if((g|0)!=1){g=v[n+4>>2];v[b>>2]=v[n>>2];v[b+4>>2]=g;wb(k);n=rh(b+8|0);v[b+8>>2]=v[k>>2];v[b+12>>2]=v[k+4>>2];b=wb(k);q=wb(n),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[k>>2]=0;v[k+4>>2]=0;q=fc(h),r=1,t[q+4|0]=r;gb=i+16|0;break f}a=P()|0;O()|0;GA(h);S(a|0);L()}zk(a,v[f+28>>2],c,v[f+8>>2]);b=ce(f+8|0);t[f+23|0]=1;GA(f+8|0)}Rj(m,yc(f+8|0,b),f+23|0);gb=f+32|0;a=m;if(!w[fc(a)|0]){c=te(a)+8|0;b=c;if(v[b>>2]){qf(b);cR(b);rg(b);qf(b);HA(wb(b),v[b>>2],rg(b));q=wb(b),r=0,v[q>>2]=r;v[b>>2]=0;v[b+4>>2]=0}dp(c,d);v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];b=wb(d);q=wb(c),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[yc(m+8|0,v[a>>2])>>2];gb=m+16|0;return a|0}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=gb-144|0;gb=c;e=Am(c+40|0,a);v[22692]=0;d=Q(616,c+24|0,49629)|0;a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22692]=0;v[c>>2]=19923014;v[c+4>>2]=0;U(617,e|0,d|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break n}Hb(d);if(v[e>>2]&1073741824){break e}v[22692]=0;d=Q(616,c+24|0,10631)|0;a=v[22692];v[22692]=0;if((a|0)==1){break m}v[22692]=0;ca(1461,e|0,b|0,d|0,1462)|0;a=v[22692];v[22692]=0;if((a|0)==1){break l}Hb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[22692]=0;d=Q(616,c+24|0,13797)|0;a=v[22692];v[22692]=0;if((a|0)==1){break k}v[22692]=0;W(1463,e|0,c+20|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break j}Hb(d);v[22692]=0;d=Q(616,c+24|0,13787)|0;a=v[22692];v[22692]=0;if((a|0)==1){break i}v[22692]=0;W(1463,e|0,c+16|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break h}Hb(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[lo(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[lo(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Ao(c+24|0);v[22692]=0;f=Q(616,c|0,11337)|0;a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;U(1464,e|0,d|0,f|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}Hb(f);if(bd(d)){break f}v[22692]=0;U(1465,d|0,v[c+20>>2],16777216);a=v[22692];v[22692]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;Hb(f);break b}v[22692]=0;R(1466,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}Lc(d)}dh(e);gb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(d)}dh(e);S(a|0);L()}function F2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-624|0;gb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2491;b=he(a+200|0,a+208|0,a+16|0);v[22692]=0;Fc(a+192|0,e);h=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22692]=0;h=T(2464,a+192|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break k}t[a+191|0]=0;e=v[e+4>>2];v[22692]=0;c=ra(2499,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if(!c){break e}c=w[11803]|w[11804]<<8|(w[11805]<<16|w[11806]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[11800]|w[11801]<<8|(w[11802]<<16|w[11803]<<24);v[a+176>>2]=w[11796]|w[11797]<<8|(w[11798]<<16|w[11799]<<24);v[a+180>>2]=c;v[22692]=0;Y(2476,h|0,a+176|0,a+186|0,a+128|0);c=v[22692];v[22692]=0;if((c|0)==1){break j}v[a+4>>2]=2440;d=he(a+8|0,0,a+4|0);h=v[a+196>>2];c=h-v[b>>2]|0;e=a+16|0;if((c|0)<393){break h}Ee(d,Cd((c>>>2|0)+2|0));if(v[d>>2]){break i}v[22692]=0;X(2441);c=v[22692];v[22692]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+168|0;while(1){j=e,k=w[(a+176|0)+(ix(a+128|0,h,c)-(a+128|0)>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;if(c>>>0<y[a+196>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((nH(a+16|0,a)|0)==1){break f}v[22692]=0;_(2493,5118);c=v[22692];v[22692]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[22692]=0;c=Q(2470,a+616|0,a+608|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Wb(a+192|0);Hc(b);gb=a+624|0;return c|0}e=P()|0;O()|0}Wb(a+192|0)}Hc(b);S(e|0);L()}L()}function $na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;v[g+24>>2]=d;k=dg(a,c);re(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!k){if(ld(a,5)){break a}}j=v[g+24>>2];d=gb-160|0;gb=d;h=Am(d+56|0,v[a+28>>2]);v[22692]=0;e=Q(616,d+8|0,34095)|0;f=v[22692];v[22692]=0;b:{c:{d:{e:{if((f|0)!=1){v[22692]=0;v[d+48>>2]=19923014;v[d+52>>2]=0;U(617,h|0,e|0,d+48|0);f=v[22692];v[22692]=0;if((f|0)==1){break e}Hb(e);if(!(v[h>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}t[d+48|0]=0;t[d+47|0]=0;v[22692]=0;e=Q(616,d+8|0,7318)|0;f=v[22692];v[22692]=0;f:{if((f|0)!=1){v[22692]=0;U(1084,h|0,d+48|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break f}Hb(e);if(!w[d+48|0]){break b}xf(d+48|0,50);v[22692]=0;e=Q(616,d+8|0,10512)|0;f=v[22692];v[22692]=0;g:{h:{i:{j:{if((f|0)!=1){v[22692]=0;U(1084,h|0,d+47|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break j}Hb(e);e=Oi(b);f=w[d+48|0];if(e>>>0<f>>>0){e=_A(d+8|0,v[b+12>>2]);v[22692]=0;U(1085,b|0,f|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break i}Sm(e)}e=0;f=x[Nj(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){i=e&255;bf(Nj(b,i),f);i=Nj(b,i);v[22692]=0;R(1086,d+8|0,d+7|0);l=v[22692];v[22692]=0;if((l|0)==1){break h}v[22692]=0;Y(1087,h|0,i|0,d+8|0,j|0);i=v[22692];v[22692]=0;if((i|0)==1){break g}Hb(d+8|0);e=e+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];j=Oi(b);t[b+16|0]=e>>>0<j>>>0?w[d+47|0]:0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}a=P()|0;O()|0;Sm(e);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(d+8|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e)}dh(h);S(a|0);L()}dh(h);gb=d+160|0}Wf(a,k,c,g+16|0);gb=g+32|0}function Eq(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);Sd(e+12|0,0,127);Sd(e+8|0,0,127);m=a+1074312|0;Db(e,m,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+780>>1]=0;t[b+837|0]=i;j=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=j}Db(e,m,36);i=B(i,d+256|0);n=(i|0)/256|0;j=Cb(e);l=v[e+8>>2];a:{if(!(l|!j|(i|0)<65024)){n=-1;a=b+788|0;if(!de(a)){break a}if(ou(a)|x[b+786>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=ne(C(10),C(C(0-l|0)*C(.00937500037252903)));i=gb-16|0;gb=i;h=C(B(v[e+12>>2],d+256|0)>>>0);l=i;d=a;b:{if(v[a+480180>>2]!=33554432){g=C(110);k=C(C(h/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}g=C(125);k=C(h*C(9227362170349807e-20))}o=l,p=Xh(C(ne(C(2),k)*g)),v[o+12>>2]=p;Sd(i+12|0,120,2e4);j=v[i+12>>2];d=v[d+24620>>2];gb=i+16|0;Db(e,m,36);h=C(C(((d|0)<j<<1?d>>>1|0:j)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){g=C(C(y[a+24620>>2])/h);h=C(C(f+C(-1))+C(g*f));z[e>>2]=h;f=C(g*g);break c}g=C(h/C(y[a+24620>>2]));f=C(f+f);z[e>>2]=g*C(C(1)-f);QP(e,C(2));h=C(C(f-z[e>>2])/g);z[e>>2]=h;f=C(C(1)/C(g*g))}g=C(C(h+C(1))+f);h=C(C(C(f+f)+h)/g);k=C(C(16777216)/g);f=C(C(-f)/g);d:{if(w[b+845|0]==1){o=b,p=Xh(C(C(16777216)-k)),v[o+60>>2]=p;o=b,p=Xh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Xh(C(f*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Xh(k),v[o+60>>2]=p;o=b,p=Xh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Xh(C(f*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}gb=e+16|0;return n}function to(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Db(f+8|0,a+1074312|0,15);if(Cb(f+8|0)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}c:{if(Gj(b)){d=x[b+768>>1];if(!d){break c}e=v[b+856>>2];c=b;g=v[a+1074392>>2];i=0-d|0;j=d;d=v[b+708>>2];h=(+(g>>>0)+1)*+(((d|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[c+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?e:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+852>>2]=d+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}v[b+708>>2]=d-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}c=1;e:{if(!(t[b+851|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){Db(f+8|0,a+1074312|0,6);if(Cb(f+8|0)){break e}}c=0;if(v[a+480180>>2]!=8){break e}c=(w[a+480208|0]&2)>>>1|0}d=x[b+768>>1];e=v[a+480180>>2];f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}e=(e|0)==268435456&d>>>0>239;if(!(e?t[b+851|0]&1:c)){break f}c=b+700|0;d=B(v[a+480180>>2]==64?2:4,e?d-240|0:d);d=mk(a)?d:0-d|0;e=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&8?0:(e|0)>=(g|0))){lk(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((e|0)<=(g|0)){break f}lk(a,b,c,0-d|0,1);e=v[b+700>>2];d=v[b+708>>2];g:{if((e|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(e|0)){break f}}Db(f+8|0,a+1074312|0,112);if(!Cb(f+8|0)){break f}t[b+851|0]=w[b+851|0]|8}if(v[b+700>>2]!=v[b+708>>2]){break c}Db(f+8|0,a+1074312|0,25);if(!(k=Cb(f+8|0),l=1,m=v[a+480180>>2]!=1,m?k:l)){break c}v[b+708>>2]=0}gb=f+16|0}function N2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2491;b=he(a+152|0,a+160|0,a+16|0);v[22692]=0;Fc(a+144|0,e);h=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22692]=0;h=T(21,a+144|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break k}t[a+143|0]=0;e=v[e+4>>2];v[22692]=0;c=ra(2492,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if(!c){break e}c=w[11803]|w[11804]<<8|(w[11805]<<16|w[11806]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[11800]|w[11801]<<8|(w[11802]<<16|w[11803]<<24);v[a+128>>2]=w[11796]|w[11797]<<8|(w[11798]<<16|w[11799]<<24);v[a+132>>2]=c;v[22692]=0;Y(2456,h|0,a+128|0,a+138|0,a+118|0);c=v[22692];v[22692]=0;if((c|0)==1){break j}v[a+4>>2]=2440;d=he(a+8|0,0,a+4|0);h=v[a+148>>2];e=a+16|0;if((h-v[b>>2]|0)<99){break h}Ee(d,Cd((h-v[b>>2]|0)+2|0));if(v[d>>2]){break i}v[22692]=0;X(2441);c=v[22692];v[22692]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+128|0;while(1){j=e,k=w[((Qm(a+118|0,h,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;if(c>>>0<y[a+148>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((nH(a+16|0,a)|0)==1){break f}v[22692]=0;_(2493,5118);c=v[22692];v[22692]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[22692]=0;c=Q(2443,a+280|0,a+272|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Wb(a+144|0);Hc(b);gb=a+288|0;return c|0}e=P()|0;O()|0}Wb(a+144|0)}Hc(b);S(e|0);L()}L()}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;q=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;n=v[a+56>>2];v[f+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;if(d){while(1){n=1;i=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];t=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];k=0;e=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[i+(h|8)>>1],o)+B(u[i+(h|4)>>1],l)|0)+B(u[i+(h|12)>>1],m)|0)+B(j,u[i+(h|16)>>1])|0)/2|0)+((((B(u[i+(h|-8)>>1],w)+B(u[i+(h|-12)>>1],x)|0)+B(u[i+(h|-4)>>1],t)|0)+B(u[i+h>>1],p)|0)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];m=v[a+60>>2];o=m;h=(f+32|0)+(k<<3)|0;k=v[h>>2];e=Mb(k,-16777216,16776704);l=v[a+64>>2];i=Mb(v[h+4>>2],-16777216,16776704);p=m>>31;m=g<<8;g=m;g=jqa(o,p,g,g>>31);o=jb;l=jqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+o|0;e=g>>>0<l>>>0?e+1|0:e;p=g;g=v[a+68>>2];g=jqa(g,g>>31,i,i>>31);i=p+g|0;e=jb+e|0;e=i>>>0<g>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[h+4>>2]=k;i=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(i&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];n=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function ZM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){if(!lg(d)){while(1){d=v[d+8>>2];if(!lg(d)){continue}break}}d=v[d+8>>2];break c}d=RV(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(lg(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){v[d+8>>2]=v[b+8>>2];f:{if(lg(b)){f=v[d+8>>2];break f}f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;_o(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){_o(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=lg(c);d=w[c+12|0];g:{h:{if(!b){if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;rr(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];i:{if(!(w[b+12|0]?0:b)){b=v[c+4>>2];if(w[b+12|0]?0:b){break i}t[c+12|0]=0;j:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break j}a=b}t[a+12|0]=1;return}if(!lg(b)){break h}b=v[b+8>>2]+4|0;break g}a=v[c+4>>2];if(w[a+12|0]?0:a){break i}t[b+12|0]=1;t[c+12|0]=0;qr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;rr(v[c+8>>2]);return}if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;qr(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];k:{if(w[d+12|0]?0:d){break k}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(lg(b)){b=v[b+8>>2]+4|0;break g}b=v[b+8>>2];break g}if(w[d+12|0]?0:d){break k}t[b+12|0]=1;t[c+12|0]=0;rr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;qr(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function r2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;x=gb-16|0;gb=x;v[c>>2]=a;B=d&512;while(1){a:{b:{switch(t[i+z|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Ss(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 3:if(ed(n)){break a}q=v[sk(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 2:if(ed(m)|!B){break a}D=c,E=Vi(zd(m),ti(m),v[c>>2]),v[D>>2]=E;break a;case 4:break b;default:break a}}C=v[c>>2];e=h?e+4|0:e;r=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!cl(g,2048,v[r>>2])){break c}r=r+4|0;if(r>>>0<f>>>0){continue}break}}if((o|0)>=1){d:{e:{if(e>>>0>=r>>>0){q=o;break e}s=v[c>>2];q=o;while(1){f:{r=r-4|0;v[s>>2]=v[r>>2];p=q;q=p-1|0;s=s+4|0;if(e>>>0>=r>>>0){break f}if((p|0)>1){continue}}break}v[c>>2]=s;if((p|0)>1){break e}p=v[c>>2];s=p+4|0;break d}A=Ss(g,48);u=v[c>>2];s=u+4|0;while(1){v[u>>2]=A;p=s;s=p+4|0;y=(q|0)>1;q=q-1|0;u=p;if(y){continue}break}}v[c>>2]=s;v[p>>2]=j}g:{if((e|0)==(r|0)){q=Ss(g,48);p=v[c>>2];s=p+4|0;v[c>>2]=s;v[p>>2]=q;break g}if(ed(l)){p=-1}else{p=t[nc(l,0)|0]}u=0;q=0;while(1){h:{if((q|0)!=(p|0)){break h}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;q=0;u=u+1|0;if(Ab(l)>>>0<=u>>>0){break h}if(w[nc(l,u)|0]==127){p=-1;break h}p=t[nc(l,u)|0]}r=r-4|0;A=v[r>>2];y=v[c>>2];s=y+4|0;v[c>>2]=s;v[y>>2]=A;q=q+1|0;if((e|0)!=(r|0)){continue}break}}hx(C,s)}z=z+1|0;if((z|0)!=4){continue}break}if(Ab(n)>>>0>1){D=x,E=zd(n),v[D+8>>2]=E;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];Oe(e+8|0);gb=e+16|0;D=c,E=Vi(v[e+8>>2],ti(n),v[c>>2]),v[D>>2]=E}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function c8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;g=mc(a);a=b+24|0;f=Sb(v[a>>2]+484360|0);v[22692]=0;h=Qi(f);f=v[22692];v[22692]=0;a:{b:{c:{if((f|0)==1){break c}v[22692]=0;R(1405,g|0,h|0);f=v[22692];v[22692]=0;if((f|0)==1){break c}d:{e:{if(h){f=0;while(1){c=x[rc(Sb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[22692]=0;d=Wl(d+484344|0,c);i=v[22692];v[22692]=0;if((i|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[rc(Sb(v[a>>2]+484360|0),f)>>1]);v[22692]=0;R(2082,e|0,c|0);c=v[22692];v[22692]=0;g:{h:{i:{if((c|0)!=1){v[22692]=0;U(2076,e+16|0,b|0,e|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}v[22692]=0;R(1407,g|0,e+16|0);c=v[22692];v[22692]=0;if((c|0)==1){break h}vb(e+16|0);vb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e+16|0)}vb(e);break a}v[22692]=0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if((c|0)==65534){v[22692]=0;c=Q(70,e+16|0,6351)|0;d=v[22692];v[22692]=0;j:{if((d|0)!=1){v[22692]=0;R(1407,g|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break j}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22692]=0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if((c|0)==65535){v[22692]=0;c=Q(70,e+16|0,6313)|0;d=v[22692];v[22692]=0;k:{if((d|0)!=1){v[22692]=0;R(1407,g|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break k}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22692]=0;c=Q(70,e+16|0,11765)|0;d=v[22692];v[22692]=0;if((d|0)==1){break e}v[22692]=0;R(1407,g|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}vb(c)}f=f+1|0;if((h|0)!=(f|0)){continue}break}}gb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function A_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb-80|0;gb=d;vc(b);os(a);a:{if(!Jh(b,d+72|0)){break a}if(!pF(d+72|0)){break a}if(!c){j=1;break a}if(!Pb(b,4)){break a}Nw(a);o=d,p=Mw(),v[o+48>>2]=p;Lw(hj(a)+32|0,d+48|0);ms(d+48|0);k=v[hj(a)+32>>2];c=em(b);if(c&1){break a}e=c-4|0;Yc(b,e);c=gb-16|0;gb=c;vw(c+8|0,b);g=w[lc(c+8|0,0)|0];f=w[lc(c+8|0,1)|0];i=w[lc(c+8|0,2)|0];gb=c+16|0;g=i|(f<<8|g<<16);if(!g){break a}v[22692]=0;R(271,k|0,g|0);c=v[22692];v[22692]=0;j=1;if((c|0)==1){a=V(89088)|0;if((O()|0)==(ea(89088)|0)){Z(a|0)|0;$();j=0;break a}S(a|0);L()}Yc(b,4);oF(d+48|0,b);i=v[k>>2];f=gb-32|0;gb=f;b=v[d+48>>2];t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=nF(f+8|0);e=b+e|0;v[c+12>>2]=e-4;v[c+8>>2]=b;$j(c,w[e-1|0]);b=g;while(1){b:{if(!$j(c,1)){v[f+4>>2]=1;while(1){e=$j(c,2);v[f+4>>2]=e+v[f+4>>2];if((e|0)==3){continue}break}tc(f+4|0,b);e=0;if(v[f+4>>2]){while(1){b=b-1|0;o=i+b|0,p=$j(c,8),t[o|0]=p;e=e+1|0;if(e>>>0<y[f+4>>2]){continue}break}}if(!b){break b}}e=$j(c,2);v[f+4>>2]=e+2;c:{if((e|0)==3){e=c;if($j(c,1)){h=w[lc(f+24|0,3)|0]}else{h=7}l=$j(e,h);while(1){e=$j(c,3);v[f+4>>2]=e+v[f+4>>2];if((e|0)==7){continue}break}break c}l=$j(c,w[lc(f+24|0,e)|0])}tc(f+4|0,b);h=0;m=v[f+4>>2];if(m){while(1){e=0;n=b+l|0;if(g>>>0>n>>>0){e=w[i+n|0]}b=b-1|0;t[i+b|0]=e;h=h+1|0;if((m|0)!=(h|0)){continue}break}}if(b){continue}}break}gb=f+32|0;Vd(d+32|0,k);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;Sh(d+40|0,d+16|0);b=Ud(d+24|0);c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=ls(d+48|0,d+8|0,d);qd(hj(a)+12|0,b);xb(b)}gb=d+80|0;return j|0}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=Cu(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=jqa(v[a+24>>2],0,8272,0)+4181|0;d=jb;i=a,j=Qc(mqa(e,e>>>0<4181?d+1|0:d,8363,0),jb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=jqa(v[a+24>>2],0,8363,0)+4136|0;d=jb;i=a,j=Qc(mqa(e,e>>>0<4136?d+1|0:d,8272,0),jb),v[i+24>>2]=j}e=gb-16|0;gb=e;g=e+8|0;d=gb-16|0;gb=d;h=v[a+24>>2];b:{if(!h){t[g|0]=0;t[g+1|0]=0;break b}ht(d+8|0,Mb(Io(Op(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];$A(g,d+7|0,d+6|0)}gb=d+16|0;yc(e,a+36|0);yc(e+4|0,a+37|0);d=e+8|0;qS(e,d);qS(e+4|0,d+1|0);gb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}d=c&4;if(d){e=x[a+34>>1];if(!(e&32)){u[a+28>>1]=128;u[a+34>>1]=e|32}xf(a+40|0,15);xf(a+41|0,63)}c:{if(!(!d|!(b&16777248)?c&16777248?b&4:0:1)|!w[a+41|0]){break c}e=w[a+40|0];if(!e){break c}b=a;d=w[a+39|0];if(d){d=_l(Qc(((e<<8|d>>>1)>>>0)/(d>>>0)|0,0))}else{d=255}t[b+39|0]=d}d:{e:{if((c|0)!=4){if((c|0)==16777216){break d}if((c|0)!=32|w[a+38|0]!=2){break e}t[a+38|0]=3;break e}if(w[a+38|0]!=4){break e}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}f:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Jo(a,0,f);break f}if(!(w[a+35|0]&2)|(c|0)!=2){break f}a=a+68|0;b=lc(a,8);t[b|0]=w[b|0]&3;a=lc(a,9);t[a|0]=w[a|0]&3}gb=f+32|0}function iz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;i=b,j=w[ac(b,f+15|0)|0],t[i|0]=j;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){h=w[d+39088|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}t[a|0]=11;t[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[ac(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}gb=f+16|0;return e}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;j=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];r=v[a+60>>2];b=Mb(m,-16777216,16776704);o=v[a+64>>2];g=Mb(g,-16777216,16776704);b=jqa(o,o>>31,b,b>>31);o=jb;q=b;j=(((((((B(i,n)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=jqa(r,r>>31,b,b>>31);e=q+f|0;b=jb+o|0;b=e>>>0<f>>>0?b+1|0:b;q=e;e=v[a+68>>2];e=jqa(e,e>>31,g,g>>31);g=q+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];e=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;n=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,n);k=e+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,i);b=b-(g&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function v2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=gb-16|0;gb=x;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=jn(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(ed(n)){break a}q=w[nc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(ed(m)|!A){break a}C=c,D=Vi(zd(m),ef(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=h?e+1|0:e;p=e;c:{if(p>>>0>=f>>>0){break c}p=e;while(1){if(!kh(g,2048,t[p|0])){break c}p=p+1|0;if((p|0)!=(f|0)){continue}break}p=f}if((o|0)>=1){q=o;d:{if(e>>>0<p>>>0){while(1){e:{p=p-1|0;r=w[p|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=r;s=q;q=q-1|0;if(e>>>0>=p>>>0){break e}if((s|0)>1){continue}}break}u=0;r=0;if((s|0)<2){break d}}u=jn(g,48);r=q}q=v[c>>2];v[c>>2]=q+1;if((r|0)>=1){while(1){t[q|0]=u;q=v[c>>2];v[c>>2]=q+1;s=(r|0)>1;r=r-1|0;if(s){continue}break}}t[q|0]=j}f:{if((e|0)==(p|0)){q=jn(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break f}if(ed(l)){q=-1}else{q=t[nc(l,0)|0]}u=0;r=0;while(1){g:{if((q|0)!=(r|0)){break g}r=v[c>>2];v[c>>2]=r+1;t[r|0]=k;r=0;u=u+1|0;if(Ab(l)>>>0<=u>>>0){break g}if(w[nc(l,u)|0]==127){q=-1;break g}q=t[nc(l,u)|0]}p=p-1|0;s=w[p|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=s;r=r+1|0;if((e|0)!=(p|0)){continue}break}}im(B,v[c>>2])}y=y+1|0;if((y|0)!=4){continue}break}if(Ab(n)>>>0>1){C=x,D=zd(n),v[C+8>>2]=D;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];v[e+8>>2]=v[e+8>>2]+1;gb=e+16|0;C=c,D=Vi(v[e+8>>2],ef(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(j>>>16&65520)+p|0;j=u[e+14>>1];i=t[b+3|0];o=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Mb(m,-16777216,16776704);n=v[a+64>>2];g=Mb(g,-16777216,16776704);b=jqa(n,n>>31,b,b>>31);n=jb;J=b;b=v[a+68>>2];q=jqa(b,b>>31,g,g>>31);g=J+q|0;b=jb+n|0;b=g>>>0<q>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,o)|0)+B(f,j)<<8)/32768<<8;f=jqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];j=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;o=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,o);k=j+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,i);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;q=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;e=v[a+48>>2];v[g+36>>2]=e;k=v[a+52>>2];v[g+40>>2]=k;n=v[a+56>>2];v[g+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];i=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=i;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;if(d){while(1){f=(((i&2147483647)<<1|j>>>31)&-2)+q|0;n=1;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];w=u[e+28>>1];x=u[e+26>>1];y=u[e+24>>1];k=0;e=1;h=0;while(1){v[(g+8|0)+(h<<2)>>2]=(((((B(t[f+(h|4)|0],o)+B(t[f+(h|2)|0],l)|0)+B(t[f+(h|6)|0],m)|0)+B(j,t[f+(h|8)|0])<<8)/2|0)+((((B(t[f+(h|-4)|0],x)+B(t[f+(h|-6)|0],y)|0)+B(t[f+(h|-2)|0],w)|0)+B(t[h+f|0],p)<<8)/2|0)|0)/16384;i=e;e=0;h=1;if(i){continue}break}while(1){j=(g+8|0)+(k<<2)|0;f=v[j>>2];m=v[a+60>>2];o=m;i=(g+32|0)+(k<<3)|0;k=v[i>>2];e=Mb(k,-16777216,16776704);l=v[a+64>>2];h=Mb(v[i+4>>2],-16777216,16776704);p=m>>31;m=f<<8;f=m;f=jqa(o,p,f,f>>31);o=jb;l=jqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+o|0;e=f>>>0<l>>>0?e+1|0:e;l=f;f=v[a+68>>2];f=jqa(f,f>>31,h,h>>31);h=l+f|0;e=jb+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Jc(h,e,24);v[i+4>>2]=k;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[i>>2]=e-(h&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],r);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];i=v[g+28>>2];continue}break}j=v[g+24>>2];i=v[g+28>>2];n=v[g+44>>2];k=v[g+40>>2];h=v[g+32>>2];e=v[g+36>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=h;v[a>>2]=j;v[a+4>>2]=i;gb=g+48|0}function rfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=gb-48|0;gb=g;h=Ki(b)^-1;a:{if(Nb(d)>>>0<=h>>>0){Vt(a);break a}Ki(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){Rb(b,4)}k=g,l=Ki(b),v[k+44>>2]=l;Rb(b,4);i=Ki(b);j=Ki(b);if(!((j|0)>36?(i|0)>=1:0)){Vt(a);break a}b:{if(!f){break b}if(!ur(Ad(e,v[Lb(d,h)>>2]),f)){break b}Vt(a);break a}Jw(g,b,j,i);b=jc(g+24|0,g);xb(g);v[22692]=0;d=T(275,b|0)|0;e=v[22692];v[22692]=0;c:{if((e|0)==1){break c}d:{e:{if(!d){v[22692]=0;T(1411,a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break e}break c}if((w[c+4|0]|w[c+5|0]<<8)>>>0<=39){v[22692]=0;Q(318,b|0,8)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}}if((w[c+4|0]|w[c+5|0]<<8)>>>0<=59){v[22692]=0;Q(318,b|0,16)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}}v[22692]=0;T(1403,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}f:{if((w[c+4|0]|w[c+5|0]<<8)>>>0>=120){v[22692]=0;T(1403,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}v[22692]=0;Q(318,b|0,8)|0;break f}if((w[c+4|0]|w[c+5|0]<<8)>>>0>=100){v[22692]=0;Q(318,b|0,4)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}v[22692]=0;T(1403,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}v[22692]=0;Q(318,b|0,4)|0;break f}if((w[c+4|0]|w[c+5|0]<<8)>>>0>=62){v[22692]=0;T(1403,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}v[22692]=0;Q(318,b|0,4)|0;break f}v[22692]=0;T(1403,b|0)|0}c=v[22692];v[22692]=0;if((c|0)==1){break c}v[22692]=0;c=T(1403,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;U(288,g|0,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break d}jc(a,g);v[a+20>>2]=v[g+44>>2];xb(g)}xb(b);break a}}a=P()|0;O()|0;xb(b);S(a|0);L()}gb=g+48|0}function Ks(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Kp(c,d);v[i+4>>2]=2440;n=eH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!ed(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22692]=0;h=Q(2442,a|0,i+120|0)|0;b=v[22692];v[22692]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22692]=0;b=Q(2443,a|0,i+120|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[22692]=0;p=T(2444,a|0)|0;b=v[22692];v[22692]=0;f:{if((b|0)!=1){if(g){break f}v[22692]=0;p=Q(2445,e|0,p|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=t[nc(h,r)|0];h:{if(g){break h}v[22692]=0;q=Q(2445,e|0,q<<24>>24)|0;u=v[22692];v[22692]=0;if((u|0)!=1){break h}break b}i:{if((p&255)==(q&255)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22692]=0;T(2446,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);S(a|0)}L()}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;h=j>>>21&2040;j=u[h+46150>>1];i=u[h+46148>>1];k=u[h+46146>>1];p=u[h+46144>>1];h=0;g=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],p)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;l=g&1;g=0;f=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;g=v[j>>2];i=v[a+60>>2];k=i;h=(b+32|0)+(h<<3)|0;p=v[h>>2];e=Mb(p,-16777216,16776704);l=v[a+64>>2];f=Mb(v[h+4>>2],-16777216,16776704);q=i>>31;i=g<<8;g=i;g=jqa(k,q,g,g>>31);k=jb;l=jqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+k|0;e=g>>>0<l>>>0?e+1|0:e;k=g;g=v[a+68>>2];g=jqa(g,g>>31,f,f>>31);f=k+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[h+4>>2]=p;f=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(f&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);n=e+n|0;k=n>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}k=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function FS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-32|0;gb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;d=!(b&2);b=w[a+14|0];if(d|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}while(1){d=Cc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Nb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}d=x[Cc(a,w[a+14|0])>>1];e=Cc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Cc(a,b)>>1]-1&65535;d=Rq(a,b,64,64);q=f,r=Vb(a),v[q+8>>2]=r;q=f,r=So(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Hd(f+24|0,f+16|0);h=nr(f,b,d&255);g=gb-32|0;gb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=Vb(a),v[q>>2]=r;d=d+(iv(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[wb(a)>>2]){i=v[b+4>>2];if((i|0)!=(d|0)){break d}nW(b,h);break c}e=wb(b);e=up(g,ch(b,Nb(b)+1|0),d-v[b>>2]>>2,e);v[22692]=0;R(1067,e|0,h|0);l=v[22692];v[22692]=0;e:{if((l|0)==1){break e}v[22692]=0;d=W(1068,b|0,e|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}dj(e);break c}a=P()|0;O()|0;dj(e);S(a|0);L()}m=gb-16|0;gb=m;l=d;o=b;p=v[b+4>>2];b=(p-(d+4|0)|0)+d|0;j=Dg(m,o,i-b>>2);f:{g:{if(b>>>0<i>>>0){k=v[j+4>>2];e=b;while(1){n=wb(o);v[22692]=0;cn(n,k,e);n=v[22692];v[22692]=0;if((n|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}$b(j);wr(l,b,p);gb=m+16|0;break f}a=P()|0;O()|0;$b(j);S(a|0);L()}u[d>>1]=x[h>>1];t[d+2|0]=w[h+2|0]}Fg(d);gb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}gb=f+32|0}function Js(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Kp(c,d);v[i+4>>2]=2440;n=eH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!ed(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22692]=0;h=Q(2469,a|0,i+120|0)|0;b=v[22692];v[22692]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22692]=0;b=Q(2470,a|0,i+120|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[22692]=0;p=T(2471,a|0)|0;b=v[22692];v[22692]=0;f:{if((b|0)!=1){if(g){break f}v[22692]=0;p=Q(2472,e|0,p|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=v[sk(h,r)>>2];h:{if(g){break h}v[22692]=0;q=Q(2472,e|0,q|0)|0;u=v[22692];v[22692]=0;if((u|0)!=1){break h}break b}i:{if((p|0)==(q|0)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22692]=0;T(2473,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);S(a|0)}L()}function f8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(xj(b)){wh(c+56|0);break n}v[22692]=0;R(2080,c+40|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break m}v[22692]=0;a=T(2068,c+40|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break l}v[c+56>>2]=a;Vf(c+40|0)}if(xj(b)){a=b+36|0}else{a=v[c+56>>2]}e=co(a);v[22692]=0;R(1405,f|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break k}h=c,i=Vb(a),v[h+32>>2]=i;h=c,i=Zb(a),v[h+24>>2]=i;if(Gb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Nj(v[a>>2]+484360|0,w[e+16|0]);v[22692]=0;R(2081,c+8|0,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break j}v[22692]=0;R(2023,c+40|0,c+8|0);d=v[22692];v[22692]=0;if((d|0)==1){break i}v[22692]=0;R(1407,f|0,c+40|0);d=v[22692];v[22692]=0;if((d|0)==1){break h}vb(c+40|0);vb(c+8|0);o:{if(!ed(CK(f))){break o}d=w[e+12|0];v[22692]=0;d=Q(470,b|0,d|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[22692]=0;d=Ck(d);g=v[22692];v[22692]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[rc(b,v[e+12>>2])>>1]);v[22692]=0;R(2082,c+8|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;Y(360,c+40|0,0,d|0,c+8|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}Eb(CK(f),c+40|0);vb(c+40|0);vb(c+8|0)}XK(c+32|0);if(Gb(c+32|0,c+24|0)){continue}break}}pl(c+56|0);gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Vf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(c+40|0)}vb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(c+8|0);break b}b=P()|0;O()|0}pl(c+56|0)}yd(f);S(b|0);L()}function jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;td(b,2);Ek(e+16|0,2,a+1|0);Bc(e+32|0,e+16|0);v[22692]=0;Q(303,b+43|0,e+32|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){vb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;g=b,h=v[Fb(e+32|0,e+16|0)>>2],v[g+4>>2]=h;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);g=b,h=v[Fb(e+32|0,b)>>2],v[g+8>>2]=h;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>y[b+4>>2]?d>>>0>=2:0){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}yi(e+16|0,a+16|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;yi(e+16|0,a+20|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+4|0]=f;t[d+5|0]=f>>>8;t[d+6|0]=f>>>16;t[d+7|0]=f>>>24;yi(e+16|0,a+24|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Jo(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[ac(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;d=a+32|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(w[a|0]==2){d=x[b>>1];v[b>>2]=d;break b}a=b;if(y[b>>2]>=65536){v[a>>2]=65535}d=v[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}v[b>>2]=a}gb=e+48|0;return}a=P()|0;O()|0;vb(e+32|0);S(a|0);L()}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=gb-32|0;gb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;d=0;m=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(m>>>0<=b>>>0){break a}if(!c|Qi(a)>>>0>=m>>>0){break a}wg(e+28|0,m-b&65535);s=e,t=Tl(a),u[s+8>>1]=t;b=Je(e+30|0,e+8|0);cW(a,x[e+28>>1]+x[b>>1]|0);b=x[e+30>>1];if(sc(a)>>>0<b>>>0){yf(a,x[e+30>>1])}s=e,t=Vb(a),v[s>>2]=t;c=x[e+30>>1];b=gb-16|0;gb=b;v[b+8>>2]=v[e>>2];v[b+8>>2]=v[b+8>>2]+(c<<1);gb=b+16|0;v[e+8>>2]=v[b+8>>2];b=v[Hd(e+16|0,e+8|0)>>2];f=x[e+28>>1];i=e+26|0;j=gb-32|0;gb=j;v[j+24>>2]=b;c=a;b=v[c>>2];s=j,t=Vb(c),v[s>>2]=t;d=b+(np(j+24|0,j)<<1)|0;b:{c:{d:{if(!f){break d}b=v[wb(c)>>2];g=v[c+4>>2];if(f>>>0<=b-g>>1>>>0){b=f;k=g-d|0;h=k>>1;if(b>>>0>h>>>0){pp(c,f-h|0,i);b=h;if(!k){break d}}p=gb-16|0;gb=p;h=c;k=g;n=d;q=v[c+4>>2];r=f<<1;f=(q-(r+d|0)|0)+d|0;l=ji(p,c,g-f>>1);if(f>>>0<g>>>0){o=v[l+4>>2];g=f;while(1){wb(h);Ko(o,g);o=o+2|0;v[l+4>>2]=o;g=g+2|0;if(k>>>0>g>>>0){continue}break}}$b(l);wr(n,f,q);gb=p+16|0;hv(d,b,d>>>0<=i>>>0?i>>>0<y[c+4>>2]?i+r|0:i:i);break d}b=wb(c);g=yn(j,Nk(c,sc(c)+f|0),d-v[c>>2]>>1,b);v[22692]=0;U(312,g|0,f|0,i|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}b=c;zp(c);f=g;k=v[f+4>>2];h=d;i=f+4|0;wk(wb(c),v[c>>2],d,i);wb(c);l=f+8|0;n=l;d=v[c+4>>2];if((h|0)!=(d|0)){c=v[n>>2];while(1){Ko(c,h);c=v[n>>2]+2|0;v[n>>2]=c;h=h+2|0;if((d|0)!=(h|0)){continue}break}}xc(b,i);xc(b+4|0,l);xc(wb(b),dc(f));v[f>>2]=v[f+4>>2];Yr(b,sc(b));d=k;Ih(g)}Fg(d);gb=j+32|0;break b}a=P()|0;O()|0;Ih(g);S(a|0);L()}if(sc(a)>>>0>m>>>0){yf(a,m)}d=x[e+28>>1]}gb=e+32|0;return d&65535}function Pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-16|0;gb=d;a:{if(!Pb(a,2)){sh(c+484344|0,b,64);break a}j=c+484344|0;h=Gd(Ir(a),1,1024);if(!sh(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){n=Rf(_b(j,b),i);g=0;if(k){while(1){pn(d+8|0,a);e=od(d+8|0);o=Te(d+8|0);c=B(g,6)+n|0;f=w[bj(d+8|0)|0];t[c+5|0]=f;l=0;m=w[d+8|0];if((m-1&255)>>>0<=35){t[c|0]=m+48;l=w[e|0]+1|0}e=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[e|0]=f&15;break b;case 2:t[c+3|0]=3;t[e|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=39;t[d+7|0]=15;p=e,q=w[ac(d+7|0,e)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=38;t[d+6|0]=15;p=e,q=w[ac(d+6|0,e)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=39;t[d+5|0]=15;p=e,q=w[ac(d+5|0,e)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=38;t[d+4|0]=15;p=e,q=w[ac(d+4|0,e)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[e|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:To(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[e|0]=f&15;break b;case 5:t[e|0]=f<<4;break b;case 6:t[d+3|0]=f&15;t[d+2|0]=14;p=e,q=w[ac(d+3|0,d+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[d+1|0]=f&15;t[d|0]=14;p=e,q=w[ac(d+1|0,d)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[e|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+16|0}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;f=v[a+52>>2];v[b+40>>2]=f;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;g=j>>>21&2040;j=u[g+46150>>1];i=u[g+46148>>1];k=u[g+46146>>1];p=u[g+46144>>1];h=0;m=1;f=1;g=0;while(1){v[(b+8|0)+(g<<2)>>2]=(((B(t[e+g|0],k)+B(t[e+(g|-2)|0],p)|0)+B(i,t[e+(g|2)|0])|0)+B(j,t[e+(g|4)|0])<<8)/16384;l=f&1;f=0;g=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;f=v[j>>2];i=v[a+60>>2];k=i;g=(b+32|0)+(h<<3)|0;p=v[g>>2];e=Mb(p,-16777216,16776704);l=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=jqa(k,r,f,f>>31);k=jb;l=jqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=v[a+68>>2];f=jqa(f,f>>31,h,h>>31);h=k+f|0;e=jb+e|0;e=f>>>0>h>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Jc(h,e,24);v[g+4>>2]=p;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[g>>2]=e-(h&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;g=n>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];f=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}g=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=f;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=g;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function lO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;f=B(b,872)+a|0;a:{if(w[f+1075082|0]&2){h=1;b:{if(!(w[a+480209|0]&16)){break b}h=0;if(!(v[a+480180>>2]&16777248)){break b}h=!(w[a+480208|0]&4)}if(v[a+480180>>2]==64){a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1;break a}k=f+1074992|0;c:{if(!h){break c}Db(g+8|0,a+1074312|0,21);if(!Cb(g+8|0)){break c}f=B(b,872)+a|0;e=f+1075811|0;t[e|0]=w[e|0]+(w[f+1075815|0]<<2)}e=B(b,872)+a|0;i=e+1075814|0;j=e+1075811|0;f=Hz(a,w[i|0],w[j|0]);d:{if(Gj(k)){z[d>>2]=C(C(B(w[e+1075816|0],f)|0)*C(6510417279059766e-21))+z[d>>2];c=e+1075843|0;d=w[c|0];t[c|0]=d&207|32;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break d}t[c|0]=d|48;break d}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}f=v[a+480180>>2]&5?(w[i|0]&3)==1?0-f|0:f:f;i=a+1074312|0;Db(g+8|0,i,21);d=Cb(g+8|0);e=v[a+480208>>2];e:{if(d){d=e&4;f=d?f:0-f|0;d=d?5:6;break e}d=5;f:{if(e&131072){break f}d=8;if(v[a+480180>>2]==1024){break f}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break f}d=6}Db(g+8|0,i,80);if(!Cb(g+8|0)){break e}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}e=B(b,872)+a|0;d=(0-B(w[e+1075816|0],f)|0)/(1<<d)|0;lk(a,k,c,d,0);c=hu(a,b);if(!c){break d}f=c;e=v[e+1075648>>2];if(e){e=w[e+33|0]}else{e=2}kb[v[v[c>>2]+88>>2]](f,d,e<<24>>24,b)}if(!h){break a}Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){break a}t[j|0]=w[j|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[f+1075662|0]&2)){break a}a=hu(a,b);if(!a){break a}kb[v[v[a>>2]+88>>2]](a,0,0,b)}gb=g+16|0}function A3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);v[22692]=0;Fc(a+16|0,d);b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){v[22692]=0;b=T(2464,a+16|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}v[22692]=0;Y(2476,b|0,83392,83418,a+224|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22692]=0;R(76,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=nc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22692]=0;d=Q(2469,a+344|0,a+336|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22692]=0;R(76,c|0,b<<1);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=Kc(c);v[22692]=0;R(76,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=nc(c,0);v[a+188>>2]=d+b}v[22692]=0;d=T(2471,a+344|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}if(jm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22692]=0;T(2473,a+344|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22692]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22692]=0;d=ga(2460)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}v[a>>2]=f;v[22692]=0;b=ca(2461,b|0,d|0,a|0,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(c);vb(h);gb=a+352|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function M3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);v[22692]=0;Fc(a+16|0,d);b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){v[22692]=0;b=T(21,a+16|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}v[22692]=0;Y(2456,b|0,83392,83418,a+224|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22692]=0;R(76,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=nc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22692]=0;d=Q(2442,a+264|0,a+256|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22692]=0;R(76,c|0,b<<1);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=Kc(c);v[22692]=0;R(76,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=nc(c,0);v[a+188>>2]=d+b}v[22692]=0;d=T(2444,a+264|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}if(km(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22692]=0;T(2446,a+264|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22692]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22692]=0;d=ga(2460)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}v[a>>2]=f;v[22692]=0;b=ca(2461,b|0,d|0,a|0,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22692]=0;b=Q(2443,a+264|0,a+256|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(c);vb(h);gb=a+272|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function fM(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=gb-16|0;gb=d;k=d,l=C(My(z[a+4216>>2])/C(vf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(Lp(C(z[zm(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=ne(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C(My(z[a+4220>>2])/C(vf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[zm(d+12|0,d+8|0)>>2];k=d,l=C(My(z[a+4224>>2])/C(vf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[zm(d+12|0,d+8|0)>>2]*C(3.1415927410125732));e=gb-16|0;gb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Vn(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=Vn(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=Vn(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=Vn(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=Vn(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=Sx(b,e+8|0);b=Vn(A[e+8>>3],c&1)}gb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Lp(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+51632>>2];gb=d+16|0}function eha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0;f=gb+-64|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}x=l-4|0;n=B(b,e);o=n-8|0;while(1){v[22692]=0;b=Q(189,c|0,l|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22692]=0;U(288,f+16|0,c|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}p=jc(f+40|0,f+16|0);xb(f+16|0);v[22692]=0;R(749,f+16|0,f+40|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;y=Td(f+16|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}q=v[f+16>>2];if(e){r=q-4|0;j=0;while(1){v[22692]=0;b=T(738,p|0)|0;h=v[22692];v[22692]=0;h:{if((h|0)!=1){v[f+12>>2]=b;v[22692]=0;b=T(374,p|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break f}v[f+8>>2]=b;Sd(f+8|0,0,89);v[22692]=0;Q(318,f+40|0,1)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}h=j+m|0;if(o>>>0<h>>>0){break h}k=0;b=e+j<<2;if(r>>>0<b>>>0){break h}while(1){i=zb(w[b+y|0]);s=k&1;i=s?i>>>4|0:i&15;g=v[f+8>>2];v[f+8>>2]=t[(i&7)+36552|0]+g;g=u[(g<<1)+36560>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=v[f+12>>2]+(i&8?0-g|0:g);Sd(f+8|0,0,88);Sd(f+12|0,-32768,32767);u[(h<<1)+a>>1]=v[f+12>>2];h=e+h|0;b=b+s|0;k=k+1|0;if((k|0)!=8){continue}if(h>>>0>o>>>0){break h}k=0;b=b+x|0;if(r>>>0>=b>>>0){continue}break}break h}break f}j=j+1|0;if((j|0)!=(e|0)){continue}break}}m=(q-l<<1)+m|0;zc(f+16|0);xb(f+40|0);continue}}xb(c);gb=f- -64|0;return}b=P()|0;O()|0;zc(f+16|0);break d}b=P()|0;O()|0}xb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}xb(c);S(b|0);L()}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Ud(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=jg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=(h<<1)+p|0;b:{if((b|0)<=0){break b}while(1){Kd(v[i+8>>2],u[(e<<1)+h>>1]/4<<16>>16);Jd(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Kd(b,u[h+(v[f+44>>2]<<1)>>1]/4<<16>>16);Jd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=gg(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Mb(o,-16777216,16776704);k=v[a+64>>2];g=Mb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=jqa(j,l,e,e>>31);j=jb;k=jqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=jqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb+-64|0;gb=c;d=x[a+480190>>1];t[c+48|0]=0;tR(b,d+1|0,c+48|0);if(x[a+480192>>1]){g=mc(c+48|0);d=a+484344|0;k=c,l=Vb(d),v[k+40>>2]=l;k=c,l=Zb(d),v[k+32>>2]=l;if(Gb(c+40|0,c+32|0)){while(1){a:{i=v[c+40>>2];if(!gi(i)){break a}d=x[a+480188>>1];v[22692]=0;t[c+8|0]=0;U(1117,g|0,d|0,c+8|0);d=v[22692];v[22692]=0;if((d|0)!=1){b:{k=c,l=Vb(i),v[k+24>>2]=l;j=0;if(!v[i+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{d=v[c+24>>2];v[22692]=0;d=de(d);e=v[22692];v[22692]=0;if((e|0)==1){break d}e:{if(!d){break e}d=w[v[c+24>>2]+1|0];t[c+23|0]=d;if(!w[v[c+24>>2]+1|0]){d=w[kc(g,f)|0];t[c+23|0]=d}if(d&255){u[c+8>>1]=0;f:{if(x[c+8>>1]>w[c+23|0]){break f}e=v[((w[v[c+24>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[wd(e+236|0,w[v[c+24>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}pe(c+8|0,b,e);Af(c+8|0,1)}k=kc(g,f),l=d,t[k|0]=l;break e}d=x[a+480192>>1];if(!d){break e}e=d;while(1){h=v[((d<<2)+a|0)+900380>>2];g:{if(!h){break g}h=x[wd(h+236|0,w[v[c+24>>2]]-1|0)>>1];if(h>>>0>x[a+480190>>1]){break g}pe(c+8|0,b,h);Af(c+8|0,1)}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}Xj(c+24|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;gc(g);S(a|0);L()}RO(c+40|0);if(Gb(c+40|0,c+32|0)){continue}break}}d=x[a+480190>>1];h:{if(!d){f=0;break h}f=0;e=d;while(1){pe(c+8|0,b,d);if(!Cb(c+8|0)){f=Nd((B(d,104)+a|0)+484380|0)+f|0}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}gc(g)}gb=c- -64|0;return f&65535}function h3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-384|0;gb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Hs(f+376|1,18699,v[c+4>>2]);v[f+332>>2]=f+336;a=we();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Ff(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=Ff(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2440;i=he(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22692]=0;a=ga(2460)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22692]=0;A[f+8>>3]=e;a=ca(2479,f+332|0,a|0,f+376|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){break e}break c}v[22692]=0;a=ga(2460)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22692]=0;a=ca(2479,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)==1){break c}break d}Ee(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=Sg(g,h,c);v[f+68>>2]=2440;g=he(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=Cd(a<<3);if(!a){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+332>>2]}v[22692]=0;Fc(f+56|0,c);l=v[22692];v[22692]=0;h:{i:{if((l|0)!=1){v[22692]=0;ja(2488,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22692];v[22692]=0;if((h|0)==1){break i}Wb(f+56|0);v[22692]=0;a=la(2489,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}Hc(g);Hc(i);gb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function s3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-208|0;gb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Hs(f+200|1,18699,v[c+4>>2]);v[f+156>>2]=f+160;a=we();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Ff(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=Ff(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2440;i=he(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22692]=0;a=ga(2460)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22692]=0;A[f+8>>3]=e;a=ca(2479,f+156|0,a|0,f+200|0,f|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){break e}break c}v[22692]=0;a=ga(2460)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22692]=0;a=ca(2479,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)==1){break c}break d}Ee(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=Sg(g,h,c);v[f+68>>2]=2440;g=he(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=Cd(a<<1);if(!a){v[22692]=0;X(2441);a=v[22692];v[22692]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+156>>2]}v[22692]=0;Fc(f+56|0,c);l=v[22692];v[22692]=0;h:{i:{if((l|0)!=1){v[22692]=0;ja(2480,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22692];v[22692]=0;if((h|0)==1){break i}Wb(f+56|0);v[22692]=0;a=la(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break h}Hc(g);Hc(i);gb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function kH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-272|0;gb=i;f=v[b>>2];v[i+12>>2]=f;l=a?d:256;d=a?a:i+16|0;e=0;a:{b:{c:{if(!f|!l){break c}h=c>>>0>=l>>>0;if(!(c>>>0>32|c>>>0>=l>>>0)){break b}while(1){h=h?l:c;c=c-h|0;m=0;n=gb-16|0;gb=n;d:{e:{f:{g:{g=d;if(g){if(h>>>0>=4){break g}f=h;break f}h=0;g=v[i+12>>2];f=v[g>>2];if(!f){break d}while(1){k=1;if(f>>>0>=128){m=-1;k=il(n+12|0,f,0);if((k|0)==-1){break d}}f=v[g+4>>2];g=g+4|0;h=h+k|0;m=h;if(f){continue}break}break d}k=v[i+12>>2];f=h;while(1){j=v[k>>2];h:{if(j-1>>>0>=127){if(!j){t[g|0]=0;v[i+12>>2]=0;break e}m=-1;j=il(g,j,0);if((j|0)==-1){break d}f=f-j|0;g=g+j|0;break h}t[g|0]=j;f=f-1|0;k=v[i+12>>2];g=g+1|0}k=k+4|0;v[i+12>>2]=k;if(f>>>0>3){continue}break}}if(f){k=v[i+12>>2];while(1){j=v[k>>2];i:{if(j-1>>>0>=127){if(!j){t[g|0]=0;v[i+12>>2]=0;break e}m=-1;j=il(n+12|0,j,0);if((j|0)==-1){break d}if(f>>>0<j>>>0){break e}il(g,v[k>>2],0);f=f-j|0;g=g+j|0;break i}t[g|0]=j;f=f-1|0;k=v[i+12>>2];g=g+1|0}k=k+4|0;v[i+12>>2]=k;if(f){continue}break}}m=h;break d}m=h-f|0}gb=n+16|0;if((m|0)==-1){l=0;f=v[i+12>>2];e=-1;break c}h=(i+16|0)==(d|0);l=l-(h?0:m)|0;d=h?d:d+m|0;e=e+m|0;f=v[i+12>>2];if(!f|!l){break c}h=c>>>0>=l>>>0;if(c>>>0>32|c>>>0>=l>>>0){continue}break}break b}if(!f){break a}}if(!l|!c){break a}h=e;while(1){j:{g=il(d,v[f>>2],0);k:{if(g+1>>>0<=1){e=-1;if(g){break a}v[i+12>>2]=0;break k}f=v[i+12>>2]+4|0;v[i+12>>2]=f;h=g+h|0;l=l-g|0;if(l){break j}}e=h;break a}d=d+g|0;e=h;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[i+12>>2]}gb=i+272|0;return e|0}function sL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=gb-48|0;gb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}hc(d+8|0,v[a>>2]+24604|0,40);v[d+8>>2]=b;Oz(v[a>>2],d+8|0);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=gb-16|0;gb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}a=ba(8)|0;v[22692]=0;c=Q(70,g|0,8017)|0;b=v[22692];v[22692]=0;i:{if((b|0)!=1){qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break g}b=P()|0;O()|0;vb(c);break i}b=P()|0;O()|0;da(a|0)}S(b|0);L()}gb=g+16|0;break f}L()}t[e+8|0]=b;if(!Dy(d+8|0,v[f>>2]+24648|0)){break d}Mz(v[f>>2],d+8|0);break d;case 3:b=a+24|0;hc(d+8|0,v[b>>2]+24604|0,40);a=d+8|0;e=gb-48|0;gb=e;j:{if((c|0)==-1){Et(a,v[Sq(e+8|0)+32>>2]);Eo(a,v[Sq(e+8|0)+36>>2]);break j}if((c|0)<=0){Et(a,0);Eo(a,0);break j}c=B(c,1e3);Et(a,c);Eo(a,c)}gb=e+48|0;if(v[v[b>>2]+24640>>2]==v[d+44>>2]?v[v[b>>2]+24636>>2]==v[d+40>>2]:0){break d}Oz(v[b>>2],d+8|0);break d;default:a=ba(8)|0;v[22692]=0;b=Q(70,d+8|0,7609)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b;case 0:break e}}h=a,i=ne(C(10),C(C(c|0)*C(.0005000000237487257))),z[h+48>>2]=i}gb=d+48|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Ud(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=jg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=h+p|0;b:{if((b|0)<=0){break b}while(1){Kd(v[i+8>>2],t[e+h|0]<<6);Jd(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Kd(b,t[h+v[f+44>>2]|0]<<6);Jd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=gg(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Mb(o,-16777216,16776704);k=v[a+64>>2];g=Mb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=jqa(j,l,e,e>>31);j=jb;k=jqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=jqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22692]=0;R(454,f|0,j|0);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[nc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22692]=0;W(455,f|0,1,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22692]=0;W(455,f|0,1,123)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(ss(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22692]=0;Q(456,f|0,g|0)|0;h=v[22692];v[22692]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(ss(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22692]=0;Q(456,f|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22692]=0;W(455,f|0,1,125)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if((l?k:0)|a){break c}}return}a=ba(8)|0;v[22692]=0;T(183,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;U(184,a|0,27288,24);a=v[22692];v[22692]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;da(a|0)}vb(f);S(e|0)}L()}function n$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22692]=0;R(180,f|0,j|0);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[nc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22692]=0;W(181,f|0,1,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22692]=0;W(181,f|0,1,123)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(ss(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22692]=0;Q(182,f|0,g|0)|0;h=v[22692];v[22692]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(ss(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22692]=0;Q(182,f|0,d|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22692]=0;W(181,f|0,1,125)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if((l?k:0)|a){break c}}return}a=ba(8)|0;v[22692]=0;T(183,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;U(184,a|0,27288,24);a=v[22692];v[22692]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;da(a|0)}vb(f);S(e|0)}L()}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{j=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?j>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?j>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?j>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];g=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=(i>>>16&65520)+m|0;f=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Mb(k,-16777216,16776704);l=v[a+64>>2];g=Mb(g,-16777216,16776704);b=jqa(l,l>>31,b,b>>31);l=jb;n=b;i=(((((((B(j,s)+B(f,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;f=jqa(o,o>>31,b,b>>31);e=n+f|0;b=jb+l|0;b=e>>>0<f>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=jqa(e,e>>31,g,g>>31);g=n+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,r);v[c+4>>2]=v[c+4>>2]+B(e,q);b=b-(g&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=e+o|0;f=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Mb(k,-16777216,16776704);l=v[a+64>>2];g=Mb(g,-16777216,16776704);b=jqa(l,l>>31,b,b>>31);l=jb;J=b;b=v[a+68>>2];n=jqa(b,b>>31,g,g>>31);g=J+n|0;b=jb+l|0;b=g>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(f,j)<<8)/32768<<8;f=jqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];f=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function $z(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=fA(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!((b|0)!=32?a:1)){break c}Ob(c,0,1);Ob(c,7,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,11,1);Ob(c,12,1);Ob(c,13,1);Ob(c,14,1);Ob(c,15,1);Ob(c,16,1);Ob(c,17,1);Ob(c,18,1);Ob(c,19,1);Ob(c,20,1);Ob(c,21,1);Ob(c,22,1);Ob(c,23,1);Ob(c,24,1);Ob(c,25,1);Ob(c,26,1);Ob(c,27,1);Ob(c,28,1);Ob(c,29,1);Ob(c,30,1);Ob(c,31,1);Ob(c,32,1);Ob(c,33,1);Ob(c,34,1);Ob(c,35,1);Ob(c,36,1);Ob(c,37,1);Ob(c,38,1);Ob(c,39,1);Ob(c,40,1);Ob(c,41,1);Ob(c,42,1);Ob(c,43,1);Ob(c,44,1);Ob(c,45,1);Ob(c,46,1);Ob(c,47,1);Ob(c,48,1);Ob(c,103,1);Ob(c,50,1);Ob(c,87,1);Ob(c,88,1);Ob(c,100,1);Ob(c,102,1);Ob(c,104,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Ob(c,0,1);Ob(c,4,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,17,1);Ob(c,40,1);Ob(c,51,1);Ob(c,52,1);Ob(c,53,1);Ob(c,54,1);Ob(c,55,1);Ob(c,56,1);Ob(c,57,1);Ob(c,58,1);Ob(c,59,1);Ob(c,60,1);Ob(c,61,1);Ob(c,62,1);Ob(c,63,1);Ob(c,64,1);Ob(c,65,1);Ob(c,66,1);Ob(c,67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Ob(c,g,1);Ob(c,e,1);Ob(c,d,1);Ob(c,A,1);Ob(c,z,1);Ob(c,y,1);Ob(c,x,1);Ob(c,w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Ob(c,o,1);Ob(c,n,1);Ob(c,m,1);Ob(c,l,1);g=k;f=j;e=i;d=h}Ob(c,g,1)}Ob(c,f,1);Ob(c,e,1);Ob(c,d,1)}}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;j=v[a+48>>2];v[b+36>>2]=j;k=v[a+52>>2];v[b+40>>2]=k;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;g=0;k=1;f=0;while(1){i=f<<1;h=u[i+e>>1];v[(b+8|0)+(f<<2)>>2]=h+((B(j,u[e+(i|4)>>1]-h|0)|0)/16384|0);h=k&1;k=0;f=1;if(h){continue}break}while(1){k=(b+8|0)+(g<<2)|0;f=v[k>>2];j=v[a+60>>2];i=j;h=(b+32|0)+(g<<3)|0;p=v[h>>2];e=Mb(p,-16777216,16776704);o=v[a+64>>2];g=Mb(v[h+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=jqa(i,r,f,f>>31);i=jb;o=jqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+i|0;e=f>>>0<o>>>0?e+1|0:e;i=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=i+f|0;e=jb+e|0;e=f>>>0>g>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=Jc(g,e,24);v[h+4>>2]=p;g=v[a+72>>2];v[k>>2]=(e|0)/256;v[h>>2]=e-(g&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];k=v[b+40>>2];j=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;gb=b+48|0}function nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;k=v[a+52>>2];v[b+40>>2]=k;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){j=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+r|0;g=0;l=1;k=1;f=0;while(1){i=t[e+f|0];v[(b+8|0)+(f<<2)>>2]=((B(j,t[e+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;f=1;if(i){continue}break}while(1){k=(b+8|0)+(g<<2)|0;j=v[k>>2];h=v[a+60>>2];o=h;i=(b+32|0)+(g<<3)|0;q=v[i>>2];e=Mb(q,-16777216,16776704);g=v[a+64>>2];f=Mb(v[i+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=jqa(o,p,h,h>>31);o=jb;p=h;h=jqa(g,g>>31,e,e>>31);g=p+h|0;e=jb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;g=v[a+68>>2];g=jqa(g,g>>31,f,f>>31);f=h+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[i+4>>2]=q;f=v[a+72>>2];v[k>>2]=(e|0)/256;v[i>>2]=e-(f&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];k=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=k;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=i;v[a+4>>2]=e;gb=b+48|0}function ofa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-112|0;gb=c;Mm(c+88|0,b,1413829443);v[22692]=0;b=T(275,c+88|0)|0;d=v[22692];v[22692]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22692]=0;U(1414,c- -64|0,a+140|0,1413894985);a=v[22692];v[22692]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22692]=0;a=Q(1419,c- -64|0,10899)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[22692]=0;a=T(465,c- -64|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break m}v[22692]=0;W(413,c- -64|0,b|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break m}v[22692]=0;d=Q(69,c+16|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break l}v[22692]=0;_(1420,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break k}v[22692]=0;U(1421,c+32|0,d|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break j}Eb(b,c+32|0);vb(c+32|0);vb(c);vb(d);v[22692]=0;U(13,c+32|0,2,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}v[22692]=0;a=T(959,c+32|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}vb(c+32|0);vb(b);b=a-1>>>0<19398657?1252:28591}xb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(c)}vb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}vb(b);break d}a=P()|0;O()|0}xb(c- -64|0);break b}v[22692]=0;a=Q(189,c+88|0,2)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22692]=0;b=T(287,c+88|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}xb(c+88|0);S(a|0);L()}xb(c+88|0);gb=c+112|0;return b|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=h;i=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=i;if(d){while(1){l=1;i=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=k>>>21&2040;k=u[b+46150>>1];j=u[b+46148>>1];m=u[b+46146>>1];n=u[b+46144>>1];f=0;b=1;g=0;while(1){h=g<<1;v[(e+8|0)+(g<<2)>>2]=(((B(u[h+i>>1],m)+B(u[i+(h|-4)>>1],n)|0)+B(u[i+(h|4)>>1],j)|0)+B(k,u[i+(h|8)>>1])|0)/16384;h=b;b=0;g=1;if(h){continue}break}while(1){k=(e+8|0)+(f<<2)|0;i=v[k>>2];j=v[a+60>>2];m=j;h=(e+32|0)+(f<<3)|0;n=v[h>>2];b=Mb(n,-16777216,16776704);f=v[a+64>>2];g=Mb(v[h+4>>2],-16777216,16776704);j=j>>31;i=i<<8;j=jqa(m,j,i,i>>31);m=jb;r=j;j=jqa(f,f>>31,b,b>>31);f=r+j|0;b=jb+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=j+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[h+4>>2]=n;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&i);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];h=v[e+28>>2];continue}break}k=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=k;v[a+4>>2]=h;gb=e+48|0}function B3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-384|0;gb=a;v[a+368>>2]=c;v[a+376>>2]=b;kx(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Kc(d);v[22692]=0;R(76,d|0,b|0);b=v[22692];v[22692]=0;a:{b:{c:{if((b|0)!=1){c=nc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=v[a+232>>2];h=v[a+236>>2];while(1){d:{v[22692]=0;g=Q(2469,a+376|0,a+368|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+196>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+196>>2]=g+c}v[22692]=0;g=T(2471,a+376|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jx(g,a+23|0,a+22|0,c,a+196|0,h,b,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22692]=0;T(2473,a+376|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22692]=0;Y(2459,a|0,c|0,v[a+196>>2],e|0);b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;gf(a+216|0,a+32|0,v[a+28>>2],e);v[22692]=0;b=Q(2470,a+376|0,a+368|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];vb(d);vb(a+216|0);gb=a+384|0;break a}}b=P()|0;O()|0;vb(d);vb(a+216|0);S(b|0);L()}return b|0}function O3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;nx(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Kc(d);v[22692]=0;R(76,d|0,b|0);b=v[22692];v[22692]=0;a:{b:{c:{if((b|0)!=1){c=nc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=t[a+238|0];h=t[a+239|0];while(1){d:{v[22692]=0;g=Q(2442,a+280|0,a+272|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+204>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+204>>2]=g+c}v[22692]=0;g=T(2444,a+280|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(mx(g,a+23|0,a+22|0,c,a+204|0,h,b,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22692]=0;T(2446,a+280|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22692]=0;Y(2459,a|0,c|0,v[a+204>>2],e|0);b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;gf(a+224|0,a+32|0,v[a+28>>2],e);v[22692]=0;b=Q(2443,a+280|0,a+272|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];vb(d);vb(a+224|0);gb=a+288|0;break a}}b=P()|0;O()|0;vb(d);vb(a+224|0);S(b|0);L()}return b|0}function UU(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-16|0;gb=f;a:{if((b|0)==(c|0)){break a}v[f+12>>2]=-1953789045;KB(b,c,f+12|0);c=c-b>>2;v[f+8>>2]=c;e=1;j=Nb(a);h=j+1|0;v[f+4>>2]=h;k=v[Mc(f+4|0,f+8|0)>>2];g=v[((v[f+8>>2]<<2)+b|0)-4>>2];i=c;d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}l=i-d>>>1|0;c=(l<<2)+b|0;i=B(Uu(g^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=i+v[c>>2];m=d+l|0;c=(m<<2)+b|0;d=c;g=v[c>>2];c=j+i|0;v[d>>2]=g+c;v[b>>2]=c;c=v[f+8>>2];if(j){while(1){g=e-1|0;d=((e+l>>>0)%(c>>>0)<<2)+b|0;n=(e>>>0)%(c>>>0)|0;o=(n<<2)+b|0;i=B(Uu(v[((g>>>0)%(c>>>0)<<2)+b>>2]^(v[d>>2]^v[o>>2])),1664525);v[d>>2]=i+v[d>>2];d=Lb(a,g);c=v[f+8>>2];g=((e+m>>>0)%(c>>>0)<<2)+b|0;d=v[d>>2]+(i+n|0)|0;v[g>>2]=d+v[g>>2];v[o>>2]=d;e=e+1|0;if(j>>>0>=e>>>0){continue}break}}if(h>>>0<k>>>0){while(1){a=((h+l>>>0)%(c>>>0)<<2)+b|0;d=(h>>>0)%(c>>>0)|0;j=(d<<2)+b|0;e=B(Uu(v[((h-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[j>>2])),1664525);v[a>>2]=e+v[a>>2];c=v[f+8>>2];a=((h+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=e+d|0;v[i>>2]=g+a;v[j>>2]=a;h=h+1|0;if((k|0)!=(h|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}e=k;while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;j=(d<<2)+b|0;h=B(Uu(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[j>>2]|0)|0),1566083941);v[a>>2]=h^v[a>>2];c=v[f+8>>2];a=((e+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=h-d|0;v[i>>2]=g^a;v[j>>2]=a;e=e+1|0;if(e>>>0<c+k>>>0){continue}break}}gb=f+16|0}function Kz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=gb-16|0;gb=j;k=j;a:{if(!Gj(c)){h=b;i=v[c+704>>2];g=gb-16|0;gb=g;v[g+12>>2]=d;f=0;b:{if(!d){break b}if(v[h+480180>>2]&20){e=h+1074312|0;Db(g,e,73);if(Cb(g)){d=d&65535;v[g+12>>2]=d}if(w[h+480208|0]&16){Db(g,e,73);e=Cb(g)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;f=v[((d>>>0)%768<<2)+40368>>2]<<6>>>e|0;break b}if(!d){v[g+12>>2]=1;d=1}f=229079296/(d>>>0)|0;break b}f=227001280/(d>>>0)|0;if(bp(h)){break b}f=(d+i<<4)-133808|0;if(v[h+480180>>2]==64){break b}d=v[h+480180>>2];tc(g+12|0,16777215);if(d&17408){f=Qc(mqa(jqa(i?i:8363,0,3506176,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}if(mk(h)){f=e>>31;d=v[g+12>>2];h=d>>>24|0;i=d<<8;e=i+e|0;d=h+f|0;d=e>>>0<i>>>0?d+1|0:d;f=(d&15)<<28|e>>>4;break b}if(w[h+480208|0]&16){f=Qc(mqa(jqa(i?i:8363,0,7012352,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}f=Qc(mqa(-1485242368,13,(v[g+12>>2]<<8)+e|0,0),jb)}gb=g+16|0;e=f;break a}e=v[c+700>>2]}v[k+12>>2]=e;d=v[c+656>>2];c=u[c+774>>1];c:{if(!c){break c}c=d?B(t[d+33|0],c):c;if(!c){break c}e=xh(Cg(+(c|0)*25431315104166665e-22)*+(e>>>0));v[j+12>>2]=e}d:{if(!d){break d}c=v[d+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];f=jqa(f,f>>31,e,e>>31);e=d+f|0;d=jb+(d>>31)|0;l=j,m=Ac(kqa(e,e>>>0<f>>>0?d+1|0:d,c,c>>31),jb),v[l+12>>2]=m}tc(j+12|0,2147483647);c=j;l=c,m=kqa(0,v[c+12>>2],v[b+24620>>2]<<4,0),v[l>>2]=m;v[c+4>>2]=jb;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;v[a+8>>2]=v[c+12>>2];gb=c+16|0}function aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;b=v[a+48>>2];v[e+36>>2]=b;g=v[a+52>>2];v[e+40>>2]=g;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];j=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=j;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;if(d){while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+o|0;b=k>>>21&2040;k=u[b+46150>>1];i=u[b+46148>>1];m=u[b+46146>>1];n=u[b+46144>>1];g=0;l=1;b=1;f=0;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+h|0],m)+B(t[h+(f|-2)|0],n)|0)+B(t[h+(f|2)|0],i)|0)+B(k,t[h+(f|4)|0])<<8)/16384;j=b;b=0;f=1;if(j){continue}break}while(1){k=(e+8|0)+(g<<2)|0;h=v[k>>2];i=v[a+60>>2];m=i;j=(e+32|0)+(g<<3)|0;n=v[j>>2];b=Mb(n,-16777216,16776704);g=v[a+64>>2];f=Mb(v[j+4>>2],-16777216,16776704);i=i>>31;h=h<<8;i=jqa(m,i,h,h>>31);m=jb;r=i;i=jqa(g,g>>31,b,b>>31);g=r+i|0;b=jb+m|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=v[a+68>>2];g=jqa(g,g>>31,f,f>>31);f=i+g|0;b=jb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Jc(f,b,24);v[j+4>>2]=n;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[j>>2]=b-(f&h);g=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];j=v[e+28>>2];continue}break}k=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];g=v[e+40>>2];f=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=g;v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=k;v[a+4>>2]=j;gb=e+48|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Ud(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=jg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[h+8>>2],u[(e<<1)+g>>1]/4<<16>>16);Jd(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Kd(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Jd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=gg(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Mb(k,-16777216,16776704);l=v[a+64>>2];i=Mb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=jqa(j,p,e,e>>31);j=jb;l=jqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=jqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function hO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=gb-16|0;gb=c;d=B(b,872)+a|0;a:{if(v[d+1075080>>2]&134218752){break a}if(!nk(d+1074992|0)){break a}h=v[(B(b,872)+a|0)+1075648>>2];if(w[h+15|0]&2){break a}d=Em(a,b,2,1);if(d-251>>>0<5|!d){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,872)+a|0;d=w[e+1075780|0];b:{if(w[e+1075782|0]==1){t[c+8|0]=64;f=w[ac(e+1075784|0,c+8|0)|0];break b}f=255;if(w[e+1075783|0]!=13){break b}t[c+8|0]=64;f=w[ac((B(b,872)+a|0)+1075785|0,c+8|0)|0]}j=a+1074312|0;Db(c+8|0,j,2);if(Cb(c+8|0)){if(d){e=a;f=b;if(ue(d)){d=w[lc(h+108|0,d-1|0)|0]}Fm(e,f,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((f|0)==255){break a}kb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=k<<2;v[c+4>>2]=e;if(!w[h+35|0]){e=v[(B(b,872)+a|0)+1075680>>2];v[c+4>>2]=e}i=u[(B(b,872)+a|0)+1075768>>1];Db(c+8|0,j,28);l=c,m=(Cb(c+8|0)?i<<2:i)+e|0,v[l+4>>2]=m;Sd(c+4|0,0,256);e=d;i=b;if(ue(d)){e=w[lc(h+108|0,d-1|0)|0]}Fm(a,i,e&255,x[c+4>>1])}e=w[h+35|0];Db(c+8|0,j,101);i=(f|0)!=255;if(Cb(c+8|0)){a=(d|0)!=0}else{a=ue(d)}if(!(!a|(e|0)!=1?a?0:i:1)){break a}c:{switch(w[h+36|0]){case 1:if((f|0)!=255){BM(g,f<<1);break a}BM(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;m=g,n=7,o=w[ac(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],kb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;p=g,o=7,n=w[Fb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],kb[l](p|0,o|0,n|0,m|0)}gb=c+16|0}function NZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;vc(c);a:{if(!Pb(c,3)){break a}while(1){Rr(e+24|0,c);f=od(e+24|0);i=Te(e+24|0);g=e+24|0;if(y[a+12>>2]<=w[g|0]){break a}h=Wc(a,w[g|0],b);g=w[f|0];b:{if(g>>>0<=126){if(!(g|w[i|0])){t[h|0]=254;break b}t[h|0]=g+1;if(w[i|0]==255){break b}t[h+2|0]=1;t[h+4|0]=w[i|0];break b}c:{switch(g-127|0){case 1:t[h+1|0]=w[i|0]+1;break b;case 0:break b;default:break c}}d=t[i|0];t[e+23|0]=d;i=0;g=g&127;if(g>>>0<=23){i=w[g+28416|0]}g=e;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=w[f|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((d|0)>-1){break g}f=0-d&15;break f}t[e+16|0]=64;d=w[ac(e+23|0,e+16|0)|0];if(w[h+2|0]>1){break e}t[h+4|0]=d;t[h+2|0]=1;break b}f=3;if((d|0)>-1){break d}f=0-d&127;break f}if(!d){break b}f=0-d|-16;if((d|0)<=-1){break f}f=d<<4|15;break f}if(!d){break b}g=(d|0)>-1;if(!g){d=0-d&15;t[e+23|0]=d;j=w[f|0]}f=g?3:2;d=((j|0)==22?-32:-16)|d;t[e+23|0]=d;break d}f=d&15|-48;break f}f=d&15|-64;break f}f=164;if((d|0)==100){break f}v[e+16>>2]=d- -64;v[e+12>>2]=0;v[e+8>>2]=128;d=v[Wj(e+16|0,e+12|0,e+8|0)>>2];if(!w[h+3|0]){break e}p:{switch(w[h+2|0]){case 0:case 2:break p;default:break b}}t[h+2|0]=2;t[h+4|0]=(d&254)>>>1;break b}f=d<<4}d=f;t[g+23|0]=d}f=i;if(!i){break b}}t[h+5|0]=d;t[h+3|0]=f}if(Pb(c,3)){continue}break}}gb=e+32|0}function Koa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-32|0;gb=f;t[f+24|0]=44;v[f+16>>2]=-1;v[f+20>>2]=0;v[f+8>>2]=1042;v[f+12>>2]=2;n=a;o=b;c=gb+-64|0;gb=c;p=c;j=f+8|0;b=v[j>>2]&2?16:10;g=gb-32|0;gb=g;d=Ge(g+16|0,1,0);a:{b:{c:{while(1){i=g+8|0;k=Jb(d);l=Jb(d)+Ab(d)|0;h=x[o>>1];e=b;d:{if((e|0)!=10){a=l;while(1){e:{if((a|0)==(k|0)){a=k;break e}m=h&65535;h=(m|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(m-B(e,h)|0)+1991|0];if(h&65535){continue}}break}f:{if(!(h&65535)){e=l-a|0;if(e){break f}}v[i+4>>2]=61;v[i>>2]=l;break d}a=vh(k,a,e);v[i+4>>2]=0;v[i>>2]=a+e;break d}oA(i,k,l,h)}if(!v[g+12>>2]){break c}a=Ab(d);v[22692]=0;v[g+4>>2]=a;e=wf(g+4|0);a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;U(75,d|0,e|0,0);a=v[22692];v[22692]=0;if((a|0)!=1){continue}}break}break b}b=v[g+8>>2];a=Jb(d);v[22692]=0;R(76,d|0,b-a|0);a=v[22692];v[22692]=0;g:{if((a|0)!=1){v[22692]=0;R(86,p|0,d|0);a=v[22692];v[22692]=0;if((a|0)!=1){break g}break b}break b}vb(d);gb=g+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}El(c+16|0,c,j);v[22692]=0;U(93,c+32|0,c+16|0,j|0);a=v[22692];v[22692]=0;h:{i:{j:{k:{l:{if((a|0)!=1){v[22692]=0;U(94,c+48|0,c+32|0,j|0);a=v[22692];v[22692]=0;if((a|0)==1){break l}v[22692]=0;R(85,n|0,c+48|0);a=v[22692];v[22692]=0;if((a|0)==1){break k}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function lM(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=gb-16|0;gb=e;c=vf(v[a+16>>2]);o=a,r=ne(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[o+4232>>2]=r;f=C(C(c>>>0)*C(.0010000000474974513));o=a,r=ne(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*f))),z[o+4236>>2]=r;o=a,r=ne(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*f))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(ne(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!((c|0)>-1?c>>>0>=8388608:0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(d*C(96817624))+C(67108864);o=a,r=C(z[zm(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(C(z[a+4228>>2]*C(4))*f)+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;gb=e+16|0}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=c;d=v[a+4>>2];v[22692]=0;R(863,d|0,b|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+56;$b(a);gb=c+16|0;break a}b=P()|0;O()|0;$b(a);S(b|0);L()}return}l=gb-32|0;gb=l;j=a;e=wb(a);f=l+8|0;g=a;d=$q(a)+1|0;h=gb-16|0;gb=h;v[h+12>>2]=d;i=gb-16|0;gb=i;v[i+12>>2]=76695844;v[22692]=0;v[i+8>>2]=2147483647;k=Fb(i+12|0,i+8|0);c=v[22692];v[22692]=0;b:{if((c|0)!=1){gb=i+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=DU(g);if(d>>>0<c>>>1>>>0){v[h+8>>2]=d<<1;c=v[Mc(h+8|0,h+12|0)>>2]}gb=h+16|0;break c}Sc();L()}d=$q(a);a=0;g=gb-16|0;gb=g;v[g+12>>2]=0;hf(f+12|0,e);if(c){a=c;if(a>>>0>=76695845){pd(8399);L()}a=Nc(B(a,56),4)}v[f>>2]=a;d=B(d,56)+a|0;v[f+8>>2]=d;v[f+4>>2]=d;m=dc(f),n=B(c,56)+a|0,v[m>>2]=n;gb=g+16|0;a=f;c=v[a+8>>2];v[22692]=0;R(863,c|0,b|0);b=v[22692];v[22692]=0;d:{if((b|0)!=1){v[a+8>>2]=v[a+8>>2]+56;b=a;f=a+4|0;k=f;c=v[j+4>>2];g=v[j>>2];if((c|0)!=(g|0)){d=v[k>>2];while(1){e=d-56|0;c=c-56|0;Qu(e,c);Qu(e+12|0,c+12|0);JB(e+24|0,c+24|0);u[e+52>>1]=x[c+52>>1];d=v[c+48>>2];v[e+44>>2]=v[c+44>>2];v[e+48>>2]=d;d=v[c+40>>2];v[e+36>>2]=v[c+36>>2];v[e+40>>2]=d;d=v[k>>2]-56|0;v[k>>2]=d;if((c|0)!=(g|0)){continue}break}}wc(j,f);wc(j+4|0,b+8|0);wc(wb(j),dc(b));v[b>>2]=v[b+4>>2];CU(a);gb=l+32|0;break d}b=P()|0;O()|0;CU(a);S(b|0);L()}}function Qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=lc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=wd(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=wd(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}$B(a+484|0,b+48|0,0);$B(a+590|0,b+68|0,0);$B(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[ac(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Pc(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Pc(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;am(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;$l(b,w[a|0]&127,w[a|0]>>>7|0);gb=e+16|0}function qJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{b:{c:{g=(b|0)>=0;f=a+8|0;d:{if(ol(f)){f=ol(f);break d}f=cq(f)}if(!((f|0)>(b|0)?g:0)){c=ba(8)|0;v[22692]=0;b=Q(70,i|0,3092)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}qc(c,b);v[22692]=0;U(184,c|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}if(c>>>0>=120){c=ba(8)|0;v[22692]=0;b=Q(70,i|0,8562)|0;a=v[22692];v[22692]=0;if((a|0)!=1){qc(c,b);v[22692]=0;U(184,c|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}a=P()|0;O()|0;da(c|0);break b}h=a+32|0;a=kA(v[h>>2],65535);j=(a|0)==65535?255:a;u[i>>1]=j;f=v[h>>2]+B(j,872)|0;g=f+1074992|0;Vm(g,7,v[h>>2],65535,1024);a=c+1|0;t[f+1075794|0]=a;t[f+1075791|0]=a;u[f+1075778>>1]=0;Gm(g);xo(v[h>>2],g,b+1|0,0,1,1);v[f+1075688>>2]=65536;lu(v[h>>2],g,a,0,1,1,65535);m=f+1075684|0,n=Io(uA(e*128,-128,128)+128),v[m>>2]=n;m=f+1075680|0,n=Io(uA(d*256,0,256)),v[m>>2]=n;a=v[h>>2]+1074478|0;k=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;l=f;g=i;c=i;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((l|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[g>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=Xq(k,b);u[v[h>>2]+480212>>1]=a;gb=i+16|0;return j|0}a=P()|0;O()|0;da(c|0)}S(a|0)}L()}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Ud(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=jg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[h+8>>2],t[e+g|0]<<6);Jd(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Kd(b,t[g+v[f+44>>2]|0]<<6);Jd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=gg(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Mb(k,-16777216,16776704);l=v[a+64>>2];i=Mb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=jqa(j,p,e,e>>31);j=jb;l=jqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=jqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;n=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=u[e-4>>1];p=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Mb(m,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];q=jqa(e,e>>31,f,f>>31);e=I+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=jqa(G,H,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function dJ(a){var b=0,c=0,d=0,e=0;ie(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){ie(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}ie(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){ie(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){ie(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}ie(d,b)}ie(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;ie(a,v[b+8>>2]);ie(a,v[b+28>>2]);ie(a,v[b+32>>2]);ie(a,v[b+2084>>2]);b=v[b+2088>>2];ie(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}ie(d,b)}ie(a,v[a+260>>2]);ie(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){ie(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){ie(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}ie(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;ie(a,v[d+800>>2]);ie(a,v[d+928>>2]);ie(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;ie(a,v[b+1068>>2]);ie(a,v[b+1076>>2]);ie(a,v[b+1084>>2]);ie(a,v[b+1092>>2]);ie(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;e=b+1298264|0;if(!Dd(e)){d=i;f=gb-16|0;gb=f;c=rf(12);v[22692]=0;h=T(1628,c|0)|0;g=v[22692];v[22692]=0;a:{if((g|0)!=1){c=gb-16|0;gb=c;v[c+12>>2]=h;sq(f+8|0,c+12|0);gb=c+16|0;gb=f+16|0;c=v[f+8>>2];break a}a=P()|0;O()|0;Xb(c);S(a|0);L()}v[d+8>>2]=c;UO(e,ce(i+8|0));du(i+8|0)}d=v[e>>2];f=0;c=gb-48|0;gb=c;PO(c+16|0,a);v[22692]=0;U(9,c+32|0,0,c+16|0);e=v[22692];v[22692]=0;b:{c:{d:{e:{f:{if((e|0)!=1){vb(c+16|0);k=c,l=Vb(d),v[k+8>>2]=l;k=c,l=Zb(d),v[k>>2]=l;g:{if(Gb(c+8|0,c)){d=0;while(1){h=0;e=v[c+8>>2];if(v[v[e>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){h=v[v[e>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}g=v[e>>2];v[22692]=0;R(1629,c+16|0,g+8|0);g=v[22692];v[22692]=0;if((g|0)==1){break g}v[22692]=0;g=NS(c+16|0,c+32|0);j=v[22692];v[22692]=0;h:{i:{if((j|0)!=1){vb(c+16|0);g=!g;if(!(g&h)){break i}f=v[e>>2];d=3;break h}d=P()|0;O()|0;vb(c+16|0);break d}if((d|0)<2&h){f=v[e>>2];d=2;break h}h=v[e>>2];e=g&(d|0)<1;f=e?h:f;d=e?1:d}Oe(c+8|0);if(Gb(c+8|0,c)){continue}break}break f}d=0;break e}d=P()|0;O()|0;break d}d=P()|0;O()|0;vb(c+16|0);break c}d=0;if(!f){break e}e=v[f+4>>2];if(!e){break e}v[22692]=0;a=W(e|0,f|0,b|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){d=(a|0)!=0;break e}d=P()|0;O()|0;break d}vb(c+32|0);gb=c+48|0;break b}vb(c+32|0)}S(d|0);L()}gb=i+16|0;return d|0}function e1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!v[i>>2]){break a}i=i+4|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}m=1;while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];n=ui(l+8|0,l+12|0);v[22692]=0;j=kH(f,e,i-c>>2,g-f|0,b);o=v[22692];v[22692]=0;d:{if((o|0)!=1){ff(n);gb=l+16|0;break d}a=P()|0;O()|0;ff(n);S(a|0);L()}e:{f:{g:{h:{i:{j:{switch(j+1|0){case 0:v[h>>2]=f;k:{if(v[e>>2]==(c|0)){break k}while(1){b=cx(f,v[c>>2],k+8|0,v[a+8>>2]);if((b|0)==-1){break k}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break i;case 1:break b;default:break j}}f=j+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break g}if((d|0)==(i|0)){c=v[e>>2];i=d;break e}j=cx(k+4|0,0,b,v[a+8>>2]);if((j|0)!=-1){break h}}m=2;break b}f=v[h>>2];if(j>>>0>g-f>>>0){break b}if(!j){break f}c=w[k+4|0];v[h>>2]=f+1;t[f|0]=c;i=k+4|0;c=j-1|0;if(!c){break f}while(1){j=w[i+1|0];f=v[h>>2];v[h>>2]=f+1;t[f|0]=j;i=i+1|0;c=c-1|0;if(c){continue}break}break f}c=v[e>>2];break c}c=v[e>>2]+4|0;v[e>>2]=c;f=c;i=d;l:{if((d|0)==(f|0)){break l}while(1){i=f;if(!v[f>>2]){break l}f=f+4|0;if((f|0)!=(d|0)){continue}break}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}m=(c|0)!=(d|0)}gb=k+16|0;return m|0}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;n=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=t[e-2|0];p=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Mb(m,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];q=jqa(e,e>>31,f,f>>31);e=J+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=jqa(H,I,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Mb(p,-16777216,16776704);o=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=jqa(k,r,f,f>>31);k=jb;o=jqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=jqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;kx(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22692]=0;R(76,d|0,b|0);b=v[22692];v[22692]=0;a:{b:{c:{if((b|0)!=1){c=nc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22692]=0;g=Q(2469,a+360|0,a+352|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+180>>2]=g+c}v[22692]=0;g=T(2471,a+360|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(jx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22692]=0;T(2473,a+360|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22692]=0;j=C(ya(2455,c|0,v[a+180>>2],e|0));b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}z[f>>2]=j;gf(a+200|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+360|0,a+352|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function aoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;j=dg(a,c);re(g+8|0,v[a+28>>2]);d=v[g+20>>2];v[g+24>>2]=v[g+16>>2];v[g+28>>2]=d;a:{if(!j){if(ld(a,5)){break a}}d=gb-144|0;gb=d;h=Am(d+40|0,v[a+28>>2]);v[22692]=0;f=Q(616,d+24|0,49634)|0;e=v[22692];v[22692]=0;b:{c:{d:{e:{if((e|0)!=1){v[22692]=0;v[d+16>>2]=19923014;v[d+20>>2]=0;U(617,h|0,f|0,d+16|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}Hb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f);break c}k=d,l=Re(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[22692]=0;f=Q(616,d+24|0,7329)|0;e=v[22692];v[22692]=0;f:{if((e|0)!=1){v[22692]=0;e=W(1081,h|0,d+14|0,f|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break f}Hb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}wg(d+16|0,4e3);g:{if(x[d+16>>1]<=Re(b)>>>0){break g}v[22692]=0;R(330,b|0,x[d+16>>1]);e=v[22692];v[22692]=0;if((e|0)!=1){break g}e=P()|0;O()|0;break c}e=0;u[d+12>>1]=0;if(!x[d+16>>1]){break b}h:{while(1){i:{f=_b(b,e&65535);v[22692]=0;R(1478,d+24|0,d+12|0);i=v[22692];v[22692]=0;if((i|0)==1){break i}v[22692]=0;ca(1461,h|0,f|0,d+24|0,1479)|0;f=v[22692];v[22692]=0;if((f|0)==1){break h}Hb(d+24|0);e=e+1|0;u[d+12>>1]=e;if(x[d+16>>1]>(e&65535)>>>0){continue}break b}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(d+24|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f)}dh(h);S(e|0);L()}dh(h);gb=d+144|0}Wf(a,j,c,g+24|0);gb=g+32|0}function S3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;nx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22692]=0;R(76,d|0,b|0);b=v[22692];v[22692]=0;a:{b:{c:{if((b|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22692]=0;g=Q(2442,a+264|0,a+256|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2444,a+264|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(mx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22692]=0;T(2446,a+264|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22692]=0;j=C(ya(2455,c|0,v[a+188>>2],e|0));b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}z[f>>2]=j;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+264|0,a+256|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+q|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Mb(p,-16777216,16776704);o=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=jqa(k,r,f,f>>31);k=jb;o=jqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=jqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function NH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-96|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=v[b>>2];j:{if(!b){Tb(a,6846);break j}if(!(b&65535)){d=gb-16|0;gb=d;e=Tb(d,1508);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22692]=0;v[c+24>>2]=b>>>24;R(132,c- -64|0,c+24|0);d=v[22692];v[22692]=0;k:{l:{m:{n:{if((d|0)!=1){v[22692]=0;v[c+8>>2]=b>>>16&255;R(133,c+48|0,c+8|0);b=v[22692];v[22692]=0;if((b|0)==1){break n}v[22692]=0;Y(134,a|0,c+80|0,c- -64|0,c+48|0);a=v[22692];v[22692]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);Hb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=gb-16|0;gb=d;e=Tb(d,1232);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22692]=0;v[c+44>>2]=b>>>24;R(132,c- -64|0,c+44|0);d=v[22692];v[22692]=0;if((d|0)==1){break i}v[22692]=0;v[c+40>>2]=b>>>16&255;R(133,c+48|0,c+40|0);d=v[22692];v[22692]=0;if((d|0)==1){break h}v[22692]=0;v[c+20>>2]=b>>>8&255;R(133,c+24|0,c+20|0);d=v[22692];v[22692]=0;if((d|0)==1){break g}v[22692]=0;v[c+4>>2]=b&255;R(133,c+8|0,c+4|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;ka(135,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);Hb(c+80|0)}gb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}Hb(c+80|0);S(b|0);L()}function C3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;kx(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22692]=0;R(76,d|0,b|0);b=v[22692];v[22692]=0;a:{b:{c:{if((b|0)!=1){c=nc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22692]=0;g=Q(2469,a+360|0,a+352|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+180>>2]=g+c}v[22692]=0;g=T(2471,a+360|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(jx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22692]=0;T(2473,a+360|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22692]=0;j=+oa(2458,c|0,v[a+180>>2],e|0);b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}A[f>>3]=j;gf(a+200|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+360|0,a+352|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function Q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;nx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22692]=0;R(76,d|0,b|0);b=v[22692];v[22692]=0;a:{b:{c:{if((b|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22692]=0;g=Q(2442,a+264|0,a+256|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2444,a+264|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}if(mx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22692]=0;T(2446,a+264|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22692]=0;j=+oa(2458,c|0,v[a+188>>2],e|0);b=v[22692];v[22692]=0;f:{if((b|0)==1){break f}A[f>>3]=j;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+264|0,a+256|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;p=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;j=v[a+48>>2];v[e+36>>2]=j;k=v[a+52>>2];v[e+40>>2]=k;g=v[a+56>>2];v[e+44>>2]=g;q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=b;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;s=a;if(d){while(1){l=i>>>18|0;k=1;g=((((b&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;f=0;b=1;j=0;while(1){h=j<<1;i=u[h+g>>1];v[(e+8|0)+(j<<2)>>2]=i+((B(l,u[g+(h|4)>>1]-i|0)|0)/16384|0);i=b;b=0;j=1;if(i){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=v[j>>2];h=v[a+60>>2];m=h;i=(e+32|0)+(f<<3)|0;o=v[i>>2];b=Mb(o,-16777216,16776704);f=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);n=h>>31;l=l<<8;h=l;h=jqa(m,n,h,h>>31);m=jb;n=h;h=jqa(f,f>>31,b,b>>31);f=n+h|0;b=jb+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=h+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&l);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];b=v[e+28>>2];continue}break}i=v[e+24>>2];b=v[e+28>>2];k=v[e+40>>2];j=v[e+36>>2];f=v[e+32>>2];g=v[e+44>>2]}v[s+56>>2]=g;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=b;gb=e+48|0}function X0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];c=d>>>0>b>>>0;a:{if(b>>>0>=d>>>0|f>>>0>=g>>>0){break a}b:{c:{while(1){c=t[b|0];i=c&255;l=a;d:{if((c|0)>=0){u[f>>1]=i;b=b+1|0;break d}c=2;if(i>>>0<194){break b}if(i>>>0<=223){if((d-b|0)<2){break c}j=w[b+1|0];if((j&192)!=128){break a}u[f>>1]=j&63|i<<6&1984;b=b+2|0;break d}if(i>>>0<=239){if((d-b|0)<3){break c}k=w[b+2|0];j=w[b+1|0];e:{f:{if((i|0)!=237){if((i|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((j&63)<<6|i<<12);b=b+3|0;break d}if(i>>>0>244){break b}c=1;if((d-b|0)<4){break a}k=w[b+3|0];j=w[b+2|0];b=w[b+1|0];g:{h:{switch(i-240|0){case 0:if((b+112&255)>>>0>=48){break b}break g;case 4:if((b&240)!=128){break b}break g;default:break h}}if((b&192)!=128){break b}}if((j&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}c=2;i=i&7;if((b<<12&196608|i<<18)>>>0>1114111){break a}b=b<<2;u[f>>1]=(j>>>4&3|(b&192|i<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=j<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[l+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;b=v[a+12>>2];c=d>>>0>b>>>0;if(b>>>0>=d>>>0){break a}if(f>>>0<g>>>0){continue}break}break a}c=1;break a}c=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return c|0}function Yh(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;return}d=b&224;a:{if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;g=c&d;b:{if(g){Eo(e,f);break b}Eo(e,0)}t[f+40|0]=!g;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){UA((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(B(b&256?d+9|0:d,44)+a|0)+16|0;d=v[a+36>>2];c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}b=c&32;WR(a,b>>>5|0);f=c>>>2&7;VR(a,f);e=a;a=c&3;UR(e,a);if(!d){break a}WR(d,(b|0)!=0);VR(d,f);UR(d,a);return}TR(a,c);if(!d){break a}TR(d,c);return}t[a+42|0]=(c&32)>>>5;t[a+41|0]=(c&16)>>>4;b=c>>>1&7;u[a+30>>1]=b?9-b|0:0;u[a+32>>1]=c&1;return}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=t[f+35280|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;Fo(a);u[a+14>>1]=x[((c&15)<<1)+35312>>1];return;case 1:u[a+68>>1]=w[(c>>>6|0)+18684|0];SR(a);u[a+22>>1]=(c&63)<<2;return;case 2:u[a+24>>1]=c>>>4;Fo(a);u[a+26>>1]=c&15;Fo(a);return;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;Fo(a);return;case 6:break d;default:break a}}u[a+12>>1]=c&7}}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-176|0;gb=b;d=Tb(b+8|0,8844);v[22692]=0;Q(70,b+20|0,8192)|0;e=v[22692];v[22692]=0;c=1;a:{b:{if((e|0)==1){break b}v[22692]=0;Q(70,b+32|0,8674)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=2;break b}v[22692]=0;Q(70,b+44|0,8184)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=3;break b}v[22692]=0;Q(70,b+56|0,5361)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=4;break b}v[22692]=0;Q(70,b+68|0,8169)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=5;break b}v[22692]=0;Q(70,b+80|0,5427)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=6;break b}v[22692]=0;Q(70,b+92|0,2712)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=7;break b}v[22692]=0;Q(70,b+104|0,9212)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=8;break b}v[22692]=0;Q(70,b+116|0,8617)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=9;break b}v[22692]=0;Q(70,b+128|0,9413)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=10;break b}v[22692]=0;Q(70,b+140|0,2564)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=11;break b}v[22692]=0;Q(70,b+152|0,4376)|0;c=v[22692];v[22692]=0;if((c|0)==1){c=12;break b}v[b+172>>2]=13;v[b+168>>2]=d;v[22692]=0;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2070,a|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){a=b+164|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}gb=b+176|0;return}a=b+164|0;break a}a=(b+8|0)+B(c,12)|0}b=P()|0;O()|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}S(b|0);L()}function W4(){var a=0,b=0;a=gb-16|0;gb=a;$s(463536);v[115894]=463592;v[115892]=90448;v[115884]=78540;v[115896]=-1;t[463588]=0;Vs(a+8|0,463536);b=v[v[115884]+8>>2];v[22692]=0;R(b|0,463536,a+8|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break a}b=P()|0;O()|0;Wb(a+8|0);rm(463536);S(b|0);L()}bu(462864);v[115716]=77148;v[115714]=77128;v[115715]=0;v[22692]=0;R(2387,462864,463536);a=v[22692];v[22692]=0;if((a|0)==1){a=P()|0;O()|0;lh(462864);S(a|0);L()}a=gb-16|0;gb=a;aI(463600);v[115910]=463656;v[115908]=90448;v[115900]=78640;v[115912]=-1;t[463652]=0;Vs(a+8|0,463600);b=v[v[115900]+8>>2];v[22692]=0;R(b|0,463600,a+8|0);b=v[22692];v[22692]=0;b:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break b}b=P()|0;O()|0;Wb(a+8|0);Xp(463600);S(b|0);L()}zH(462952);v[115738]=77196;v[115736]=77176;v[115737]=0;v[22692]=0;R(2388,462952,463600);a=v[22692];v[22692]=0;if((a|0)==1){a=P()|0;O()|0;lh(462952);S(a|0);L()}DH(463664,90592,463712);Ax(463032,463664);CH(463720,90592,463768);zx(463116,463720);DH(463776,90072,463824);Ax(463200,463776);Ax(463368,v[(v[v[115800]-12>>2]+463200|0)+24>>2]);CH(463832,90072,463880);zx(463284,463832);zx(463452,v[(v[v[115821]-12>>2]+463284|0)+24>>2]);BH(v[v[115714]-12>>2]+462856|0);AH(v[v[115736]-12>>2]+462944|0);VN(v[v[115800]-12>>2]+463200|0);VN(v[v[115821]-12>>2]+463284|0);BH(v[v[115800]-12>>2]+463200|0);AH(v[v[115821]-12>>2]+463284|0)}function rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;j=v[a+56>>2];v[e+44>>2]=j;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;j=1;b=1;f=0;while(1){h=t[f+g|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){k=(e+8|0)+(i<<2)|0;f=v[k>>2];l=v[a+60>>2];m=l;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Mb(i,-16777216,16776704);n=v[a+64>>2];g=Mb(v[h+4>>2],-16777216,16776704);r=l>>31;l=f<<8;f=l;f=jqa(m,r,f,f>>31);m=jb;n=jqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=jqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[h+4>>2]=i;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&l);i=1;b=j&1;j=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];j=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=j;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=gb-16|0;gb=g;m=a+44|0;if(ki(m)){j=Od(m,0);k=Od(m,1);h=md(m,0);i=md(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Fb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){e=0;if(!f){break b}while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=z[k>>2]*n;i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Fb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(r<C(1))){e=0;if(f){break e}break d}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=z[j>>2]*n;z[i>>2]=z[k>>2]*n;i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}Ei(a,b,c,md(m,0),md(m,1),d)}gb=g+16|0}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=gb-16|0;gb=e;f=Tb(e,1547);Dc(d- -64|0,f);vb(f);gb=e+16|0;v[22692]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=jqa(e,e>>31,1e4,0)+14780|0;b=jb;b=kqa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(112,d+48|0,d+44|0);g=v[22692];v[22692]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22692]=0;v[d+28>>2]=(e-B(f,12)|0)+1;R(114,d+32|0,d+28|0);e=v[22692];v[22692]=0;if((e|0)==1){break j}v[22692]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(114,d+16|0,d+12|0);b=v[22692];v[22692]=0;if((b|0)==1){break i}v[22692]=0;ha(552,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}Df(d- -64|0,1527);v[22692]=0;R(553,d+48|0,d+78|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;U(165,a|0,d- -64|0,d+48|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}}vb(d+48|0);Hb(d- -64|0);gb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}Hb(d- -64|0);S(b|0);L()}function _I(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=C(0);d=(b<<2)+a|0;g=d+1068|0;l=c<<1&-4;r=g,s=$d(a,l),v[r>>2]=s;j=d+1076|0;r=j,s=$d(a,l),v[r>>2]=s;k=$d(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}j=v[j>>2];if(!j|!k){break a}d=c;b:{if((d|0)<4){break b}m=C(d|0);i=C(C(1)/m);q=d>>>2|0;while(1){n=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))*i);r=n+g|0,t=C(Ke(f)),z[r>>2]=t;o=e|1;p=o<<2;r=p+g|0,t=C(-C(qi(f))),z[r>>2]=t;f=+C(C(C(o|0)*C(1.5707963705062866))*i);r=j+n|0,t=C(C(Ke(f))*C(.5)),z[r>>2]=t;r=j+p|0,t=C(C(qi(f))*C(.5)),z[r>>2]=t;e=e+2|0;h=h+1|0;if((q|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;i=C(C(1)/m);e=0;h=0;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))*i);r=k+(e<<2)|0,t=C(Ke(f)),z[r>>2]=t;r=k+(g<<2)|0,t=C(-C(qi(f))),z[r>>2]=t;e=e+2|0;h=h+1|0;if((d|0)!=(h|0)){continue}break}}e=(b<<2)+a|0;d=$d(a,l);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;h=(b|0)>1?b:1;f=1/+(b|0);b=0;while(1){i=C(qi((+(b|0)*1.5707963705062866+.7853981852531433)*f));r=d+(b<<2)|0,t=C(qi(+C(i*i)*1.5707963705062866)),z[r>>2]=t;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=$d(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=wm(a);if((a|0)>=8){c=36-d|0;d=a>>>3|0;a=0;while(1){r=b+(a<<1)|0,s=um(a)>>>c<<2,u[r>>1]=s;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}ec(a,3);return 0}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=On(d,a+224|0);Nn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22692]=0;h=Q(2469,a+344|0,a+336|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=h+c}v[22692]=0;h=T(2471,a+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22692]=0;T(2473,a+344|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22692]=0;b=vs(2450,c,v[a+188>>2],e,b);c=jb;g=v[22692];v[22692]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function E3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=On(d,a+224|0);Nn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22692]=0;h=Q(2469,a+344|0,a+336|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=h+c}v[22692]=0;h=T(2471,a+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22692]=0;T(2473,a+344|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22692]=0;b=vs(2454,c,v[a+188>>2],e,b);c=jb;g=v[22692];v[22692]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Fz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;h=kO(b,c);a:{if(!v[b+656>>2]|!(t[h+6|0]&1)){break a}e=v[h>>2];i=a+1074312|0;Db(f+8|0,i,31);g=Cb(f+8|0);d=ew(v[b+656>>2],c);if(bd(d)){break a}g=e+(g^1)|0;Db(f+8|0,i,31);j=Cb(f+8|0);e=w[d+12|0];b:{c:{if(!j){d:{if(!(e&2)){break d}e=x[Lb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){Db(f+8|0,i,70);k=Cb(f+8|0)}if((e|0)!=(g|0)|k){break d}g=x[Lb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Lb(d,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Lb(d,w[d+15|0])>>1];Db(f+8|0,i,93);if(!Cb(f+8|0)|(c|0)!=1|v[b+88>>2]&2048){break b}t[h+6|0]=w[h+6|0]&254;break b}k=1;e=x[oo(d)>>1];if(g>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(x[h+4>>1]==65535){break f}Db(f+8|0,i,97);if(Cb(f+8|0)){break f}e=w[d+12|0]}if(e&2){e=x[Lb(d,w[d+13|0])>>1];j=x[Lb(d,w[d+14|0])>>1]+1|0;break e}e=x[oo(d)>>1];k=g>>>0>e>>>0;j=e;break e}e=x[Lb(d,w[d+15|0])>>1];j=x[Lb(d,w[d+16|0])>>1]+1|0}e=g>>>0<j>>>0?g:e}g:{if(!k|c){break g}if(!(w[b+89|0]&8)|v[a+480180>>2]==16384?v[a+480180>>2]&16777248:1){v[b+88>>2]=v[b+88>>2]|4096}if(w[oo(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}g=e}Db(f+8|0,i,31);l=h,m=Cb(f+8|0)+g|0,v[l>>2]=m}gb=f+16|0}function QR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(qk(a)){h=gb-16|0;gb=h;j=h+8|0;f=rf(3848);k=v[e+12>>2];c=f+808|0;b=f+16|0;while(1){v[b+16>>2]=0;v[b+20>>2]=0;v[b+36>>2]=0;t[b+40|0]=1;v[b+24>>2]=0;v[b+28>>2]=0;u[b+32>>1]=0;b=b+44|0;if((c|0)!=(b|0)){continue}break}c=f+3832|0;b=f+808|0;while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+68>>2]=0;v[b+72>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;u[b+20>>1]=511;v[b+16>>2]=-1;u[b+14>>1]=1;u[b+6>>1]=0;u[b+8>>1]=0;u[b+10>>1]=0;u[b+12>>1]=0;t[b+73|0]=0;t[b+74|0]=0;t[b+75|0]=0;t[b+76|0]=0;t[b+77|0]=0;t[b+78|0]=0;t[b+79|0]=0;t[b+80|0]=0;b=b+84|0;if((c|0)!=(b|0)){continue}break}b=f;v[b+3832>>2]=0;v[b+3836>>2]=0;c=b+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){cf((b+B(g,84)|0)+808|0,b);g=g+1|0;if((g|0)!=36){continue}break}while(1){v[(b+B(d,44)|0)+32>>2]=b;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=(b+B(d,44)|0)+16|0;g=v[(d<<2)+35200>>2];b:{if(!(!(1<<d&3591)|d>>>0>11)){i=c;c=b+B(g,84)|0;YR(i,c+808|0,c+1060|0,c+1312|0,c+1564|0);break b}i=c;c=b+B(g,84)|0;YR(i,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Fo((b+B(d,84)|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}XR(b,k);b=v[Wi(j,f)>>2];gb=h+16|0;v[e+8>>2]=b;NC(a,e+8|0);fn(e+8|0);break a}XR(v[a>>2],b)}SA(a);gb=e+16|0}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=On(d,a+224|0);Nn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22692]=0;g=Q(2469,a+344|0,a+336|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2471,a+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22692]=0;T(2473,a+344|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2447,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=On(d,a+224|0);Nn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22692]=0;g=Q(2469,a+344|0,a+336|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2471,a+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22692]=0;T(2473,a+344|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2451,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}u[f>>1]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function G3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=On(d,a+224|0);Nn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22692]=0;g=Q(2469,a+344|0,a+336|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2471,a+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22692]=0;T(2473,a+344|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2452,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=On(d,a+224|0);Nn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22692]=0;g=Q(2469,a+344|0,a+336|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2471,a+344|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(jm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22692]=0;T(2473,a+344|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2453,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2470,a+344|0,a+336|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function U3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Pn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22692]=0;h=Q(2442,a+232|0,a+224|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=h+c}v[22692]=0;h=T(2444,a+232|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(km(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83392)){break c}v[22692]=0;T(2446,a+232|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22692]=0;b=vs(2454,c,v[a+188>>2],e,b);c=jb;g=v[22692];v[22692]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+232|0,a+224|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function $3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Pn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22692]=0;h=Q(2442,a+232|0,a+224|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=h+c}v[22692]=0;h=T(2444,a+232|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(km(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83392)){break c}v[22692]=0;T(2446,a+232|0)|0;h=v[22692];v[22692]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22692]=0;b=vs(2450,c,v[a+188>>2],e,b);c=jb;g=v[22692];v[22692]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+232|0,a+224|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;gb=g+32|0}function l3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;m=Fx(g);g=lx(g);Tg(k,g);a:{b:{c:{d:{if(ed(k)){v[22692]=0;Y(2476,m|0,a|0,c|0,d|0);g=v[22692];v[22692]=0;if((g|0)==1){break d}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;e:{f:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break f;default:break e}}v[22692]=0;j=Q(2486,m|0,h<<24>>24)|0;h=v[22692];v[22692]=0;if((h|0)==1){break d}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22692]=0;h=Q(2486,m|0,48)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22692]=0;h=Q(2486,m|0,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}im(j,c);v[22692]=0;n=T(2474,g|0)|0;g=v[22692];v[22692]=0;g:{if((g|0)!=1){if(c>>>0>j>>>0){break g}g=v[f>>2];break b}break d}o=(c-j|0)+j|0;g=j;h=0;i=0;while(1){h:{if(!w[nc(k,h)|0]){break h}if(t[nc(k,h)|0]!=(i|0)){break h}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=n;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}l=t[g|0];v[22692]=0;p=Q(2486,m|0,l|0)|0;l=v[22692];v[22692]=0;if((l|0)!=1){l=v[f>>2];v[f>>2]=l+4;v[l>>2]=p;i=i+1|0;g=g+1|0;if((o|0)==(g|0)){break c}continue}break}}a=P()|0;O()|0;vb(k);S(a|0);L()}g=l+4|0}hx((j-a<<2)+d|0,g);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;vb(k);gb=k+16|0}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=jg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function b4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Pn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22692]=0;g=Q(2442,a+232|0,a+224|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2444,a+232|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(km(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83392)){break c}v[22692]=0;T(2446,a+232|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2447,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+232|0,a+224|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Pn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22692]=0;g=Q(2442,a+232|0,a+224|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2444,a+232|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(km(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83392)){break c}v[22692]=0;T(2446,a+232|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2451,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}u[f>>1]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+232|0,a+224|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function X3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Pn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22692]=0;g=Q(2442,a+232|0,a+224|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2444,a+232|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(km(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83392)){break c}v[22692]=0;T(2446,a+232|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2452,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+232|0,a+224|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function V3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Pn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){c=nc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22692]=0;g=Q(2442,a+232|0,a+224|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22692]=0;R(76,d|0,c<<1);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=Kc(d);v[22692]=0;R(76,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=nc(d,0);v[a+188>>2]=g+c}v[22692]=0;g=T(2444,a+232|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break d}if(km(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83392)){break c}v[22692]=0;T(2446,a+232|0)|0;g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22692]=0;b=ca(2453,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22692];v[22692]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22692]=0;b=Q(2443,a+232|0,a+224|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function k_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){td(b,32);ii(d,1,a+4|0);Bc(d+16|0,d);v[22692]=0;Q(303,b+43|0,d+16|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}vb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;wg(b+30|0,256);u[b+32>>1]=w[a+17|0];wg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;wg(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);rk(b);t[b+38|0]=w[(w[a+79|0]&7)+46128|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=d+32|0;return c|0}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=gb-144|0;gb=k;IB(a);a:{b:{if(!Tf(a,64)){break b}c:{d:{if(!Nl(a,60)){break d}if(!nU(a,11355)){break d}g=15;d=450;break c}IB(a);if(!Tf(a,128)){break b}b=0;if(!Nl(a,124)){break a}if(!nU(a,12478)){break a}g=31;d=930}IB(a);b=0;while(1){j=0;e=gb-16|0;gb=e;c=gb-32|0;gb=c;yi(c+24|0,e+8|0);h=yb(c+24|0);f=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=f;v[c>>2]=i;v[c+4>>2]=f;f=a;fd(c+16|0,a,c);i=yb(c+16|0);if((h|0)==(i|0)){ad(f,yb(c+24|0))}gb=c+32|0;if((h|0)==(i|0)){c=e+8|0;j=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}gb=e+16|0;if(j>>>0>131072){break a}l=l+1|0;if((l&65535)>>>0<g>>>0){continue}break}ad(a,4);if(!Tf(a,2)){break b}g=0;e=gb-16|0;gb=e;c=gb-32|0;gb=c;un(c+24|0,e+8|0);j=yb(c+24|0);h=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=h;v[c>>2]=i;v[c+4>>2]=h;fd(c+16|0,a,c);h=yb(c+16|0);if((h|0)==(j|0)){ad(f,yb(c+24|0))}gb=c+32|0;if((h|0)==(j|0)){f=e+8|0;g=Ib(w[f|0]|w[f+1|0]<<8)}gb=e+16|0;if(g>>>0<178){break a}b=-1;if(!Tf(a,d)){break a}ad(a,d);d=gb-32|0;gb=d;g=k+8|0;lV(d+24|0,g);f=yb(d+24|0);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;fd(d+16|0,a,d);c=yb(d+16|0);if((c|0)==(f|0)){ad(a,yb(d+24|0))}gb=d+32|0;a=(c|0)==(f|0);if(!a){QB(g)}if(!a){break a}b=mU(k+8|0);break a}b=-1}gb=k+144|0;return b|0}function s_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-1088|0;gb=e;oi(a);Qb(a+20|0,0,1040);i=a;v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;g=a+1072|0;v[g>>2]=0;v[g+4>>2]=0;v[a+1080>>2]=0;t[a+1084|0]=d;a:{if(dd(c)){g=a+1064|0;while(1){v[a+1064>>2]=0;v[a+1068>>2]=0;b:{if(!v[c>>2]){break b}while(1){v[22692]=0;d=Q(189,b|0,2)|0;f=v[22692];v[22692]=0;c:{d:{e:{if((f|0)!=1){if(!d){break b}v[22692]=0;d=T(287,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break e}if(!d){break c}v[22692]=0;U(288,e|0,b|0,d|0);d=v[22692];v[22692]=0;f:{g:{if((d|0)!=1){v[22692]=0;d=Gp(e+24|0,e);f=v[22692];v[22692]=0;if((f|0)==1){break g}qd(i,d);hc(i+20|0,d+20|0,1040);xb(e+24|0);xb(e);v[a+1076>>2]=0;v[a+1080>>2]=0;f=fj(v[a+1060>>2]);d=v[a+1060>>2];if(f>>>0<2){break f}d=v[d+20>>2];v[22692]=0;R(289,a|0,d+(h<<1)|0);d=v[22692];v[22692]=0;if((d|0)!=1){break c}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;xb(e);break a}d=v[d+20>>2];v[22692]=0;R(290,a|0,d+h|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}break c}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(27348)|0;if((O()|0)!=(ea(27348)|0)){break a}Z(d|0)|0;v[22692]=0;X(20);d=v[22692];v[22692]=0;if((d|0)!=1){break c}d=P()|0;O()|0;break a}if(y[g>>2]<y[c>>2]){continue}break}}h=h+1|0;if(dd(v[a+1060>>2])>>>0>h>>>0){continue}break}}gb=e+1088|0;return a|0}xb(a);S(d|0);L()}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=gb-32|0;gb=i;v[i+24>>2]=b;b=v[a>>2];p=i,q=Vb(a),v[p>>2]=q;b=b+B(Rt(i+24|0,i),6)|0;a:{b:{if(!c){break b}f=v[wb(a)>>2];g=v[a+4>>2];if((f-g|0)/6>>>0>=c>>>0){e=c;j=g-b|0;f=(j|0)/6|0;if(f>>>0<c>>>0){JC(a,c-f|0,d);e=f;if(!j){break b}}l=gb-16|0;gb=l;j=a;f=g;k=b;n=v[a+4>>2];o=B(c,6);h=B((n-(o+b|0)|0)/6|0,6)+b|0;m=yr(l,a,(g-h|0)/6|0);if(g>>>0>h>>>0){g=v[m+4>>2];c=h;while(1){wb(j);xN(g,c);g=g+6|0;v[m+4>>2]=g;c=c+6|0;if(f>>>0>c>>>0){continue}break}}$b(m);c=h-k|0;if(c){vh(B((c|0)/-6|0,6)+n|0,k,c)}gb=l+16|0;c=b;d=d>>>0>=c>>>0?y[a+4>>2]>d>>>0?d+o|0:d:d;if(e){while(1){a=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;a=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=a;t[c+5|0]=a>>>8;c=c+6|0;e=e-1|0;if(e){continue}break}}break b}e=wb(a);e=HW(i,uC(a,Ig(a)+c|0),(b-v[a>>2]|0)/6|0,e);v[22692]=0;U(638,e|0,c|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}HC(a);c=v[e+4>>2];j=e+4|0;FW(wb(a),v[a>>2],b,j);wb(a);f=e+8|0;h=f;d=v[a+4>>2];if((d|0)!=(b|0)){k=v[h>>2];while(1){xN(k,b);k=v[h>>2]+6|0;v[h>>2]=k;b=b+6|0;if((d|0)!=(b|0)){continue}break}}xc(a,j);xc(a+4|0,f);xc(wb(a),dc(e));v[e>>2]=v[e+4>>2];wC(a,Ig(a));b=c;lv(e)}Fg(b);gb=i+32|0;return}a=P()|0;O()|0;lv(e);S(a|0);L()}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;gb=f+32|0}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Mb(k,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];l=jqa(e,e>>31,f,f>>31);e=I+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;h=jqa(G,H,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function A2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-448|0;gb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2491;h=he(a+24|0,a+32|0,a+20|0);v[22692]=0;Fc(a+16|0,e);b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){v[22692]=0;i=T(2464,a+16|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[22692]=0;b=ra(2499,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}if(!b){break c}c=gb-16|0;gb=c;b=g;e:{if(De(b)){d=v[b>>2];v[c+12>>2]=0;Fe(d,c+12|0);ee(b,0);break e}v[c+8>>2]=0;Fe(b,c+8|0);Xe(b,0)}gb=c+16|0;if(!w[a+15|0]){break d}v[22692]=0;b=Q(2486,i|0,45)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(63,g|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22692]=0;b=Q(2486,i|0,48)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;f:{if(e>>>0>=d>>>0){break f}while(1){if((b|0)!=v[e>>2]){break f}e=e+4|0;if(d>>>0>e>>>0){continue}break}}v[22692]=0;U(2504,g|0,e|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break c}break b}v[22692]=0;b=Q(2470,a+440|0,a+432|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Wb(a+16|0);Hc(h);gb=a+448|0;return b|0}e=P()|0;O()|0;Wb(a+16|0)}Hc(h);S(e|0);L()}function ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-1072|0;gb=e;v[e+1068>>2]=c;l=Ae(b);g=eD(e+8|0,b);v[22692]=0;m=hp(g);c=v[22692];v[22692]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22692]=0;c=T(465,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}v[e+4>>2]=c;v[22692]=0;v[e>>2]=536870911;c=Fb(e+4|0,e);d=v[22692];v[22692]=0;if((d|0)==1){break c}tc(e+1068|0,v[c>>2]<<3);v[22692]=0;k=Q(511,a|0,v[e+1068>>2])|0;a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;a=8;f=Q(198,g|0,8)|0;d=v[22692];v[22692]=0;c=1;e:{f:{if((d|0)==1){break f}d=zb(f&255);n=kc(k,0),o=d,t[n|0]=o;g:{if(y[e+1068>>2]<2){break g}while(1){v[22692]=0;j=a&255;d=Q(198,g|0,j|0)|0;h=v[22692];v[22692]=0;h:{i:{j:{k:{if((h|0)!=1){if(d){break k}if(j>>>0>8){break g}a=a+1|0;break j}break f}h=f;f=d>>>1|0;f=h+(d&1?0-f|0:f)|0;h=zb(f&255);n=kc(k,c),o=h,t[n|0]=o;c=c+1|0;if(!(d<<1>>>j|0)){break i}}i=0;break h}i=i+1|0;d=i&255;a=a-(j>>>0>1&d>>>0>=l>>>0)|0;i=d>>>0<l>>>0?i:0}if(y[e+1068>>2]>c>>>0){continue}break}}v[22692]=0;a=hp(g);c=v[22692];v[22692]=0;if((c|0)==1){break f}v[22692]=0;Q(188,b|0,((a-m|0)+3&-4)+m|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;gc(k);break a}xb(g);gb=e+1072|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(g);S(a|0);L()}function Y0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;if(c>>>0<d>>>0){continue}break}}f=0;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return f|0}function xu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{f=a;d=b;b:{c:{i=a+58|0;h=lc(i,b);b=t[h|0];if((b|0)==-1){break c}if((b|0)>-1){break b}b=b&127;e=wd(f+22|0,b);g=x[e>>1];if((d|0)!=(g|0)?(g|0)!=65535:0){break c}u[e>>1]=d;t[h|0]=b;break b}m=f+4|0;j=f+22|0;g=255;b=0;e=255;while(1){k=wd(j,b);l=x[k>>1];if((l|0)==65535){u[k>>1]=d;t[h|0]=b;break b}if(!(w[lc(m,b)|0]&32)){g=t[lc(i,l)|0]>-1?g:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(g&255)==255?e:g;e=wd(j,b&255);n=lc(i,x[e>>1]),o=255,t[n|0]=o;u[e>>1]=d;t[h|0]=b}b=Gl(f,d)}e=b&255;if((e|0)==255){break a}if(qk(a)){break a}d=QA(a+314|0,e);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=b;t[d+9|0]=b>>>8;t[d+10|0]=b>>>16;t[d+11|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=b;t[d+5|0]=b>>>8;t[d+6|0]=b>>>16;t[d+7|0]=b>>>24;g=PR(e);h=g+3|0;b=0;d=1;while(1){f=d;d=d?g:h;Yh(v[a>>2],(d|32)&65535,w[lc(c,b)|0]);Yh(v[a>>2],(d|64)&65535,w[lc(c,b|2)|0]);Yh(v[a>>2],(d|96)&65535,w[lc(c,b|4)|0]);Yh(v[a>>2],(d|128)&65535,w[lc(c,b|6)|0]);Yh(v[a>>2],(d|224)&65535,w[lc(c,b|8)|0]);d=0;b=1;if(f){continue}break}Yh(v[a>>2],yu(e)|192,w[lc(c,10)|0])}}function w3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;l=sD(g);g=px(g);Tg(k,g);a:{b:{if(ed(k)){v[22692]=0;Y(2456,l|0,a|0,c|0,d|0);g=v[22692];v[22692]=0;if((g|0)==1){break a}g=(c-a|0)+d|0;v[f>>2]=g;break b}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22692]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22692]=0;h=Q(22,l|0,48)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22692]=0;h=Q(22,l|0,h|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}im(j,c);v[22692]=0;o=T(2448,g|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}if(c>>>0>j>>>0){p=(c-j|0)+j|0;g=j;h=0;i=0;while(1){e:{if(!w[nc(k,h)|0]){break e}if(t[nc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22692]=0;n=Q(22,l|0,n|0)|0;m=v[22692];v[22692]=0;if((m|0)==1){break a}m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;i=i+1|0;g=g+1|0;if((p|0)!=(g|0)){continue}break}}im((j-a|0)+d|0,v[f>>2]);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);S(a|0);L()}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Mb(k,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];l=jqa(e,e>>31,f,f>>31);e=J+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;h=jqa(H,I,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=c>>>4;v[e+16>>2]=v[a>>2];j=v[Fb(e+24|0,e+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){d=b;f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[$g(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=fe(h);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=d,n=Uc(f),u[m>>1]=n;d=b;f=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24);g=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[$g(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=fe(h);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=d,n=Uc(f),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=e+32|0;return j<<4}function Gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;e=u[f>>1];v[b+8>>2]=e;v[b+12>>2]=u[f+2>>1];i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Mb(n,-16777216,16776704);m=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=jqa(l,r,e,e>>31);l=jb;m=jqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=jqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function q2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-496|0;gb=a;Fc(a+488|0,d);v[22692]=0;m=T(2464,a+488|0)|0;g=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=v[sk(f,0)>>2];v[22692]=0;h=Q(2486,m|0,45)|0;k=v[22692];v[22692]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[22692]=0;na(2508,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}v[a+4>>2]=2440;c=he(a+8|0,0,a+4|0);i=Ab(f);l=v[a+420>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Cd(j<<2));i=v[c>>2];if(i){break e}v[22692]=0;X(2441);b=v[22692];v[22692]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22692]=0;qa(2509,i|0,a+4|0,a|0,j|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;b=la(2489,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}Ic(h);Ic(g);vb(k)}Wb(a+488|0);S(f|0);L()}Hc(c);Ic(h);Ic(g);vb(k);Wb(a+488|0);gb=a+496|0;return b|0}function una(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kv(a);if(b>>>0<=63){k=gb-32|0;gb=k;a:{b:{j=64-b|0;c:{if(j>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/33>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(j,33);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){tC(a);a=a+33|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}i=wb(a);f=k+8|0;d=a;c=kv(a)+j|0;h=gb-16|0;gb=h;v[h+12>>2]=c;e=gb-16|0;gb=e;v[e+12>>2]=130150524;v[22692]=0;v[e+8>>2]=2147483647;g=Fb(e+12|0,e+8|0);b=v[22692];v[22692]=0;d:{if((b|0)!=1){gb=e+16|0;b=v[g>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0>=c>>>0){c=oW(d);if(c>>>0<b>>>1>>>0){v[h+8>>2]=c<<1;b=v[Mc(h+8|0,h+12|0)>>2]}gb=h+16|0;break e}Sc();L()}d=kv(a);e=0;g=gb-16|0;gb=g;v[g+12>>2]=0;hf(f+12|0,i);if(b){c=b;if(b>>>0>=130150525){pd(8399);L()}e=Nc(B(c,33),1)}v[f>>2]=e;c=B(d,33)+e|0;v[f+8>>2]=c;v[f+4>>2]=c;l=dc(f),m=B(b,33)+e|0,v[l>>2]=m;gb=g+16|0;v[22692]=0;sW(f,j);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=a;c=f;i=c+4|0;d=v[a+4>>2];a=v[a>>2];g=d-a|0;d=v[i>>2]+B((g|0)/-33|0,33)|0;v[i>>2]=d;if((g|0)>=1){hc(d,a,g)}wc(b,i);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];rW(f)}gb=k+32|0;break a}a=P()|0;O()|0;rW(f);S(a|0);L()}return}if((b|0)!=64){Sk(a,v[a>>2]+2112|0)}}function d1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;i=d;j=(c|0)==(d|0);a:{if(j){break a}i=c;while(1){if(!w[i|0]){break a}i=i+1|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];m=ui(l+8|0,l+12|0);v[22692]=0;j=jH(f,e,i-c|0,g-f>>2,b);n=v[22692];v[22692]=0;d:{if((n|0)!=1){ff(m);gb=l+16|0;break d}a=P()|0;O()|0;ff(m);S(a|0);L()}e:{f:{g:{h:{i:{j:{k:{if((j|0)==-1){v[h>>2]=f;if(v[e>>2]!=(c|0)){while(1){g=1;l:{m:{n:{b=zG(f,c,i-c|0,k+8|0,v[a+8>>2]);switch(b+2|0){case 0:break i;case 2:break l;case 1:break n;default:break m}}v[e>>2]=c;break k}g=b}f=v[h>>2]+4|0;v[h>>2]=f;c=c+g|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break c}f=v[h>>2]+(j<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break h}c=v[e>>2];if((d|0)==(i|0)){i=d;break e}if(!zG(f,c,1,b,v[a+8>>2])){break j}}a=2;break b}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;if((c|0)==(d|0)){break g}while(1){if(!w[i|0]){break f}i=i+1|0;if((i|0)!=(d|0)){continue}break}break g}v[e>>2]=c;a=1;break b}c=v[e>>2];break c}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}a=(c|0)!=(d|0)}gb=k+16|0;return a|0}function Hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+o|0;e=t[f|0]<<8;v[b+8>>2]=e;v[b+12>>2]=t[f+1|0]<<8;i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Mb(n,-16777216,16776704);m=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=jqa(l,r,e,e>>31);l=jb;m=jqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=jqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function Boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;a:{b:{if(!Pb(b,9)){break b}i=a+484344|0;j=a+480280|0;while(1){ap(b,c+44|0);d=qg(b);c:{if(!((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1229999433|(w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1397771593|((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1297110104|(w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1297110099))){if(Pb(b,d)){break c}}ng(b,8);break b}ud(c,b,d);g=jc(c+24|0,c);xb(c);d=j;d:{if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1481001027){while(1){v[22692]=0;e=T(190,g|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}t[d+8|0]=e;d=d+32|0;if((i|0)!=(d|0)){continue}break d}}e:{if(w[c+44|0]!=70){break e}d=w[c+45|0];e=(d|0)==88;if(!((d-48&255)>>>0>9?e:1)){break e}f=w[c+46|0];if((f-48&255)>>>0>9){break e}h=w[c+47|0];if((h-48&255)>>>0>9){break e}d=(B(f,10)+(e?-16:B(d,100)+48|0)|0)+h&255;if(d>>>0>249){break d}v[22692]=0;R(601,g|0,(B(d,160)+a|0)+906300|0);d=v[22692];v[22692]=0;if((d|0)!=1){break d}break a}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;k=1}xb(c+24|0);if(Pb(b,9)){continue}break}}gb=c+48|0;return k|0}a=P()|0;O()|0;xb(c+24|0);S(a|0);L()}function rea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);i=gb-16|0;gb=i;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Nb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}h=u[d+2>>1];if((h|0)<(g|0)){break a}if((Nb(b)-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Nb(b)){break b}while(1){if(!(z[Lb(b,f)>>2]<C(0))){f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=lN(Nb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;wl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=Vb(b);f=Zb(b);l=i,m=Vb(g),v[l+8>>2]=m;h=So(i+8|0,u[e>>1]-u[d>>1]|0);b=gb-16|0;gb=b;yc(b+8|0,Fn(Sl(c),Sl(f),Sl(h)));gb=b+16|0;c=u[a+28>>1];f=u[e>>1];c:{if((c|0)>=(f|0)){break c}b=f;while(1){b=b-1|0;j=z[Lb(g,u[a+30>>1]+(b-c|0)|0)>>2];k=z[a+32>>2];l=Lb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;f=u[e>>1];c=u[a+28>>1];if((c|0)>=(b|0)){break c}if((f|0)!=-32768){continue}break}}d:{h=u[a+30>>1];b=h+f|0;if((b|0)>u[d+2>>1]|(32767-h|0)<(f|0)){break d}while(1){j=z[a+32>>2];k=z[Lb(g,b-((c<<16>>16)+h|0)|0)>>2];l=Lb(g,b-u[a+28>>1]|0),n=C(k*j),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}h=u[a+30>>1];if(u[e>>1]>(32767-h|0)){break d}b=b+1|0;c=x[a+28>>1];continue}}iq(a);f=1}gb=i+16|0;return f|0}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=jg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function nga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;b=a+8|0;fu(b,Yd(b));l=wb(b),m=0,v[l>>2]=m;l=b,m=fc(b),v[l>>2]=m;l=fc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;d=a+4|0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];j=x[b+480188>>1];v[h+8>>2]=0;v[h+12>>2]=0;i=h+8|0;u[i+4>>1]=65280;v[i>>2]=0;g=gb-16|0;gb=g;v[g+12>>2]=j;f=a+20|0;a:{if(rg(f)>>>0>=j>>>0){l=g,m=qf(f),v[l+8>>2]=m;c=v[f>>2];b=i;e=v[Fb(g+12|0,g+8|0)>>2];if(e){while(1){v[c>>2]=v[b>>2];u[c+4>>1]=x[b+4>>1];c=c+8|0;e=e-1|0;if(e){continue}break}}b=v[g+12>>2];c=v[g+8>>2];if(b>>>0>c>>>0){bP(f,b-c|0,i);break a}Sk(f,v[f>>2]+(b<<3)|0);break a}b=f;if(v[b>>2]){Pd(b);cP(v[b>>2],rg(b));l=wb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}c=fs(f,j);if(yw()>>>0<c>>>0){Sc();L()}e=c;if(c>>>0>=536870912){pd(8399);L()}e=Nc(e<<3,4);v[b>>2]=e;v[b+4>>2]=e;l=wb(b),m=e+(c<<3)|0,v[l>>2]=m;bP(f,j,i)}gb=g+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(k,872);Vm((b+v[d>>2]|0)+616|0,7,v[a>>2],k&65535,134217728);t[(b+v[d>>2]|0)+1433|0]=0;t[(b+v[d>>2]|0)+1432|0]=0;t[(b+v[d>>2]|0)+1415|0]=0;t[(b+v[d>>2]|0)+1418|0]=0;t[(b+v[d>>2]|0)+1413|0]=0;k=k+1|0;if(k>>>0<x[v[a>>2]+480188>>1]){continue}break}}gb=h+16|0}function xx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;g=gb-1040|0;gb=g;s=v[115173];m=g+16|0;a:{b:{c:{n=g+16|0;e=b;h=v[22597];d:{e:{while(1){if((e|0)!=w[d+74880|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=74976;break d}d=74976;while(1){i=w[d|0];e=d+1|0;d=e;if(i){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[h+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];j=v[f>>2]+1794895138|0;l=lm(v[f+8>>2],j);h=lm(v[f+12>>2],j);i=lm(v[f+16>>2],j);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((h|i)&3|(c>>>0<=h>>>0|c>>>0<=i>>>0)){break f}u=i>>>2|0;x=h>>>2|0;while(1){o=l>>>1|0;h=o+p|0;i=h<<1;c=(i+x<<2)+f|0;q=lm(v[c>>2],j);c=lm(v[c+4>>2],j);if(c>>>0>=k>>>0|k-c>>>0<=q>>>0|w[(c+q|0)+f|0]){break f}c=sj(d,c+f|0);if(!c){d=(i+u<<2)+f|0;c=lm(v[d>>2],j);d=lm(v[d+4>>2],j);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}r=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?o:l-o|0;p=c?p:h;continue}}}d=r?r:e;e=Mf(d);g:{if(e>>>0>=1024){hc(n,d,1023);t[n+1023|0]=0;e=68;break g}hc(n,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[115173]}m=18699;if((e|0)==28){break a}Da();L()}if(!w[m|0]){v[g>>2]=b;Nx(g+16|0,1024,10299,g);m=g+16|0}v[115173]=s;Tb(a,m);gb=g+1040|0}function hqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;hb=a-B(b,c)|0;ib=0;jb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}hb=a;ib=f&g;a=g>>>iqa(e)|0;jb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}hb=0;a=(g>>>0)/(e>>>0)|0;ib=g-B(a,e)|0;jb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}hb=a&f;ib=0;if((e|0)==1){break a}c=a;a=iqa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}jb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}hb=l;ib=f;e=b<<1|a>>>31;a=k|a<<1;jb=e|m;return a}hb=a;ib=b;a=0;b=0}jb=b;return a}function VY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;f=gb-144|0;gb=f;v[22692]=0;l=T(416,a|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){a:{if(l){p=f+8|4;q=f+8|6;r=f+8|5;k=f+8|2;m=f+8|3;n=f+16|0;while(1){v[22692]=0;R(447,a|0,f+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}e=f+8|0;e=Ib(w[e|0]|w[e+1|0]<<8);b:{if(!e|e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[22692]=0;e=hi(e,b);g=v[22692];v[22692]=0;if((g|0)==1){break a}c:{if(!w[m|0]){break c}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=w[m|0];v[22692]=0;t[f+7|0]=31;g=ac(f+4|0,f+7|0);i=v[22692];v[22692]=0;if((i|0)==1){break a}g=w[g|0];v[22692]=0;i=g+1&255;R(448,e|0,i|0);g=v[22692];v[22692]=0;if((g|0)==1){break a}t[e+13|0]=w[r|0];t[e+14|0]=w[q|0];g=w[p|0];t[e+15|0]=g;t[e+16|0]=g;g=0;if(!i){break b}while(1){h=g<<2;j=h+n|0;j=Ib(w[j|0]|w[j+1|0]<<8);s=Lb(e,g),y=j,u[s>>1]=y;h=(h|2)+n|0;h=Ib(w[h|0]|w[h+1|0]<<8);u[f+4>>1]=d?h+128>>>2|0:h;wg(f+4|0,64);h=w[f+4|0];s=Lb(e,g),y=h,t[s+2|0]=y;g=g+1|0;if((i|0)!=(g|0)){continue}break}}o=o+1|0;if((o&65535)>>>0<l>>>0){continue}break}}xb(a);gb=f+144|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function u2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-192|0;gb=a;Fc(a+184|0,d);v[22692]=0;m=T(21,a+184|0)|0;g=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=w[nc(f,0)|0];v[22692]=0;h=Q(22,m|0,45)|0;k=v[22692];v[22692]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[22692]=0;na(2506,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}v[a+4>>2]=2440;c=he(a+8|0,0,a+4|0);i=Ab(f);l=v[a+124>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Cd(j));i=v[c>>2];if(i){break e}v[22692]=0;X(2441);b=v[22692];v[22692]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22692]=0;qa(2507,i|0,a+4|0,a|0,j|0,o|0,f+p|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;b=la(17,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}vb(h);vb(g);vb(k)}Wb(a+184|0);S(f|0);L()}Hc(c);vb(h);vb(g);vb(k);Wb(a+184|0);gb=a+192|0;return b|0}function uga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;g=gb-32|0;gb=g;s=g,t=B(v[a>>2],dd(a)),v[s+4>>2]=t;tc(g+4|0,c>>>3|0);c=zb(b);i=A[e+8>>3];j=v[g+4>>2];a:{if(!j){break a}e=j;while(1){k=0;f=c;m=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=h<<24|h<<8&16711680;o=k;k=m<<24|h>>>8;f=m<<8|h>>>24;o=o|0;k=k&65280|f&255|q;f=m;l(0,((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24)|o);l(1,k&2147483647);i=G(+n(),i);c=c+8|0;e=e-1|0;if(e){continue}break}if(i==0){break a}r=1/i;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24;q=0;m=h<<8&16711680|f;o=a<<24|h>>>8;f=a<<8|h>>>24;e=a;l(0,((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,m|(o&65280|f&255));s=g,x=+n()*r,A[s+24>>3]=x;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;p=A[$g(g+24|0,g+16|0,g+8|0)>>3]*32768;A[g+24>>3]=p;a=c;p=fe(p);b:{if(D(p)<2147483648){e=~~p;break b}e=-2147483648}s=a,t=Uc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;j=j-1|0;if(j){continue}break}}if(d){A[d>>3]=i}gb=g+32|0;return v[g+4>>2]<<3}function tW(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+28880|0];b:{switch(d-8|0){case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[ac(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[ac(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 0:t[b|0]=w[b|0]<<1;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0>=224){if(a>>>0>239){break a}t[b|0]=a>>>2&3|240;break a}t[b|0]=a>>>0>63?15:a>>>2|0}gb=c+16|0}function EP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;d=v[b+64>>2];a:{b:{g=v[b+60>>2];f=x[b+68>>1];if(!((f|0)==65535?(g|0)==-1:0)){c:{if((d|0)==-1){break c}d=a+1074312|0;Db(e+24|0,d,68);if(Cb(e+24|0)){break c}Db(e+16|0,d,103);if(h=Cb(e+16|0),i=0,j=(f|0)!=65535,j?h:i){break c}Db(e+8|0,d,49);if(h=Cb(e+8|0),i=0,j=(f|0)!=65535,j?h:i){break c}d=v[b+64>>2];break b}if((f|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((g|0)==-1){v[b+60>>2]=0}d=x[b+68>>1];f=a+484360|0;d:{if(sc(Sb(f))>>>0>d>>>0){d=x[b+68>>1];break d}d=x[Sb(f)+28>>1];u[b+68>>1]=d}e:{if(x[b+72>>1]==(d&65535)){break e}d=a+1074312|0;Db(e+24|0,d,26);if(Cb(e+24|0)){break e}Db(e+16|0,d,68);if(Cb(e+16|0)|v[a+480180>>2]==1|!x[a+480188>>1]){break e}d=0;while(1){t[(B(d,872)+b|0)+1457|0]=0;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[b+52>>2]=v[b+60>>2];if(c){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((d|0)!=-1){break b}c=0;break a}v[b+52>>2]=d;u[b+74>>1]=x[b+72>>1];f:{if(!v[b+20>>2]){break f}if(v[a+480180>>2]==32){Db(e+24|0,a+1074312|0,103);if(Cb(e+24|0)){break f}}if(v[a+480180>>2]==2){break f}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[_b(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}gb=e+32|0;return c}function wI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=gb-16|0;gb=k;a:{b:{c:{if((c|0)<=36){g=w[a|0];if(g){break c}f=a;break b}v[115173]=28;d=0;e=0;break a}f=a;d:{while(1){if(!tm(g<<24>>24)){break d}g=w[f+1|0];h=f+1|0;f=h;if(g){continue}break}f=h;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=-48;h=t[f|0];h:{if((h-48&255)>>>0<10){break h}g=-87;if((h-97&255)>>>0<26){break h}g=-55;if((h-65&255)>>>0>25){break g}}h=g+h|0;if((h|0)>=(l|0)){break g}pf(k,p,q,0,0,j,i,0,0);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=jqa(j,i,p,q);n=jb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[115173]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[115173]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[115173]=68;break a}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^i)-((a>>>0>b>>>0)+c|0)|0}gb=k+16|0;jb=e;return d}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb-2160|0;gb=b;Qb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[22692]=0;b=Q(70,b+96|0,7677)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}g=v[c>>2];d=v[c+12>>2];h=v[c+8>>2];v[b+88>>2]=h;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;c=b;j=b;i=ZK(b+32|0);if(i){e=b- -64|0;v[e>>2]=h;v[b+68>>2]=d;d=v[e+4>>2];v[b+24>>2]=v[e>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;d=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=d;d=YK(b+16|0)}else{d=0}v[j+72>>2]=d;v[c+76>>2]=0;c=0;d=2048;while(1){d:{e=kb[f|0](g,(b+112|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}c=vd(b+48|0,zb(b+112|0),c);f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;a=_z(a,b+8|0,i?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[22692]=0;b=Q(70,b+96|0,5175)|0;c=v[22692];v[22692]=0;if((c|0)!=1){qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0);break b}gb=b+2160|0;return a|0}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function U0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];j=d>>>0>b>>>0;a:{if(b>>>0>=d>>>0|f>>>0>=g>>>0){break a}b:{while(1){j=t[b|0];c=j&255;c:{if((j|0)>-1){i=1;break c}j=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-b|0)<2){break b}i=w[b+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(c>>>0<=239){if((d-b|0)<3){break b}k=w[b+2|0];i=w[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(c>>>0>244){break a}if((d-b|0)<4){break b}l=w[b+3|0];m=w[b+2|0];k=w[b+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=b+i;f=v[a+8>>2]+4|0;v[a+8>>2]=f;b=v[a+12>>2];j=d>>>0>b>>>0;if(b>>>0>=d>>>0){break a}if(f>>>0<g>>>0){continue}break}break a}j=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return j|0}function Poa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;e=a;g=a+3|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=w[a+3|0];switch(b-14|0){case 0:break j;case 2:case 3:case 4:case 5:break b;case 8:break g;case 6:case 7:break h;case 1:break i;default:break k}}switch(b-31|0){case 2:break e;case 0:break f;default:break b}}c=w[a+5|0];if(!c){c=14;break d}l:{if((c|0)!=15){if((c|0)!=240){break l}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(c>>>0>=16){t[a+5|0]=c|15;break c}t[a+5|0]=c|240;break c}t[a+5|0]=w[a+5|0]^128;break c}c=w[a+5|0];if(c>>>0>=16){t[d+15|0]=c>>>4;t[d+14|0]=15;h=a,i=w[ac(d+15|0,d+14|0)|0]|240,t[h+5|0]=i;break c}t[a+5|0]=c|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}h=a,i=ei(w[a+5|0]<<1),t[h+5|0]=i;break c}b=32;m:{n:{o:{p:{q:{r:{s:{f=w[a+5|0];switch(f>>>4|0){case 12:case 13:break m;case 3:break n;case 5:break o;case 14:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break d}}b=64;break n}b=176;break n}b=224;break n}t[a+5|0]=119;break c}b=48}t[a+5|0]=f&15|b;break c}if(f){break c}}t[e+3|0]=w[c+28816|0];break a}b=w[e+3|0]}if(b>>>0<36){t[e+3|0]=w[b+28816|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;t[a+4|0]=w[a+5|0];g=a+5|0}t[g|0]=0}gb=d+16|0}function rpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-32|0;gb=h;v[h+24>>2]=b;b=v[a>>2];m=h,n=Vb(a),v[m>>2]=n;b=Yj(h+24|0,h)+b|0;a:{g=QX(c,d);b:{if((g|0)<1){break b}i=v[wb(a)>>2];e=v[a+4>>2];if((g|0)<=(i-e|0)){v[h>>2]=d;i=e-b|0;if((i|0)<(g|0)){v[h>>2]=c;cw(h,i);l=v[h>>2];k=gb-16|0;gb=k;j=zi(k,a,g-i|0);wb(a);f=gb-16|0;gb=f;v[f>>2]=d;v[f+8>>2]=l;if(Gb(f+8|0,f)){while(1){ep(v[j+4>>2],v[f+8>>2]);Ne(f+8|0);v[j+4>>2]=v[j+4>>2]+1;if(Gb(f+8|0,f)){continue}break}}gb=f+16|0;$b(j);gb=k+16|0;if((i|0)<1){break b}}k=gb-16|0;gb=k;f=e;j=b;i=a;l=v[a+4>>2];a=(l-(b+g|0)|0)+b|0;g=zi(k,i,e-a|0);if(a>>>0<e>>>0){e=v[g+4>>2];d=a;while(1){wb(i);ep(e,d);e=e+1|0;v[g+4>>2]=e;d=d+1|0;if(f>>>0>d>>>0){continue}break}}$b(g);wr(j,a,l);gb=k+16|0;Vi(c,v[h>>2],b);break b}e=wb(a);e=Yg(h,nh(a,pc(a)+g|0),b-v[a>>2]|0,e);v[22692]=0;PX(e,c,d);c=v[22692];v[22692]=0;if((c|0)==1){break a}rt(a);c=v[e+4>>2];j=e+4|0;wk(wb(a),v[a>>2],b,j);wb(a);i=e+8|0;d=i;g=v[a+4>>2];if((g|0)!=(b|0)){f=v[d>>2];while(1){ep(f,b);f=v[d>>2]+1|0;v[d>>2]=f;b=b+1|0;if((g|0)!=(b|0)){continue}break}}xc(a,j);xc(a+4|0,i);xc(wb(a),dc(e));v[e>>2]=v[e+4>>2];pt(a,pc(a));b=c;be(e)}Fg(b);gb=h+32|0;return}a=P()|0;O()|0;be(e);S(a|0);L()}function KO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b:{d=a+484360|0;if(sc(Sb(d))>>>0<=b>>>0){break b}if(Go(Sb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(sc(Sb(d))>>>0<=c>>>0){break a}if(!Go(Sb(d),b&65535)){continue}break}break a}c=b}if(sc(Sb(d))>>>0>c>>>0){d=a+1074312|0;f=a+1298224|0;c=a+1074992|0;while(1){t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;Db(e+8|0,d,23);if(Cb(e+8|0)){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;if((f|0)!=(c|0)){continue}break}JO(a);c:{if(!(b&65535)){b=a;c=0;while(1){Vm((b+B(c,872)|0)+1074992|0,7,b,c&65535,134217728);c=c+1|0;if((c|0)!=256){continue}break}Co(b+1298224|0,1);v[b+1074456>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;mA(b+1074376|0);u[b+1074450>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}gb=e+16|0}function uq(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)==2097152){break a}break d}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=Vb(a),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;d=1;if(!Gb(c+8|0,c)){break a}while(1){a=v[c+8>>2];if(!(!gi(a)|v[a+12>>2]==64)){d=4;break a}RO(c+8|0);if(Gb(c+8|0,c)){continue}break}break a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}gb=c+16|0;return d}function p8(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-80|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(xj(a)){wh(d+72|0);break g}ho(d+32|0,a);v[22692]=0;c=T(2068,d+32|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}v[d+72>>2]=c;Vf(d+32|0)}if(xj(a)){e=a+36|0}else{e=v[d+72>>2]}c=v[a+8>>2];if((c|0)!=-1){break c}c=v[e+4>>2]-24|0;h=co(e);if(h){break e}break d}g=P()|0;O()|0;Vf(d+32|0);break a}j=A[c>>3];while(1){f=Ol(e,g);if(A[f>>3]+i>b){c=f;break d}i=j+i;g=g+1|0;if((h|0)!=(g|0)){continue}break}}b=b-i;break b}c=Ol(e,c)}e=a+24|0;f=v[e>>2];g=x[c+12>>1];v[22692]=0;R(2069,f|0,g|0);f=v[22692];v[22692]=0;if((f|0)!=1){h:{f=v[e>>2];g=w[a+64|0];c=rL(uV(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22692]=0;h=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=h;h=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=h;h=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=h;Y(2033,d+56|0,f|0,(g?7:1)|0,d+8|0);c=v[22692];v[22692]=0;if((c|0)==1){break h}c=FO(d+56|0);f=t[c+26|0]&1;g=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];$m(d+56|0);u[v[e>>2]+1074448>>1]=f;u[v[e>>2]+1074450>>1]=f;v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;b=b+i;A[a+16>>3]=b;pl(d+72|0);gb=d+80|0;return+b}}g=P()|0;O()|0;pl(d+72|0)}S(g|0);L()}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=g+32|0}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;a:{b:{if(!Nd(a)){break b}if((b|0)==(c|0)|(dd(a)|0)!=2){break b}if(l=Nd(b),m=0,n=(a|0)!=(b|0),n?l:m){break b}if(l=Nd(c),m=0,n=(a|0)!=(c|0),n?l:m){break b}if((a|0)==(b|0)){j=v[b+20>>2]}else{j=Oq(v[a>>2],fj(a))}e=j;if((a|0)==(c|0)){f=v[c+20>>2]}else{f=Oq(v[a>>2],fj(a))}if(!(f?e:0)){if((a|0)!=(b|0)){Pq(j)}if((a|0)==(c|0)){break b}Pq(f);break b}c:{if((fj(a)|0)==2){g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){u[g>>1]=x[h>>1];u[e>>1]=x[h+2>>1];h=h+4|0;e=e+2|0;g=g+2|0;i=i-1|0;if(i){continue}break}}break c}if((fj(a)|0)!=1){break c}g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){t[g|0]=w[h|0];t[e|0]=w[h+1|0];h=h+2|0;e=e+1|0;g=g+1|0;i=i-1|0;if(i){continue}break}}}Uo(b,a);v[b+20>>2]=j;u[b+34>>1]=x[b+34>>1]&65471;Uo(c,a);v[c+20>>2]=f;u[c+34>>1]=x[c+34>>1]&65471;j=d+1298224|0;a=d+1074992|0;while(1){f=v[a+104>>2];if(!((c|0)!=(f|0)?(f|0)!=(b|0):0)){v[a+88>>2]=v[a+88>>2]&-65}a=a+872|0;if((j|0)!=(a|0)){continue}break}v[22692]=0;_h(b,d,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[22692]=0;_h(c,d,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}g=1}gb=k+16|0;return g|0}a=P()|0;O()|0;S(a|0);L()}function Afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=gb-48|0;gb=j;l=-1;d=gb-32|0;gb=d;i=j+8|0;jF(d+24|0,i);g=yb(d+24|0);f=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=f;v[d>>2]=e;v[d+4>>2]=f;f=a;fd(d+16|0,f,d);e=yb(d+16|0);if((e|0)==(g|0)){ad(f,yb(d+24|0))}gb=d+32|0;f=(e|0)==(g|0);if(!f){kF(i)}a:{if(!f){break a}l=0;if(!TN(j+8|0)){break a}if(c){d=a;e=j+8|0;b:{if(!c){break b}m=Mf(c);if(!m){break b}q=v[d+12>>2];if(Nl(d,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))){c:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break c}while(1){if(!Tf(d,5)){break c}d:{if((w[e+4|0]|w[e+5|0]<<8)>>>0>=64){f=d;i=Wv(d);h=i&63;e:{if(!(i&64)){break e}g=6;while(1){k=Wv(f);h=(k&127)<<g|h;if(!(k&128)){break e}k=g>>>0<25;g=g+7|0;if(k){continue}break}}if(((i&128?0-h|0:h)|0)<1){break d}}h=0;g=1;while(1){f=Wv(d);if(f){k=Vq(f<<24>>24);o=h>>>0>=m>>>0;i=o&g;f=i;f:{if(o){break f}f=i;if(!(g&1)){break f}f=w[c+h|0]==(k&255)}g=f;h=h+1|0;continue}break}ad(d,4);n=(h|0)==(m|0)?g?1:n:n}p=p+1|0;if(p>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}h=n&1}Nl(d,q)}if(!h){break a}}l=Me(a,b,SN(j+8|0),0)}gb=j+48|0;return l|0}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=jg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function kZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;t[g+12|0]=0;l=ND(g+16|0,d,g+12|0);h=v[l>>2];v[g+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=g;i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[22692]=0;v[g+8>>2]=f;f=Fb(g+8|0,g+12|0);i=v[22692];v[22692]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[h|0]=i;f=v[g+12>>2]-1|0;v[g+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;gc(l);S(a|0);L()}t[h|0]=e;f=v[g+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[g+12>>2]-1|0}v[m+12>>2]=f;h=h+1|0}if(!i){break a}a=k;b=i;if(f){continue}break}}k=v[l>>2];e=d-f|0;if(e){h=128;i=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+i|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=i+1|0;i=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(B(h,257)&65535)>>>f&255;k=k+1|0;n=n+1|0;if((n|0)!=(e|0)){continue}break}j=0;while(1){d=c;f=d;m=j<<24>>24;b=t[d|0];d=128;e:{if((b|0)==-128){break e}a=b;d=a;if((a|0)>-1){break e}d=0-(b&127)|0}j=m-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}gc(l);gb=g+32|0}function gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;t[f+16|0]=44;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=1058;v[f+4>>2]=2;j=a;c=gb+-64|0;gb=c;k=c;a=f;h=v[a>>2]&2?16:10;g=gb-32|0;gb=g;d=Ge(g+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);i=Jb(d);l=Ab(d);m=v[b>>2];v[22692]=0;ha(92,g+8|0,e|0,i+l|0,m|0,h|0);e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!v[g+12>>2]){break c}e=Ab(d);v[22692]=0;v[g+4>>2]=e;e=wf(g+4|0);i=v[22692];v[22692]=0;if((i|0)!=1){v[22692]=0;U(75,d|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)!=1){continue}}break}break b}b=v[g+8>>2];h=Jb(d);v[22692]=0;R(76,d|0,b-h|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(77,k|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=g+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}El(c+16|0,c,a);v[22692]=0;U(89,c+32|0,c+16|0,a|0);b=v[22692];v[22692]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22692]=0;U(90,c+48|0,c+32|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}v[22692]=0;R(72,j|0,c+48|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function Zg(a,b,c,d){var e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+12>>2]=d;e=b-1|0;f=0;a:{if(e>>>0>249){break a}h=bp(a);f=v[a+480180>>2];if(!h){if(f&17408){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+39680>>1]<<4>>>a|0;break a}if(mk(a)){a=((e&255)>>>0)/12|0;b=jqa(v[(e-B(a,12)<<6&960)+43568>>2]<<a,0,d,0);a=jb;c=a>>>21|0;f=Qc((a&2097151)<<11|b>>>21,c);break a}if(w[a+480208|0]&16){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+39680>>1]<<5>>>a|0;break a}if(!d){v[g+12>>2]=8363}a=((e&255)>>>0)/12|0;tc(g+12|0,-1>>>a|0);f=Qc(mqa(jqa(x[((e-B(a,12)&255)<<1)+39680>>1],0,267616,0),jb,v[g+12>>2]<<a,0),jb);break a}if(f&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Db(g,a+1074312|0,76);b=Cb(g)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;f=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[g>>2]=c+8;Sd(g,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;f=B(x[(((c|0)<95?c:95)<<1)+40176>>1],b)+B(x[(v[g>>2]<<1)+40160>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(e>>>0<108?a|e>>>0<24:1){b=B(a,12);a=((e&255)>>>0)/12|0;f=x[(b+(e-B(a,12)&255)<<1)+39280>>1]<<5>>>a|0;break a}f=x[(b<<1)+39054>>1]<<2}gb=g+16|0;return f}function L$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Rg(a,v[b+8>>2],e)){Uw(b,c,d);return}a:{if(Rg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}d=v[a+12>>2];if((d|0)<=0){v[b+44>>2]=4;break b}i=((d<<3)+a|0)+16|0;f=a+16|0;j=b;c:{d:{while(1){e:{u[b+52>>1]=0;Tw(f,b,c,c,1,e);if(w[b+54|0]){break e}f:{if(!w[b+53|0]){break f}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break d}h=1;g=1;if(w[a+8|0]&2){break f}break d}h=1;d=g;if(!(t[a+8|0]&1)){break d}}f=f+8|0;if(i>>>0>f>>>0){continue}}break}d=g;a=4;if(!h){break c}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;ys(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(v[b+36>>2]!=1?a&2:1){while(1){if(w[b+54|0]){break a}ys(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}ys(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|(v[b+24>>2]==1?v[b+36>>2]==1:0)){break a}ys(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function EM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=gb-96|0;gb=c;d=v[b+4>>2];v[c+64>>2]=v[b>>2];v[c+68>>2]=d;b=Ud(c+56|0);d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=ls(c+72|0,c+8|0,c);v[22692]=0;b=T(465,d|0)|0;e=v[22692];v[22692]=0;a:{if((e|0)==1){break a}v[22692]=0;b=W(1580,d|0,c+16|0,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break a}b:{if(!b|v[c+16>>2]!=542066252){break b}b=c+16|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+24|0;f=a,g=zo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+28|0;f=a,g=zo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+32|0;f=a,g=zo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+36|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+40|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+44|0]!=0;t[a+4241|0]=w[c+45|0]!=0;t[a+4242|0]=w[c+46|0]!=0;t[a+4243|0]=w[c+47|0]!=0;t[a+4244|0]=w[c+48|0]!=0;Uy(a)}xb(d);gb=c+96|0;return}a=P()|0;O()|0;xb(d);S(a|0);L()}function H2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-160|0;gb=h;v[h+144>>2]=c;v[h+152>>2]=b;v[h+20>>2]=2491;b=he(h+24|0,h+32|0,h+20|0);v[22692]=0;Fc(h+16|0,e);a=v[22692];v[22692]=0;a:{b:{c:{d:{if((a|0)!=1){v[22692]=0;a=T(21,h+16|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break b}t[h+15|0]=0;e=v[e+4>>2];v[22692]=0;c=ra(2492,h+152|0,c|0,d|0,h+16|0,e|0,f|0,h+15|0,a|0,b|0,h+20|0,h+132|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!c){break c}_e(g);if(!w[h+15|0]){break d}v[22692]=0;c=Q(22,a|0,45)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;R(61,g|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22692]=0;d=Q(22,a|0,48)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}e=v[b>>2];c=v[h+20>>2];e:{if(e>>>0>=c-1>>>0){break e}a=(c+(e^-1)|0)+e|0;d=d&255;while(1){if((d|0)!=w[e|0]){break e}e=e+1|0;if((a|0)!=(e|0)){continue}break}e=a}v[22692]=0;U(2498,g|0,e|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break b}v[22692]=0;a=Q(2443,h+152|0,h+144|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}if(a){v[f>>2]=v[f>>2]|2}a=v[h+152>>2];Wb(h+16|0);Hc(b);gb=h+160|0;return a|0}e=P()|0;O()|0;Wb(h+16|0)}Hc(b);S(e|0);L()}function aT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(w[d|0]){e=me(g+8|0,b);b=Mj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Fb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){sd(a,c,iqa(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){kB(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){sd(a,c,iqa(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}sd(a,c,iqa(e));break b}sd(a,c,b)}break a}e=me(g,b);b=Mj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Fb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){sd(a,c,iqa(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){kB(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){sd(a,c,iqa(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}sd(a,c,iqa(e));break d}sd(a,c,b)}}gb=d+16|0;gb=g+16|0}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=e;h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=e;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=i+q|0;i=t[e+2|0];m=t[e+1|0];n=t[e|0];o=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];p=jqa(e,e>>31,f,f>>31);e=w+p|0;f=jb+j|0;f=e>>>0<p>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(n,u[e+46146>>1])+B(o,u[e+46144>>1])|0)+B(m,u[e+46148>>1])|0)+B(i,u[e+46150>>1])<<8)/16384<<8;e=i;h=jqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=h+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Hm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;f=a+1074312|0;Db(e+8|0,f,96);d=Cb(e+8|0);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[a+480180>>2]==16384?v[b+88>>2]&1:0)|0;b:{if(de(b+788|0)){d=v[b+656>>2];if(d){d=x[wd(d+236|0,w[b+788|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if(!(w[b+88|0]&2)|y[b+84>>2]>c>>>0?y[b+76>>2]>c>>>0:0){break b}Db(e+8|0,f,57);if(h=Cb(e+8|0),i=1,j=v[a+480180>>2]!=16,j?h:i){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){Db(e+8|0,f,27);if(Cb(e+8|0)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}gb=e+16|0}function AV(a,b){var c=0,d=0;d=b;a:{b:{c:{d:{if(ke(a,13792)){break d}if(ke(a,14574)){break d}if(ke(a,10837)){break d}if(ke(a,10974)){break d}if(!ke(a,11424)){break c}}v[b>>2]=9244;a=4;break b}e:{f:{if(ke(a,14569)){break f}if(ke(a,10842)){break f}if(!ke(a,13782)){break e}}t[b+10|0]=1;v[b>>2]=5523;a=4;break b}g:{if(!ke(a,11459)){if(!ke(a,11464)){break g}}v[b>>2]=5287;a=8;break b}h:{if(!ke(a,12468)){if(!ke(a,12473)){break h}}v[b>>2]=14146;a=t[a+2|0]-48|0;break b}i:{if(!ke(a,33176)){if(!ke(a,33181)){break i}}v[b+4>>2]=1;v[b>>2]=13952;a=w[a|0]==56?8:4;break b}if(!(rd(a,12569,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=5641;a=t[a+3|0]-48|0;break b}j:{if(rd(a,10907,3)){if(rd(a,11031,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+13|0]=1;t[b+11|0]=1;v[b>>2]=5386;a=t[a+3|0]-48|0;break b}k:{if((w[a|0]-49&255)>>>0>8){break k}c=a;if(!rd(a+1|0,11052,3)){t[b+12|0]=1;v[b>>2]=5689;a=t[a|0]-48|0;break b}if((w[c+1|0]-48&255)>>>0>9|((w[a+2|0]|w[a+3|0]<<8)!=20035?(w[a+2|0]|w[a+3|0]<<8)!=18499:0)){break k}t[b+12|0]=1;v[b>>2]=5689;a=(t[a+1|0]+B(t[a|0],10)|0)-528|0;break b}c=0;if(rd(a,10728,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=5550;a=t[a+3|0]-48|0}u[d+8>>1]=a;c=1}return c}function Id(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;v[a+480180>>2]=b;b=uq(a);bA(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;$t(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Xb(jv(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;aA(a,4);e=gb+-64|0;gb=e;b=a+484344|0;wN(b);f=Qf(b);c=dz(e+8|0,b);v[22692]=0;U(1472,b|0,f|0,c|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){Dm(c);gb=e- -64|0;break a}a=P()|0;O()|0;Dm(c);S(a|0);L()}jS(a+484360|0);_e(a+1298268|0);_e(a+1298280|0);_e(a+1298292|0);c=a+1298304|0;d=Qb(d,0,64);b=XO(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];eu(b);jD(a+1298368|0);Eg(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}gb=d- -64|0}function fda(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-32|0;gb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=kb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[nd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[22692]=0;R(440,d+4|0,b+4|0);b=v[22692];v[22692]=0;c:{if((b|0)!=1){b=v[a+20>>2];v[22692]=0;Vd(c+8|0,b+4|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[c>>2]=0;v[c+4>>2]=0;b=v[c+12>>2];v[c+16>>2]=v[c+8>>2];v[c+20>>2]=b;b=v[c+4>>2];v[c+24>>2]=v[c>>2];v[c+28>>2]=b;v[22692]=0;_(1617,c+16|0);b=v[22692];v[22692]=0;d:{e:{if((b|0)==1){break e}b=v[v[a>>2]+180>>2];v[22692]=0;R(b|0,a|0,-1);b=v[22692];v[22692]=0;if((b|0)==1){break e}b=0;if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[22692]=0;f=C(Za(d|0,a|0,b|0));d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;z[c+8>>2]=f;R(1618,c+16|0,c+8|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+184>>2];v[22692]=0;_(b|0,a|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(89088)|0;break c}b=V(89088)|0;break c}b=V(89088)|0;break c}b=V(89088)|0}if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;vr(v[a+20>>2]+4|0);$()}gb=c+32|0;return}S(b|0);L()}function Uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=gb-32|0;gb=e;a:{b:{c:{f=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;gb=e+32|0}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;i=u[f>>1];m=u[f-2>>1];n=u[f+2>>1];r=u[f+4>>1];p=v[a+60>>2];f=Mb(b,-16777216,16776704);o=v[a+64>>2];g=Mb(e,-16777216,16776704);e=jqa(o,o>>31,f,f>>31);o=jb;f=e;e=j>>>21&2040;j=(((B(i,u[e+46146>>1])+B(m,u[e+46144>>1])|0)+B(n,u[e+46148>>1])|0)+B(r,u[e+46150>>1])|0)/16384<<8;e=j;i=jqa(p,p>>31,e,e>>31);f=f+i|0;e=jb+o|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=jqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);k=g+k|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,m);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;i=g;c=gb-160|0;gb=c;e=c+24|0;h=bu(e+56|0);v[e>>2]=78e3;v[h>>2]=78020;v[22692]=0;f=e+4|0;W(95,e|0,78032,f|0)|0;d=v[22692];v[22692]=0;a:{if((d|0)!=1){b:{v[e>>2]=78e3;v[h>>2]=78020;v[22692]=0;Q(96,f|0,16)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}break a}}a=P()|0;O()|0;lh(h);S(a|0);L()}h=v[v[e>>2]-12>>2];v[22692]=0;f=ga(79)|0;d=v[22692];v[22692]=0;c:{d:{e:{f:{g:{h:{if((d|0)==1){break h}v[22692]=0;U(80,c+16|0,h+(c+24|0)|0,f|0);d=v[22692];v[22692]=0;if((d|0)==1){break h}Wb(c+16|0);v[22692]=0;f=Fg(17);d=v[22692];v[22692]=0;if((d|0)==1){break g}v[22692]=0;v[c>>2]=f;f=mP(e,c);d=v[22692];v[22692]=0;if((d|0)==1){break g}j=A[b>>3];v[22692]=0;_a(83,f|0,+j)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;R(84,c|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;R(77,i|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}vb(c);xq(e);gb=c+160|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(c)}xq(e);S(a|0);L()}v[22692]=0;R(72,a|0,g|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(g);gb=g+16|0;return}a=P()|0;O()|0;vb(g);S(a|0);L()}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;td(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=xh(Cg(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[ac(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+46128|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[ac(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=e+16|0}function Gu(a,b){var c=0,d=0,e=0,f=0;f=gb-48|0;gb=f;qT(f+24|0,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);qT(f,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=1;e=f+24|0;a=v[e>>2];d=Ib(w[a|0]|w[a+1|0]<<8);a=f;c=v[a>>2];a:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=0;c=v[a>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=1;c=v[e+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+4>>2];b:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=0;c=v[a+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+4>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=1;c=v[e+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+8>>2];c:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=0;c=v[a+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+8>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=1;c=v[e+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[a+12>>2];d:{if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=0;c=v[a+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[e+12>>2];if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=v[e+16>>2];c=Ib(w[b|0]|w[b+1|0]<<8);b=v[a+16>>2];b=c>>>0<Ib(w[b|0]|w[b+1|0]<<8)>>>0;if(!b){a=v[a+16>>2];Ib(w[a|0]|w[a+1|0]<<8);a=v[e+16>>2];Ib(w[a|0]|w[a+1|0]<<8)}}}}}gb=f+48|0;return b}function ho(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;g=cd(a);e=b+24|0;a:{b:{if(Oi(v[e>>2]+484360|0)){if(Oi(v[e>>2]+484360|0)){b=0;while(1){f=v[e>>2];a=rL(vV(c+40|0,1),b&255,0,0);v[22692]=0;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;Y(2033,c- -64|0,f|0,0,c|0);a=v[22692];v[22692]=0;c:{d:{if((a|0)!=1){i=c,j=Vb(c- -64|0),v[i+32>>2]=j;i=c,j=Zb(c- -64|0),v[i+24>>2]=j;if(Gb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{a=v[c+32>>2];h=A[a>>3];f=v[a+16>>2];d=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=d;v[a+8>>2]=f;A[a>>3]=h;v[22692]=0;R(2034,g|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break e}v[c+32>>2]=v[c+32>>2]+32;if(Gb(c+32|0,c+24|0)){continue}break c}break}a=P()|0;O()|0;$m(c- -64|0);break b}$m(c- -64|0);b=b+1|0;if(Oi(v[e>>2]+484360|0)>>>0>b>>>0){continue}break}}gb=c+80|0;return}b=ba(8)|0;v[22692]=0;c=Q(70,c+40|0,4351)|0;a=v[22692];v[22692]=0;if((a|0)!=1){qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;da(b|0)}Vf(g);S(a|0)}L()}function Bna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(kv(c)>>>0>d>>>0){g=uW(c,d);h=gb-16|0;gb=h;c=a;t[c+12|0]=0;Eg(c);f=gb-32|0;gb=f;a:{b:{d=c;if(ye(d)>>>0<=14){e=wb(d);e=up(f+8|0,15,Nb(d),e);v[22692]=0;R(300,d|0,e|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}dj(e)}gb=f+32|0;break a}a=P()|0;O()|0;dj(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=nr(h+8|0,f&65535,w[ac(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[wb(d)>>2]){nW(d,j);break d}k=gb-32|0;gb=k;e=d;l=wb(d);d=up(k+8|0,ch(d,Nb(d)+1|0),Nb(d),l);m=v[d+8>>2];v[22692]=0;cn(l,m,j);j=v[22692];v[22692]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[22692]=0;R(300,e|0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break f}dj(d);gb=k+32|0;break e}a=P()|0;O()|0;dj(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}gb=h+16|0}g:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break g}b=bd(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c}function VJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(If(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=fe(A[Vg(a,h,k)>>3]*134217728);c=Lb(b,h);m=c;c=Tm(f)+(v[c>>2]>>1)|0;n=c;c=ut(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=Yn(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=d- -64|0}function $J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(If(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=fe(A[Vg(a,h,k)>>3]*134217728);c=Lb(b,h);m=c;c=Tm(f)+(v[c>>2]>>1)|0;n=c;c=ut(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=Zn(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=d- -64|0}function qI(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=kd(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;g=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=kd(a)}b=c-48|0;if(!(g|b>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(b>>>0<10){while(1){e=B(d,10)+c|0;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=kd(a)}b=c-48|0;d=e-48|0;if((d|0)<214748364?b>>>0<=9:0){continue}break}e=d;d=d>>31;h:{if(b>>>0>=10){break h}while(1){e=jqa(e,d,10,0);c=e+c|0;b=jb;b=c>>>0<e>>>0?b+1|0:b;e=c-48|0;d=b-(c>>>0<48)|0;b=v[a+4>>2];i:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break i}c=kd(a)}b=c-48|0;if(b>>>0>9){break h}if((d|0)<21474836?1:(d|0)<=21474836?e>>>0<2061584302:0){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];j:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break j}b=kd(a)}if(b-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;jb=-2147483648;return 0}jb=d;return e}function TN(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}d=a+16|0;b=d;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}e=a+24|0;b=e;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}f=a+32|0;b=f;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}c=a+12|0;b=c;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=c;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>858993459){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>536870911){break a}a=a+28|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>1073741823|B(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24),-5)-1>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<<3^-1)>>>0){break a}g=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))<<2^-1)>>>0}return g}function Pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(y[a+4>>2]<y[wb(a)>>2]){h=gb-16|0;gb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+28;a=wb(a);d=v[c+4>>2];v[22692]=0;ru(a,d,b);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+28;$b(c);gb=h+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}return}i=gb-32|0;gb=i;h=a;j=wb(a);e=i+8|0;c=Ch(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=c;d=c;c=gb-16|0;gb=c;g=a;wb(a);v[c+12>>2]=153391689;v[22692]=0;v[c+8>>2]=2147483647;k=Fb(c+12|0,c+8|0);l=v[22692];v[22692]=0;b:{if((l|0)!=1){gb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=Yi(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break c}Sc();L()}g=Ch(a);a=0;d=gb-16|0;gb=d;v[d+12>>2]=0;yh(e+12|0,j);if(c){a=c;if(a>>>0>153391689){pd(8399);L()}a=Nc(B(a,28),4)}v[e>>2]=a;g=B(g,28)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=dc(e),n=B(c,28)+a|0,v[m>>2]=n;gb=d+16|0;a=v[e+8>>2];v[22692]=0;ru(j,a,b);a=v[22692];v[22692]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+28;v[22692]=0;OQ(h,e);a=v[22692];v[22692]=0;if((a|0)==1){break e}NQ(e);gb=i+32|0;break d}a=P()|0;O()|0;NQ(e);S(a|0);L()}}function jka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=gb-48|0;gb=j;if(Re(b)>>>0>c>>>0){while(1){f=l&65535;if(gi(af(b,f))){e=Vb(af(b,f));f=Zb(af(b,f));m=jT(j,d);n=m;h=gb-16|0;gb=h;v[h>>2]=f;v[h+8>>2]=e;if(Gb(h+8|0,h)){while(1){f=n;i=gb-16|0;gb=i;e=v[h+8>>2];if(!(w[e+3|0]!=4|w[e+5|0])){pe(i+8|0,f,x[f+14>>1]);Af(i+8|0,0);t[e+3|0]=0}g=w[e+2|0];a:{if((g|0)!=11){break a}g=11;if(w[e+4|0]){break a}pe(i+8|0,f,x[f+14>>1]);g=0;Af(i+8|0,0);t[e+2|0]=0}b:{c:{d:{if(!w[e|0]){pe(i+8|0,f,x[f+14>>1]);if(Cb(i+8|0)){break d}g=w[e+2|0]}k=w[e+3|0];pe(i+8|0,f,x[f+14>>1]);Af(i+8|0,(k|0)==4|(g|0)==11);g=w[e+3|0];break c}g=w[e+3|0];k=w[e+2|0];if(!(g|(k|0)==11)){t[e+5|0]=0;t[e+3|0]=4;break b}if(k|(g|0)==4){break c}t[e+4|0]=0;t[e+2|0]=11}e:{if(!(!w[f+16|0]|g)){t[e+5|0]=125;t[e+3|0]=17;break e}f:{switch(g-16|0){case 1:break e;case 0:break f;default:break b}}if(w[e+5|0]){break b}t[e+5|0]=6;t[f+16|0]=1;break b}t[f+16|0]=0}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];gb=i+16|0;Xj(h+8|0);if(Gb(h+8|0,h)){continue}break}}iT(j+24|0,n);gb=h+16|0;Ce(j+24|0);Ce(m)}l=l+1|0;if((l&65535)>>>0<=c>>>0){continue}break}}iT(a,d);gb=j+48|0}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=jg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[f+8>>2],u[(i<<1)+g>>1]/4<<16>>16);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Kd(b,u[g+(v[e+44>>2]<<1)>>1]/4<<16>>16);Jd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!ki(i)){break a}k=Od(i,0);l=Od(i,1);m=md(i,0);n=md(i,1);if(d){j=a+4256|0;f=v[a+4268>>2];p=a+4236|0;q=a+4240|0;o=d;while(1){e=z[l>>2];g=z[k>>2];w=Lb(j,f<<1),x=g,z[w>>2]=x;w=Lb(j,v[a+4268>>2]<<1|1),x=e,z[w>>2]=x;e=C(D(gM(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)));g=z[a+4276>>2];e=C(e*C(4.656612873077393e-10));e=C(C(z[(g>e?q:p)>>2]*C(g-e))+e);z[a+4276>>2]=e;r=m;s=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];e=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(e,g))))+C(2147483392));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}h=f<<5;t=h;u=h|-2147483648;h=f>>>0<67108864;e=C(s*C((h?t:u)>>>(h?31:32-(f>>>26|0)|0)>>>0));f=v[a+4272>>2];f=(((f+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(f|0)<<1;w=r,x=C(e*z[Lb(j,f)>>2]),z[w>>2]=x;w=n,x=C(e*z[Lb(j,f|1)>>2]),z[w>>2]=x;h=v[a+4268>>2];f=h-1|0;v[a+4268>>2]=f;if(!h){f=v[a+4272>>2]+f|0;v[a+4268>>2]=f}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}Ei(a,b,c,md(i,0),md(i,1),d)}}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;if(!w[a+4242|0]){Wy(a);a:{if(!w[a+4240|0]){break a}e=LO(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Lt(a)}f=a+4256|0;b:{if(w[a+4244|0]){g=f;if(!(A[f>>3]<=1)){v[g>>2]=0;v[g+4>>2]=1072693248}break b}j=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(j|(g|0)<1)){Ty(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=qi(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];i=A[a+4272>>3];e=e*e*e*(A[a+4280>>3]-i)*((e*6+-15)*e+10)+i}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];SP(h+8|0,1);f=ik(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|bn(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],kb[k](l|0,m|0)|0;break f}kb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}g=a;a=a+44|0;Ei(g,b,c,Od(a,0),Od(a,1),d);gb=h+16|0}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;o=k,p=Zb(a),v[o>>2]=p;d=v[Hd(k+8|0,k)>>2];h=gb-32|0;gb=h;v[h+24>>2]=d;d=v[a>>2];o=h,p=Vb(a),v[o>>2]=p;d=d+(np(h+24|0,h)<<1)|0;a:{b:{f=Xq(b,c);c:{if((f|0)<1){break c}i=v[wb(a)>>2];e=v[a+4>>2];if((f|0)<=i-e>>1){j=e-d|0;i=j>>1;d:{if((i|0)>=(f|0)){g=c;break d}v[h>>2]=b;gS(h,i);g=v[h>>2];$R(a,g,c,f-i|0);if((j|0)<1){break c}}m=gb-16|0;gb=m;i=e;j=d;l=a;n=v[a+4>>2];a=(n-((f<<1)+d|0)|0)+d|0;f=ji(m,l,e-a>>1);if(a>>>0<e>>>0){e=v[f+4>>2];c=a;while(1){wb(l);Ko(e,c);e=e+2|0;v[f+4>>2]=e;c=c+2|0;if(i>>>0>c>>>0){continue}break}}$b(f);wr(j,a,n);gb=m+16|0;Fn(b,g,d);break c}g=wb(a);e=yn(h,Nk(a,sc(a)+f|0),d-v[a>>2]>>1,g);v[22692]=0;WQ(e,b,c);b=v[22692];v[22692]=0;if((b|0)==1){break b}b=a;zp(a);c=e;i=v[c+4>>2];g=d;l=c+4|0;wk(wb(a),v[a>>2],d,l);wb(a);f=c+8|0;j=f;d=v[a+4>>2];if((g|0)!=(d|0)){a=v[j>>2];while(1){Ko(a,g);a=v[j>>2]+2|0;v[j>>2]=a;g=g+2|0;if((d|0)!=(g|0)){continue}break}}xc(b,l);xc(b+4|0,f);xc(wb(b),dc(c));v[c>>2]=v[c+4>>2];Yr(b,sc(b));d=i;Ih(e)}Fg(d);gb=h+32|0;break a}a=P()|0;O()|0;Ih(e);S(a|0);L()}gb=k+16|0}
function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=jg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function dv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;t[e+16|0]=44;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=1058;v[e+4>>2]=2;i=a;c=gb+-64|0;gb=c;j=c;a=e;h=v[a>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){cO(f+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Ab(d);v[22692]=0;v[f+4>>2]=g;g=wf(f+4|0);k=v[22692];v[22692]=0;if((k|0)!=1){v[22692]=0;U(75,d|0,g|0,0);g=v[22692];v[22692]=0;if((g|0)!=1){continue}}break}break b}b=v[f+8>>2];h=Jb(d);v[22692]=0;R(76,d|0,b-h|0);b=v[22692];v[22692]=0;d:{if((b|0)!=1){v[22692]=0;R(77,j|0,d|0);b=v[22692];v[22692]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=f+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}El(c+16|0,c,a);v[22692]=0;U(89,c+32|0,c+16|0,a|0);b=v[22692];v[22692]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22692]=0;U(90,c+48|0,c+32|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break i}v[22692]=0;R(72,i|0,c+48|0);a=v[22692];v[22692]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=e+32|0}function bda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;g=cd(a);v[22692]=0;_(1631,g|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){b=50384;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=ug(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22692]=0;f=Q(70,c+32|0,f|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break k}v[22692]=0;R(1632,c+48|0,f|0);e=v[22692];v[22692]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22692]=0;e=Q(70,c|0,e|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break i}v[22692]=0;R(1632,c+16|0,e|0);i=v[22692];v[22692]=0;if((i|0)==1){break h}v[22692]=0;ca(1633,d|0,h|0,c+48|0,c+16|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break g}Hb(c+16|0);vb(e);Hb(c+48|0);vb(f);v[c+60>>2]=d;v[22692]=0;R(1634,g|0,c+60|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=50696){continue}break}gb=c- -64|0;return a|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Hb(c+16|0)}vb(e)}Hb(c+48|0)}vb(f)}Xb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}zl(g);S(b|0);L()}function Fka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-16|0;gb=i;td(d,32);IT(i+8|0,a+20|0,b);p=i+8|0;g=fc(i+8|0);IT(i,a+36|0,c);q=i;a=0;g=v[g>>2];if(g-1>>>0<=838859){a=v[fc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;n=Um(d);if(n){r=+(g>>>0);s=+(a>>>0);m=g<<2;o=1/+(m>>>0);z=1/+y[d>>2];g=0;while(1){k=+(g>>>0);a=v[p>>2];j=0;if(Nd(b)){e=k*r*o+ +(a>>>0);a:{if(e<4294967296&e>=0){a=~~e>>>0;break a}a=0}f=dd(b);h=B(a,f);e=e-J(e);b:{if(t[b+34|0]&1){l=v[b+20>>2];a=u[l+(h<<1)>>1];f=x[l+(f+h<<1)>>1];break b}a=v[b+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}j=+(a<<16>>16);j=(+(f<<16>>16)-j)*e+j}a=v[q>>2];if(Nd(c)){e=k*s*o+ +(a>>>0);c:{if(e<4294967296&e>=0){a=~~e>>>0;break c}a=0}f=dd(c);h=B(a,f);e=e-J(e);d:{if(t[c+34|0]&1){l=v[c+20>>2];a=u[l+(h<<1)>>1];f=x[l+(f+h<<1)>>1];break d}a=v[c+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}k=+(a<<16>>16);e=(+(f<<16>>16)-k)*e+k}else{e=0}e=e-j;f=0;a=g;while(1){h=HT(e*+(a>>>0)*z+j);u[v[d+20>>2]+(a<<1)>>1]=h;a=a+m|0;f=f+1|0;if((f|0)!=80){continue}break}g=g+1|0;if((m|0)!=(g|0)){continue}break}}a=(n|0)!=0}gb=i+16|0;return a|0}function hc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){$a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Sf(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>11>>>0){c=gb-16|0;gb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){wb(g);v[22692]=0;Vy(a);e=v[22692];v[22692]=0;if((e|0)==1){break d}a=a+2048|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}h=wb(a);i=f+8|0;b=Sf(a)+e|0;d=gb-16|0;gb=d;v[d+12>>2]=b;c=b;b=gb-16|0;gb=b;g=a;wb(a);v[b+12>>2]=2097151;v[22692]=0;v[b+8>>2]=2147483647;j=Fb(b+12|0,b+8|0);k=v[22692];v[22692]=0;e:{if((k|0)!=1){gb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=vl(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Mc(d+8|0,d+12|0)>>2]}gb=d+16|0;break f}Sc();L()}b=LM(i,b,Sf(a),h);v[22692]=0;R(1526,b|0,e|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(1522,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Mt(b)}gb=f+32|0;break a}a=P()|0;O()|0;Mt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;Sf(a);KM(a,b);MM(a)}}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=jg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[f+8>>2],t[g+i|0]<<6);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Kd(b,t[g+v[e+44>>2]|0]<<6);Jd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function QT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ah(a);if(c>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=v[wb(a)>>2]-v[a+4>>2]>>8>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(i<<8);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){qB(a);a=a+256|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}k=wb(a);e=j+8|0;d=a;b=ah(a)+i|0;f=gb-16|0;gb=f;v[f+12>>2]=b;g=gb-16|0;gb=g;v[g+12>>2]=16777215;v[22692]=0;v[g+8>>2]=2147483647;h=Fb(g+12|0,g+8|0);c=v[22692];v[22692]=0;d:{if((c|0)!=1){gb=g+16|0;c=v[h>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0<=c>>>0){b=uB(d);if(b>>>0<c>>>1>>>0){v[f+8>>2]=b<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break e}Sc();L()}d=ah(a);b=0;h=gb-16|0;gb=h;v[h+12>>2]=0;hf(e+12|0,k);if(c){b=c;if(b>>>0>=16777216){pd(8399);L()}b=Nc(b<<8,1)}v[e>>2]=b;d=(d<<8)+b|0;v[e+8>>2]=d;v[e+4>>2]=d;l=dc(e),m=(c<<8)+b|0,v[l>>2]=m;gb=h+16|0;v[22692]=0;uT(e,i);b=v[22692];v[22692]=0;if((b|0)==1){break b}Rk(a,e);tT(e)}gb=j+32|0;break a}a=P()|0;O()|0;tT(e);S(a|0);L()}return}if(b>>>0<c>>>0){Sk(a,v[a>>2]+(b<<8)|0)}}function Bc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{f=w[b+8|0];d=v[b>>2];c=v[b+4>>2];b=gb-48|0;gb=b;e=Kb(a);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((f|0)!=1){if(!c|(f|0)!=4){break k}break l}if(c){break l}c=0;break j}c=c-1|0}switch(f-1|0){case 0:case 1:break j;case 2:case 3:break i;default:break h}}t[b+32|0]=0;a=Qm(d,c+d|0,b+32|0);v[22692]=0;U(68,e|0,d|0,a|0);a=v[22692];v[22692]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}v[22692]=0;U(68,e|0,d|0,c+d|0);a=v[22692];v[22692]=0;if((a|0)==1){break g}c=zd(e);d=ef(e);f=zd(e);a=gb-32|0;gb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=f;if(Gb(a+24|0,a+16|0)){while(1){c=t[v[a+24>>2]];t[v[a+8>>2]]=c?c:32;Ne(a+24|0);Ne(a+8|0);if(Gb(a+24|0,a+16|0)){continue}break}}gb=a+32|0;v[22692]=0;c=Q(69,b+16|0,e|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}v[22692]=0;d=Q(70,b|0,14884)|0;a=v[22692];v[22692]=0;if((a|0)==1){break e}v[22692]=0;U(71,b+32|0,c|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}Eb(e,b+32|0);vb(b+32|0);vb(d);vb(c)}gb=b+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d)}vb(c)}vb(e);S(a|0);L()}}function r7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Jf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(If(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Tm(fe(A[Vg(g,b,i)>>3]*134217728))+gd(tt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[$g(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=Yn(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=c- -64|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Jf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(If(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Tm(fe(A[Vg(g,b,i)>>3]*134217728))+gd(tt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[$g(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=Zn(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=c- -64|0}function rK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;v[a+4>>2]=c;v[a>>2]=b;b=(c>>>0)/48|0;g=((B(b,48)|0)!=(c|0))+b|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;i=b>>>0<64;e=a;j=a;d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}f=i?0:0;v[j+24>>2]=f;j=e;e=i?d&65536:0;v[j+28>>2]=e;a:{b:{d=f;i=0-d|0;f=mqa(d,e,g,0);e=65536-(e+((d|0)!=0)|0)|0;d=jb;if((e|0)==(d|0)&f>>>0<i>>>0|d>>>0<e>>>0){g=g+1|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;if(b>>>0>63){break b}d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}v[a+24>>2]=0;v[a+28>>2]=d&65536}v[a+16>>2]=g-((c>>>0)%(g>>>0)|0);if(b>>>0>62){break a}h=1;c=b+1|0;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}k=d&65536;break a}v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=(B(b,g)-c|0)+g}v[a+32>>2]=l;v[a+36>>2]=k;c=a;f=a;d=63-b|0;e=d&31;if((d&63)>>>0>=32){d=0;e=-1>>>e|0}else{d=-1>>>e|0;e=(1<<e)-1<<32-e|-1>>>e}v[f+48>>2]=h?e:-1;v[c+52>>2]=h?d:-1;h=b;e=a;b=64-b|0;d=b&31;if((b&63)>>>0>=32){b=0;d=-1>>>d|0}else{b=-1>>>d|0;d=(1<<d)-1<<32-d|-1>>>d}v[e+40>>2]=h?d:0;v[c+44>>2]=h?b:0;return a}function PZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-32|0;gb=h;d=b;e=sc(d);f=c;a:{if(e>>>0<f>>>0){l=gb-32|0;gb=l;b:{c:{i=f-e|0;d:{if(i>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){e=gb-16|0;gb=e;e:{f=ji(e,d,i);g=v[f+4>>2];i=v[f+8>>2];if((g|0)!=(i|0)){while(1){wb(d);v[22692]=0;Hk(g);j=v[22692];v[22692]=0;if((j|0)==1){break e}g=g+2|0;v[f+4>>2]=g;if((g|0)!=(i|0)){continue}break}}$b(f);gb=e+16|0;break d}a=P()|0;O()|0;$b(f);S(a|0);L()}k=wb(d);f=Nk(d,sc(d)+i|0);m=sc(d);j=gb-16|0;gb=j;v[j+12>>2]=0;e=l+8|0;yh(e+12|0,k);if(f){g=f;if(f>>>0>2147483647){pd(8399);L()}g=Nc(g<<1,1)}v[e>>2]=g;k=(m<<1)+g|0;v[e+8>>2]=k;v[e+4>>2]=k;n=dc(e),o=(f<<1)+g|0,v[n>>2]=o;gb=j+16|0;v[22692]=0;R(345,e|0,i|0);f=v[22692];v[22692]=0;if((f|0)==1){break c}v[22692]=0;R(346,d|0,e|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}cE(e)}gb=l+32|0;break b}a=P()|0;O()|0;cE(e);S(a|0);L()}break a}if(e>>>0>f>>>0){rn(d,v[d>>2]+(f<<1)|0)}}c=Pb(a,c<<1);if(c){d=gb-16|0;gb=d;bc(h+24|0,v[b>>2],sc(b)<<1);gb=d+16|0;b=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=b;id(h+16|0,a,h+8|0)}gb=h+32|0;return c|0}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;gb=g+16|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=f+32|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+q|0;m=t[e+1|0];e=t[e|0];g=v[a+60>>2];n=g;o=g>>31;g=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);g=jqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=jqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=((B(m-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=jqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Vm(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;if(b&2){t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;Db(f+8|0,c+1074312|0,23);if(Cb(f+8|0)){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&240;To(a+788|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&207}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0}gb=f+16|0}function oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+q|0;m=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];n=g;o=g>>31;g=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);g=jqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=jqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=e+((B(m-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=jqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Ot(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22692]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22692]=0;v[f+4>>2]=e;e=wf(f+4|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;U(75,d|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22692]=0;R(76,d|0,b-g|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(86,j|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}El(a+16|0,a,c);v[22692]=0;U(93,a+32|0,a+16|0,c|0);b=v[22692];v[22692]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22692]=0;U(94,a+48|0,a+32|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;R(85,i|0,a+48|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function JV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22692]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22692]=0;v[f+4>>2]=e;e=wf(f+4|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;U(75,d|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22692]=0;R(76,d|0,b-g|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(77,j|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}El(a+16|0,a,c);v[22692]=0;U(89,a+32|0,a+16|0,c|0);b=v[22692];v[22692]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22692]=0;U(90,a+48|0,a+32|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;R(72,i|0,a+48|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Dw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);b:{c:{d:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22692]=0;ha(92,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}if(!v[f+12>>2]){break d}e=Ab(d);v[22692]=0;v[f+4>>2]=e;e=wf(f+4|0);h=v[22692];v[22692]=0;if((h|0)!=1){v[22692]=0;U(75,d|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)!=1){continue}}break}break c}b=v[f+8>>2];g=Jb(d);v[22692]=0;R(76,d|0,b-g|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(86,j|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d);gb=f+32|0;break b}}a=P()|0;O()|0;vb(d);S(a|0);L()}El(a+16|0,a,c);v[22692]=0;U(93,a+32|0,a+16|0,c|0);b=v[22692];v[22692]=0;e:{f:{g:{h:{if((b|0)!=1){v[22692]=0;U(94,a+48|0,a+32|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;R(85,i|0,a+48|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break a}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;gb=f+16|0}function YI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){jl(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=vm(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}ec(a,21);return 0}k=B(d,l);m=(k+(j+m|0)|0)>(p|0)?(j+p|0)-k|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}ec(a,21);return 0}aa(4581,10482,1872,3605);L()}function ona(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-432|0;gb=e;vc(b);oC(b,e+376|0,e+296|0,e+8|0);d=e;f=e+408|0;if(Yb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){f=w[e+427|0]+1|0}else{f=1}n=d,o=ei(f),t[n+4|0]=o;h=w[ac(29008,e+4|0)|0];t[e+7|0]=h;u[e+4>>1]=4;a:{b:{if(!h){break b}f=e+392|0;k=e+291|0;while(1){d=e+8|0;d=Ib(w[d|0]|w[d+1|0]<<8);c:{d:{if(w[k|0]>63){break d}d=d<<16>>16;if((d|0)<0){break d}if(d){l=d&65535;g=0;while(1){d=f;e:{if(!Yc(b,Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(g<<2)|0)){break e}if(!Yc(b,Gr(b))){break e}d=e;f:{if(!c){j=Ae(b);break f}j=Ir(b)}u[d+2>>1]=j;n=e,o=x[Je(e+4|0,e+2|0)>>1],u[n+4>>1]=o}g=g+1|0;if((l|0)!=(g|0)){continue}break}}d=e+296|0;if(Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>m>>>0){d=e+296|0;if(Yc(b,Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break c}}t[e+7|0]=i+1;break b}Ur(a);break a}d=e+296|0;m=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));oC(b,e+376|0,e+296|0,e+8|0);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}mC(a,e+4|0,e+7|0)}gb=e+432|0}function Nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(WE(b)){j=b>>>0>4?b:4;b=a?a:1;a:{b:{while(1){f=gb-16|0;gb=f;v[f+12>>2]=0;c=b;c:{d:{a=j;if((a|0)!=8){if(a&3|a>>>0<4){break c}d=a>>>2|0;if(d-1&d|c>>>0>-64-a>>>0){break c}d=16;e=a>>>0>16?a:16;e:{if(!(e-1&e)){a=e;break e}while(1){a=d;d=a<<1;if(a>>>0<e>>>0){continue}break}}if(c>>>0>=-64-a>>>0){v[115173]=48;break c}g=c>>>0<11?16:c+11&-8;c=Cd((g+a|0)+12|0);if(!c){break c}d=c-8|0;f:{if(!(c&a-1)){a=d;break f}i=c-4|0;e=v[i>>2];c=((a+c|0)-1&0-a)-8|0;a=c-d>>>0>15?c:a+c|0;h=a-d|0;c=(e&-8)-h|0;if(!(e&3)){d=v[d>>2];v[a+4>>2]=c;v[a>>2]=d+h;break f}v[a+4>>2]=c|v[a+4>>2]&1|2;e=a+c|0;v[e+4>>2]=v[e+4>>2]|1;v[i>>2]=h|v[i>>2]&1|2;e=d+h|0;v[e+4>>2]=v[e+4>>2]|1;xs(d,h)}e=v[a+4>>2];g:{if(!(e&3)){break g}d=e&-8;if(d>>>0<=g+16>>>0){break g}v[a+4>>2]=g|e&1|2;c=a+g|0;e=d-g|0;v[c+4>>2]=e|3;d=a+d|0;v[d+4>>2]=v[d+4>>2]|1;xs(c,e)}a=a+8|0;break d}a=Cd(c);if(a){break d}break c}v[f+12>>2]=a}gb=f+16|0;a=v[f+12>>2];if(!a){a=v[116498];if(!a){break b}kb[a|0]();continue}break}break a}a=ba(4)|0;gm(a);ia(a|0,89088,1912);L()}return a}return rf(a)}function TY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=Vb(a),v[m>>2]=n;b=b+(np(f+24|0,f)<<1)|0;d=v[a+4>>2];a:{b:{if(d>>>0<y[wb(a)>>2]){if((b|0)!=(d|0)){break b}d=gb-16|0;gb=d;a=ji(d,a,1);Cr(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;$b(a);gb=d+16|0;break a}d=wb(a);e=tD(f,MY(a,sc(a)+1|0),b-v[a>>2]>>1,d);v[22692]=0;R(449,e|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=v[e+4>>2];j=e+4|0;hl(v[a>>2],b,j);h=e+8|0;i=h;g=v[a+4>>2];if((g|0)!=(b|0)){d=v[i>>2];while(1){Cr(d,b);d=v[i>>2]+2|0;v[i>>2]=d;b=b+2|0;if((g|0)!=(b|0)){continue}break}}wc(a,j);wc(a+4|0,h);wc(wb(a),dc(e));v[e>>2]=v[e+4>>2];b=c;mp(e);break a}a=P()|0;O()|0;mp(e);S(a|0);L()}l=gb-16|0;gb=l;j=d;k=v[a+4>>2];i=b;e=b+(k-(b+2|0)|0)|0;h=ji(l,a,d-e>>1);if(d>>>0>e>>>0){g=v[h+4>>2];d=e;while(1){Cr(g,d);g=g+2|0;v[h+4>>2]=g;d=d+2|0;if(j>>>0>d>>>0){continue}break}}$b(h);if((e|0)!=(i|0)){while(1){k=k-2|0;e=e-2|0;DY(k,e);if((e|0)!=(i|0)){continue}break}}gb=l+16|0;a=b>>>0<=c>>>0?y[a+4>>2]>c>>>0?c+2|0:c:c;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}Fg(b);gb=f+32|0}function HV(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!kf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!kf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}gb=f+16|0}function CD(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((w[a|0]-1&255)>>>0>14){break a}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<=-2){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){b:{h=0;f=B(d,13)+a|0;if(w[f+14|0]){break b}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}c=e+422|0;if(w[f+942|0]|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048575){break b}b=B(d,11)+a|0;f=b+1346|0;if(w[f|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break b}c:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break c}b=e+430|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>1048574){break c}if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break b}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break b}}h=1;b=1;d:{if(g){break d}e:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break e}if(rd(f,28477,11)){break e}b=0;break d}b=1}g=b;d=d+1|0;if((d|0)!=32){continue}}break}g=g&h}return g}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=C(0);h=a+44|0;g=Od(h,0);k=Od(h,1);m=md(h,0);n=md(h,1);p=B(w[a+4233|0],v[v[a+16>>2]+1074404>>2]);e=p<<1;i=a+4208|0;if(Nb(i)>>>0<e>>>0){wl(i,e)}j=xM(a);a:{if(j){if(!d){break a}e=v[a+4220>>2];x=j-1|0;j=0;while(1){if(e>>>0>=p>>>0){v[a+4220>>2]=0;e=0}s=z[k>>2];t=z[g>>2];o=e;e=e-p|0;e=((e|0)<0?o:e)<<1;u=z[Lb(i,e)>>2];f=z[Lb(i,e|1)>>2];q=C(u+t);z[m>>2]=q;r=C(f+s);z[n>>2]=r;f=C(0);l=C(0);b:{c:{switch(x|0){case 0:f=z[a+4224>>2];l=C(f*r);f=C(f*q);break b;case 1:case 2:f=z[a+4224>>2];l=C(f*q);f=C(f*r);break b;case 3:break c;default:break b}}f=C(z[a+4224>>2]*C(u+C(C(s+t)*C(.5))));l=f}n=n+4|0;m=m+4|0;k=k+4|0;g=g+4|0;y=Lb(i,v[a+4220>>2]<<1),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Lb(i,v[a+4220>>2]<<1|1),A=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[y>>2]=A;e=v[a+4220>>2]+1|0;v[a+4220>>2]=e;j=j+1|0;if((j|0)!=(d|0)){continue}break}break a}o=g;g=d<<2;wM(o,o+g|0,m);wM(k,g+k|0,n)}Ei(a,b,c,md(h,0),md(h,1),d)}function epa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;td(b,32);e=a+4|0;h=b,i=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;e=b;if(c?d:1){c=a+46|0;c=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!Ib(w[d|0]|w[d+1|0]<<8)){break a}if((Ib(w[d|0]|w[d+1|0]<<8)|0)==48){break a}c=(c-(Ib(w[d|0]|w[d+1|0]<<8)<<7)|0)+6144|0}Ho(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[ac(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}gb=f+16|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=Qf(a);if(e>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{d=b-e|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/52>>>0){cz(a,d,c);break c}f=wb(a);g=uN(a,Qf(a)+d|0);i=Qf(a);e=0;h=gb-16|0;gb=h;v[h+12>>2]=0;b=j+8|0;hf(b+12|0,f);if(g){e=qN(g)}v[b>>2]=e;f=B(i,52)+e|0;v[b+8>>2]=f;v[b+4>>2]=f;l=dc(b),m=B(g,52)+e|0,v[l>>2]=m;gb=h+16|0;v[22692]=0;U(1477,b|0,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}c=a;AO(a);wb(a);e=b;f=b+4|0;g=f;h=v[a>>2];a=v[a+4>>2];if((h|0)!=(a|0)){d=v[g>>2];while(1){d=d-52|0;a=a-52|0;i=oN(d,wb(a));v[d>>2]=v[a>>2];v[d+4>>2]=v[a+4>>2];k=v[wb(a)>>2];l=wb(i),m=k,v[l>>2]=m;l=wb(a),m=0,v[l>>2]=m;v[a>>2]=0;v[a+4>>2]=0;v[d+20>>2]=v[a+20>>2];i=v[a+16>>2];v[d+12>>2]=v[a+12>>2];v[d+16>>2]=i;Qu(d+24|0,a+24|0);Dc(d+36|0,a+36|0);v[d+48>>2]=v[a+48>>2];d=v[g>>2]-52|0;v[g>>2]=d;if((a|0)!=(h|0)){continue}break}}wc(c,f);wc(c+4|0,e+8|0);wc(wb(c),dc(e));v[e>>2]=v[e+4>>2];pN(c,Qf(c));nN(b)}gb=j+32|0;break a}a=P()|0;O()|0;nN(b);S(a|0);L()}return}if(b>>>0<e>>>0){vN(a,v[a>>2]+B(b,52)|0)}}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;gb=f+32|0}function cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];i=v[a+4>>2];h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=i;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=i+n|0;i=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];k=jqa(e,e>>31,f,f>>31);e=w+k|0;f=jb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(u[e+46146>>1],p)+B(q,u[e+46144>>1])|0)+B(o,u[e+46148>>1])|0)+B(i,u[e+46150>>1])<<8)/16384<<8;e=i;h=jqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,m);v[c+4>>2]=v[c+4>>2]+B(h,l);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=zb(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break b}c=0;break d}f=1;c=0;if((d|0)!=4){break a}break c}while(1){f:{g:{h:{d=w[c+h|0];switch(d-10|0){case 3:break h;case 0:break g;default:break f}}e=e+1|0;break f}g=g+1|0}i=((f&255)==13&(c|0)!=0&(d|0)==10)+i|0;f=d;c=c+1|0;if((b|0)!=(c|0)){continue}break}}i:{if((e|0)==(g|0)){d=2;if((e|0)==(i|0)){break i}}if(e){d=0;if(!g){break i}}d=e?3:g?1:3}if(b){break b}f=1;c=0;break a}f=0;e=(d|0)!=2;c=0;while(1){j=(e|w[c+h|0]!=10)+j|0;c=c+1|0;if((b|0)!=(c|0)){continue}break}c=b}e=c;Fq(a,j);if(!f){f=(d|0)==2;g=d&-3;i=(d|0)==1?32:13;b=0;c=0;while(1){j:{k:{l:{m:{n:{o:{d=t[b+h|0];switch(d-10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}k=nc(a,c),l=i,t[k|0]=l;b=b+f|0;break j}d=nc(a,c);if(g){t[d|0]=13;break j}t[d|0]=32;break j}if(!d){break k}}k=nc(a,c),l=d,t[k|0]=l;break j}k=nc(a,c),l=32,t[k|0]=l}c=c+1|0;b=b+1|0;if(e>>>0>b>>>0){continue}break}}return 1}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=Nb(f);e=c;a:{if(d>>>0<e>>>0){l=gb-32|0;gb=l;b:{c:{h=e-d|0;d:{if(h>>>0<=v[wb(f)>>2]-v[f+4>>2]>>2>>>0){i=gb-16|0;gb=i;e:{d=Dg(i,f,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){wb(f);v[22692]=0;Vj(e);j=v[22692];v[22692]=0;if((j|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=i+16|0;break d}a=P()|0;O()|0;$b(d);S(a|0);L()}k=wb(f);i=ch(f,Nb(f)+h|0);m=Nb(f);e=0;j=gb-16|0;gb=j;v[j+12>>2]=0;d=l+8|0;yh(d+12|0,k);if(i){e=OW(i)}v[d>>2]=e;k=(m<<2)+e|0;v[d+8>>2]=k;v[d+4>>2]=k;n=dc(d),o=(i<<2)+e|0,v[n>>2]=o;gb=j+16|0;v[22692]=0;R(658,d|0,h|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;R(659,f|0,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break c}PW(d)}gb=l+32|0;break b}a=P()|0;O()|0;PW(d);S(a|0);L()}break a}if(d>>>0>e>>>0){ej(f,v[f>>2]+(e<<2)|0)}}c=Pb(a,c<<2);if(c){f=gb-16|0;gb=f;bc(g+24|0,v[b>>2],Nb(b)<<2);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;id(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function Qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;o=d,p=mf(a)>>>5|0,u[o+32>>1]=p;u[d+16>>1]=3999;o=c,p=x[Pc(d+32|0,d+16|0)>>1],u[o+480190>>1]=p;VU(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=Ml(c,j&65535);Zu(a,d+32|0);td(f,0);Uj(d,2,d+32|0);Bc(d+16|0,d);v[22692]=0;Q(301,((i<<5)+c|0)+946304|0,d+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break a}vb(d+16|0);u[f+32>>1]=64;v[f+24>>2]=8287;o=d,p=Ib(w[m|0]|w[m+1|0]<<8),u[o+16>>1]=p;u[d>>1]=64;o=f,p=x[Pc(d+16|0,d)>>1]<<2,u[o+30>>1]=p;e=n;o=f,p=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))&-2,v[o>>2]=p;e=Ib(w[l|0]|w[l+1|0]<<8);g=Ib(w[k|0]|w[k+1|0]<<8);b:{if(g>>>0<2){break b}g=e+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=e<<1;u[f+34>>1]=x[f+34>>1]|8}if(Ib(w[h|0]|w[h+1|0]<<8)){e=(Ib(w[h|0]|w[h+1|0]<<8)|0)==2}else{e=1}pe(d+16|0,b,i-1|0);Af(d+16|0,e);j=j+1|0;i=j&65535;if(i>>>0<=x[c+480190>>1]){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;e=gb-16|0;gb=e;VW(e+8|0,b);gb=e+16|0;v[g+16>>2]=v[e+8>>2];d=gb-32|0;gb=d;h=b;c=a;b=Yd(c);e=fc(c);a:{b:{if(b){c:{while(1){d:{f=b+16|0;e:{if(su(wb(c),h,f)){if(!v[b>>2]){break b}e=b;break e}if(!su(wb(c),f,h)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=fc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){h=gb-16|0;gb=h;b=fc(a);i=Nc(40,4);f=h+8|0;t[f+4|0]=0;v[f>>2]=b;c=gb-16|0;gb=c;v[c+12>>2]=i;v[22692]=0;b=d+8|0;KQ(b,c+12|0,f);f=v[22692];v[22692]=0;f:{if((f|0)!=1){gb=c+16|0;break f}V(0)|0;O()|0;Bb();L()}c=v[b>>2];v[22692]=0;f=c+16|0;c=v[22692];v[22692]=0;g:{if((c|0)!=1){c=gb-16|0;gb=c;v[c+8>>2]=v[g+16>>2];Dc(f,v[c+8>>2]);Kb(f+12|0);gb=c+16|0;j=fc(b),k=1,t[j+4|0]=k;gb=h+16|0;break g}a=P()|0;O()|0;LQ(b);S(a|0);L()}xS(a,v[d+28>>2],e,v[d+8>>2]);b=ce(d+8|0);t[d+27|0]=1;LQ(d+8|0)}j=g,k=v[yc(d+8|0,b)>>2],v[j+24>>2]=k;t[g+28|0]=w[d+27|0];gb=d+32|0;a=te(g+24|0);gb=g+32|0;return a+12|0}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-48|0;gb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;ap(b,f+44|0);a:{if(!RS(f+44|0)){break a}c=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(d,6)+(e<<1)|0)+33656>>1]<<g;e=B(B(w[(e+B(d,3)|0)+33433|0],x[((B(d,90)+B(e,30)|0)+(c>>>3&30)|0)+33440>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+(c&6)|0)+33632>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[(g|d<<1)+33668|0];if(e+8>>>0>(c&65535)>>>0){break a}d=f;c=gb-48|0;gb=c;v[c+44>>2]=e+4;v[c+24>>2]=36;g=v[Fb(c+44|0,c+24|0)>>2];if(!Pb(b,g)){g=mf(b)}as(c+24|0,d);h=vd(c+32|0,v[c+24>>2],g);i=v[h+4>>2];v[c+8>>2]=v[h>>2];v[c+12>>2]=i;cc(c+16|0,b,c+8|0);as(c+24|0,d);Qb(v[c+24>>2]+g|0,0,36-g|0);Rb(b,v[c+44>>2]);gb=c+48|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+f|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){d=1}else{d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=d}gb=f+48|0;return a|0}function Gpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-2608|0;gb=f;d=f;eD(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22692]=0;_(488,d|0);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){v[22692]=0;j=Q(198,d|0,1)|0;a=v[22692];v[22692]=0;if((a|0)==1){break f}a=0;g:{while(1){v[22692]=0;k=Q(198,d|0,1)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}a=B(a,6)+d|0;a=u[(k?a+1070|0:a+1068|0)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break h}if(u[e+1070>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break d}break}a=V(27348)|0;break e}a=V(27348)|0;break e}a=V(27348)|0}if((O()|0)!=(ea(27348)|0)){break a}Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break c}}v[22692]=0;b=hp(d);a=v[22692];v[22692]=0;if((a|0)==1){break b}xb(d);gb=f+2608|0;return b|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(d);S(a|0);L()}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Mb(b,-16777216,16776704);k=v[a+64>>2];g=Mb(f,-16777216,16776704);f=jqa(k,k>>31,e,e>>31);k=jb;e=f;f=i>>>21&2040;i=(((B(j,u[f+46146>>1])+B(p,u[f+46144>>1])|0)+B(u[f+46148>>1],q)|0)+B(r,u[f+46150>>1])|0)/16384<<8;f=i;j=jqa(l,l>>31,f,f>>31);e=e+j|0;f=jb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];g=jqa(e,e>>31,g,g>>31);e=j+g|0;f=jb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];g=(f|0)/256|0;v[c>>2]=v[c>>2]+B(g,n);v[c+4>>2]=v[c+4>>2]+B(g,m);e=f-(e&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function ck(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;Fc(i+8|0,d);v[22692]=0;j=T(2464,i+8|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(bl(i+24|0,i+16|0)){break b}c:{if((Kn(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Kn(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Kn(j,v[g+8>>2])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(cl(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(cl(j,8192,v[g>>2])){continue}}break}if(!pm(i+24|0,i+16|0)){break c}while(1){if(!cl(j,8192,om(i+24|0))){break c}nm(i+24|0);if(pm(i+24|0,i+16|0)){continue}break}break c}if((jn(j,om(i+24|0))|0)==(jn(j,v[g>>2])|0)){g=g+4|0;nm(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(bl(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function dk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;Fc(i+8|0,d);v[22692]=0;j=T(21,i+8|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(fk(i+24|0,i+16|0)){break b}c:{if((Ln(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Ln(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Ln(j,t[g+2|0])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(kh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(kh(j,8192,t[g|0])){continue}}break}if(!gk(i+24|0,i+16|0)){break c}while(1){if(!kh(j,8192,gl(i+24|0))){break c}fl(i+24|0);if(gk(i+24|0,i+16|0)){continue}break}break c}if((ox(j,gl(i+24|0))|0)==(ox(j,t[g|0])|0)){g=g+1|0;fl(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(fk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function XI(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}aa(12870,10482,2408,6322);L()}function u5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;v[22692]=0;g=Q(15,d+24|0,a|0)|0;c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=v[v[a>>2]-12>>2];v[22692]=0;Fc(d+16|0,a+c|0);c=v[22692];v[22692]=0;e:{f:{g:{if((c|0)!=1){v[22692]=0;c=T(2301,d+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}Wb(d+16|0);e=$i(d+8|0,a);f=v[v[a>>2]-12>>2];v[22692]=0;f=a+f|0;h=T(16,f|0)|0;i=v[22692];v[22692]=0;if((i|0)==1){break f}e=v[e>>2];v[22692]=0;c=Ra(2302,c|0,e|0,f|0,h|0,+b)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Sv(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22692]=0;R(18,a+c|0,5);c=v[22692];v[22692]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Wb(d+16|0);break e}c=V(0)|0;O()|0}el(g);break c}el(g);break b}c=V(0)|0;O()|0}Z(c|0)|0;c=v[v[a>>2]-12>>2];v[22692]=0;_(19,a+c|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}$()}gb=d+32|0;return a|0}a=P()|0;O()|0;v[22692]=0;X(20);d=v[22692];v[22692]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;v[a+4>>2]=0;if(w[pj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[22692]=0;b=v[(a+b|0)+24>>2];d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;b=T(2293,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}if(He(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!He(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[22692]=0;d=v[(a+d|0)+24>>2];e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;e=T(2293,d|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}if(He(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(He(e,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;Z(b|0)|0;d=1;oj(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Bb()}L()}d=2}fh(v[v[a>>2]-12>>2]+a|0,d)}gb=f+16|0;return a|0}function P4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Ms(b,c,0)|0)!=-1){while(1){f=Ms(b,c,e);v[22692]=0;Y(138,d|0,b|0,e|0,f-e|0);f=v[22692];v[22692]=0;if((f|0)==1){break j}v[22692]=0;R(139,d+16|0,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break i}v[22692]=0;R(140,a|0,d+16|0);f=v[22692];v[22692]=0;if((f|0)==1){break h}vb(d+16|0);vb(d);e=Ms(b,c,e)+Ab(c)|0;if((Ms(b,c,e)|0)!=-1){continue}break}}k:{if(bd(a)){v[22692]=0;Y(138,d+16|0,b|0,e|0,-1);c=v[22692];v[22692]=0;if((c|0)==1){break f}c=Ab(d+16|0);vb(d+16|0);if(!c){break k}}v[22692]=0;Y(138,d|0,b|0,e|0,-1);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;R(139,d+16|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;R(140,a|0,d+16|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d+16|0);vb(d)}gb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;vb(d+16|0)}vb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0)}vb(d)}mm(a);S(e|0);L()}function Pu(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;default:break b}}t[a+3|0]=0}}function Vx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Kf(g+16|0,a,b,c,e,h-15233|0);hm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}gb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function B7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Jf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(If(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Vg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=fe(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=Zn(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=b- -64|0}
function s7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Jf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(If(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Vg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=fe(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=Yn(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=b- -64|0}function nz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;d=a+2|0;if(!(w[d|0]==255|!w[d|0])){v[f+12>>2]=w[d|0]+1;v[f+8>>2]=10;hh(b,v[nd(f+12|0,f+8|0)>>2]);d=w[a+3|0];t[b+15|0]=d;t[b+16|0]=d;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];d=0;g=511;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Nb(b)){c=g>>>1|e;while(1){h=(d<<2)+a|0;e=h+6|0;e=w[e|0]|w[e+1|0]<<8;i=Lb(b,d),j=e>>>4|0,u[i>>1]=j;e=0;c:{if(d){e=d-1|0;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break c}e=x[Lb(b,e)>>1]+1|0}i=Lb(b,d),j=e,u[i>>1]=j}e=h+8|0;v[f+12>>2]=(c+((w[e|0]|w[e+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;e=v[Wj(f+12|0,f+8|0,f+4|0)>>2];i=Lb(b,d),j=e,t[i+2|0]=j;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;if(w[a|0]&2){d=w[b+15|0];e=Nb(b);d=w[b+12|0]&-5|(d>>>0<=e>>>0)<<2}else{d=w[b+12|0]&-5}t[c+12|0]=d;c=b;d:{e:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break e}}a=w[b+12|0]&-3;break d}d=Nb(b);a=w[b+12|0]&-3|(a>>>0<=d>>>0)<<1}t[c+12|0]=a}gb=f+16|0}function tP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=B(b,872)+a|0;a:{if(c){Db(e+8|0,a+1074312|0,90);if(!Cb(e+8|0)){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[g+1075804|0]}f=g+1074992|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);oP(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,872)+a|0)+1075648>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){nP(a,f,240-h|0);break b}if(!(b>>>0<224|d)){lP(f,224-h|0);break b}kP(f,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=65535}if((c&255)>>>0>223&i){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}iP(a,f,d);break b}if(v[a+480180>>2]==524288){break d}qP(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){Db(e+8|0,a+1074312|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}lk(a,f,(B(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}gb=e+16|0}function EO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=jqa(c,c>>31,5e4,0);f=jb;b=v[Mc(d+12|0,d+8|0)>>2];c=Ac(kqa(c,f,b,b>>31),jb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=jqa(c,c>>31,1e4,0);f=jb;b=v[Mc(d+12|0,d+8|0)>>2];c=Ac(kqa(c,f,b,b>>31),jb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(jqa(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(jb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!le(c,x[b+70>>1])){break d}if(!(bd(_b(c,x[b+70>>1])+24|0)^1)){break d}c=_b(c,x[b+70>>1])+24|0;break c}c=a+480248|0}if(!bd(c)){e=e*5.960464477539063e-8*+y[Lb(c,y[b+48>>2]%(Nb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074384>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=jqa(v[a+480244>>2],0,c,0)+32768|0;a=jb;a=b>>>0<32768?a+1|0:a;a=Qc((a&65535)<<16|b>>>16,a>>>16|0);gb=d+16|0;return(a?a:1)|0}function v_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-112|0;gb=d;vc(b);os(a);a:{if(!hF(b,d+72|0)){break a}if(!iF(d+72|0)){break a}b:{if(!c){break b}c=d+72|4;if(!Pb(b,Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}Nw(a);g=d,h=Mw(),v[g+48>>2]=h;Lw(hj(a)+32|0,d+48|0);ms(d+48|0);f=v[hj(a)+32>>2];v[22692]=0;R(281,d+48|0,b|0);b=v[22692];v[22692]=0;c:{if((b|0)==1){break c}e=v[d+48>>2];c=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));b=Yb(w[d+84|0]|w[d+85|0]<<8|(w[d+86|0]<<16|w[d+87|0]<<24));v[22692]=0;c=ca(282,e|0,c-28|0,f|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}e=0;if(!c){break a}Vd(d+32|0,f);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;Sh(d+40|0,d+16|0);c=Ud(d+24|0);b=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=b;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;b=ls(d+48|0,d+8|0,d);qd(hj(a)+12|0,b);xb(b);break b}b=Ca(89088,28288)|0;a=O()|0;d:{if((ea(89088)|0)!=(a|0)){if((ea(28288)|0)!=(a|0)){break d}}Z(b|0)|0;$();e=0;break a}S(b|0);L()}e=1}gb=d+112|0;return e|0}function Tv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=a;a=gb+-64|0;gb=a;i=a;g=v[c>>2]&2?16:10;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){cO(e+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],g);if(!v[e+12>>2]){break c}f=Ab(d);v[22692]=0;v[e+4>>2]=f;f=wf(e+4|0);j=v[22692];v[22692]=0;if((j|0)!=1){v[22692]=0;U(75,d|0,f|0,0);f=v[22692];v[22692]=0;if((f|0)!=1){continue}}break}break b}b=v[e+8>>2];g=Jb(d);v[22692]=0;R(76,d|0,b-g|0);b=v[22692];v[22692]=0;d:{if((b|0)!=1){v[22692]=0;R(86,i|0,d|0);b=v[22692];v[22692]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=e+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}El(a+16|0,a,c);v[22692]=0;U(93,a+32|0,a+16|0,c|0);b=v[22692];v[22692]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22692]=0;U(94,a+48|0,a+32|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break i}v[22692]=0;R(85,h|0,a+48|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22692]=0;b=T(2464,g|0)|0;a=v[22692];v[22692]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22692]=0;a=T(2465,g|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}Wb(g);v[22692]=0;R(2466,g|0,a|0);d=v[22692];v[22692]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22692]=0;R(2467,g|12,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break e}v[22692]=0;d=g+24|0;a=sa(2468,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Ic(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;while(1){d=Ic(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;Ic(g)}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function iq(a){a=a|0;var b=0,c=0,d=0,e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0);b=v[a+36>>2];if(!b){Eg(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Eg(c);return}wl(c,b);b=x[a+28>>1];d=a+4|0;Nb(d);e=Bm(a,(b<<16)+65536>>16);f=u[a+28>>1];Nb(d);b=1;e=ne(C(e/Bm(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){g=ne(e,C(b>>>0));k=Lb(c,b-1|0),l=g,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:c=a+16|0;d=x[a+30>>1];if(d>>>0>1e3/(b>>>0)>>>0){Eg(c);return}wl(c,B(b,d));b=u[a+28>>1];Nb(a+4|0);h=b;b=x[a+30>>1];h=ko(h,b);if(!d){break b}while(1){b=ko(f+h<<16>>16,b&65535)<<16;j=b>>16;e=ne(C(Bm(a,b+65536>>16)/Bm(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));i=1;b=1;if(v[a+36>>2]){while(1){g=ne(e,C((b&65535)>>>0));k=Lb(c,(B(v[a+36>>2],j)+i|0)-1|0),l=g,z[k>>2]=l;b=b+1|0;i=b&65535;if(i>>>0<=y[a+36>>2]){continue}break}}f=f+1|0;if(d>>>0<=(f&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}Eg(a+16|0);v[a+36>>2]=0}return}Eg(a+16|0)}function e4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22692]=0;b=T(21,g|0)|0;a=v[22692];v[22692]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22692]=0;a=T(2436,g|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break g}Wb(g);v[22692]=0;R(2437,g|0,a|0);d=v[22692];v[22692]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22692]=0;R(2438,g|12,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break e}v[22692]=0;d=g+24|0;a=sa(2439,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;vb(g)}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function YB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;tV(a,b);i=gb-16|0;gb=i;td(c,1);a=b+22|0;k=c,l=Ib(w[a|0]|w[a+1|0]<<8)<<1,v[k>>2]=l;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[ac(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;j=Ib(w[a|0]|w[a+1|0]<<8);a=j<<1;f=b+28|0;g=Ib(w[f|0]|w[f+1|0]<<8);f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(f-a>>>0>3?f>>>0<4|a>>>0>f>>>0:1){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}gb=i+16|0;Jk(h,3,b);Bc(h+16|0,h);v[22692]=0;Q(301,d|0,h+16|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){a=d+32|0;vb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=ZB(b);gb=h+32|0;return a}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}function _p(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=jg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=(h<<1)+j|0;a:{if((b|0)<=0){break a}while(1){Kd(v[f+8>>2],u[(i<<1)+h>>1]/4<<16>>16);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Kd(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function uP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;h=B(b,872)+a|0;a:{if(c){Db(e+8|0,a+1074312|0,90);if(!Cb(e+8|0)){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[h+1075803|0]}f=h+1074992|0;g=c&255;i=d?i:!(v[a+480180>>2]&204473357);oP(a,b,g,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}h=v[(B(b,872)+a|0)+1075648>>2];if(!h|!v[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){nP(a,f,g-240|0);break b}if(!(b>>>0<224|d)){lP(f,g-224|0);break b}kP(f,g);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=1}if((c&255)>>>0>223&i){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}jP(a,f,d);break b}if(v[a+480180>>2]==524288){break d}pP(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){Db(e+8|0,a+1074312|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}lk(a,f,(B(b,872)+a|0)+1075692|0,g<<2,0)}gb=e+16|0}function Eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=u[(g<<1)+o>>1];i=v[a+60>>2];f=Mb(b,-16777216,16776704);n=v[a+64>>2];g=Mb(e,-16777216,16776704);j=j<<8;e=j;e=jqa(i,i>>31,e,e>>31);i=jb;k=jqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=jqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Wd(a){var b=0,c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;v[c+12>>2]=0;v[c+8>>2]=2543;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;d=gb-16|0;gb=d;e=a;if(v[a>>2]!=-1){yc(d,pT(d+8|0,b));b=d;a:{b:{c:{if(!v[e>>2]){d:{cf(e,1);v[22692]=0;f=v[22692];v[22692]=0;e:{if((f|0)==1){break e}v[22692]=0;_(2549,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[e>>2]=-1;v[22692]=0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;b=v[22692];v[22692]=0;if((b|0)!=1){break d}}a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;a=v[22692];v[22692]=0;f:{if((a|0)==1){break f}cf(e,0);v[22692]=0;a=v[22692];v[22692]=0;if((a|0)==1){break f}v[22692]=0;a=v[22692];v[22692]=0;if((a|0)==1){break f}v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[22692]=0;X(20);d=v[22692];v[22692]=0;if((d|0)==1){break c}S(a|0);L()}}break a}V(0)|0;O()|0;Bb()}L()}}gb=d+16|0;gb=c+32|0;return v[a+4>>2]-1|0}function CO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-560|0;gb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=DS(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;Uz(b+48|0,c+48|0);Uz(b+68|0,c+68|0);Uz(b+88|0,c+88|0);hc(b+108|0,c+108|0,448);jv(c);break c}b=ug(556);if(!b){f=0;v[d>>2]=0;break b}v[22692]=0;f=Q(1309,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}v[d>>2]=b}h=a,i=x[Je(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}gb=e+560|0;return f|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function Fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=t[g+o|0];i=v[a+60>>2];f=Mb(b,-16777216,16776704);n=v[a+64>>2];g=Mb(e,-16777216,16776704);j=j<<16;e=j;e=jqa(i,i>>31,e,e>>31);i=jb;k=jqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=jqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function V0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{b=v[a+12>>2];d:{if(d>>>0>b>>>0){while(1){c=v[b>>2];if(c>>>0>1114111|(c&-2048)==55296){break b}e:{if(c>>>0<=127){f=v[a+8>>2];b=1;if((g-f|0)<1){break d}v[a+8>>2]=f+1;t[f|0]=c;break e}if(c>>>0<=2047){b=v[a+8>>2];if((g-b|0)<2){break c}v[a+8>>2]=b+1;t[b|0]=c>>>6|192;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}b=v[a+8>>2];f=g-b|0;if(c>>>0<=65535){if((f|0)<3){break c}v[a+8>>2]=b+1;t[b|0]=c>>>12|224;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}if((f|0)<4){break c}v[a+8>>2]=b+1;t[b|0]=c>>>18|240;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>12&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;if(b>>>0<d>>>0){continue}break}}b=0}break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return b|0}function zM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;yi(f+8|0,b);b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;h=gb-32|0;gb=h;c=v[f+4>>2];b=h;d=v[f>>2];v[b+8>>2]=d;v[b+12>>2]=c;v[b+16>>2]=d;v[b+20>>2]=c;Sh(b+24|0,b+8|0);c=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=c;c=gb-32|0;gb=c;i=c,j=Fg(a),v[i+24>>2]=j;a=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=a;v[c+16>>2]=b;v[c+20>>2]=a;d=c+8|0;b=gb-16|0;gb=b;g=v[c+24>>2];e=g;a=v[e+12>>2];e=v[e+8>>2];a:{if((a|0)<0){break a}if(i=1,j=(l=yb(g)>>>0<e>>>0,m=0,n=(a|0)>=0,n?l:m),k=(a|0)>0,k?i:j){break a}g=yb(v[c+24>>2]);e=v[c+24>>2];a=v[e+8>>2];e=0-((g>>>0<a>>>0)+v[e+12>>2]|0)|0;v[b+8>>2]=g-a;v[b+12>>2]=e;i=b,j=yb(d),v[i>>2]=j;v[b+4>>2]=0;a=Lr(b+8|0,b);a=CA(v[a>>2],v[a+4>>2]);if((yb(d)|0)!=(a|0)){break a}Qg(v[d>>2],a+v[d>>2]|0,zb(v[v[c+24>>2]>>2]+v[v[c+24>>2]+8>>2]|0));d=v[c+24>>2];e=d;g=a+v[d+8>>2]|0;d=v[d+12>>2];v[e+8>>2]=g;v[e+12>>2]=a>>>0>g>>>0?d+1|0:d}gb=b+16|0;gb=c+32|0;gb=h+32|0;gb=f+16|0}function Pfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=d;b=gb-32|0;gb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;v[b+12>>2]=15;c=rf(64);v[22692]=0;f=T(1301,c|0)|0;g=v[22692];v[22692]=0;a:{b:{c:{if((g|0)!=1){c=ks(b+8|0,f);f=v[c>>2];v[22692]=0;R(1302,f|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}a=v[c>>2];v[22692]=0;a=W(1303,a|0,b+22|0,b+16|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}d:{if(!a){Wz(b+24|0);break d}a=v[c>>2];v[22692]=0;R(1304,a|0,b+12|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}ni(b+24|0,c)}Hg(c);gb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Xb(c);break b}a=P()|0;O()|0;Hg(c)}S(a|0);L()}v[e+24>>2]=a;a=0;e:{f:{g:{while(1){b=v[d+24>>2];v[22692]=0;u[d+22>>1]=a;e=Q(2,d+8|0,(a<<2)+38416|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break g}v[22692]=0;U(1300,b|0,d+22|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}vb(e);a=a+1|0;if((a|0)!=12){continue}break}gb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e)}Hg(d+24|0);S(a|0);L()}function WK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{b:{c:{d:{e:{f:{g:{if(xj(a)){wh(c+24|0);break g}ho(c+8|0,a);v[22692]=0;d=T(2068,c+8|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}v[c+24>>2]=d;Vf(c+8|0)}if(xj(a)){d=a+36|0}else{d=v[c+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((co(d)|0)>(b|0)){break d}}b=ba(8)|0;v[22692]=0;d=Q(70,c+8|0,8153)|0;a=v[22692];v[22692]=0;if((a|0)==1){break e}qc(b,d);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(d);break c}a=P()|0;O()|0;Vf(c+8|0);break b}a=P()|0;O()|0;da(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Ol(d,e)+16|0];v[22692]=0;Pi(b+484360|0,f);b=v[22692];v[22692]=0;h:{if((b|0)==1){break h}b=Ol(d,e);d=v[b+8>>2];b=v[b+12>>2];v[22692]=0;+oa(1928,a|0,b|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;pl(c+24|0);gb=c+32|0;return}a=P()|0;O()|0}pl(c+24|0)}S(a|0)}L()}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;g=gb-16|0;gb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;ON(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);ON(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=wd(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;h=w[d+31|0];a:{b:{if(!h){e=1;break b}e=16;if(h>>>0<17){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[Pc(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];gb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=wd(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Jk(f,3,a+4|0);Bc(f+16|0,f);v[22692]=0;Q(301,b+492|0,f+16|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){vb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}gb=f+32|0;return}a=P()|0;O()|0;vb(f+16|0);S(a|0);L()}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;sK(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;$b(c);gb=c+16|0;return}i=gb-32|0;gb=i;j=wb(a);d=i+8|0;e=a;h=co(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=h;a:{c=DV();if(h>>>0<=c>>>0){e=cv(e);if(e>>>0<c>>>1>>>0){v[f+8>>2]=e<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break a}Sc();L()}h=co(a);f=gb-16|0;gb=f;v[f+12>>2]=0;hf(d+12|0,j);if(c){e=c;if(c>>>0>=178956971){pd(8399);L()}g=Nc(B(e,24),8)}v[d>>2]=g;e=B(h,24)+g|0;v[d+8>>2]=e;v[d+4>>2]=e;k=dc(d),l=B(c,24)+g|0,v[k>>2]=l;gb=f+16|0;c=d;sK(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=a;e=c+4|0;g=v[a>>2];a=v[a+4>>2]-g|0;f=v[e>>2]+B((a|0)/-24|0,24)|0;v[e>>2]=f;if((a|0)>=1){hc(f,g,a)}wc(b,e);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];a=c;b=v[c+8>>2];d=v[c+4>>2];if((b|0)!=(d|0)){v[a+8>>2]=b+B(((b-d|0)-24>>>0)/24^-1,24)}a=v[c>>2];if(a){uy(a,(v[dc(c)>>2]-v[c>>2]|0)/24|0)}gb=i+32|0}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;td(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Pc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Pc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49034|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}gb=e+16|0}function x0(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb+-64|0;gb=c;a=Kb(a);v[22692]=0;b=ga(145)|0;d=v[22692];v[22692]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[22692]=0;d=Q(2,c+32|0,6079)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;b=ga(145)|0;e=v[22692];v[22692]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[22692]=0;v[c+12>>2]=b;R(151,c+16|0,c+12|0);b=v[22692];v[22692]=0;if((b|0)==1){break h}v[22692]=0;U(3,c+48|0,d|0,c+16|0);b=v[22692];v[22692]=0;if((b|0)==1){break g}Eb(a,c+48|0);vb(c+48|0);vb(c+16|0);vb(d);v[22692]=0;b=ga(147)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!b){break e}v[22692]=0;Q(152,a|0,14577)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(c+16|0)}vb(d);break a}v[22692]=0;b=ga(146)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!b){break d}v[22692]=0;Q(152,a|0,13848)|0;b=v[22692];v[22692]=0;if((b|0)==1){break b}}gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(a);S(b|0);L()}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=hg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=jg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=h+j|0;a:{if((b|0)<=0){break a}while(1){Kd(v[f+8>>2],t[h+i|0]<<6);Jd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Kd(b,t[h+v[e+44>>2]|0]<<6);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=gg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function FI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-208|0;gb=d;v[d+8>>2]=1;v[d+12>>2]=0;a:{h=b<<2;if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;e=4;f=2;while(1){g=e;e=b;b=(b+4|0)+g|0;v[(d+16|0)+(f<<2)>>2]=b;f=f+1|0;if(b>>>0<h>>>0){continue}break}e=(a+h|0)-4|0;b:{if(e>>>0<=a>>>0){f=1;b=1;break b}f=1;b=1;while(1){c:{if((f&3)==3){Rx(a,c,b,d+16|0);gt(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=e-a>>>0){ft(a,c,d+8|0,b,0,d+16|0);break d}Rx(a,c,b,d+16|0)}if((b|0)==1){et(d+8|0,1);b=0;break c}et(d+8|0,g);b=1}f=v[d+8>>2]|1;v[d+8>>2]=f;a=a+4|0;if(e>>>0>a>>>0){continue}break}}ft(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(f|0)!=1)){if(v[d+12>>2]){break g}break a}if((b|0)>1){break f}}e=EI(d+8|0);gt(d+8|0,e);f=v[d+8>>2];b=b+e|0;break e}et(d+8|0,2);v[d+8>>2]=v[d+8>>2]^7;gt(d+8|0,1);g=a-4|0;e=b-2|0;ft(g-v[(d+16|0)+(e<<2)>>2]|0,c,d+8|0,b-1|0,1,d+16|0);et(d+8|0,1);f=v[d+8>>2]|1;v[d+8>>2]=f;ft(g,c,d+8|0,e,1,d+16|0);b=e}a=a-4|0;continue}}gb=d+208|0}function oL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){v[22692]=0;b=c;T(1277,b|0)|0;a=v[22692];v[22692]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;xk(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=wb(f);v[22692]=0;d=d-4|0;R(1311,e|0,d|0);e=v[22692];v[22692]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[f+4>>2]=g;ai(wb(a),v[a>>2],ye(a))}Xb(c)}v[b+4>>2]=0;eA(b+1298368|0);eu(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);du(b+1298264|0);cu(b+1298260|0);zq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=wq(a-160|0);if((c|0)!=(a|0)){continue}break}Bu(b+484360|0);cA(b+484344|0);Lc(b+480248|0);break a}V(0)|0;O()|0;eA(b+1298368|0);eu(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);du(b+1298264|0);cu(b+1298260|0);zq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=wq(a-160|0);if((c|0)!=(a|0)){continue}break}Bu(b+484360|0);cA(b+484344|0);Lc(b+480248|0);Bb();L()}Xb(b)}}}function mu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;g=a+1074312|0;Db(e+8|0,g,77);a:{if(j=Cb(e+8|0),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{i=c;if(d){f=w[c+841|0];if(!f){break c}d=f-1|0;t[c+841|0]=d;if(d&255){break b}Db(e+8|0,g,16);if(!(j=Cb(e+8|0),k=1,l=v[a+480180>>2]!=2,l?j:k)){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[i+764>>2]=a;break a}Db(e+8|0,g,17);if(!(Cb(e+8|0)|v[a+480180>>2]&3|!x[a+480188>>1])){f=b+616|0;while(1){if(w[f+841|0]?(c|0)!=(f|0):0){break a}f=f+872|0;h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;d:{if((d|0)==-1){break d}e:{if(v[b+60>>2]==-1){break e}Db(e+8|0,g,68);if(!Cb(e+8|0)){break e}v[b+60>>2]=d}v[b+64>>2]=d;Db(e+8|0,g,103);if(!Cb(e+8|0)){break d}u[b+68>>1]=65535}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break a}d=0;while(1){f=B(d,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}gb=e+16|0}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;gb=f+32|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=e+o|0;p=t[g+1|0];g=t[g|0];e=v[a+60>>2];q=e;r=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=jqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=((B(p-g|0,i>>>10&4194048)|0)/16384|0)+(g<<8)<<8;i=jqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function GS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;f=gb-16|0;gb=f;if(Gj(a)){e=w[(ue(w[a+797|0])?a+797|0:a+799|0)|0];Db(f+8|0,d+1074312|0,34);a:{if(!Cb(f+8|0)){break a}d=e;if(e){if(d>>>0>120){break a}e=w[lc(v[a+656>>2]+108|0,d-1|0)|0];break a}e=0}d=a;k=C(C(v[a+704>>2]<<4)*b);e=(c+e<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];i=v[c+36>>2];a=v[a+852>>2]+u[a+772>>1]|0;b:{if(!(a?i:0)){b=Bm(c,a+e<<16>>16);break b}j=i+1|0;l=_y(a,j);g=ko(a,j);a=u[c+28>>1];h=c+4|0;Nb(h);b=C(1);e=e+l<<16>>16;c:{if((e|0)<(a|0)){break c}if((e|0)>(x[c+28>>1]+Nb(h)<<16)-65536>>16){break c}if(!g){b=z[Lb(h,e-u[c+28>>1]|0)>>2];break b}a=x[c>>1];d:{if((a|0)==3){a=c+16|0;if(Nb(a)){b=z[Lb(a,g-1|0)>>2];break d}a=x[c>>1]}e:{if((a&65535)!=1){break e}a=c+16|0;if(!Nb(a)){break e}b=z[Lb(a,(B(i,ko(e,x[c+30>>1])<<16>>16)+g|0)-1|0)>>2];break d}b=ne(C(Bm(c,(e<<16)+65536>>16)/Bm(c,e)),C(C(g|0)/C(j|0)))}b=C(z[Lb(h,e-u[c+28>>1]|0)>>2]*b)}}m=d,n=Fj(C(k*b)),v[m+700>>2]=n}gb=f+16|0}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=(e<<1)+o|0;p=u[g+2>>1];g=u[g>>1];e=v[a+60>>2];q=e;r=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=jqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=jqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=g+((B(p-g|0,i>>>18|0)|0)/16384|0)<<8;i=jqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function Ry(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=gb+-64|0;gb=b;d=v[a+20>>2];a:{if(!d){break a}if(pc(d+4|0)>>>0<4){break a}Vd(b+32|0,v[a+20>>2]+4|0);d=Ud(b+24|0);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[d+4>>2];v[b+8>>2]=v[d>>2];v[b+12>>2]=c;d=SX(b+40|0,b+16|0,b+8|0);v[22692]=0;c=T(190,d|0)|0;f=v[22692];v[22692]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[22692]=0;c=T(c|0,a|0)|0;f=v[22692];v[22692]=0;c:{if((f|0)==1){break c}if(pc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+172>>2];f=0;v[22692]=0;R(e|0,a|0,-1);e=v[22692];v[22692]=0;if((e|0)==1){break c}if(c){while(1){v[22692]=0;g=C(Ba(631,d|0));e=v[22692];v[22692]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[22692]=0;Aa(e|0,a|0,f|0,C(g));e=v[22692];v[22692]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+176>>2];v[22692]=0;_(c|0,a|0);a=v[22692];v[22692]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;xb(d);S(a|0);L()}xb(d)}gb=b- -64|0}function Nf(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function jx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=ix(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+83392|0];d:{e:{switch(nqa(f-88|0,30)|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function dg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;d=v[a+28>>2];go(v[v[d>>2]-12>>2]+d|0,0);if(!ld(a,4)){Hy(a)}a:{if(!v[a+4>>2]){break a}if(ld(a,6)){break a}if(ld(a,7)){break a}g=v[a+28>>2];e=v[a+84>>2];h=B(v[a+20>>2],v[a+4>>2]);f=h+v[a+80>>2]|0;e=oh(c- -64|0,f,f>>>0<h>>>0?e+1|0:e);f=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=f;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;ek(g,c+16|0)}d=0;b:{if(!ld(a,5)){break b}g=0;e=a+44|0;h=tf(e);d=0;if(!h){break b}d=a+32|0;while(1){c:{f=(v[a+96>>2]+g>>>0)%(h>>>0)|0;if(y[Tc(e,f)>>2]>=pc(d)>>>0){break c}i=io(c+48|0,kc(d,v[Tc(e,f)>>2]),x[Tc(e,f)+12>>1]);j=Ky(b,i);Hb(i);if(!j){break c}v[a+96>>2]=(f+1>>>0)%(h>>>0);b=v[Tc(e,f)+4>>2];if(b){h=v[a+28>>2];g=b+v[a+8>>2]|0;a=v[a+12>>2];a=oh(c+32|0,g,b>>>0>g>>>0?a+1|0:a);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;ek(h,c)}d=Tc(e,f);break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}d=0}gb=c+80|0;return d}function cJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];a:{b:{c:{b=v[a+1380>>2];d:{if((b|0)==-1){h=1;b=-1;break d}d=v[a+1116>>2];e:{if((d|0)<=(b|0)){break e}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break e}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){break c}b=(b|0)==(d|0)?-1:b}while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){ec(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[90056]|w[90057]<<8|(w[90058]<<16|w[90059]<<24))){ec(a,21);break a}if(w[c+4|0]){ec(a,21);break a}f:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break f}ec(a,21);break a}if(t[c+5|0]&1){break f}ec(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break b}h=0;b=0;f=0;g:{if(!e){break g}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break g}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}ec(a,1);break a}ec(a,1);break a}ec(a,1)}return 0}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function H8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;v[e+72>>2]=c;c=ni(a,e+72|0);g=wh(a+4|0);h=wh(a+24|0);i=wh(a+32|0);j=cd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22692]=0;R(2063,a|0,d|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];l=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=l;b=Ud(e+24|0);f=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=f;v[22692]=0;f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;U(2057,e+48|0,e+8|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;U(2064,a|0,e+48|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}xb(e+48|0);v[22692]=0;_(2065,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}cg(e+72|0);gb=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+48|0);break a}a=P()|0;O()|0}yd(k);Vf(j);dq(i);Di(h);Ci(g);cg(c);cg(e+72|0);S(a|0);L()}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(If(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Wg(a,g,j);c=Lb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=ut(f)+c&-4096;v[l>>2]=e-c;c=gd(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=Zn(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=d- -64|0}function WJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(If(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Wg(a,g,j);c=Lb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=ut(f)+c&-4096;v[l>>2]=e-c;c=gd(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=Yn(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=d- -64|0}function rT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=gb-16|0;gb=d;e=Kb(a);i=b;b:{if(Ab(b)){while(1){a=v[sk(i,g)>>2];c:{if(a>>>0>=2097152){v[22692]=0;R(66,e|0,63);a=v[22692];v[22692]=0;if((a|0)!=1){break c}break b}c=0;d:{e:{while(1){f=a&63;t[(d+10|0)+c|0]=f;if(a>>>0<64){break e}a=a>>>6|0;c=c+1|0;if((c|0)!=6){continue}break}b=7;c=6;break d}f:{if(!c){v[22692]=0;R(66,e|0,t[d+10|0]);break f}b=c+1|0;if((b|0)!=2){break d}c=1;b=2;if((f|0)!=1){break d}v[22692]=0;R(66,e|0,t[d+10|0]|64)}a=v[22692];v[22692]=0;if((a|0)!=1){break c}break b}f=(-1<<b^-1)<<7-c;c=b-1|0;j=c+(d+10|0)|0;a=b;while(1){g:{if((a|0)==(b|0)){a=w[j|0];v[22692]=0;R(66,e|0,(a|f)<<24>>24);h=v[22692];v[22692]=0;a=c;if((h|0)!=1){break g}break b}v[22692]=0;a=a-1|0;R(66,e|0,t[a+(d+10|0)|0]|-128);h=v[22692];v[22692]=0;if((h|0)==1){break b}}if(a){continue}break}}g=g+1|0;if(Ab(i)>>>0>g>>>0){continue}break}}gb=d+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function mx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Qm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+83392|0];d:{e:{switch(f-22|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;gb=f+32|0}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>4;v[d+16>>2]=v[a>>2];h=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=fe(e);a:{if(D(e)<2147483648){g=~~e;break a}g=-2147483648}i=f,j=Uc(g),u[i>>1]=j;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[d+24>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=fe(e);b:{if(D(e)<2147483648){g=~~e;break b}g=-2147483648}i=f,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return h<<4}function pI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;Kf(h+16|0,a,b,g,e,f-16129|0);hm(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}gb=h+32|0;return l(2,d&-2147483648|e),q()}function xH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Gf(c+24|0,a+44|0)>>2];if((e|0)>=1){h=(e|0)>0?e:0;while(1){f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;if((h|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(KH(v[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Qs(Kg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}j=a,k=Kg(t[c+23|0]),v[j+48>>2]=k}d=Kg(t[c+23|0]);break a}d=-1}gb=c+32|0;return d}function ON(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;t[k+15|0]=c;t[k+14|0]=12;hh(b,w[ac(k+15|0,k+14|0)|0]);if(Nb(b)){c=0;l=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(h|0){case 0:i=c<<2;j=i+l|0;j=w[j|0]|w[j+1|0]<<8;n=Lb(b,c),o=j,u[n>>1]=o;i=(i|2)+l|0;break b;case 1:break c;default:break a}}i=c<<2;j=i+a|0;j=w[j|0]|w[j+1|0]<<8;n=Lb(b,c),o=j,u[n>>1]=o;i=a+(i|2)|0}i=w[i|0];n=Lb(b,c),o=i,t[n+2|0]=o}d:{if(!c){break d}i=c-1|0;if(x[Lb(b,c)>>1]>=x[Lb(b,i)>>1]){break d}if(x[Lb(b,c)>>1]>255){break d}j=w[Lb(b,i)+1|0];m=Lb(b,c);u[m>>1]=x[m>>1]|j<<8;if(x[Lb(b,c)>>1]>=x[Lb(b,i)>>1]){break d}i=Lb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(bd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}gb=k+16|0}function PT(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;b=v[a>>2];yc(g+8|0,b);a:{b:{c:{d:{e=b+16|0;e:{if(Dd(e)){while(1){f:{d=v[e>>2];v[22692]=0;d=T(56,d|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break f}f=d|f;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(89064)|0;if((O()|0)!=(ea(89064)|0)){break c}Z(c|0)|0;t[b+20|0]=0;v[22692]=0;_(38,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break d}v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break c}t[b+20|0]=0}if(!w[b+20|0]){b=v[b+24>>2];c=v[b+2496>>2];e=(c<<2)+b|0;h=v[b+((c+397>>>0)%624<<2)>>2];d=(c+1>>>0)%624|0;c=v[b+(d<<2)>>2];c=h^(c&2147483647|v[e>>2]&-2147483648)>>>1^B(c&1,-1727483681);v[e>>2]=c;v[b+2496>>2]=d;b=c^c>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;f=f^(b>>>18^b)}gb=g+16|0;break a}c=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Bb();L()}return v[a+28>>2]&f}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);c=0;while(1){if((l|0)>=1){j=(k<<1)+b|0;n=j+(l<<1)|0;while(1){o=c;u[e+6>>1]=0;HV(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{if(!i){h=x[e+6>>1];break a}h=x[e+6>>1];c=x[e+12>>1];g=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!kf(a,e+5|0)){break a}f=w[e+5|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}h=f|h<<1;g=g-1|0;if(g&255){continue}break}}c=1;m=h&65535;b:{if(m>>>0<4){break b}g=15;while(1){c=g;f=c&255;if(m>>>f&1){break b}g=c-1|0;if(f>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=h&1;t[e+14|0]=c;g=c-1^(h&65534)>>>1;c=g+x[e+8>>1]|0;u[e+6>>1]=c;u[j>>1]=c;v[e+8>>2]=((g>>1)-(o<<16>>16)|0)+(c<<16>>16<<1);Sd(e+8|0,-32768,32767);j=(d<<1)+j|0;if(n>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=0,u=0,x=0,y=0,A=0,B=C(0);f=gb-16|0;gb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!ki(g)){break a}s=z[a+4220>>2];y=f,A=Od(g,0),v[y+8>>2]=A;y=f,A=Od(g,1),v[y+12>>2]=A;y=f,A=md(g,0),v[y>>2]=A;y=f,A=md(g,1),v[y+4>>2]=A;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;t=v[((n<<2)+a|0)+4248>>2];u=v[a+4240>>2];x=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;l=z[e>>2];e=x-t|0;q=z[Lb(m,n+((e>>31&u)+e<<1)|0)>>2];r=C(C(z[a+4224>>2]*q)+C(l*z[a+4260>>2]));y=Lb(m,v[a+4244>>2]<<1|h),B=C(D(r))<C(1.0000000195414814e-24)?C(0):r,z[y>>2]=B;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(q-l)*s);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}Ei(a,b,c,md(g,0),md(g,1),d)}gb=f+16|0}function kT(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+33376|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&240)!=32?(d&15)!=2:0)){t[a|0]=20;t[b|0]=159;d=159}if((d&15)!=12&(d&240)!=192|c>>>0<51){break b}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:d:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break d;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function W0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){i=d;f=t[a|0];b=1;b:{if((f|0)>-1){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}b=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}b=3;if((h&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(h&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}g=g+1|0;b=4}a=b+a|0;if(i>>>0<=a>>>0){break a}g=g+1|0;if(g>>>0<e>>>0){continue}break}}return a-c|0}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Od(f,0);j=Od(f,1);k=md(f,0);l=md(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Lb(h,e)>>2];e=Lb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));w=Lb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));w=Lb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}Ei(a,b,c,md(f,0),md(f,1),d)}}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=g>>>21&2040;g=u[b+46150>>1];m=u[b+46148>>1];n=u[b+46146>>1];o=u[b+46144>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;gb=e+32|0}function G1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=Nb(465792);if(b>>>0<a>>>0){g=gb-32|0;gb=g;e=a-b|0;a:{if(e>>>0<=v[116452]-v[116449]>>2>>>0){JG(e);break a}f=$w(465792);b=g+8|0;d=Nb(465792)+e|0;c=gb-16|0;gb=c;v[c+12>>2]=d;b:{a=fp();if(d>>>0<=a>>>0){d=tG(465792);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;break b}Sc();L()}h=Nb(465792);c=0;d=gb-16|0;gb=d;v[d+12>>2]=0;hf(b+12|0,f);if(a){c=uG(v[b+16>>2],a)}v[b>>2]=c;f=(h<<2)+c|0;v[b+8>>2]=f;v[b+4>>2]=f;i=dc(b),j=(a<<2)+c|0,v[i>>2]=j;gb=d+16|0;d=gb-16|0;gb=d;a=Lk(d,b+8|0,e);c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Qo(c);c=v[a>>2]+4|0;v[a>>2]=c;if(v[a+4>>2]!=(c|0)){continue}break}}Zc(a);gb=d+16|0;a=b+4|0;hl(v[116448],v[116449],a);wc(465792,a);wc(465796,b+8|0);wc(465808,dc(b));v[b>>2]=v[b+4>>2];a=b;iC(a);b=v[a>>2];if(b){sG(v[a+16>>2],b,vk(a))}}gb=g+32|0;return}if(a>>>0<b>>>0){ee(465792,v[116448]+(a<<2)|0)}}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Kb(d+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[22692]=0;c=T(1403,b|0)|0;e=v[22692];v[22692]=0;d:{if((e|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22692]=0;Q(70,a|0,18699)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break b}}break a}v[22692]=0;c=T(465,b|0)|0;e=v[22692];v[22692]=0;e:{if((e|0)==1){break e}c=Ti(c);v[22692]=0;v[d+8>>2]=c;c=nd(d+12|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}c=v[c>>2];v[22692]=0;R(60,f|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[22692]=0;c=T(374,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break g}if(!c){break f}v[22692]=0;W(1404,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}break a}v[22692]=0;Q(318,b|0,4)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}Dc(a,f)}vb(f);gb=d+32|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function DS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=aB(a+48|0);e=aB(a+68|0);f=aB(a+88|0);v[22692]=0;Qq(a+492|0);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Qq(a+524|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}v[22692]=0;am(a,0,0);c=v[22692];v[22692]=0;if((c|0)==1){break a}v[22692]=0;$l(a,0,0);c=v[22692];v[22692]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[22692]=0;mr(a,b);b=v[22692];v[22692]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=lc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;Wo(f);Wo(e);Wo(d);S(a|0);L()}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=ze(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>5>>>0){f=gb-16|0;gb=f;d=sB(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){NB(e);e=e+32|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=Wq(e,ze(e)+i|0);m=ze(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;hf(d+12|0,j);if(f){h=f;if(f>>>0>=134217728){pd(8399);L()}h=Nc(h<<5,1)}v[d>>2]=h;j=(m<<5)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<5)+h|0,v[n>>2]=o;gb=l+16|0;v[22692]=0;BT(d,i);f=v[22692];v[22692]=0;if((f|0)==1){break c}Rk(e,d);AT(d)}gb=k+32|0;break b}a=P()|0;O()|0;AT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Sk(e,v[e>>2]+(d<<5)|0)}}if(Pb(a,c<<5)){bc(g+24|0,v[b>>2],ze(b)<<5);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;id(g+16|0,a,g+8|0)}gb=g+32|0}function wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=tf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){f=gb-16|0;gb=f;d=Zp(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){yv(e);e=e+16|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=Wx(e,tf(e)+i|0);m=tf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;hf(d+12|0,j);if(f){h=f;if(f>>>0>=268435456){pd(8399);L()}h=Nc(h<<4,1)}v[d>>2]=h;j=(m<<4)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<4)+h|0,v[n>>2]=o;gb=l+16|0;v[22692]=0;wT(d,i);f=v[22692];v[22692]=0;if((f|0)==1){break c}Rk(e,d);vT(d)}gb=k+32|0;break b}a=P()|0;O()|0;vT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Sk(e,v[e>>2]+(d<<4)|0)}}if(Pb(a,c<<4)){bc(g+24|0,v[b>>2],tf(b)<<4);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;id(g+16|0,a,g+8|0)}gb=g+32|0}function T0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){f=1;b=t[a|0];b:{if((b|0)>-1){break b}b=b&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}f=3;if((g&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244){break a}f=w[a+3|0];i=w[a+2|0];g=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((g+112&255)>>>0<48){break e}break a;case 4:if((g&240)==128){break e}break a;default:break f}}if((g&192)!=128){break a}}if((i&192)!=128|(f&192)!=128){break a}f=4;if((b<<18&1835008|(g&48)<<12)>>>0>1114111){break a}}a=a+f|0;if(d>>>0<=a>>>0){break a}h=h+1|0;if(h>>>0<e>>>0){continue}break}}return a-c|0}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb+-64|0;gb=e;g=lo(a);a:{b:{if(b-1>>>0>1023){break b}f=v[a+12>>2];if((f|0)==(b|0)){break b}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break b}f=v[a+12>>2]}f=B(Ji(a),b>>>0>f>>>0?b-f|0:f-b|0);c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=Zb(a);break d}d=Vb(a)}v[c+48>>2]=d;c=Hd(e+56|0,e+48|0);Eh(e+40|0);c=v[c>>2];v[22692]=0;Y(1459,a|0,c|0,f|0,e+40|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(a|0)|0;$();break b}if(d){i=e,j=Zb(a),v[i+48>>2]=j;i=e,j=QC(e+48|0,f),v[i+40>>2]=j;c=Hd(e+32|0,e+40|0);i=e,j=Zb(a),v[i+16>>2]=j;d=Hd(e+24|0,e+16|0);GN(a,v[c>>2],v[d>>2]);break c}i=e,j=Vb(a),v[i+40>>2]=j;c=Hd(e+8|0,e+40|0);i=e,j=Vb(a),v[i+16>>2]=j;i=e,j=xX(e+16|0,f),v[i+48>>2]=j;d=Hd(e,e+48|0);GN(a,v[c>>2],v[d>>2])}v[a+12>>2]=b;h=1}gb=e- -64|0;return h|0}S(a|0);L()}function H5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[pj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;Fc(c+16|0,a+d|0);d=v[22692];v[22692]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[22692]=0;d=T(2286,c+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break h}e=$i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22692]=0;ka(2289,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22692];v[22692]=0;if((d|0)==1){break h}Wb(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;oj(v[v[a>>2]-12>>2]+a|0,b);if(!(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1)){break e}v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function vH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Gf(c+24|0,a+44|0)>>2];if((e|0)>=1){h=(e|0)>0?e:0;while(1){f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;if((h|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(KH(v[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Qs(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}gb=c+32|0;return d}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=ge(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Uc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=ge(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function vga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=gb-32|0;gb=f;m=f,o=B(v[a>>2],dd(a)),v[m+4>>2]=o;tc(f+4|0,c>>>3|0);c=zb(b);g=A[e+8>>3];h=v[f+4>>2];a:{if(!h){break a}e=h;while(1){j=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,j|0);g=G(+n(),g);c=c+8|0;e=e-1|0;if(e){continue}break}if(g==0){break a}k=1/g;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=+n()*k,A[m+24>>3]=p;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;i=A[$g(f+24|0,f+16|0,f+8|0)>>3]*32768;A[f+24>>3]=i;a=c;i=fe(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Uc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;h=h-1|0;if(h){continue}break}}if(d){A[d>>3]=g}gb=f+32|0;return v[f+4>>2]<<3}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;v[g+12>>2]=1;a:{if(bi(a)){n=g,o=ze(a),v[n+8>>2]=o;f=v[a>>2];c=b;k=v[Fb(g+12|0,g+8|0)>>2];if(k){while(1){d=c;if((c|0)!=(f|0)){h=Vb(d);l=Zb(d);i=gb-16|0;gb=i;j=lD(h,l);e=f;b:{if(j>>>0<=Ng(e)>>>0){if(sc(e)>>>0<j>>>0){v[i+8>>2]=h;gS(i+8|0,sc(e));m=h;h=v[i+8>>2];Vi(m,h,v[e>>2]);pS(e,h,l,j-sc(e)|0);break b}rn(e,Vi(h,l,v[e>>2]));break b}oS(e);OB(e,Nk(e,j));pS(e,h,l,j)}gb=i+16|0;bk(f+12|0,d+12|0);u[f+28>>1]=x[d+28>>1]}f=f+32|0;k=k-1|0;if(k){continue}break}}d=v[g+12>>2];c=v[g+8>>2];if(d>>>0>c>>>0){ZA(a,d-c|0,b);break a}iS(a,v[a>>2]+(d<<5)|0);break a}c=a;if(v[c>>2]){ze(c);dS(c);bS(c);Qk(wb(c),v[c>>2],bi(c));n=wb(c),o=0,v[n>>2]=o;v[c>>2]=0;v[c+4>>2]=0}f=Wq(a,1);if(yT()>>>0<f>>>0){Sc();L()}wb(c);d=aS(f);v[c>>2]=d;v[c+4>>2]=d;n=wb(c),o=d+(f<<5)|0,v[n>>2]=o;YA(c,0);ZA(a,1,b)}gb=g+16|0}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22692]=0;_(1991,a|0);e=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22692]=0;_(1944,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break e}e=0;v[22692]=0;_(1992,c|0);f=v[22692];v[22692]=0;if((f|0)==1){break e}a=Qb(c,0,d);if(!w[b|0]){break b}if(sj(b,4307)|(d|0)!=8){break d}v[a+4>>2]=1993;v[a>>2]=1994;break c}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,9474,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();return 0}if(sj(b,8485)|(d|0)!=64){break b}v[a+60>>2]=1995;v[a+56>>2]=1996;v[a+52>>2]=1997;v[a+48>>2]=1998;v[a+44>>2]=1999;v[a+40>>2]=2e3;v[a+36>>2]=2001;v[a+32>>2]=2002;v[a+28>>2]=2003;v[a+24>>2]=2004;v[a+20>>2]=2005;v[a+16>>2]=2006;v[a+12>>2]=2007;v[a+8>>2]=2008;v[a+4>>2]=2009;v[a>>2]=2010}e=1}return e|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;i=c,j=qL(),v[i+24>>2]=j;oL(a+24|0,ce(c+24|0));Di(c+24|0);u[a+28>>1]=0;f=$X();v[c+16>>2]=4;d=c;g=gb-16|0;gb=g;e=rf(144);h=v[c+16>>2];v[22692]=0;f=W(2036,e|0,f|0,h|0)|0;h=v[22692];v[22692]=0;a:{if((h|0)!=1){e=v[Wi(g+8|0,f)>>2];gb=g+16|0;break a}a=P()|0;O()|0;Xb(e);S(a|0);L()}v[d+24>>2]=e;nL(a+32|0,ce(c+24|0));dq(c+24|0);i=c,j=pL(v[a>>2]),v[i+24>>2]=j;mL(a+4|0,ce(c+24|0));Ci(c+24|0);fo(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;i=c,j=lr(b),v[i+24>>2]=j;i=c,j=Ah(b),v[i+16>>2]=j;b:{if(mg(c+24|0,c+16|0)){while(1){d=te(c+24|0);b=eg(c,d);v[22692]=0;Y(1984,a|0,b|0,d+12|0,0);d=v[22692];v[22692]=0;if((d|0)==1){break b}vb(b);Oj(c+24|0);if(mg(c+24|0,c+16|0)){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=h>>>21&2040;h=u[b+46150>>1];m=u[b+46148>>1];n=u[b+46146>>1];o=u[b+46144>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;gb=e+32|0}function boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;g=dg(a,c);re(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{if(!g){if(ld(a,5)){break a}}d=gb-48|0;gb=d;h=v[a+28>>2];_f(h,d+46|0);b:{c:{d:{e:{f:{if(x[d+46>>1]>=4001){j=v[b+12>>2];f=gb-16|0;gb=f;i=Tb(f,13006);Dc(d+16|0,i);vb(i);gb=f+16|0;v[22692]=0;U(1079,d+32|0,d+16|0,d+46|0);f=v[22692];v[22692]=0;if((f|0)==1){break f}v[22692]=0;U(556,j|0,2,d+32|0);f=v[22692];v[22692]=0;if((f|0)==1){break e}vb(d+32|0);Hb(d+16|0);u[d+46>>1]=4e3}yf(Nj(b,0),x[d+46>>1]);b=Nj(b,0);k=d,l=Vb(b),v[k+32>>2]=l;k=d,l=Zb(b),v[k+16>>2]=l;if(Gb(d+32|0,d+16|0)){break c}break b}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d+32|0)}Hb(d+16|0);S(a|0);L()}while(1){b=v[d+32>>2];_f(h,d+14|0);u[b>>1]=x[d+14>>1];nf(d+32|0);if(Gb(d+32|0,d+16|0)){continue}break}}gb=d+48|0}Wf(a,g,c,e+24|0);gb=e+32|0}function AU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-48|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;wb(b);df(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){Vr(a,v[b+4>>2]);uk(c+32|0,b);Ll(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=gb-80|0;gb=b;i=a;f=v[a+4>>2];d=v[c+20>>2];k=d;g=v[c+16>>2];v[b+72>>2]=g;v[b+76>>2]=d;e=v[c+12>>2];l=e;h=v[c+8>>2];v[b+64>>2]=h;v[b+68>>2]=e;v[b+24>>2]=g;v[b+28>>2]=d;v[b+16>>2]=h;v[b+20>>2]=e;d=yU(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}j=v[i>>2];v[(d>>>0<33?j:(e>>>3&536870908)+j|0)>>2]=0}v[b+48>>2]=h;v[b+52>>2]=l;v[b+56>>2]=g;v[b+60>>2]=k;tp(b+40|0,i,f);d=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=d;d=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=d;TU(b+32|0,b+8|0,b,b+40|0);gb=b+80|0}gb=c+48|0;return a|0}function vm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;jl(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=um(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}ec(a,21);v[a+1396>>2]=0}return-1}aa(8622,10482,1690,2537);L()}function t7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Jf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(If(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=gd((v[Wg(a,b,g)>>2]+gd(tt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=Yn(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=c- -64|0}function C7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Jf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(If(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=gd((v[Wg(a,b,g)>>2]+gd(tt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=Zn(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=c- -64|0}function ux(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=Mf(a);a:{if(!v[115976]|!w[a|0]){break a}c=a;b:{if(c&3){while(1){b=w[c|0];if(!b|(b|0)==61){break b}c=c+1|0;if(c&3){continue}break}}b=v[c>>2];c:{if((b^-1)&b-16843009&-2139062144){break c}while(1){b=b^1027423549;if((b^-1)&b-16843009&-2139062144){break c}b=v[c+4>>2];c=c+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}while(1){b=c;e=w[c|0];if(e){c=b+1|0;if((e|0)!=61){continue}}break}c=b}if(w[c|0]==61?c:0){break a}d=v[v[115976]>>2];if(!d){break a}d:{while(1){i=v[115976];c=a;e=0;g=h;b=0;e:{if(!g){break e}b=w[c|0];f:{if(!b){break f}while(1){g:{j=w[d|0];if(!j){break g}g=g-1|0;if(!g|(b|0)!=(j|0)){break g}d=d+1|0;b=w[c+1|0];c=c+1|0;if(b){continue}break f}break}e=b}b=(e&255)-w[d|0]|0}if(!b){c=v[(f<<2)+i>>2]+h|0;if(w[c|0]==61){break d}}f=f+1|0;d=v[(f<<2)+i>>2];if(d){continue}break}return 0}f=c+1|0}return f}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);n=(l|0)<1;j=4;while(1){if(!n){i=b+k|0;o=l+i|0;while(1){p=g;t[e+7|0]=0;GV(a,e+15|0,e+12|0,e+7|0);a:{if(!j){g=w[e+7|0];break a}g=w[e+7|0];c=x[e+12>>1];f=j;b:{while(1){h=c<<1;c=h&254;c:{if(c){h=(h&65534)>>>0>255;break c}if(!kf(a,e+6|0)){break b}c=w[e+6|0];h=c>>>7|0;c=c<<1&254|1}g=g<<1|h;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;m=g&255;d:{if(m>>>0<4){break d}f=7;while(1){c=f;h=c&255;if(m>>>h&1){break d}f=c-1|0;if(h>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;f=f-1^(g&254)>>>1;g=f+w[e+8|0]|0;t[e+7|0]=g;t[i|0]=g;v[e+8>>2]=((f>>1)-(p<<24>>24)|0)+(g<<24>>24<<1);Sd(e+8|0,-128,127);j=(c+j&254)>>>1|0;i=d+i|0;if(o>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function Ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(g<<1)+n>>1];j=v[a+60>>2];f=Mb(b,-16777216,16776704);k=v[a+64>>2];g=Mb(e,-16777216,16776704);i=i<<8;e=i;e=jqa(j,j>>31,e,e>>31);j=jb;k=jqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=jqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function kA(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1298260|0;while(1){e=B(d,872)+a|0;c=e+1075068|0;b:{if(v[c>>2]){break b}if(!nk(e+1074992|0)){break a}if(v[c>>2]){break b}if(w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Dd(f)){break a}if(!zP(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){d=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,872)+a|0;if(!(v[c+1075688>>2]?0:v[c+1075068>>2])){f=(v[c+1075680>>2]|v[c+1075672>>2]<<9)>>>(v[c+1075080>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075716>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075716>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function z3(){var a=0,b=0,c=0,d=0;c=gb-32|0;gb=c;a:{a=Tb(c+16|0,12462);if(!Ab(a)){break a}b:{if((tg(a,11794)|0)!=-1){b=tg(a,11794);v[22692]=0;Y(149,c|0,a|0,b+1|0,-1);b=v[22692];v[22692]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((tg(a,13846)|0)!=-1){b=tg(a,13846);v[22692]=0;Y(149,c|0,a|0,b+1|0,-1);b=v[22692];v[22692]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((tg(a,11111)|0)!=-1){b=tg(a,11111);v[22692]=0;Y(149,c|0,a|0,0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((tg(a,10986)|0)!=-1){b=tg(a,10986);v[22692]=0;Y(149,c|0,a|0,0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((tg(a,11029)|0)!=-1){b=tg(a,11029);v[22692]=0;Y(149,c|0,a|0,0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}v[22692]=0;b=T(150,a|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;vb(a);S(c|0);L()}vb(a);gb=c+32|0;return b|0}function Jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[g+n|0];j=v[a+60>>2];f=Mb(b,-16777216,16776704);k=v[a+64>>2];g=Mb(e,-16777216,16776704);i=i<<16;e=i;e=jqa(j,j>>31,e,e>>31);j=jb;k=jqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=jqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Baa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){d=Kb(b+32|0);c=v[a+24>>2];v[22692]=0;R(1943,b+16|0,c|0);c=v[22692];v[22692]=0;d:{if((c|0)!=1){e=b,f=Vb(b+16|0),v[e+8>>2]=f;e=b,f=Zb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[22692]=0;Q(1161,d|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break e}pr(b+8|0);e=b,f=Zb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}v[22692]=0;Q(1901,d|0,11769)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;yd(b+16|0);break d}c=V(0)|0;O()|0}vb(d);break c}c=V(0)|0;O()|0}Z(c|0)|0;c=0;v[22692]=0;Y(1895,3645,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}c=je(Jb(d));yd(b+16|0);vb(d)}gb=b+48|0;return c|0}function W9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)!=1){d=Kb(b+32|0);c=v[a+24>>2];v[22692]=0;R(1978,b+16|0,c|0);c=v[22692];v[22692]=0;d:{if((c|0)!=1){e=b,f=Vb(b+16|0),v[e+8>>2]=f;e=b,f=Zb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[22692]=0;Q(1161,d|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break e}pr(b+8|0);e=b,f=Zb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}v[22692]=0;Q(1901,d|0,11769)|0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;yd(b+16|0);break d}c=V(0)|0;O()|0}vb(d);break c}c=V(0)|0;O()|0}Z(c|0)|0;c=0;v[22692]=0;Y(1895,4108,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}c=je(Jb(d));yd(b+16|0);vb(d)}gb=b+48|0;return c|0}function jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=d;i=dg(a,c);re(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!i){if(ld(a,5)){break a}}k=v[e+24>>2];d=gb-48|0;gb=d;h=v[a+28>>2];rl(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>=257|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){_f(h,d+38|0);f=Kb(d+24|0);v[22692]=0;W(650,h|0,f|0,255)|0;g=v[22692];v[22692]=0;if((g|0)==1){break f}v[22692]=0;U(13,d+8|0,k|0,f|0);g=v[22692];v[22692]=0;if((g|0)==1){break e}v[22692]=0;g=Q(1500,b|0,d+38|0)|0;l=v[22692];v[22692]=0;if((l|0)==1){break d}Eb(g,d+8|0);vb(d+8|0);vb(f);f=v[d+44>>2];j=j+1|0;if(!f&j>>>0<y[d+40>>2]|f){continue}break}}gb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+8|0)}vb(f);S(a|0);L()}}Wf(a,i,c,e+16|0);gb=e+32|0}function Vpa(){var a=0,b=0,c=0;b=gb-16|0;gb=b;Kb(90780);a=gb-16|0;gb=a;v[a+12>>2]=0;v[22698]=v[a+12>>2];gb=a+16|0;t[90796]=0;a=gb-16|0;gb=a;v[a+12>>2]=0;v[22700]=v[a+12>>2];gb=a+16|0;v[22692]=0;a=ga(36)|0;c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;NX(90792,ce(b+8|0));hD(b+8|0);t[90796]=0;a=0;break e}a=Ca(89088,89064)|0;c=O()|0;if((ea(89088)|0)==(c|0)){Z(a|0)|0;v[22692]=0;X(37);a=v[22692];v[22692]=0;if((a|0)==1){break c}L()}if((ea(89064)|0)!=(c|0)){break b}Z(a|0)|0;v[22692]=0;t[90796]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){a=P()|0;O()|0;break b}a=w[90796]}if(a&255){break d}v[22692]=0;_(38,90776);a=v[22692];v[22692]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}gb=b+16|0;return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break a}}fn(90800);hD(90792);vb(90780);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function wga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],dd(a)),v[k>>2]=m;tc(f,c>>>2|0);c=zb(b);h=z[e+4>>2];e=v[f>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);h=C(G(C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q()))),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;i=C(z[Zf(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=i;a=c;i=ge(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Uc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}gb=f+16|0;return v[f>>2]<<2}function gJ(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=gb-96|0;gb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){j=f<<3;h=f<<4;i=z[(h|8)+a>>2];g=z[(h|4)+a>>2];z[(e+48|0)+(j|4)>>2]=i+g;k=f<<1;z[(8-k<<2)+e>>2]=g-i;i=z[(a+h|0)+16>>2];g=z[(h|12)+a>>2];z[(7-k<<2)+e>>2]=i-g;z[(e+j|0)+56>>2]=-C(g+i);f=f+1|0;if((f|0)!=4){continue}break}fJ(e+48|0);fJ(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];h=0;while(1){f=h<<2;j=f+b|0;i=z[j>>2];g=z[f+68160>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];n=z[f+68196>>2];z[j>>2]=C(g*l)-C(m*n);j=a+f|0;f=c+f|0;g=C(C(g*m)+C(n*l));z[j>>2]=C(i*z[f>>2])-C(z[f+36>>2]*g);z[(17-h<<2)+a>>2]=C(z[f>>2]*g)+C(i*z[f+36>>2]);h=h+1|0;if((h|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}gb=e+96|0}function F8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb+-64|0;gb=f;v[f+56>>2]=d;d=ni(a,f+56|0);g=wh(a+4|0);h=wh(a+24|0);i=wh(a+32|0);j=cd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22692]=0;R(2063,a|0,e|0);l=v[22692];v[22692]=0;a:{b:{c:{d:{if((l|0)!=1){v[22692]=0;bc(f+24|0,b,c);b=v[22692];v[22692]=0;if((b|0)==1){break d}b=Ud(f+16|0);v[22692]=0;c=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=c;c=v[b+4>>2];v[f>>2]=v[b>>2];v[f+4>>2]=c;U(2067,f+32|0,f+8|0,f|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;U(2064,a|0,f+32|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}xb(f+32|0);v[22692]=0;_(2065,a|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(f+32|0)}yd(k);Vf(j);dq(i);Di(h);Ci(g);cg(d);cg(f+56|0);S(a|0);L()}cg(f+56|0);gb=f- -64|0;return a|0}function u7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=gd(v[Wg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=Yn(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=b- -64|0}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=gd(v[Wg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=Zn(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=b- -64|0}function sp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{if(!b){break a}if(c){c=me(f+8|0,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}gb=a+16|0;break a}c=me(f,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}gb=a+16|0}gb=f+16|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];c=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(c){a=v[a+20>>2];h=c;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=ge(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=e,j=Uc(g),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=ge(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=e,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;h=h-1|0;if(h){continue}break}}gb=d+16|0;return c<<3}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+32;wb(a);aP(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=Wq(a,ze(a)+1|0);i=ze(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;hf(c+12|0,f);if(d){e=d;if(d>>>0>=134217728){pd(8399);L()}e=Nc(e<<5,8)}v[c>>2]=e;f=(i<<5)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=dc(c),k=(d<<5)+e|0,v[j>>2]=k;gb=h+16|0;aP(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;_u(a);wb(a);b=c+4|0;hl(v[a>>2],v[a+4>>2],b);wc(a,b);wc(a+4|0,c+8|0);wc(wb(a),dc(c));v[c>>2]=v[c+4>>2];YA(a,ze(a));a=c;b=c;c=v[c+4>>2];a:{while(1){d=v[b+8>>2];if((d|0)==(c|0)){break a}v[b+8>>2]=d-32;v[22692]=0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){kV(v[a+16>>2],b,rB(a))}gb=g+32|0}function gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=gb-4112|0;gb=c;i=kb[v[v[a>>2]+116>>2]](a)|0;if(!i){kb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=gb-16|0;gb=f;h=a+44|0;if(Sf(h)){while(1){d=An(h,e);g=An(h,e);v[f+12>>2]=0;g=(g+2048|0)-d>>2;if((g|0)>=1){while(1){z[d>>2]=z[f+12>>2];d=d+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}e=e+1|0;if(Sf(h)>>>0>e>>>0){continue}break}}gb=f+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;tc(c+8|0,512);Po(c+16|0);kb[v[v[a>>2]+60>>2]](a,c+16|0,f,v[c+8>>2]);d=0;e=0;if(v[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[d>>2]);k=c,l=z[Sy(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[d+2048>>2]);k=c,l=z[Sy(c+12|0,c+4|0)>>2],z[k+12>>2]=l;d=v[c+8>>2];e=e+1|0;if(d>>>0>e>>>0){continue}break}}b=b-d|0;if(b){continue}break}}if(!i){kb[v[v[a>>2]+124>>2]](a)}gb=c+4112|0;return C(z[c+12>>2])}function Rw(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+90016>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=aj(c,b)}return c}return a+1}function Bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;j=g,k=Yq(b),v[j+16>>2]=k;c=gb-32|0;gb=c;e=b;d=a;b=Yd(d);f=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+13|0;e:{if(Fu(e,d)){if(!v[b>>2]){break b}f=b;break e}if(!Fu(d,e)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=f;break a}v[c+28>>2]=b;b=f;break a}b=fc(d)}v[c+28>>2]=b}f=b;b=v[b>>2];t[c+27|0]=0;if(!b){h=gb-16|0;gb=h;b=fc(a);i=Pj(c+8|0,cC(),Qj(h+8|0,b));e=v[i>>2];d=gb-16|0;gb=d;v[d+8>>2]=v[g+16>>2];b=v[d+8>>2];b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[e+17|0]=0;t[e+13|0]=b;t[e+14|0]=b>>>8;t[e+15|0]=b>>>16;t[e+16|0]=b>>>24;gb=d+16|0;j=fc(i),k=1,t[j+4|0]=k;gb=h+16|0;zk(a,v[c+28>>2],f,v[c+8>>2]);b=ce(c+8|0);t[c+27|0]=1;dC(c+8|0)}Rj(g+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;gb=g+32|0;return v[g+24>>2]+17|0}function jga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;i=a;a:{b:{if(!((b|0)==(c|0)|(e|0)>-1)){t[b|0]=45;f=d;d=0-d|0;e=0-(((f|0)!=0)+e|0)|0;b=b+1|0}f=c-b|0;if((f|0)<=19){g=E(e);g=B(64-((g|0)==32?E(d|1)+32|0:g)|0,1233)>>>12|0;h=(g<<3)+27072|0;j=f;f=v[h+4>>2];if((j|0)<((g-((e|0)==(f|0)&d>>>0<y[h>>2]|e>>>0<f>>>0)|0)+1|0)){break b}}c=a;c:{if(!e&d>>>0<=99999999){a=Px(b,d);break c}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){a=mqa(d,e,1e8,0);e=jb;f=Px(b,a);a=d-jqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=rj(rj(f,b),a-B(b,1e4)|0);break c}a=mqa(d,e,1874919424,2328306);f=jb;g=Ox(b,a);a=jqa(a,f,1874919424,2328306);b=d-a|0;a=mqa(b,e-(jb+(a>>>0>d>>>0)|0)|0,1e8,0);e=jb;f=(a>>>0)/1e4|0;d=rj(rj(g,f),a-B(f,1e4)|0);a=b-jqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=rj(rj(d,b),a-B(b,1e4)|0)}v[c>>2]=a;a=0;break a}v[a>>2]=c;a=61}v[i+4>>2]=a}function OF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[22692]=0;g=Q(15,d+24|0,a|0)|0;e=v[22692];v[22692]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=$i(d+8|0,a);h=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];f=v[v[a>>2]-12>>2];v[22692]=0;f=a+f|0;i=T(16,f|0)|0;j=v[22692];v[22692]=0;if((j|0)==1){break d}e=v[e>>2];v[22692]=0;c=b+c|0;b=la(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Sv(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[22692]=0;R(18,a+b|0,5);b=v[22692];v[22692]=0;if((b|0)!=1){break e}break d}el(g);break b}b=V(0)|0;O()|0;el(g);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=v[v[a>>2]-12>>2];v[22692]=0;_(19,a+b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}$()}gb=d+32|0;return a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){V(0)|0;O()|0;Bb();L()}S(a|0);L()}function M5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[pj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;Fc(c+16|0,a+d|0);d=v[22692];v[22692]=0;d:{e:{f:{if((d|0)!=1){v[22692]=0;d=T(2286,c+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}e=$i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22692]=0;ka(2287,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;oj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function J5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[pj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;Fc(c+16|0,a+d|0);d=v[22692];v[22692]=0;d:{e:{f:{if((d|0)!=1){v[22692]=0;d=T(2286,c+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}e=$i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22692]=0;ka(2288,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;oj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[pj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;Fc(c+16|0,a+d|0);d=v[22692];v[22692]=0;d:{e:{f:{if((d|0)!=1){v[22692]=0;d=T(2286,c+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}e=$i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22692]=0;ka(2290,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;oj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function D5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[pj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;Fc(c+16|0,a+d|0);d=v[22692];v[22692]=0;d:{e:{f:{if((d|0)!=1){v[22692]=0;d=T(2286,c+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}e=$i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22692]=0;ka(2291,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;oj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function B5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[pj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;Fc(c+16|0,a+d|0);d=v[22692];v[22692]=0;d:{e:{f:{if((d|0)!=1){v[22692]=0;d=T(2286,c+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}e=$i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22692]=0;ka(2292,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;oj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function jN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;i=f,j=Yq(b),v[i+16>>2]=j;c=gb-32|0;gb=c;g=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+16|0;e:{if(aN(d,g,h)){if(!v[b>>2]){break b}e=b;break e}if(!$M(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=fc(a);d=Pj(c+8|0,XW(),Qj(g+8|0,b));b=v[d>>2];v[22692]=0;h=b+16|0;b=v[22692];v[22692]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[f+16>>2];u[h>>1]=x[v[b+8>>2]>>1];Kb(h+4|0);gb=b+16|0;i=fc(d),j=1,t[i+4|0]=j;gb=g+16|0;break f}a=P()|0;O()|0;_M(d);S(a|0);L()}zk(a,v[c+28>>2],e,v[c+8>>2]);b=ce(c+8|0);t[c+27|0]=1;_M(c+8|0)}Rj(f+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=te(f+24|0);gb=f+32|0;return a+4|0}function Ys(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;c=v[v[a>>2]-12>>2];v[22692]=0;c=v[(a+c|0)+24>>2];b=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[22692]=0;c=Q(15,d+8|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[22692]=0;b=v[(a+b|0)+24>>2];e=v[22692];v[22692]=0;f:{if((e|0)==1){break f}v[22692]=0;b=T(2284,b|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[22692]=0;R(18,a+b|0,1);b=v[22692];v[22692]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;el(c);break c}b=V(0)|0;O()|0;break c}el(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22692]=0;_(19,a+c|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function bA(a,b){var c=0;c=gb-16|0;gb=c;a=fA(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(a,7,1);Ob(a,9,1);Ob(a,10,1);Ob(a,13,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,20,1);Ob(a,21,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,28,1);Ob(a,30,1);Ob(a,31,1);Ob(a,33,1);Ob(a,34,1);Ob(a,39,1);Ob(a,41,1);Ob(a,44,1);Ob(a,46,1);Ob(a,45,1);Ob(a,47,1);Ob(a,48,1);Ob(a,50,1);Ob(a,99,1);Ob(a,102,1);Ob(a,104,1);Ob(a,105,1);break a;case 1:$z(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Pf(a,107);break a;case 3:$z(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Pf(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}$z(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}gb=c+16|0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=gb-16|0;gb=i;j=a+44|0;if(ki(j)){h=Od(j,0);v[i+8>>2]=h;k=Od(j,1);v[i+12>>2]=k;e=md(j,0);v[i>>2]=e;f=md(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;hc(e,g,h);hc(f,k,h)}Ei(a,b,c,md(j,0),md(j,1),d)}gb=i+16|0}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22692]=0;_(1944,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break g}v[22692]=0;_(1944,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22692]=0;d=Q(70,e+16|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;c=Q(70,e|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break f}v[22692]=0;Y(1984,f|0,d|0,c|0,1);b=v[22692];v[22692]=0;if((b|0)==1){break e}vb(c);vb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;vb(c)}vb(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,3463,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=e+32|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vD(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+28512|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function tq(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=jqa(b,d,5e4,0);e=jb;b=v[Mc(c+8|0,c)>>2];b=Ac(kqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=jqa(v[a+1074420>>2],0,jqa(v[a+1074408>>2],0,v[a+1074416>>2],0),jb),v[g>>2]=h;v[c+4>>2]=jb;d=gb-16|0;gb=d;e=c+8|0;f=iw(e,c);gb=d+16|0;d=jqa(b,0,6e5,0);b=f?c:e;b=mqa(d,jb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=jqa(b,d,1e4,0);e=jb;b=v[Mc(c+8|0,c)>>2];b=Ac(kqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=jqa(a,a>>31,b,b>>31)+32768|0;a=jb;a=Ac(kqa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[d>>2]=a?a:1;gb=c+16|0}function haa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1964,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22692]=0;Q(1965,c|0,4458)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(184,c|0,89436,204);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18699;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=je(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,9119,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1966,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22692]=0;Q(1965,c|0,4458)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(184,c|0,89436,204);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18699;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=je(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,9087,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function faa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1967,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22692]=0;Q(1965,c|0,4458)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(184,c|0,89436,204);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18699;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=je(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,9025,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1968,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22692]=0;Q(1965,c|0,4458)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(184,c|0,89436,204);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18699;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=je(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,9055,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function daa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1969,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22692]=0;Q(1965,c|0,4458)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(184,c|0,89436,204);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18699;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=je(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,8990,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1970,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22692]=0;Q(1965,c|0,4458)|0;b=v[22692];v[22692]=0;if((b|0)==1){break g}v[22692]=0;U(184,c|0,89436,204);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18699;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=je(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,9151,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function VU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-80|0;gb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){g=Ud(d+72|0);f=b-e|0;b=Wu(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Ll(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}wb(a);b=Xu(d+56|0);e=v[a+4>>2];v[22692]=0;e=Q(823,a|0,e+f|0)|0;h=v[22692];v[22692]=0;c:{if((h|0)==1){break c}v[22692]=0;R(824,b|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;uk(d+40|0,a);Ll(d+32|0,a);uk(d+24|0,b);v[22692]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;Y(825,d+48|0,d+8|0,d|0,d+24|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;LB(a,b);Ce(b);break b}a=P()|0;O()|0;Ce(b);S(a|0);L()}v[a+4>>2]=b;break a}sp(me(d+16|0,g),f,c)}gb=d+80|0}function py(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Tm(fe(A[Vg(a,c,f)>>3]*134217728));i=ry(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=b- -64|0}function ny(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Tm(fe(A[Vg(a,c,f)>>3]*134217728));i=oy(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=b- -64|0}function jH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;h=gb-1040|0;gb=h;i=v[b>>2];v[h+12>>2]=i;g=a?d:256;j=a?a:h+16|0;d=0;a:{b:{c:{if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(f>>>0<g>>>0?c>>>0<=131:0){break b}while(1){f=k?g:f;c=c-f|0;f=rx(j,h+12|0,f,e);if((f|0)==-1){g=0;i=v[h+12>>2];d=-1;break c}i=(h+16|0)==(j|0);g=g-(i?0:f)|0;j=i?j:(f<<2)+j|0;d=d+f|0;i=v[h+12>>2];if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(c>>>0>131|f>>>0>=g>>>0){continue}break}break b}if(!i){break a}}if(!g|!c){break a}f=d;while(1){d:{d=Wp(j,i,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[h+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}i=v[h+12>>2]+d|0;v[h+12>>2]=i;f=f+1|0;g=g-1|0;if(g){break d}}d=f;break a}j=j+4|0;c=c-d|0;d=f;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+1040|0;return d|0}function Jm(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;if(e){v[e>>2]=0}i=a+484344|0;a:{if(!le(i,b)){break a}d=Wc(_b(i,b),c,d);g=w[d+5|0];b:{c:{d:{e:{h=w[d+3|0];switch(h-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(h-35>>>0>=2){break a}}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[f+12>>2]=2;j=0}m=f,n=v[_b(i,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;a=v[Fb(f+8|0,f+12|0)>>2];f:{g:{h:{i:{if(a){c=0;k=a;j:{while(1){d=B(Ji(_b(i,b)),6)+d|0;if(w[d+3|0]!=34){break j}l=g<<8;g=w[d+5|0]|(j?g>>>0<256?l+-8192|0:l:l);c=c+1|0;k=k-1|0;if(k){continue}break}c=a}if((h|0)!=35){break i}break h}c=0;if((h|0)==35){break g}}if((h|0)!=36){break f}}if(c){break f}}g=g<<8;c=0}if(!e){break a}v[e>>2]=c}gb=f+16|0;return g|0}function DL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=gb+-64|0;gb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[22692]=0;v[j+20>>2]=d?d:1903;a=Q(1904,j+20|0,j+60|0)|0;b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[eq(j+32|0,j+24|0)>>2];b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;v[22692]=0;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+za(1905,j|0,+c,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}zj(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;zj(j+24|0)}Z(a|0)|0;v[22692]=0;ja(1906,12194,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}gb=j- -64|0;return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Jw(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+60>>2]=d;a:{f=v[b>>2];b:{if(!(kb[v[v[f>>2]+36>>2]](f,c,d)|0)){HF(a);break b}bm(e+40|0,b);v[22692]=0;b=v[b>>2];d=v[22692];v[22692]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[22692]=0;b=T(d|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}v[22692]=0;v[e+36>>2]=b-c;b=Fb(e+60|0,e+36|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;b=gb-16|0;gb=b;d=e+16|0;f=bm(b+8|0,d);v[22692]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;Y(221,e+48|0,b|0,c|0,g|0);c=v[22692];v[22692]=0;c:{if((c|0)!=1){Ld(d);gb=b+16|0;break c}a=P()|0;O()|0;Ld(d);S(a|0);L()}b=Ud(e+24|0);c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;xw(a,e+8|0,e)}gb=e- -64|0;return}a=P()|0;O()|0;Ld(e+40|0);S(a|0);L()}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);while(1){if((m|0)>=1){j=(k<<1)+b|0;o=j+(m<<1)|0;while(1){u[e+10>>1]=0;HV(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{if(!i){g=x[e+10>>1];break a}g=x[e+10>>1];c=x[e+12>>1];h=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!kf(a,e+9|0)){break a}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}g=f|g<<1;h=h-1|0;if(h&255){continue}break}}c=1;f=g&65535;b:{if(f>>>0<4){break b}h=15;while(1){c=h;n=c&255;if(f>>>n&1){break b}h=c-1|0;if(n>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=g&1;t[e+14|0]=c;l=(c-1^(g&65534)>>>1)+l|0;u[e+10>>1]=l;u[j>>1]=l;j=(d<<1)+j|0;if(o>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function uK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;v[f+12>>2]=c;a:{if(!b){a=a+120|0;_n(a);c=v[f+12>>2];b=a;d=rh(b);b:{if(!c){break b}v[22692]=0;R(2096,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;xt(b,c);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;ty(d);S(a|0);L()}t[a+20|0]=0;break a}d=gb-16|0;gb=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;_n(b);eK(b,a,d+12|0);t[b+20|0]=1;break c}e=gb-16|0;gb=e;v[e+12>>2]=c;d:{if((b|0)==2){a=a+120|0;_n(a);c=v[e+12>>2];b=a;g=b;h=rh(b);e:{if(!c){break e}v[22692]=0;R(2098,g|0,c|0);i=v[22692];v[22692]=0;if((i|0)!=1){v[22692]=0;xt(g,c);c=v[22692];v[22692]=0;if((c|0)!=1){break e}}a=P()|0;O()|0;ty(h);S(a|0);L()}Ud(b+12|0);t[a+20|0]=2;break d}b=gb-16|0;gb=b;v[b+12>>2]=c;c=a+120|0;_n(c);eK(c,a,b+12|0);t[c+20|0]=3;gb=b+16|0}gb=e+16|0}gb=d+16|0}gb=f+16|0}function ek(a,b){var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;d=v[v[a>>2]-12>>2]+a|0;f=v[d+16>>2]&-3;go(d,f);a:{b:{if(w[pj(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[22692]=0;d=v[(a+d|0)+24>>2];e=v[22692];v[22692]=0;c:{d:{if((e|0)==1){break d}v[22692]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;Y(2296,c+40|0,d|0,c+8|0,8);b=v[22692];v[22692]=0;if((b|0)==1){break d}b=oh(c+24|0,-1,-1);v[22692]=0;b=FJ(c+40|0,b);d=v[22692];v[22692]=0;if((d|0)==1){break d}b=b?f|4:f;break c}b=V(0)|0;O()|0;Z(b|0)|0;b=f|1;oj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,b)}gb=c- -64|0;return}V(0)|0;O()|0;Bb()}L()}function kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;td(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;f=c,g=w[ac(d+16|0,d)|0]<<2,u[f+30>>1]=g;e=b+14|0;v[c+24>>2]=(w[e|0]|w[e+1|0]<<8)<<1;Ek(d,2,b+1|0);Bc(d+16|0,d);v[22692]=0;Q(303,c+43|0,d+16|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){vb(d+16|0);e=Rc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}Xi(e,16);zf(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;i=g,j=ZW(b),v[i+16>>2]=j;c=gb-32|0;gb=c;e=b;f=a;b=Yd(a);d=fc(a);a:{b:{if(b){f=wb(f);c:{while(1){d:{h=b+16|0;e:{if(EC(f,e,h)){if(!v[b>>2]){break b}d=b;break e}if(!DC(h,e)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=d;break a}v[c+28>>2]=b;b=d;break a}b=fc(f)}v[c+28>>2]=b}d=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;b=fc(a);h=Pj(c+8|0,XW(),Qj(e+8|0,b));f=v[h>>2]+16|0;b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];u[f>>1]=x[v[b+8>>2]>>1];Kb(f+4|0);gb=b+16|0;i=fc(h),j=1,t[i+4|0]=j;gb=e+16|0;zk(a,v[c+28>>2],d,v[c+8>>2]);b=ce(c+8|0);t[c+27|0]=1;d=c+8|0;e=d;a=v[e>>2];v[e>>2]=0;if(a){if(w[fc(d)+4|0]){yk(a+16|0)}if(a){WW(a)}}}Rj(g+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=te(g+24|0);gb=g+32|0;return a+4|0}function lZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;td(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Or(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Or(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Cu(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}gb=d+16|0}function r8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Qi(Sb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[rc(Sb(v[e>>2]+484360|0),b)>>1];c:{if(!Wl(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;c=b&65535;KO(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;nu(d+48|0,e,f?7:1,d);h=a,i=A[FO(d+48|0)>>3],A[h+16>>3]=i;$m(d+48|0);a=a+16|0}gb=d- -64|0;return+A[a>>3]}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((Sf(a)|0)==(b|0)){if((Sf(a+12|0)|0)==(c|0)){break b}}v[22692]=0;R(1519,a|0,b|0);d=v[22692];v[22692]=0;c:{d:{if((d|0)==1){break d}v[22692]=0;e=a+12|0;R(1519,e|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;f=a+24|0;R(1520,f|0,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;g=a+36|0;R(1520,g|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=An(a,d);i=Lb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;VM(a);UM(a);b=a+12|0;VM(b);UM(b);b=a+24|0;Eg(b);TM(b);a=a+36|0;Eg(a);TM(a);$();return 0}a=0;while(1){b=An(e,a);i=Lb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function st(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=v[Wg(a,c,f)>>2];i=ry(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=b- -64|0}function hW(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-48|0;gb=b;f=b,g=Yb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[f+8>>2]=g;v[b+12>>2]=0;f=b,g=Yb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[f+16>>2]=g;v[b+20>>2]=0;d=b;c=b;if(Yb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))){e=Yb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))}else{e=52}v[c+24>>2]=e;v[d+28>>2]=0;a=Yb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24));v[b+44>>2]=4;v[b+32>>2]=a+80;v[b+36>>2]=0;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;d=gb-16|0;gb=d;a=v[b>>2];e=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}c=a+8|0;if((e|0)==(c|0)){break a}while(1){a=iw(a,c)?c:a;c=c+8|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0;gb=b+48|0;b=v[a>>2];d=b-52|0;jb=v[a+4>>2]-(b>>>0<52)|0;return d}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;f=c+32|0;Yc(b,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));h=cd(a);f=c+28|0;a=f;e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=0;v[22692]=0;R(1408,h|0,e|0);e=v[22692];v[22692]=0;if((e|0)!=1){a:{e=f;b:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break b}e=c+4|0;while(1){v[22692]=0;c=Q(189,b|0,4)|0;i=v[22692];v[22692]=0;if((i|0)==1){break a}if(!c){break b}c=w[e|0]|w[e+1|0]<<8;v[22692]=0;c=Q(1409,b|0,c|0)|0;i=v[22692];v[22692]=0;c:{if((i|0)!=1){v[g+12>>2]=c;if(Ec(d)>>>0<=c>>>0){break c}v[22692]=0;R(1410,h|0,g+12|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}}break a}a=a+1|0;c=f;if(a>>>0<(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){continue}break}}gb=g+16|0;return}}a=P()|0;O()|0;Lc(h);S(a|0);L()}function qt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Wg(a,c,f);i=oy(g,c,f),j=C(C(v[h>>2])*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6130,36,5874);L()}aa(2989,6130,35,5874);L()}aa(4208,6130,34,5874);L()}aa(4243,6130,33,5874);L()}gb=b- -64|0}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;a:{b:{c:{if((b|0)!=(c|0)){j=v[115173];v[115173]=0;g=gb-16|0;gb=g;we();h=gb-16|0;gb=h;e=gb-16|0;gb=e;Kx(e,b,f+28|0,2);b=v[e+4>>2];v[h>>2]=v[e>>2];v[h+4>>2]=b;b=h;h=v[e+12>>2];v[b+8>>2]=v[e+8>>2];v[b+12>>2]=h;gb=e+16|0;e=v[b+4>>2];v[g>>2]=v[b>>2];v[g+4>>2]=e;e=g;g=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=g;gb=b+16|0;b=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=b;b=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=b;gb=e+16|0;e=v[f+8>>2];g=v[f+12>>2];h=v[f>>2];i=v[f+4>>2];b=v[115173];if(!b){break c}if(v[f+28>>2]!=(c|0)){break b}k=h;l=i;m=e;n=g;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115173]=j;if(v[f+28>>2]==(c|0)){break a}}v[d>>2]=4;h=k;i=l;e=m;g=n}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=e;v[a+12>>2]=g;gb=f+32|0}function W3(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-192|0;gb=b;Yf(b+16|0,a);v[22692]=0;R(99,b+32|0,b+16|0);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22692]=0;a=W(100,b+48|0,b+32|0,8)|0;c=v[22692];v[22692]=0;if((c|0)==1){break e}vb(b+32|0);vb(b+16|0);c=v[v[a>>2]-12>>2];v[22692]=0;d=ga(79)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;U(80,b+8|0,c+(b+48|0)|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}Wb(b+8|0);v[22692]=0;c=CN(a);d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;c=Q(105,c|0,b+32|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[v[c>>2]-12>>2];v[22692]=0;c=xl(c+d|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[b+32>>2];uf(a);gb=b+192|0;a=c?0:d;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break b}c=P()|0;O()|0;uf(a)}S(c|0);L()}return a|0}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;td(b,4);u[b+30>>1]=w[a+12|0]<<2;wg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Tb(d,18699);v[22692]=0;Q(303,b+43|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){vb(a);gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function b8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=mc(a);f=b+24|0;a=v[f>>2];v[22692]=0;a=jq(a+484344|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)==1){break c}v[22692]=0;R(1405,e|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[22692]=0;c=jq(c+484344|0);g=v[22692];v[22692]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[22692]=0;R(2082,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;U(2076,d+16|0,b|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break g}v[22692]=0;R(1407,e|0,d+16|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}a=a+1|0;vb(d+16|0);vb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=ge(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Uc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=ge(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<3}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=gb-16|0;gb=g;v[g+12>>2]=c;c=gb+-64|0;gb=c;m=c;j=c+16|0;k=gb-16|0;gb=k;n=fU(k+8|0);while(1){e=b;h=gb+-64|0;gb=h;d=n;f=v[d+4>>2]-v[d>>2]|0;a:{if(!f){d=v[d>>2];break a}f=f+1|0;if(!f){d=qK(rK(h+8|0,e,32));break a}i=e;e=E(f);e=rK(h+8|0,i,(f&-1>>>e+1?32:31)-e|0);while(1){i=qK(e);if(f>>>0<=i>>>0){continue}break}d=v[d>>2]+i|0}gb=h- -64|0;o=Ri(j,l),p=d,v[o>>2]=p;l=l+1|0;if((l|0)!=12){continue}break}gb=k+16|0;d=oU(m,j,tU(j));v[22692]=0;b=a;HB(b,d,0);e=v[22692];v[22692]=0;b:{if((e|0)!=1){Lc(d);gb=c- -64|0;break b}a=P()|0;O()|0;Lc(d);S(a|0);L()}c=b+120|0;pK(c,b,g+12|0);t[c+20|0]=1;v[22692]=0;R(2091,b|0,v[g+12>>2]);b=v[22692];v[22692]=0;c:{if((b|0)!=1){gb=g+16|0;break c}a=P()|0;O()|0;_n(c);S(a|0);L()}return a|0}function $oa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-304|0;gb=e;_e(b);if(Pb(a,1)){a:{while(1){d=e+48|0;sd(e+24|0,d,d+256|0);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;d=gb-48|0;gb=d;f=v[a>>2];i=v[a+8>>2];g=v[e+12>>2];h=v[e+8>>2];v[d+16>>2]=h;v[d+20>>2]=g;v[d+24>>2]=h;v[d+28>>2]=g;Sh(d+32|0,d+16|0);g=v[v[f>>2]+28>>2];h=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=h;kb[g|0](d+40|0,f,i,d+8|0);f=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=f;Sh(e+32|0,d);gb=d+48|0;j=e,k=yb(e+32|0),v[j+44>>2]=k;j=e,k=c-Ab(b)|0,v[j+20>>2]=k;d=v[Fb(e+44|0,e+20|0)>>2];if(!d){break a}t[e+32|0]=0;f=d+(e+48|0)|0;d=Qm(e+48|0,f,e+32|0);j=e,k=ef(b),v[j+32>>2]=k;Hd(e+16|0,e+32|0);HX(b,v[e+16>>2],e+48|0,d);Rb(a,d-(e+48|0)|0);if(d>>>0>=f>>>0){continue}break}Rb(a,1)}d=(Ab(b)|0)!=0}gb=e+304|0;return d|0}function vma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-528|0;gb=d;c=-1;a:{if(!Tf(a,1468)){break a}Nl(a,1464);CV(a,d+524|0);if(!ke(d+524|0,33186)){c=0;if(!ke(d+524|0,12608)){break a}}Nl(a,20);b=1;while(1){c=-1;if(!zV(a,d)){break a}e=ZB(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;c=gb-32|0;gb=c;b=a;b:{if(!Tf(a,2)){t[c+16|0]=0;fE(e,c+16|0);break b}un(c+24|0,e);e=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=e;RB(c+16|0,b,c+8|0)}gb=c+32|0;e=od(d+520|0);c=0;if(w[d+520|0]>128){break a}b=d;c=gb-32|0;gb=c;c:{if(!Tf(a,512)){hV(b);break c}Lv(c+24|0,b);f=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=f;RB(c+16|0,a,c+8|0)}gb=c+32|0;a=d+512|0;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}gb=d+528|0;return c|0}function mH(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=ux(11113);if(w[b|0]?b:0){break a}b=ux(B(a,12)+79440|0);if(w[b|0]?b:0){break a}b=ux(11360);if(w[b|0]?b:0){break a}b=11902}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=11902;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!sj(d,11902)){break e}if(sj(d,10794)){break d}}if(!a){c=74804;if(w[d+1|0]==46){break c}}return 0}c=v[115979];if(c){while(1){if(!sj(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115979];if(c){while(1){if(!sj(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=Cd(28);g:{if(!c){c=0;break g}v[c+4>>2]=20;v[c>>2]=74784;b=c+8|0;hc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115979];v[115979]=c}c=a|c?c:74804}return c}function XM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-16|0;gb=d;a:{if(Nb(a)>>>0>511){break a}if(!Xf(v[v[b>>2]-12>>2]+b|0)){break a}j=d;g=b;h=c;f=gb-16|0;gb=f;e=rf(64);v[22692]=0;i=T(1301,e|0)|0;k=v[22692];v[22692]=0;b:{c:{if((k|0)!=1){e=ks(f,i);i=v[e>>2];v[22692]=0;g=W(1514,i|0,g|0,h|0)|0;h=v[22692];v[22692]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}Wz(f+8|0);break d}a=P()|0;O()|0;Hg(e);break c}ni(f+8|0,e)}Hg(e);gb=f+16|0;g=v[f+8>>2];break b}a=P()|0;O()|0;Xb(e)}S(a|0);L()}v[j+8>>2]=g;f:{g:{if(!Dd(d+8|0)){v[22692]=0;b=Q(1512,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break g}v[d>>2]=b;$W(d+8|0,ce(d));Hg(d)}if(!Dd(d+8|0)){break f}l=v[d+8>>2];v[22692]=0;R(1513,a|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;Hg(d+8|0);S(a|0);L()}Hg(d+8|0)}gb=d+16|0;return l}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;t[e+15|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);o=(m|0)<1;j=4;while(1){if(!o){i=b+k|0;p=m+i|0;while(1){t[e+11|0]=0;GV(a,e+15|0,e+12|0,e+11|0);a:{if(!j){h=w[e+11|0];break a}h=w[e+11|0];c=x[e+12>>1];f=j;b:{while(1){g=c<<1;c=g&254;c:{if(c){g=(g&65534)>>>0>255;break c}if(!kf(a,e+10|0)){break b}c=w[e+10|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;g=h&255;d:{if(g>>>0<4){break d}f=7;while(1){c=f;n=c&255;if(g>>>n&1){break d}f=c-1|0;if(n>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&254)>>>1)+l|0;t[e+11|0]=l;t[i|0]=l;j=(c+j&254)>>>1|0;i=d+i|0;if(p>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function By(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;rq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=kg(g+32|0,g+80|0,dL(g+80|0),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;vt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=56236;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=55440;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Ct(c,v[Mk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function Ay(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;rq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=kg(g+32|0,g+80|0,dL(g+80|0),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;vt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=57080;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=56316;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Ct(c,v[Mk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function vW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}tW(g+15|0,g+13|0);tW(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}hz(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){mo(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(no(c)>>>0<=no(w[g+14|0])>>>0){break b}Dh(g+15|0,g+14|0);Dh(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];gb=g+16|0}function yj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-48|0;gb=d;e=a+24|0;f=v[v[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|v[v[e>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}qO(v[e>>2],1);break a}hc(d+8|0,v[e>>2]+24604|0,40);g=v[d+40>>2];h=v[d+44>>2];v[d+28>>2]=c;v[d+24>>2]=b;Et(d+8|0,g);Eo(d+8|0,h);Oz(v[e>>2],d+8|0);if((b|0)==(f|0)){break a}b=v[e>>2];f=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break b}kb[v[v[b>>2]+108>>2]](b,0);kb[v[v[b>>2]+96>>2]](b);kb[v[v[b>>2]+124>>2]](b)}c=c+160|0;if((f|0)!=(c|0)){continue}break}b=v[e>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(kb[v[v[b>>2]+116>>2]](b)|0){break c}kb[v[v[b>>2]+108>>2]](b,1);kb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}}t[a+29|0]=1;gb=d+48|0}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;j=g,k=Yq(b),v[j+16>>2]=k;c=gb-32|0;gb=c;f=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if($O(f,d)){if(!v[b>>2]){break b}e=b;break e}if(!$O(d,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);i=Pj(c+8|0,cC(),Qj(d+8|0,b));b=v[i>>2];f=gb-16|0;gb=f;v[f+8>>2]=v[g+16>>2];h=v[f+8>>2];h=x[h>>1]|x[h+2>>1]<<16;u[b+18>>1]=0;u[b+14>>1]=h;u[b+16>>1]=h>>>16;gb=f+16|0;j=fc(i),k=1,t[j+4|0]=k;gb=d+16|0;zk(a,v[c+28>>2],e,v[c+8>>2]);b=ce(c+8|0);t[c+27|0]=1;dC(c+8|0)}Rj(g+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Pl(g+24|0);gb=g+32|0;return a+4|0}function Jn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;h=a;a=gb-16|0;gb=a;i=a;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);j=Ab(d);k=v[b>>2];v[22692]=0;qu(e+8|0,c,f+j|0,k);c=v[22692];v[22692]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22692]=0;v[e+4>>2]=c;c=wf(e+4|0);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;U(75,d|0,c|0,0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22692]=0;R(76,d|0,b-c|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(86,i|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22692]=0;R(85,h|0,a|0);b=v[22692];v[22692]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=g+16|0}function x7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=A[Vg(a,c,f)>>3];i=ry(g,c,f),j=C(h),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=b- -64|0}function o7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Vg(a,c,f);i=oy(g,c,f),j=C(A[h>>3]),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6130,80,5841);L()}aa(2989,6130,79,5841);L()}aa(4208,6130,78,5841);L()}aa(4243,6130,77,5841);L()}gb=b- -64|0}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;gb=e+32|0}function sV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0>32768){break a}h=Ib(w[d+42|0]|w[d+43|0]<<8)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function M8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-96|0;gb=d;v[22692]=0;e=v[b+12>>2];v[d+40>>2]=v[b+8>>2];v[d+44>>2]=e;e=v[b+4>>2];v[d+32>>2]=v[b>>2];v[d+36>>2]=e;e=T(2059,d+32|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){a:{b:{if(e){v[22692]=0;R(2060,d+72|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){ww(d+80|0,d+72|0);b=Uf(d+88|0,d+80|0);e=Uf(d- -64|0,c);f=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=f;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;xw(a,d+8|0,d);break b}break a}v[22692]=0;R(2061,d+72|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}ww(d+80|0,d+72|0);b=Uf(d+56|0,d+80|0);e=Uf(d+48|0,c);f=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=f;b=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=b;xw(a,d+24|0,d+16|0)}Ld(d+80|0);Ld(d+72|0);Ld(c);gb=d+96|0;return}}a=P()|0;O()|0;Ld(c);S(a|0);L()}function Kea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;c=Ji(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((Ig(a)|0)!=(c|0)){break b}b=gb-16|0;gb=b;c=Vb(a);d=Zb(a);Eh(b+8|0);a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=c;d=Rt(a,a+8|0);g=gb-16|0;gb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){c=v[g+8>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;Xj(g+8|0);d=d-1|0;if(c){continue}break}}gb=g+16|0;gb=a+16|0;gb=b+16|0;break a}Eh(f+8|0);c=hX(f+16|0,c,f+8|0);yN(a);dp(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[wb(c)>>2];h=wb(a),i=d,v[h>>2]=i;h=wb(c),i=0,v[h>>2]=i;v[c>>2]=0;v[c+4>>2]=0;dn(c);v[a+12>>2]=b}a=1}else{a=0}gb=f+32|0;return a|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];j=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){k=0;e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24|h>>>8;e=0;l=f&65280;f=e;e=g<<8|h>>>24;f=f|k;k=e&255|l|(h<<24|h<<8&16711680);v[d+24>>2]=((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24)|f;v[d+28>>2]=k;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;i=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=i;e=a;i=fe(i);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}m=e,n=Uc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return j<<3}function uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){g=Jb(d);i=Jb(d);j=Ab(d);k=v[b+4>>2];c=v[b>>2];v[22692]=0;Pa(78,e+8|0,g|0,i+j|0,c|0,k|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22692]=0;v[e+4>>2]=c;c=wf(e+4|0);g=v[22692];v[22692]=0;if((g|0)!=1){v[22692]=0;U(75,d|0,c|0,0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22692]=0;R(76,d|0,b-c|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(77,h|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22692]=0;R(72,a|0,f|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function mO(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=-1;a:{if(!Gz(a,b,2)){break a}h=v[b+656>>2];f=a+1074312|0;Db(e+8|0,f,31);b:{if(Cb(e+8|0)){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Db(e+8|0,f,31);f=d-Cb(e+8|0)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Rq(h+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+746|0]&16){g=Eq(a,b,!(v[b+88>>2]&32768),d);break a}if(Gj(b)){if((d|0)==u[b+772>>1]){break a}i=b,j=Uc(d),u[i+772>>1]=j;t[b+851|0]=w[b+851|0]|32;break a}b=mk(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;Zj(e+8|0,255);a=(v[e+8>>2]<<2)+(b?44592:43568)|0;break c}Zj(e+8|0,255);a=(v[e+8>>2]<<2)+(b?43568:44592)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];i=f,j=Ac(kqa(jqa(b,d,a,a>>31),jb,65536,0),jb),v[i>>2]=j}gb=e+16|0;return g}function Lp(a){var b=C(0),c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=ri(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-ri(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=si(f+1.5707963267948966);break a}b=si(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ri(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=si(-4.71238898038469-+a);break a}b=si(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Sx(a,c+8|0)&3){case 0:b=ri(A[c+8>>3]);break a;case 1:b=si(-A[c+8>>3]);break a;case 2:b=C(-ri(A[c+8>>3]));break a;default:break b}}b=si(A[c+8>>3])}a=b;gb=c+16|0;return a}function kN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=C(0);f=gb-16|0;gb=f;g=u[d>>1];e=u[d+2>>1];if(!(!x[b>>1]|(g|0)>(e|0)|(!(z[c>>2]>C(0))|(e-g|0)>32766))){u[a>>1]=3;h=a+4|0;Eg(h);u[a+28>>1]=65472;v[f+12>>2]=1065353216;mN(h,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Eg(a+16|0);u[a+28>>1]=x[d>>1];g=a;e=gb-16|0;gb=e;u[e+14>>1]=x[b>>1];v[22692]=0;u[e+12>>1]=32767;b=Pc(e+14|0,e+12|0);j=v[22692];v[22692]=0;a:{if((j|0)!=1){gb=e+16|0;b=u[b>>1];break a}V(0)|0;O()|0;Bb();L()}u[g+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=ne(i,C(C(1)/C(u[a+30>>1])));j=1;wl(h,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){k=ne(i,C(b|0));l=Lb(h,b-u[a+28>>1]|0),m=k,z[l>>2]=m;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}iq(a)}gb=f+16|0;return j|0}function xL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);d=Ab(b);h=Jb(c);i=Ab(c);g=d+f|0;d=-1;a:{while(1){if((f|0)==(g|0)){break a}g=g-1|0;if(op(h,i,g)){continue}break}d=g-f|0}b:{c:{if((d|0)!=-1){k=e,l=zd(b),v[k+16>>2]=l;k=e,l=ve(e+16|0,d),v[k+24>>2]=l;k=e,l=ve(e+24|0,1),v[k+32>>2]=l;c=Hd(e+40|0,e+32|0);k=e,l=ef(b),v[k>>2]=l;d=Hd(e+8|0,e);ZF(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}i=Jb(b);f=Ab(b);d=Jb(c);c=Ab(c);if(!c|!f){c=-1}else{g=d;j=c+d|0;d=i;f=f+d|0;d:{if((d|0)==(f|0)){break d}c=f;while(1){h=g;if((j|0)!=(g|0)){while(1){if(kb[26](t[d|0],t[h|0])|0){break d}h=h+1|0;if((j|0)!=(h|0)){continue}break}}d=d+1|0;if((c|0)!=(d|0)){continue}break}d=c}c=(d|0)==(f|0)?-1:d-i|0}if(c){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;gb=e+32|0}function vo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}a=f+48|0;h=b,i=Uc(Rq(a,v[b+724>>2],256,64)),u[h+728>>1]=i;h=b,i=x[Lb(a,w[f+65|0])>>1],v[h+724>>2]=i}}function nZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-208|0;gb=e;d=a;if(!Rv(c,a)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0}OD(c,e+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=e;d=gb-16|0;gb=d;v[d+12>>2]=64;v[22692]=0;v[d+8>>2]=255;f=Fb(d+12|0,d+8|0);g=v[22692];v[22692]=0;b:{if((g|0)!=1){gb=d+16|0;d=w[f|0];break b}V(0)|0;O()|0;Bb();L()}t[c+12|0]=d;hh(b,w[ac(a+4|0,e+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Nb(b)){break a}a=0;while(1){if(a){c=x[Lb(b,a-1|0)>>1];v[e+12>>2]=1;d=(e+16|0)+B(a,3)|0;v[e+8>>2]=(t[d+1|0]&1)<<8|w[d|0];d=x[Gf(e+12|0,e+8|0)>>1];h=Lb(b,a),i=c+d|0,u[h>>1]=i}c=w[((e+16|0)+B(a,3)|0)+2|0];h=Lb(b,a),i=c,t[h+2|0]=i;a=a+1|0;if(Nb(b)>>>0>a>>>0){continue}break}}gb=e+208|0}function oG(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=si(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-ri(d+1.5707963267948966));break a}a=ri(d+-1.5707963267948966);break a}a=si(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=ri(d+4.71238898038469);break a}a=C(-ri(d+-4.71238898038469));break a}a=si(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Sx(a,b+8|0)&3){case 0:a=si(A[b+8>>3]);break a;case 1:a=ri(A[b+8>>3]);break a;case 2:a=si(-A[b+8>>3]);break a;default:break b}}a=C(-ri(A[b+8>>3]))}gb=b+16|0;return a}function ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=f>>>21&2040;l=u[b+46150>>1];m=u[b+46148>>1];n=u[b+46146>>1];o=u[b+46144>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function nw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;g=a+1|0;hh(b,w[ac(g,f+15|0)|0]);d=w[ac(a+2|0,f+15|0)|0];t[b+13|0]=d;j=b,k=Gd(w[a+3|0],d,w[f+15|0]),t[j+14|0]=k;d=w[ac(a+4|0,f+15|0)|0];t[b+15|0]=d;j=b,k=Gd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[ac(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Mb(w[e+6|0]+c<<24>>24,0,64);j=Lb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Lb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break a}if(x[Lb(b,d)>>1]>255){break a}h=w[Lb(b,e)+1|0];i=Lb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break a}e=Lb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[ac(f+14|0,g)|0]){continue}break}}gb=f+16|0}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Qz(c,a);wb(a);Yy(v[d+4>>2],b);v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;return}f=gb-32|0;gb=f;d=wb(a);d=po(f+8|0,hr(a,Nb(a)+1|0),Nb(a),d);Yy(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;b=a;xk(a);wb(a);c=d;h=c+4|0;e=h;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[e>>2];while(1){a=a-4|0;Yy(g-4|0,a);g=v[e>>2]-4|0;v[e>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];_m(b,Nb(b));a=d;b=a;d=v[a+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-4|0;v[b+8>>2]=c;v[22692]=0;R(1311,e|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){ai(v[a+16>>2],b,vk(a))}gb=f+32|0}function qba(){var a=0,b=0,c=0,d=0,e=0;a=gb-48|0;gb=a;c=Kb(a+32|0);v[22692]=0;_(1900,a+16|0);b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){d=a,e=Vb(a+16|0),v[d+8>>2]=e;d=a,e=Zb(a+16|0),v[d>>2]=e;if(!Gb(a+8|0,a)){break c}while(1){e:{b=v[a+8>>2];v[22692]=0;Q(1161,c|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}pr(a+8|0);d=a,e=Zb(a+16|0),v[d>>2]=e;if(!Gb(a+8|0,a)){break c}v[22692]=0;Q(1901,c|0,11769)|0;b=v[22692];v[22692]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(a+16|0);break d}b=V(0)|0;O()|0}vb(c);Z(b|0)|0;b=0;v[22692]=0;Y(1895,4039,0,0,0);c=v[22692];v[22692]=0;if((c|0)==1){break a}$();break b}b=je(Jb(c));yd(a+16|0);vb(c)}gb=a+48|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fJ(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function ws(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[22692]=0;b=Q(2,d|0,12936)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}Eb(a,b);vb(b);break b;case 1:v[22692]=0;b=Q(2,d|0,12961)|0;c=v[22692];v[22692]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 2:v[22692]=0;b=Q(2,d|0,12909)|0;c=v[22692];v[22692]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 3:v[22692]=0;b=Q(2,d|0,12883)|0;c=v[22692];v[22692]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 4:v[22692]=0;b=Q(2,d|0,10265)|0;c=v[22692];v[22692]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 5:break c;default:break b}}v[22692]=0;b=Q(2,d|0,4277)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}Eb(a,b);vb(b)}gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function s2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=MG(c);b:{if(b){_k(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zk(k,a);break b}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}jj(i,k);Ic(k);l=e,m=nj(a),v[l>>2]=m;l=f,m=mj(a),v[l>>2]=m;Tg(k,a);Eb(g,k);vb(k);Ph(k,a);jj(h,k);Ic(k);a=Yk(a);break a}a=LG(c);c:{if(b){_k(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zk(k,a);break c}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}jj(i,k);Ic(k);l=e,m=nj(a),v[l>>2]=m;l=f,m=mj(a),v[l>>2]=m;Tg(k,a);Eb(g,k);vb(k);Ph(k,a);jj(h,k);Ic(k);a=Yk(a)}v[j>>2]=a;gb=k+16|0}function VC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=a;a=gb-16|0;gb=a;h=a;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);i=Ab(d);j=v[b>>2];v[22692]=0;lA(e+8|0,c,f+i|0,j);c=v[22692];v[22692]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22692]=0;v[e+4>>2]=c;c=wf(e+4|0);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;U(75,d|0,c|0,0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22692]=0;R(76,d|0,b-c|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(86,h|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22692]=0;R(85,g|0,a|0);b=v[22692];v[22692]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}}function xga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=0,j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],dd(a)),v[k>>2]=m;tc(f,c>>>2|0);c=zb(b);g=z[e+4>>2];e=v[f>>2];if(e){while(1){g=C(G(C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=j*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;h=C(z[Zf(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=h;a=c;h=ge(h);b:{if(C(D(h))<C(2147483648)){i=~~h;break b}i=-2147483648}k=a,m=Uc(i),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}gb=f+16|0;return v[f>>2]<<2}function el(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22692]=0;b=v[(b+c|0)+24>>2];c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22692]=0;b=Xf(b+c|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(tH()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22692]=0;b=v[(b+c|0)+24>>2];c=v[22692];v[22692]=0;c:{if((c|0)==1){break c}v[22692]=0;b=T(2284,b|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22692]=0;R(18,a+b|0,1);a=v[22692];v[22692]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;j=f,k=ZW(b),v[j+16>>2]=k;c=gb-32|0;gb=c;g=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+14|0;e:{if(EC(d,g,h)){if(!v[b>>2]){break b}e=b;break e}if(!DC(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=fc(a);h=Pj(c+8|0,cC(),Qj(g+8|0,b));d=v[h>>2];b=gb-16|0;gb=b;v[b+8>>2]=v[f+16>>2];i=x[v[b+8>>2]>>1];u[d+16>>1]=0;u[d+14>>1]=i;gb=b+16|0;j=fc(h),k=1,t[j+4|0]=k;gb=g+16|0;zk(a,v[c+28>>2],e,v[c+8>>2]);b=ce(c+8|0);t[c+27|0]=1;dC(c+8|0)}Rj(f+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Pl(f+24|0);gb=f+32|0;return a+2|0}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;td(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49034|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){a=v[a+20>>2];c=g;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=ge(e);a:{if(C(D(e))<C(2147483648)){f=~~e;break a}f=-2147483648}i=h,j=Uc(f),u[i>>1]=j;v[d+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=ge(e);b:{if(C(D(e))<C(2147483648)){f=~~e;break b}f=-2147483648}i=h,j=Uc(f),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return g<<3}function w2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=PG(c);b:{if(b){_k(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zk(k,a);break b}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=nj(a),t[l|0]=m;l=f,m=mj(a),t[l|0]=m;Tg(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=Yk(a);break a}a=OG(c);c:{if(b){_k(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zk(k,a);break c}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=nj(a),t[l|0]=m;l=f,m=mj(a),t[l|0]=m;Tg(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=Yk(a)}v[j>>2]=a;gb=k+16|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0;g=gb-16|0;gb=g;j=a+44|0;if(ki(j)){p=g,q=Od(j,0),v[p+8>>2]=q;p=g,q=Od(j,1),v[p+12>>2]=q;p=g,q=md(j,0),v[p>>2]=q;p=g,q=md(j,1),v[p+4>>2]=q;if(d){k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=gM(C(i*C(1073741824)),w[a+4272|0],w[a+4273|0]);e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(C(i*z[a+4260>>2])-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}Ei(a,b,c,md(j,0),md(j,1),d)}gb=g+16|0}function qla(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-192|0;gb=b;Yf(b+16|0,a);v[22692]=0;R(99,b+32|0,b+16|0);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22692]=0;a=W(100,b+48|0,b+32|0,8)|0;c=v[22692];v[22692]=0;if((c|0)==1){break e}vb(b+32|0);vb(b+16|0);c=v[v[a>>2]-12>>2];v[22692]=0;d=ga(79)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;U(80,b+8|0,c+(b+48|0)|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}Wb(b+8|0);v[22692]=0;c=Q(101,a|0,b+32|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[v[c>>2]-12>>2];v[22692]=0;c=xl(c+d|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}d=x[b+32>>1];uf(a);gb=b+192|0;a=(c?0:d)&65535;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break b}c=P()|0;O()|0;uf(a)}S(c|0);L()}return a|0}function PL(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=vf(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(Cg(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(Cg(d*+y[a+4292>>2])),z[m>>2]=n;l=(1/+g+-1)*d;c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=Cg(l*+(j+v[(e+h|0)+16>>2]>>>0));b=Cg(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=Cg(+OL(z[a+4208>>2])*.16609640474436813);b=Cg(+OL(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Fi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=52528;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Ao(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22692]=0;W(1517,a+44|0,2,2)|0;b=v[22692];v[22692]=0;a:{if((b|0)!=1){v[22692]=0;Uh(d);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Lc(c);if((c|0)!=(e|0)){continue}break}jf(d);S(a|0);L()}return a|0}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=w[b|0];v[22692]=0;qu(e+8|0,c,g+i|0,j);c=v[22692];v[22692]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22692]=0;v[e+4>>2]=c;c=wf(e+4|0);g=v[22692];v[22692]=0;if((g|0)!=1){v[22692]=0;U(75,d|0,c|0,0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22692]=0;R(76,d|0,b-c|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(77,h|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22692]=0;R(72,a|0,f|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Tt(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function Iq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=v[b>>2];v[22692]=0;qu(e+8|0,c,g+i|0,j);c=v[22692];v[22692]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22692]=0;v[e+4>>2]=c;c=wf(e+4|0);g=v[22692];v[22692]=0;if((g|0)!=1){v[22692]=0;U(75,d|0,c|0,0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22692]=0;R(76,d|0,b-c|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[22692]=0;R(77,h|0,d|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22692]=0;R(72,a|0,f|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function k8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[22692]=0;c=Xz(c,b&65535);d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;c=Q(70,e|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}d=ed(c);v[22692]=0;Q(1161,a|0,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}v[22692]=0;Q(1901,a|0,18669)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22692]=0;Q(368,h|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function j8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[22692]=0;c=Yz(c,b&65535);d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;c=Q(70,e|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}d=ed(c);v[22692]=0;Q(1161,a|0,c|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}v[22692]=0;Q(1901,a|0,18669)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22692]=0;Q(368,h|0,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Ec(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/12>>>0){c=gb-16|0;gb=c;d=Ip(c,a,e);a=v[d+4>>2];b=v[d+8>>2];if((a|0)!=(b|0)){while(1){UT(a);a=a+12|0;v[d+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(d);gb=c+16|0;break c}b=wb(a);d=Ou(f+8|0,FB(a,Ec(a)+e|0),Ec(a),b);v[22692]=0;XT(d,e);b=v[22692];v[22692]=0;if((b|0)==1){break b}c=d;e=c+4|0;g=e;b=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){h=v[g>>2];while(1){a=a-12|0;EB(h-12|0,a);h=v[g>>2]-12|0;v[g>>2]=h;if((a|0)!=(i|0)){continue}break}}wc(b,e);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];WT(d)}gb=f+32|0;break a}a=P()|0;O()|0;WT(d);S(a|0);L()}return}if(b>>>0<c>>>0){ZT(a,v[a>>2]+B(b,12)|0)}}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;h=dg(a,c);re(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!h){if(ld(a,5)){break a}}g=v[a+28>>2];d=gb-16|0;gb=d;v[d+12>>2]=0;WM(g,d+12|0,1);e=v[d+12>>2];i=e>>>2&3;t[d+11|0]=i;if(i){t[d+4|0]=3;e=w[ac(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!e){break b}Wh(g,d+4|0);if((e|0)==1){break b}Wh(g,d);if(e>>>0<3){break b}Wh(g,d+10|0);j=w[d+10|0]<<24}e=w[d+12|0]|w[d+4|0]<<8|w[d|0]<<16|j;v[d+12>>2]=e}v[d+4>>2]=e>>>4;v[d>>2]=1e6;Fq(b,v[Fb(d+4|0,d)>>2]);if(Ab(b)){e=0;while(1){dl(g,nc(b,e),1);e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}b=(v[d+12>>2]>>>4|0)-Ab(b)|0;v[d+12>>2]=b;if(b){qm(g,b,-1)}gb=d+16|0}Wf(a,h,c,f+24|0);gb=f+32|0}function U2(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-192|0;gb=b;Yf(b+16|0,a);v[22692]=0;R(99,b+32|0,b+16|0);a=v[22692];v[22692]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22692]=0;a=W(100,b+48|0,b+32|0,8)|0;c=v[22692];v[22692]=0;if((c|0)==1){break e}vb(b+32|0);vb(b+16|0);c=v[v[a>>2]-12>>2];v[22692]=0;d=ga(79)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;U(80,b+8|0,c+(b+48|0)|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}Wb(b+8|0);v[22692]=0;c=Q(103,a|0,b+32|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[v[c>>2]-12>>2];v[22692]=0;c=xl(c+d|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[b+32>>2];uf(a);gb=b+192|0;a=c?0:d;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break b}c=P()|0;O()|0;uf(a)}S(c|0);L()}return a|0}function o5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=v[b+44>>2];g=v[b+24>>2];if(i>>>0<g>>>0){v[b+44>>2]=g;i=g}l=-1;g=-1;m=f&24;a:{if(!m|((e|0)==1?(m|0)==24:0)){break a}if(i){h=i-Jb(b+32|0)|0;n=h;h=h>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=n;k=h}e=d+k|0;c=c+j|0;e=j>>>0>c>>>0?e+1|0:e;d=c;c=e;if((e|0)<0|((e|0)>(h|0)?1:(h|0)<=(e|0)?d>>>0>n>>>0:0)){break a}e=f&8;d:{if(!(c|d)){break d}if(v[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(e){e=v[b+8>>2];Rn(b,e,d+e|0,v[b+44>>2])}if(f&16){Dx(b,v[b+20>>2],v[b+28>>2]);Ws(b,d)}l=d;g=c}oh(a,l,g)}function vh(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return hc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}t[d|0]=w[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[d>>2]=v[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;td(b,0);ii(d,1,a);Bc(d+16|0,d);v[22692]=0;Q(303,b+43|0,d+16|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){vb(d+16|0);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Ho(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;e=b,f=w[ac(d+16|0,d)|0]<<2,u[e+30>>1]=f;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=f>>>21&2040;l=u[b+46150>>1];m=u[b+46148>>1];n=u[b+46146>>1];o=u[b+46144>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function G7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-80|0;gb=d;a=v[a+4>>2];oz(d+16|0,b);v[22692]=0;b=Q(2,d|0,14837)|0;e=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22692]=0;U(3,d+32|0,d+16|0,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break h}v[22692]=0;U(647,d+48|0,d+32|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break g}v[22692]=0;R(2023,d- -64|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22692]=0;R(c|0,a|0,d- -64|0);a=v[22692];v[22692]=0;if((a|0)==1){break e}vb(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);gb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);S(a|0);L()}function a8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[22692]=0;R(1405,g|0,a|0);c=v[22692];v[22692]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[22692]=0;c=Xz(c,a&65535);e=v[22692];v[22692]=0;if((e|0)==1){break e}v[22692]=0;c=Q(70,d|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}v[22692]=0;U(2076,d+16|0,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(1407,g|0,d+16|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function $7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[22692]=0;R(1405,g|0,a|0);c=v[22692];v[22692]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[22692]=0;c=Yz(c,a&65535);e=v[22692];v[22692]=0;if((e|0)==1){break e}v[22692]=0;c=Q(70,d|0,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break e}v[22692]=0;U(2076,d+16|0,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(1407,g|0,d+16|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function dO(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:pq(a,C(1));oq(a,C(3.725290298461914e-9));nq(a,C(268435456));mq(a,0);break b;case 1:pq(a,C(32));oq(a,C(4.656612873077393e-10));nq(a,C(2147483648));mq(a,0);break b;case 2:pq(a,C(2));oq(a,C(7.450580596923828e-9));nq(a,C(134217728));mq(a,1);break b;default:pq(a,C(1));oq(a,C(7.450580596923828e-9));nq(a,C(134217728));mq(a,1);Cz(a,0);Bz(a,1);Az(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}pq(a,C(.75));oq(a,C(7.450580596923828e-9));nq(a,C(134217728));mq(a,1);Cz(a,0);b=(b|0)==4;Bz(a,b?2:3);Az(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Cz(a,1);Bz(a,0);Az(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function bL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;rq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=kg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;vt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=57908;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57136;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Ct(c,v[Mk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function aL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;rq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=kg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;vt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=58736;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57964;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Ct(c,v[Mk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=c;e=gb-32|0;gb=e;h=b;d=Yd(b);f=fc(b);a:{b:{if(d){c:{while(1){d:{b=d+16|0;e:{if(DA(c,b)){if(!v[d>>2]){break b}b=d;break e}if(!DA(b,c)){break c}b=d+4|0;if(!v[d+4>>2]){break d}d=b;b=d}f=b;d=v[d>>2];continue}break}v[e+28>>2]=d;break a}v[e+28>>2]=d;b=f;break a}d=fc(b)}v[e+28>>2]=d;b=d}d=v[b>>2];t[e+27|0]=0;if(!d){c=gb-16|0;gb=c;d=fc(h);d=Pj(e+8|0,Nc(28,4),Qj(c+8|0,d));f=v[d>>2];v[22692]=0;R(1401,f+16|0,i|0);f=v[22692];v[22692]=0;f:{if((f|0)!=1){j=fc(d),k=1,t[j+4|0]=k;gb=c+16|0;break f}a=P()|0;O()|0;WN(d);S(a|0);L()}zk(h,v[e+28>>2],b,v[e+8>>2]);d=ce(e+8|0);t[e+27|0]=1;WN(e+8|0)}Rj(g+8|0,yc(e+8|0,d),e+27|0);gb=e+32|0;BS(a,g+8|0);gb=g+16|0}function HX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=b;k=e,l=zd(a),v[k+8>>2]=l;g=Yj(e+24|0,e+8|0);b=Zh(c,d);a:{b:{if(!b){break b}if(WC(c,Jb(a),Jb(a)+Ab(a)|0)){b=Kj(e+8|0,c,d);c=v[e+24>>2];d=Jb(b);g=Jb(b);h=Ab(b);v[22692]=0;c=ca(539,a|0,c|0,d|0,g+h|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}h=Ab(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Jb(a);i=h-g|0;if(!i){break c}j=g+f|0;Xl(b+j|0,j,i);break c}Rm(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;gh(a,b);t[e+8|0]=0;Bd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Bd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=zd(a),v[k+8>>2]=l;c=ve(e+8|0,g)}gb=e+32|0;return c|0}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;a:{if(nv(a)){v[b>>2]=0;a=0;break a}KW(c+32|0,c+48|0);e=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=e;cc(c+40|0,a,c+16|0);g=yb(c+40|0);d=zb(w[c+48|0]);e=d&127;v[b>>2]=e;h=d<<24>>24;i=(h|0)<0;d=1;if(e){while(1){f=f+1|0;j=e>>>0>1;e=e>>>1|0;if(j){continue}break}}e=f;b:{if(g>>>0<2|(h|0)>-1){break b}while(1){f=zb(w[(c+48|0)+d|0]);v[b>>2]=f&127|v[b>>2]<<7;e=e+7|0;f=f<<24>>24;i=(f|0)<0;d=d+1|0;if((g|0)==(d|0)){Rb(a,g);KW(c+24|0,c+48|0);d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;cc(c+40|0,a,c+8|0);g=yb(c+40|0);d=0}if(d>>>0>=g>>>0){break b}if((f|0)<0){continue}break}}Rb(a,d);if(e>>>0>=33){v[b>>2]=-1;a=0;break a}a=!i}gb=c- -64|0;return a|0}function uJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{b:{c:{d:{if((b|0)>=0){if(($n(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22692]=0;b=Q(70,f|0,7947)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}gb=f+16|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function _U(a){var b=0,c=0;a:{b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break b}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<1108){break b}c=a+1104|0;if(((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-1108|0)!=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>262144){break b}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break b}b=a+1096|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4){break b}if(!Yu(a+8|0)){break b}c=a+1094|0;b=a+40|0;while(1){if(w[b+32|0]>15|w[b+33|0]>64){break b}if(!Yu(b)){break b}a=1;b=b+34|0;if((c|0)!=(b|0)){continue}break}break a}a=0}return a}function Op(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);e=j(1)|0;g=j(0)|0;a:{b:{c:{b=e;e=b;if(!((b|0)>-1?b>>>0>=1048576:0)){if(!(b&2147483647|g)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;h=-1023;if((e|0)!=1072693248){b=e;break b}if(g){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;g=j(0)|0;h=-1077}b=b+614242|0;d=+((b>>>20|0)+h|0);a=d*.6931471803691238;l(0,g|0);l(1,(b&1048575)+1072079006|0);f=+n()+-1;c=f/(f+2);i=a;k=d*1.9082149292705877e-10;m=c;a=f*(f*.5);d=c*c;c=d*d;a=i+(f+(k+m*(a+(c*(c*(c*.15313837699209373+.22222198432149784)+.3999999999940942)+d*(c*(c*(c*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-a))}return a}function l6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;b=d+16|0;a:{b:{c:{if(!dt(xa(v[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!dt(xa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}gb=d+32|0;return a|0}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-80|0;gb=d;g=FR(a,1<<b-1);v[a+12>>2]=b;c=1<<b;h=c>>>2|0;a:{if(b>>>0>=2){i=1/+(c>>>0);b=h;f=1;while(1){A[d+40>>3]=+(b>>>0)*-6.283185307179586*i;e=v[12051];c=d+48|0;v[c+8>>2]=v[12050];v[c+12>>2]=e;e=v[12049];v[c>>2]=v[12048];v[c+4>>2]=e;NA(c,A[d+40>>3]);v[22692]=0;MA(d- -64|0,d+48|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}c=Tc(g,f);e=v[d+76>>2];v[c+8>>2]=v[d+72>>2];v[c+12>>2]=e;e=v[d+68>>2];v[c>>2]=v[d+64>>2];v[c+4>>2]=e;f=f<<1;c=b>>>0<2;b=b>>>1|0;if(!c){continue}break}}b=Om(d+24|0,1,0);c=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;wz(a,0,h,d+8|0);gb=d+80|0;return a|0}a=P()|0;O()|0;Jq(g);S(a|0);L()}function wF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=qf(a);if(c>>>0<b>>>0){g=gb-32|0;gb=g;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>3>>>0){c=gb-16|0;gb=c;b=ds(c,a,e);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){cm(a);a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}f=wb(a);b=fs(a,qf(a)+e|0);i=qf(a);c=0;h=gb-16|0;gb=h;v[h+12>>2]=0;d=g+8|0;hf(d+12|0,f);if(b){c=b;if(b>>>0>=536870912){pd(8399);L()}c=Nc(c<<3,1)}v[d>>2]=c;f=(i<<3)+c|0;v[d+8>>2]=f;v[d+4>>2]=f;j=dc(d),k=(b<<3)+c|0,v[j>>2]=k;gb=h+16|0;v[22692]=0;zw(d,e);b=v[22692];v[22692]=0;if((b|0)==1){break b}Rk(a,d);uF(d)}gb=g+32|0;break a}a=P()|0;O()|0;uF(d);S(a|0);L()}return}if(b>>>0<c>>>0){Sk(a,v[a>>2]+(b<<3)|0)}}function Oea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=b+24|0;o=a+1298224|0;g=a+1074992|0;k=mk(a);p=b+4|0;q=b+12|0;r=b+8|0;s=b+16|0;while(1){if(v[g+104>>2]==(b|0)){if(v[g+16>>2]){v[g+16>>2]=c}if(y[g+4>>2]>d>>>0){v[g>>2]=0;v[g+4>>2]=0}if(v[g+76>>2]){tc(g+76|0,d)}h=eF(g);i=v[(h?q:p)>>2];v[g+84>>2]=v[(h?s:r)>>2];v[g+80>>2]=i;h=v[g+88>>2]|v[e>>2];v[g+88>>2]=h;v[g+88>>2]=h&(v[f>>2]^-1);h=g+704|0;a:{if(!v[g+704>>2]|!v[b+24>>2]){break a}if(bp(a)){break a}l=v[(k?h:j)>>2];m=jqa(v[(k?j:h)>>2],0,v[g+700>>2],0);n=m+(l>>>1|0)|0;i=jb;t=g,u=Qc(mqa(n,n>>>0<m>>>0?i+1|0:i,l,0),jb),v[t+700>>2]=u}v[h>>2]=v[j>>2]}g=g+872|0;if((o|0)!=(g|0)){continue}break}}function rV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}break a}SB(c+8|0,b);b=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=b;id(c+16|0,a,c)}gb=c+32|0}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{c:{if((e|0)==1){break c}v[22692]=0;_(1944,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;_(1944,c|0);f=v[22692];v[22692]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=uc(d+24|0,b);c=uc(d+16|0,c);v[22692]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;Y(1988,f|0,d+8|0,d|0,1);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2599,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}gb=d+32|0;return e|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function iR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=Ge(d+16|0,1,0);GP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22692]=0;v[d+4>>2]=e;e=wf(d+4|0);h=v[22692];v[22692]=0;if((h|0)==1){break c}v[22692]=0;U(75,c|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)==1){break c}GP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22692]=0;R(76,c|0,b-e|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;R(86,g|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22692]=0;R(85,a|0,f|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=jqa(d,0,1,1);f=jb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function km(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0;k=gb-16|0;gb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Qm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83392|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83392|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function jm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;k=gb-16|0;gb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=ix(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83392|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83392|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=0;Ak(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22692]=0;u[d+14>>1]=0;f=W(648,a|0,e|0,255)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}if(!f){break d}v[22692]=0;Q(642,a|0,d+14|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;U(13,d|0,c|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break f}v[22692]=0;f=Q(649,b|0,d+14|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Xf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;u[d+30>>1]=0;_f(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22692]=0;u[d+14>>1]=0;f=W(650,a|0,e|0,255)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}if(!f){break d}v[22692]=0;Q(642,a|0,d+14|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}v[22692]=0;U(13,d|0,c|0,e|0);f=v[22692];v[22692]=0;if((f|0)==1){break f}v[22692]=0;f=Q(649,b|0,d+14|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Xf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function VP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b|0]);d=zb(w[b+1|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+2|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+3|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+4|0])|(f|g);j=a,k=Jc(d,zb(w[b+5|0])<<8|f|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;e=zb(w[b+8|0]);d=zb(w[b+9|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+10|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+11|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+12|0])|(f|g);j=a,k=Jc(d,zb(w[b+13|0])<<8|f|zb(w[b+14|0])<<16|zb(w[b+15|0])<<24,48),u[j+2>>1]=k;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function UP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b+7|0]);d=zb(w[b+6|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+5|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+4|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+3|0])|(f|g);j=a,k=Jc(d,zb(w[b+2|0])<<8|f|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;e=zb(w[b+15|0]);d=zb(w[b+14|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+13|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+12|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+11|0])|(f|g);j=a,k=Jc(d,zb(w[b+10|0])<<8|f|zb(w[b+9|0])<<16|zb(w[b+8|0])<<24,48),u[j+2>>1]=k;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function Sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{if(kk(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Pc(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){pe(d+8|0,b,c);if(!Cb(d+8|0)){v[22692]=0;e=Q(1299,a|0,c&65535)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(e){v[22692]=0;e=Q(70,d+8|0,18699)|0;f=v[22692];v[22692]=0;if((f|0)==1){break d}v[22692]=0;Q(301,((c<<5)+a|0)+946304|0,e|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}vb(e);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}gb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(e);break a}c=P()|0;O()|0}S(c|0);L()}function tI(a,b,c,d,e,f){var g=0;g=gb-80|0;gb=g;a:{if((f|0)>=16384){Fd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}Fd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Fd(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}Fd(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Fd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;gb=g+80|0}function pR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=Ge(d+16|0,1,0);RP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22692]=0;v[d+4>>2]=e;e=wf(d+4|0);h=v[22692];v[22692]=0;if((h|0)==1){break c}v[22692]=0;U(75,c|0,e|0,0);e=v[22692];v[22692]=0;if((e|0)==1){break c}RP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22692]=0;R(76,c|0,b-e|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;R(86,g|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22692]=0;R(85,a|0,f|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function dA(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){d=gb-32|0;gb=d;Qq(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;gb=d+32|0;a=a+32|0;if((e|0)!=(a|0)){continue}break}}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46146>>1])+B(u[e-2>>1],u[f+46144>>1])|0)+B(u[e+2>>1],u[f+46148>>1])|0)+B(u[e+4>>1],u[f+46150>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function $K(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=gb-16|0;gb=f;c=v[a+4>>2];d=f;a=v[a>>2];v[d>>2]=a;v[d+4>>2]=c;v[d+8>>2]=a;v[d+12>>2]=c;a=gb+-64|0;gb=a;a:{if(!v[d+4>>2]){break a}c=38464;b:{while(1){b=v[d+4>>2];v[a+56>>2]=v[d>>2];v[a+60>>2]=b;b=uc(a+48|0,v[c+8>>2]);e=v[a+60>>2];v[a+24>>2]=v[a+56>>2];v[a+28>>2]=e;e=v[b+4>>2];v[a+16>>2]=v[b>>2];v[a+20>>2]=e;if(aO(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=39028){continue}break}c=39040;while(1){b=v[d+4>>2];v[a+40>>2]=v[d>>2];v[a+44>>2]=b;b=uc(a+32|0,v[c+8>>2]);e=v[a+44>>2];v[a+8>>2]=v[a+40>>2];v[a+12>>2]=e;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;b=aO(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=39088){continue}break}break a}b=1}gb=a- -64|0;gb=f+16|0;return b|0}function wo(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}d=v[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Bq(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Aq(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288?!(t[b+851|0]&1)|w[a+480208|0]&2:1)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Mb(c,0,256),v[g+688>>2]=h}function Gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0);c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[er(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Zf(c+12|0,c+8|0,c+4|0)>>2]*C(128));z[c+12>>2]=f;f=ge(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=EV(g);t[v[a>>2]+(B(v[a+4>>2],d)+e|0)|0]=g;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14333,6099,28,6621);L()}aa(14383,6099,27,6621);L()}function pC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Nb(e);d=c;a:{if(f>>>0<d>>>0){j=gb-32|0;gb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){ir(e,h);break d}i=wb(e);k=hr(e,Nb(e)+h|0);m=Nb(e);f=0;l=gb-16|0;gb=l;v[l+12>>2]=0;d=j+8|0;hf(d+12|0,i);if(k){f=XV(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=dc(d),o=(k<<2)+f|0,v[n>>2]=o;gb=l+16|0;v[22692]=0;gv(d,h);f=v[22692];v[22692]=0;if((f|0)==1){break c}Rk(e,d);YV(d)}gb=j+32|0;break b}a=P()|0;O()|0;YV(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Sk(e,v[e>>2]+(d<<2)|0)}}if(Pb(a,c<<2)){bc(g+24|0,v[b>>2],Nb(b)<<2);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;id(g+16|0,a,g+8|0)}gb=g+32|0}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0;c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[er(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Zf(c+12|0,c+8|0,c+4|0)>>2]*C(32768));z[c+12>>2]=f;f=ge(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=Uc(g);j=FV(a,e,d),l=g,u[j>>1]=l;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14333,6099,28,6621);L()}aa(14383,6099,27,6621);L()}function NI(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}kb[d|0](a,c)}}function $B(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;hh(b,w[ac(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Nb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Lb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break a}e=x[Lb(b,e)>>1];h=Lb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Mb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Lb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=g+16|0}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=f>>>21&2040;b=(((B(t[b|0],u[f+46146>>1])+B(t[b-1|0],u[f+46144>>1])|0)+B(t[b+1|0],u[f+46148>>1])|0)+B(t[b+2|0],u[f+46150>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;gb=e+16|0}function d6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;if(wa(1,d+32|0)|0){Os(v[115173],9974);L()}c=ct(d+16|0,d+32|0);g=ct(d+8|0,d+32|4);e=gb-32|0;gb=e;b=gb-16|0;gb=b;h=gb-16|0;gb=h;a=gb-16|0;gb=a;i=a,j=jqa(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=jb;c=Ql(a+8|0,a);f=v[c+4>>2];c=v[c>>2];gb=a+16|0;gb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;gb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Ql(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=Ql(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];gb=d+48|0;jb=b;return a|0}function Jca(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=vf(v[a+16>>2]);b=Ac(kqa(jqa(b,b>>31,3840,0),jb,1e3,0),jb);v[a+4316>>2]=b;v[22692]=0;v[c+12>>2]=0;U(1525,a+4264|0,b|0,c+12|0);b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[a+4260|0]){break e}b=v[a+4316>>2];v[22692]=0;v[c+12>>2]=0;U(1525,a+4276|0,b|0,c+12|0);b=v[22692];v[22692]=0;if((b|0)!=1){break e}b=V(89088)|0;break c}v[22692]=0;v[c+12>>2]=0;Py(a+4288|0,c+12|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}v[22692]=0;v[c+12>>2]=0;Py(a+4300|0,c+12|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}b=V(89088)|0;break c}b=V(89088)|0;break c}b=V(89088)|0}if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;v[a+4316>>2]=0;$()}gb=c+16|0;return}S(b|0);L()}function IN(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;t[h+15|0]=b;t[h+14|0]=10;hh(g,w[ac(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Nb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Lb(g,c),j=d>>>4|0,u[i>>1]=j;e=0;a:{if(c){d=c-1|0;if(x[Lb(g,c)>>1]>=x[Lb(g,d)>>1]){break a}e=x[Lb(g,d)>>1]+1|0}i=Lb(g,c),j=e,u[i>>1]=j}b=Gd(w[b+2|0],0,64);i=Lb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Nb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;c=g;if(a&2){b=w[g+15|0];d=Nb(g);b=w[g+12|0]&-5|(b>>>0<=d>>>0)<<2}else{b=b&251}t[c+12|0]=b;c=g;b:{c:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break c}}a=b&253;break b}b=Nb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[c+12|0]=a;gb=h+16|0}function nba(a){a=a|0;var b=0;b=5134;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=14632;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=18699;break a}b=5167;break a}b=2107;break a}b=5190;break a}b=5204;break a}b=2480;break a}b=2500;break a}b=5216;break a}b=5148;break a}b=10093;break a}b=9361;break a}b=3111;break a}if((a|0)!=357){break a}b=5101}return je(b)|0}function SN(a){var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;v[b+12>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+16>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);v[b+28>>2]=3;v[b+20>>2]=c+(a<<2);v[b+24>>2]=b+12;a=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=a;a=v[b>>2];d=_C(b);e=gb-16|0;gb=e;a:{if((a|0)==(d|0)){break a}c=a+4|0;if((d|0)==(c|0)){break a}while(1){a=sn(a,c)?c:a;c=c+4|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+32|0;return v[a>>2]-36|0}function eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;c=gb-16|0;gb=c;d=a;k=d;h=b;e=Yd(d);f=fc(d);i=gb-16|0;gb=i;if(e){while(1){j=su(wb(k),e+16|0,h);f=j?f:e;e=v[(j?4:0)+e>>2];if(e){continue}break}}h=v[yc(i+8|0,f)>>2];gb=i+16|0;v[c+8>>2]=h;l=c,m=zh(d),v[l>>2]=m;a:{b:{if(!Rl(c+8|0,c)){break b}if(su(wb(d),b,te(c+8|0))){break b}b=v[c+8>>2];break a}b=zh(d)}gb=c+16|0;v[g+24>>2]=b;l=g,m=zh(a),v[l+16>>2]=m;if(!Zo(g+24|0,g+16|0)){b=v[yc(g+8|0,b)>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;h=v[d+8>>2];e=h;c=gb-16|0;gb=c;f=yc(c+8|0,e);Oj(f);b=a;if((e|0)==v[b>>2]){v[b>>2]=v[f>>2]}f=wb(b);v[f>>2]=v[f>>2]-1;ZM(v[fc(b)>>2],e);gb=c+16|0;fc(a);Lm(te(d+8|0));AA(h);gb=d+16|0}gb=g+32|0}function hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;d=b;f=sc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){i=gb-16|0;gb=i;e=ji(i,d,f);d=v[e+4>>2];f=v[e+8>>2];if((d|0)!=(f|0)){while(1){Hk(d);d=d+2|0;v[e+4>>2]=d;if((d|0)!=(f|0)){continue}break}}$b(e);gb=i+16|0;break d}e=wb(d);e=tD(h+8|0,MY(d,sc(d)+f|0),sc(d),e);v[22692]=0;QV(e,f);f=v[22692];v[22692]=0;if((f|0)==1){break c}Rk(d,e);mp(e)}gb=h+32|0;break b}a=P()|0;O()|0;mp(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Sk(d,v[d>>2]+(e<<1)|0)}}c=Pb(a,c<<1);if(c){bc(g+24|0,v[b>>2],sc(b)<<1);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;id(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=c;e=gb-32|0;gb=e;h=b;f=b;b=Yd(b);d=fc(f);a:{b:{if(b){wb(f);c:{while(1){d:{f=b+14|0;e:{if(zn(c,f)){if(!v[b>>2]){break b}d=b;break e}if(!zn(f,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=fc(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){b=gb-16|0;gb=b;d=fc(h);d=Pj(e+8|0,Nc(16,4),Qj(b+8|0,d));Ko(v[d>>2]+14|0,i);j=fc(d),k=1,t[j+4|0]=k;gb=b+16|0;xS(h,v[e+28>>2],c,v[e+8>>2]);b=ce(e+8|0);t[e+27|0]=1;d=e+8|0;c=v[d>>2];v[d>>2]=0;if(c){d=fc(d);if(c){Sn(v[d>>2],c,1)}}}Rj(g+8|0,yc(e+8|0,b),e+27|0);gb=e+32|0;BS(a,g+8|0);gb=g+16|0}function e6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=gb-48|0;gb=b;if(wa(0,b+32|0)|0){Os(v[115173],9937);L()}d=ct(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;g=ct(b+8|0,b+4|0);e=gb-32|0;gb=e;c=gb-16|0;gb=c;a=gb-16|0;gb=a;h=a,i=jqa(v[d>>2],v[d+4>>2],1e6,0),v[h>>2]=i;v[a+4>>2]=jb;d=Ql(a+8|0,a);f=v[d+4>>2];d=v[d>>2];gb=a+16|0;v[c+8>>2]=d;v[c+12>>2]=f;a=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=a;gb=c+16|0;f=v[e+8>>2];d=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;d=v[a+4>>2]+d|0;c=v[a>>2];f=f+c|0;v[a+16>>2]=f;v[a+20>>2]=c>>>0>f>>>0?d+1|0:d;a=Ql(a+24|0,a+16|0);c=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[b+24>>2]=a;v[b+28>>2]=c;a=Ql(b+40|0,b+24|0);c=v[a+4>>2];a=v[a>>2];gb=b+48|0;jb=c;return a|0}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function V9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22692]=0;_(1944,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22692]=0;c=Q(70,d|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;Y(1979,d+16|0,e|0,c|0,1);b=v[22692];v[22692]=0;if((b|0)==1){break d}b=je(Jb(d+16|0));vb(d+16|0);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,3486,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function BZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;td(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Or(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Or(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Cu(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}gb=d+16|0}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22692]=0;_(1944,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22692]=0;c=Q(70,d|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break e}v[22692]=0;U(1945,d+16|0,e|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break d}b=je(Jb(d+16|0));vb(d+16|0);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22692]=0;Y(1895,10591,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-32|0;gb=e;td(b,0);ii(e,1,a+33|0);Bc(e+16|0,e);v[22692]=0;Q(303,b+43|0,e+16|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){vb(e+16|0);d=a+50|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+54|0;v[b+24>>2]=w[d|0]|w[d+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;f=b,g=w[ac(e+16|0,e)|0]<<2,u[f+30>>1]=g;d=a+57|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+61|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!c|!v[b+4>>2])){v[b+8>>2]=v[b>>2]}a:{if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function FM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-48|0;gb=c;v[c+8>>2]=542066252;d=c+8|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Gk(b,33);hc(v[b>>2],c+8|0,33);Vd(c,b);me(a,c);gb=c+48|0}function hh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){e=gb-16|0;gb=e;d:{b=Dg(e,a,c);c=v[b+4>>2];f=v[b+8>>2];if((c|0)!=(f|0)){while(1){wb(a);v[22692]=0;Ur(c);g=v[22692];v[22692]=0;if((g|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(f|0)){continue}break}}$b(b);gb=e+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}b=wb(a);b=up(d+8|0,ch(a,Nb(a)+c|0),Nb(a),b);v[22692]=0;R(299,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(300,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}dj(b)}gb=d+32|0;break a}a=P()|0;O()|0;dj(b);S(a|0);L()}return}if(b>>>0<c>>>0){ej(a,v[a>>2]+(b<<2)|0)}}function dqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=a+8|0;a:{c=v[a+8>>2];i=dc(a);b:{if((c|0)!=v[i>>2]){break b}h=a+4|0;d=v[a+4>>2];f=v[a>>2];if(d>>>0>f>>>0){f=((d-f>>1)+1|0)/-2<<1;a=f+d|0;if((c|0)!=(d|0)){while(1){DY(a,d);a=a+2|0;d=d+2|0;if((d|0)!=(c|0)){continue}break}}c=a;v[g>>2]=a;v[h>>2]=f+v[h>>2];break b}v[e+24>>2]=c-f;v[e+44>>2]=1;c=v[Mc(e+24|0,e+44|0)>>2];c=tD(e+24|0,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22692]=0;EY(c,d,f);d=v[22692];v[22692]=0;if((d|0)==1){break a}wc(a,c);wc(h,c+4|0);wc(g,c+8|0);wc(i,dc(c));mp(c);c=v[a+8>>2]}Cr(c,b);v[g>>2]=v[g>>2]+2;gb=e+48|0;return}a=P()|0;O()|0;mp(c);S(a|0);L()}function n3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}Fc(f+24|0,c);v[22692]=0;a=T(2465,f+24|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}g=f,h=zd(f+24|0),v[g+16>>2]=h;g=f,h=ti(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=v[v[f+16>>2]>>2];v[22692]=0;Q(2484,f+40|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}Oe(f+16|0);g=f,h=ti(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){continue}break}b=v[f+40>>2]}Ic(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;Ic(f+24|0)}S(b|0);L()}function Wk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{d=v[a+32>>2];if((d|0)>=(b|0)){f=v[a+28>>2];break a}i=a+36|0;g=v[a+24>>2];e=v[a+20>>2];h=d;while(1){b:{if(e>>>0>=g>>>0){sd(c+16|0,i,i+1024|0);d=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=d;id(c+24|0,a,c+8|0);g=yb(c+24|0);v[a+24>>2]=g;v[a+20>>2]=0;if(!g){break b}e=0;h=v[a+32>>2]}j=e+1|0;v[a+20>>2]=j;e=w[(a+e|0)+36|0];d=h+8|0;v[a+32>>2]=d;f=v[a+28>>2]|e<<h;v[a+28>>2]=f;h=d;e=j;if((b|0)>(d|0)){continue}break a}break}a=ba(8)|0;v[22692]=0;T(203,a|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){b=P()|0;O()|0;da(a|0);S(b|0);L()}ia(a|0,27348,204);L()}v[a+32>>2]=d-b;v[a+28>>2]=f>>>b;gb=c+32|0;return(-1<<b^-1)&f}function re(a,b){var c=0,d=0,e=0;d=gb-32|0;gb=d;a=oh(a,-1,-1);a:{b:{if(w[pj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[22692]=0;c=v[(b+c|0)+24>>2];e=v[22692];v[22692]=0;c:{d:{if((e|0)==1){break d}v[22692]=0;Ga(2295,d+8|0,c|0,0,0,1,8);c=v[22692];v[22692]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;Z(a|0)|0;a=1;oj(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}$()}fh(v[v[b>>2]-12>>2]+b|0,a)}gb=d+32|0;return}V(0)|0;O()|0;Bb()}L()}function VH(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22692]=0;c=Q(2298,d+8|0,a|0)|0;b=v[22692];v[22692]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22692]=0;b=T(2299,b|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22692]=0;_(2300,a+b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;UH(c);break c}UH(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22692]=0;_(19,a+c|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Tz(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-16|0;gb=c;if(!bd(a)){l=c,m=Vb(a),v[l+8>>2]=m;l=c,m=Zb(a),v[l>>2]=m;if(Gb(c+8|0,c)){while(1){b=v[c+8>>2];Ap(b,4194304,67108864);e=v[b>>2];f=e+f|0;b=g;b=f>>>0<e>>>0?b+1|0:b;g=b;Oe(c+8|0);if(Gb(c+8|0,c)){continue}break}}b=Nb(a);h=Nb(a);l=c,m=Vb(a),v[l+8>>2]=m;l=c,m=Zb(a),v[l>>2]=m;b=mqa(f,g,b,0);e=jb;f=h<<24;g=0;if(Gb(c+8|0,c)){h=b;e=((e&1)<<31|b>>>1)&2147483647;while(1){b=v[c+8>>2];i=b;d=v[b>>2];b=d>>>8|0;d=e+(d<<24)|0;b=b+j|0;b=Qc(mqa(d,e>>>0>d>>>0?b+1|0:b,h,k),jb);v[i>>2]=b;d=f;f=d-b|0;g=g-(b>>>0>d>>>0)|0;Oe(c+8|0);if(Gb(c+8|0,c)){continue}break}}if(!Nb(a)){Qx();L()}a=v[a>>2];v[a>>2]=f+v[a>>2]}gb=c+16|0}function y3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}Fc(f+24|0,c);v[22692]=0;a=T(2436,f+24|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}g=f,h=zd(f+24|0),v[g+16>>2]=h;g=f,h=ef(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=t[v[f+16>>2]];v[22692]=0;Q(2303,f+40|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}Ne(f+16|0);g=f,h=ef(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){continue}break}b=v[f+40>>2]}vb(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;vb(f+24|0)}S(b|0);L()}function yZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Lg(a,d+8|0)){v[d+4>>2]=w[d+8|0];e=v[Fb(d+4|0,d+12|0)>>2];c=gb+-64|0;gb=c;Qe(c+40|0,a,e);a=v[c+40>>2];v[22692]=0;e=Td(c+40|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22692]=0;Ve(c+8|0,3,e,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,c+24|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(400,c|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[22692]=0;Q(401,c|0,c+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}gb=d+16|0}function p5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{if(!He(b,-1)){h=v[a+12>>2];i=v[a+8>>2];g=v[a+24>>2];if((g|0)==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}e=v[a+20>>2];j=v[a+44>>2];v[22692]=0;c=a+32|0;R(61,c|0,0);d=v[22692];v[22692]=0;if((d|0)==1){break b}d=Kc(c);v[22692]=0;R(76,c|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}d=Jb(c);Dx(a,d,Ab(c)+d|0);Ws(a,g-e|0);v[a+44>>2]=v[a+20>>2]+(j-e|0)}v[f+12>>2]=v[a+24>>2]+1;c=a+44|0;e=f+12|0;k=a,l=v[(sn(e,c)?c:e)>>2],v[k+44>>2]=l;if(w[a+48|0]&8){c=Jb(a+32|0);Rn(a,c,c+(h-i|0)|0,v[a+44>>2])}c=XH(a,th(b));break a}c=Us(b);break a}a=V(0)|0;O()|0;Z(a|0)|0;$();c=-1}gb=f+16|0;return c|0}function Wp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=d?d:463900;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[22597]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+76784>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115173]=25;e=-1;break a}v[f>>2]=d}gb=h+16|0;return e|0}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=gb-112|0;gb=h;a:{if(!Nd(a)){break a}if(Ec(b)>>>0<2){break a}f=Uo(h+8|0,a);v[f+20>>2]=0;v[f>>2]=0;c=Ec(b);b:{if(!c){break b}e=v[a>>2];while(1){d=Ad(b,g);j=v[d>>2];if(e>>>0<=j>>>0){break b}d=v[d+4>>2];if(d>>>0>e-j>>>0|268435456-d>>>0<i>>>0){break b}i=d+i|0;v[f>>2]=i;g=g+1|0;if((c|0)!=(g|0)){continue}break}g=c}if(!Um(f)){break a}if(g){c=0;e=0;while(1){d=Ad(b,c);hc(zb(v[f+20>>2])+e|0,zb(v[a+20>>2])+v[d>>2]|0,v[d+4>>2]);v[d>>2]=e;if(!(!c|c>>>0>9)){v[((c<<2)+f|0)- -64>>2]=e}e=v[d+4>>2]+e|0;c=c+1|0;if((g|0)!=(c|0)){continue}break}}Hl(a);Uo(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}gb=h+112|0}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;Mm(c+24|0,b,1819307379);qd(a+40|0,c+24|0);xb(c+24|0);Mm(c+24|0,b,1953721961);qd(a+60|0,c+24|0);xb(c+24|0);Mm(c+24|0,b,543520099);qd(a+120|0,c+24|0);xb(c+24|0);Mm(c,b,1414744396);v[22692]=0;e=UQ(c+24|0,c);d=v[22692];v[22692]=0;a:{b:{c:{if((d|0)!=1){xb(c);v[22692]=0;d=Q(551,e|0,11043)|0;f=v[22692];v[22692]=0;if((f|0)==1){break c}if(d){v[22692]=0;U(1413,c|0,e|0,2);d=v[22692];v[22692]=0;if((d|0)==1){break c}PN(a+140|0,c);Wm(c)}v[22692]=0;U(1414,c|0,b|0,1634890872);b=v[22692];v[22692]=0;if((b|0)!=1){break a}break c}b=P()|0;O()|0;xb(c);break b}b=P()|0;O()|0;xb(e)}S(b|0);L()}qd(a+80|0,c);xb(c);xb(e);gb=c+48|0}function iA(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}c=v[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{if(!(v[a+480180>>2]&1048580)){d=c&240;c=c&15;if(!(!d|(c|0)!=15)){if(!(w[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=v[a+480208>>2]&4096;if(!(!c|(d|0)!=240)){if(!f){break b}c=c<<2;break c}if(f){break b}if(c){c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Db(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(e+8|0)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Mb(v[b+692>>2]+c|0,0,256);u[b+784>>1]=0;v[b+692>>2]=a}gb=e+16|0}function eN(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;f=Kb(e+32|0);v[22692]=0;Q(1502,a|0,e+24|0)|0;d=v[22692];v[22692]=0;a:{b:{if((d|0)!=1){g=v[e+28>>2];d=v[e+24>>2];_e(f);v[22692]=0;g=!g&d>>>0<255?d:255;R(76,f|0,g|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=nc(f,d);v[22692]=0;Q(1503,a|0,h|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((mI(f)|0)!=-1){a=mI(f);v[22692]=0;R(76,f|0,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}}v[22692]=0;U(13,e+8|0,c|0,f|0);a=v[22692];v[22692]=0;if((a|0)!=1){break b}break a}break a}Eb(b,e+8|0);vb(e+8|0);vb(f);gb=e+48|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function HP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-112|0;gb=f;v[f+108>>2]=0;d=Jm(a,x[d+70>>1],v[d+48>>2],c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=!w[b+792|0]&(c|0)==15;d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}d=(e?0:w[b+836|0]<<16)+d|0}b:{if((c|0)!=15){break b}c=w[b+792|0];if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Mc(f,f+108|0)>>2]<<3;g=jqa(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=jb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Qc(c,e);break b}dU(f,0);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[(c+(w[b+792|0]<<2)|0)- -64>>2]+d|0}Hm(a,b,d);gb=f+112|0}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;a:{b:{if(v[a+8>>2]!=v[dc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];e=v[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,j=Qg(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=d,j=v[dc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[d+44>>2]=1;c=v[Mc(d+24|0,d+44|0)>>2];c=up(d+24|0,c,c>>>2|0,v[a+16>>2]);e=yc(d+16|0,v[a+4>>2]);f=v[yc(d+8|0,v[a+8>>2])>>2];e=v[e>>2];v[22692]=0;U(1069,c|0,e|0,f|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}xc(a,c);xc(h,c+4|0);xc(g,c+8|0);xc(dc(a),dc(c));dj(c)}cn(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;gb=d+48|0;return}a=P()|0;O()|0;dj(c);S(a|0);L()}function _2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=IF(v[v[a>>2]-12>>2]+a|0,10);e=gb-16|0;gb=e;v[22692]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[22692];v[22692]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=$i(e,c);v[22692]=0;Q(2303,b|0,f|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){if(!Sv(b)){break e}b=v[v[c>>2]-12>>2];v[22692]=0;R(18,b+c|0,1);b=v[22692];v[22692]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;el(d);break d}el(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;d=v[v[c>>2]-12>>2];v[22692]=0;_(19,c+d|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}$()}gb=e+16|0;break a}a=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}Ys(a);return a|0}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;IQ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;h=wb(a);i=g+8|0;j=a;f=EA(a)+1|0;d=gb-16|0;gb=d;v[d+12>>2]=f;e=gb-16|0;gb=e;v[e+12>>2]=613566756;v[22692]=0;v[e+8>>2]=2147483647;k=Fb(e+12|0,e+8|0);c=v[22692];v[22692]=0;a:{if((c|0)!=1){gb=e+16|0;c=v[k>>2];break a}V(0)|0;O()|0;Bb();L()}b:{if(c>>>0>=f>>>0){f=zA(j);if(f>>>0<c>>>1>>>0){v[d+8>>2]=f<<1;c=v[Mc(d+8|0,d+12|0)>>2]}gb=d+16|0;break b}Sc();L()}c=TQ(i,c,EA(a),h);IQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;SQ(a,c);RQ(c);gb=g+32|0}function Uq(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Ab(b);v[22692]=0;R(60,d|0,a|0);a=v[22692];v[22692]=0;if((a|0)!=1){a:{if(Ab(b)){while(1){f=v[sk(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[22692]=0;R(61,d|0,a<<24>>24);a=v[22692];v[22692]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[22692]=0;R(61,d|0,a<<24>>24);a=v[22692];v[22692]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[22692]=0;R(61,d|0,63);a=v[22692];v[22692]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;vb(d);S(a|0);L()}function P2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;c=gb-416|0;gb=c;v[c+12>>2]=c+416;d=gb-144|0;gb=d;v[d+28>>2]=d+132;SG(a+8|0,d+32|0,d+28|0,e,f,g);v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=d+32;f=c+16|0;h=TV(f,v[c+12>>2]);e=gb-16|0;gb=e;v[e+12>>2]=v[a+8>>2];g=ui(e+8|0,e+12|0);v[22692]=0;a=rx(f,d+12|0,h,d+16|0);h=v[22692];v[22692]=0;a:{if((h|0)!=1){ff(g);gb=e+16|0;break a}a=P()|0;O()|0;ff(g);S(a|0);L()}if((a|0)==-1){Gs(9816);L()}v[c+12>>2]=f+(a<<2);gb=d+144|0;e=v[c+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;d=c+16|0;if((e|0)!=(d|0)){while(1){LH(a+8|0,v[d>>2]);d=d+4|0;if((e|0)!=(d|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=c+416|0;return b|0}function c9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=Zp(c,a,1);vy(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;$b(a);gb=c+16|0;return}e=gb-32|0;gb=e;c=wb(a);c=SI(e+8|0,Wx(a,tf(a)+1|0),tf(a),c);vy(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;b=c;h=c+4|0;f=h;d=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[f>>2];while(1){a=a-16|0;vy(g-16|0,a);g=v[f>>2]-16|0;v[f>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(d,h);wc(d+4|0,b+8|0);wc(wb(d),dc(b));v[b>>2]=v[b+4>>2];a=c;b=a;d=v[a+8>>2];c=v[a+4>>2];if((d|0)!=(c|0)){while(1){d=d-16|0;v[b+8>>2]=d;yk(d);d=v[b+8>>2];if((c|0)!=(d|0)){continue}break}}b=v[a>>2];if(b){tK(b,Hx(a))}gb=e+32|0}function xma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;f=g+8|0;jV(c+24|0,f);e=yb(c+24|0);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;b=a;fd(c+16|0,b,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(b,yb(c+24|0))}gb=c+32|0;c=(d|0)==(e|0);if(!c){iV(f)}b=-1;a:{if(!c){break a}b=0;if(!sV(g+8|0)){break a}b=-1;if(!Tf(a,1024)){break a}b=0;e=gb-1024|0;gb=e;c=gb-32|0;gb=c;SB(c+24|0,e);f=yb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(f|0)){ad(a,yb(c+24|0))}gb=c+32|0;if((d|0)==(f|0)){b=VB(e,0)>>>0<17}gb=e+1024|0}gb=g+608|0;return b|0}function yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;gb=e+32|0}function ln(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&(c|0)!=0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&(g|0)!=0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function wJ(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=gb-16|0;gb=d;a:{b:{c:{d:{if((b|0)>=0){if(($n(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22692]=0;d=Q(70,d|0,7947)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,d);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}if(c<=1?c<0:1){a=ba(8)|0;v[22692]=0;d=Q(70,d|0,8960)|0;b=v[22692];v[22692]=0;if((b|0)!=1){qc(a,d);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}b=P()|0;O()|0;da(a|0);break b}e=Io(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;gb=d+16|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Z4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=gb+-64|0;gb=g;Kh(g+16|0,c);v[22692]=0;R(142,g+28|0,d|0);d=v[22692];v[22692]=0;c=1;b:{c:{if((d|0)==1){break c}v[22692]=0;R(142,g+40|0,e|0);c=v[22692];v[22692]=0;if((c|0)==1){c=2;break c}v[22692]=0;R(142,g+52|0,f|0);c=v[22692];v[22692]=0;if((c|0)==1){c=3;break c}c=g+16|0;v[g+8>>2]=c;v[g+12>>2]=c+48;v[22692]=0;c=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=c;U(144,a|0,b|0,g|0);a=v[22692];v[22692]=0;if((a|0)==1){c=P()|0;O()|0;eG(g+16|0);break b}eG(g+16|0);gb=g- -64|0;break a}a=(g+16|0)+B(c,12)|0;c=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(g+16|0)){continue}break}}S(c|0);L()}}function wla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;td(b,0);RC(d,a+1|0);Bc(d+16|0,d);v[22692]=0;Q(303,b+43|0,d+16|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){vb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=b;wb(b);e=a;h=oN(a,d+8|0);b:{f=Ig(b);if(!f){break b}v[22692]=0;R(613,e|0,f|0);g=v[22692];v[22692]=0;if((g|0)!=1){g=v[c+4>>2];c=v[c>>2];v[22692]=0;Y(1481,e|0,c|0,g|0,f|0);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}a=P()|0;O()|0;pv(h);S(a|0);L()}gb=d+16|0;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22692]=0;c=Q(1480,a+24|0,b+24|0)|0;d=v[22692];v[22692]=0;c:{d:{if((d|0)!=1){v[22692]=0;Q(69,a+36|0,b+36|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Lc(c)}dn(e);S(a|0);L()}}function cB(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function p4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;a:{if(lH(c)){while(1){if(a>>>d&1){i=(d<<2)+c|0,j=mH(d,b),v[i>>2]=j}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){h=(e+8|0)+(d<<2)|0;f=1<<d&a;if(f|!c){f=mH(d,f?b:18699)}else{f=v[(d<<2)+c>>2]}v[h>>2]=f;g=((f|0)!=0)+g|0;d=d+1|0;if((d|0)!=6){continue}break}c=74832;b:{c:{switch(g|0){case 0:break a;case 1:break c;default:break b}}if(v[e+8>>2]!=74804){break b}c=74856;break a}c=Cd(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}gb=e+32|0;return c|0}function kd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=v[a+112>>2];d=v[a+116>>2];b:{if(c|d){b=c>>>0<=y[a+120>>2];c=v[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=Mx(a);if((g|0)>-1){break a}}v[a+104>>2]=0;return-1}h=v[a+4>>2];j=a;b=v[a+116>>2];e=b;d=v[a+8>>2];c=d;f=v[a+112>>2];c:{if(!(b|f)){break c}c=d;i=v[a+120>>2]^-1;f=i+f|0;b=(v[a+124>>2]^-1)+e|0;b=f>>>0<i>>>0?b+1|0:b;e=d-h|0;i=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?i:0){break c}c=f+h|0}v[j+104>>2]=c;if(d){c=a;j=(d-h|0)+1|0;b=j;d=b+v[a+120>>2]|0;a=v[a+124>>2]+(b>>31)|0;v[c+120>>2]=d;v[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=h-1|0;if(w[a|0]!=(g|0)){t[a|0]=g}return g}function HM(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;Wy(a);Hi(d+12|0);a:{b:{c:{d:{e:{f:{g:{h:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];break g;case 8:break b;case 7:break c;case 6:break d;case 5:break e;case 4:break f;case 3:break h;default:break a}}t[a+4240|0]=z[d+12>>2]>=C(.5)}Uy(a);break a}b=a;a=Xh(C(z[d+12>>2]*C(32)));v[b+4232>>2]=(a|0)<5?a:5;break a}t[a+4241|0]=z[d+12>>2]>=C(.5);break a}t[a+4242|0]=z[d+12>>2]>=C(.5);break a}t[a+4244|0]=z[d+12>>2]>=C(.5);break a}b=a;c=z[d+12>>2];if(c==C(0)){Ty(a);c=z[d+12>>2]}A[b+4256>>3]=c}gb=d+16|0}function ph(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=VL(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));f=z[a+4268>>2];e=ne(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612))*f)));c=C(C(ne(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Lp(c>C(1)?C(3.1415927410125732):C(C(d*C(6.2831854820251465))/f))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(C(D(g))<=C(1)){break a}g=C(C(-C(c+d))/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{b:{c:{d:{if(i=ed(b),j=1,k=v[b+12>>2],k?i:j){Kb(a);break d}f=gb-16|0;gb=f;e=Kb(c+16|0);d=Ab(b);g=Mf(11469);h=Jb(b);v[22692]=0;Y(116,e|0,h|0,d|0,d+g|0);d=v[22692];v[22692]=0;e:{if((d|0)!=1){v[22692]=0;W(117,e|0,11469,g|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);S(a|0);L()}gb=f+16|0;v[22692]=0;R(151,c|0,b+12|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;U(3,a|0,c+16|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);S(b|0);L()}function Fi(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=50124;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;g=cd(b);e=cd(b+12|0);f=cd(b+24|0);d=cd(b+36|0);v[22692]=0;W(1517,b|0,2,0)|0;b=v[22692];v[22692]=0;if((b|0)==1){a=P()|0;O()|0;Lc(d);Lc(f);Jt(e);Jt(g);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;e=v[a+16>>2];v[e+946300>>2]=v[e+946300>>2]+1;v[c>>2]=a+99&-8;f=v[a+20>>2];if((f|0)!=(e+906300|0)){d=a+4200|0;while(1){a:{c=b+1|0;if(b>>>0>247){break a}b=c;if((f|0)!=((e+B(b,160)|0)+906300|0)){continue}}break}t[d|0]=c}return a}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=gb+-64|0;gb=d;e=v[a+28>>2];go(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];f=v[a+12>>2];g=e;e=v[a+8>>2]+e|0;f=g>>>0>e>>>0?f+1|0:f;e=oh(d+48|0,e,f);f=v[e+12>>2];v[d+16>>2]=v[e+8>>2];v[d+20>>2]=f;g=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=g;ek(h,d+8|0)}re(d+24|0,v[a+28>>2]);e=v[d+36>>2];v[d+40>>2]=v[d+32>>2];v[d+44>>2]=e;hS(v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=io(d+24|0,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22692]=0;ca(1511,a|0,c|0,b|0,d+40|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Hb(b);gb=d- -64|0;break a}a=P()|0;O()|0;Hb(b);S(a|0);L()}}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function xja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function N8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=gb-96|0;gb=d;v[d+88>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=f;v[d+48>>2]=c;v[d+52>>2]=e;a=Ud(d+40|0);c=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=c;v[22692]=0;c=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;U(2057,d- -64|0,d+16|0,d+8|0);a=v[22692];v[22692]=0;a:{b:{if((a|0)!=1){a=v[ni(d+32|0,d+88|0)>>2];v[22692]=0;b=+za(2058,d- -64|0,+b,a|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}xb(d- -64|0);cg(d+88|0);gb=d+96|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(d- -64|0)}cg(d+88|0);S(a|0);L()}function eU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=b,g=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[f>>2]=g;t[d+15|0]=w[a+4|0];t[d+14|0]=64;f=b,g=w[ac(d+15|0,d+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;f=b,g=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;a=a+10|0;a=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0;v[b+8>>2]=a;e=v[b+4>>2];c=v[b>>2];if(e>>>0>=c>>>0){e=c-1|0;v[b+4>>2]=e}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<e>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=e>>>0){break a}v[b+68>>2]=e;u[b+34>>1]=x[b+34>>1]|2}gb=d+16|0}function dl(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!w[pj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[22692]=0;d=v[(a+d|0)+24>>2];f=v[22692];v[22692]=0;d:{if((f|0)==1){break d}v[22692]=0;b=W(2294,d|0,b|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;Z(b|0)|0;d=1;oj(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22692]=0;X(2011);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)==1){break b}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,d);gb=e+16|0;return}V(0)|0;O()|0;Bb()}L()}function bga(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;if((c|0)!=(b|0)){continue}break}wN(a+484344|0);_e(a+1298268|0);_e(a+1298280|0);_e(a+1298292|0);jD(a+1298368|0);c=a+900380|0;b=a+484380|0;while(1){Hl(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Xb(jv(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){yM(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];go(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];g=v[a+12>>2];f=v[a+8>>2]+d|0;g=f>>>0<d>>>0?g+1|0:g;f=oh(e+40|0,f,g);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;ek(h,e)}re(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;eN(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=io(e+16|0,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22692]=0;ca(1511,a|0,c|0,b|0,e+32|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];go(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];g=v[a+12>>2];f=v[a+8>>2]+d|0;g=f>>>0<d>>>0?g+1|0:g;f=oh(e+40|0,f,g);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;ek(h,e)}re(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;XM(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=io(e+16|0,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22692]=0;ca(1511,a|0,c|0,b|0,e+32|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function zpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;td(b,0);ii(d,1,a);Bc(d+16|0,d);v[22692]=0;Q(303,b+43|0,d+16|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){vb(d+16|0);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;e=b,f=w[ac(d+16|0,d)|0]<<2,u[e+30>>1]=f;gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function oY(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(0-c|0,6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function nG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);g=Ab(b);i=Jb(c);j=Ab(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(op(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=zd(b),v[k+32>>2]=l;c=Hd(e+40|0,e+32|0);k=e,l=zd(b),v[k+8>>2]=l;k=e,l=ve(e+8|0,h),v[k+16>>2]=l;d=Hd(e+24|0,e+16|0);ZF(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}f=Jb(b);h=Ab(b);g=Jb(c);d=-1;i=Ab(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!op(g,i,c)){continue}break}d=c-f|0}}if((Ab(b)-1|0)!=(d|0)){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function Kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function PA(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;h=Gl(a,b);a:{if((h|0)==255){break a}if(qk(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=jqa(1<<20-f,0,c,0)+24858e3|0;f=jb;c=Qc(mqa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),jb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Pc(g+14|0,g+12|0)>>1]}e=yu(h);b=lc(a+4|0,h);t[b|0]=(i<<10|c)>>>8|(d?0:32);Yh(v[a>>2],e|160,c&255);Yh(v[a>>2],e|176,w[b|0]);t[a+530|0]=1}gb=g+16|0}function sJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb-16|0;gb=e;a:{b:{c:{d=a+8|0;d:{if(!ol(d)){if((b|0)<0|(cq(d)|0)<=(b|0)){break d}a=Ml(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=ol(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}b=ba(8)|0;v[22692]=0;c=Q(70,e|0,3092)|0;a=v[22692];v[22692]=0;e:{if((a|0)!=1){qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;da(b|0)}S(a|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}gb=e+16|0;return}L()}function oI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;gb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[22597]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+76784>>2];if(d<<B(c,6)-6<0?c>>>0<=3:0){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[115173]=25;e=-1}return e|0}function QI(a,b,c,d,e){var f=0,g=0,h=0;f=gb-208|0;gb=f;v[f+204>>2]=c;Qb(f+160|0,0,40);v[f+200>>2]=v[f+204>>2];a:{if((Ux(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}g=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}h=c&32;b:{if(v[a+48>>2]){b=Ux(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;v[a+16>>2]=f+80;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=Ux(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!c){break b}kb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|h;b=a&32?-1:b;if(!g){break a}}gb=f+208|0;return b}function xV(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[rc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}yf(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(em(a)&-2)){break c}Yc(a,i+(c<<10)|0);if(!XB(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Yc(a,i+((j&65535)<<10)|0);h=XB(a,64,1)?h:j}Yc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(em(a)|0)){break d}}if(c>>>0>=255){$u(b,254,65534);$u(b,255,65535)}k=h}return k&65535}function SZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;td(b,0);ii(d,1,a+33|0);Bc(d+16|0,d);v[22692]=0;Q(303,b+43|0,d+16|0)|0;c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){vb(d+16|0);c=a+50|0;v[b>>2]=w[c|0]|w[c+1|0]<<8;c=a+52|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;e=b,f=w[ac(d+16|0,d)|0]<<2,u[e+30>>1]=f;c=a+55|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;if((c|0)!=65535){break b}v[b+4>>2]=0;v[b+8>>2]=0;break a}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0}function Lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function A$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=gb-32|0;gb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;v[22692]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ka(1911,a|0,b|0,k|0)|0;b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;ja(1906,7639,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}$();a=-255}gb=l+32|0;break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Tj(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=gb-16|0;gb=e;c=iY(e,a,c);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){wb(a);MW(b);b=b+48|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=e+16|0;break c}b=wb(a);b=gY(d+8|0,hY(a,Tj(a)+c|0),Tj(a),b);v[22692]=0;NW(b,c);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(483,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}zv(b)}gb=d+32|0;break a}a=P()|0;O()|0;zv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Tj(a);jY(a,b);rY(a)}}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;a:{b:{c:{if((d|0)==1){break c}v[22692]=0;_(1944,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22692]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;Y(1983,c+16|0,d|0,c|0,1);b=v[22692];v[22692]=0;if((b|0)==1){break c}b=je(Jb(c+16|0));vb(c+16|0);break b}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22692]=0;Y(1895,2627,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=c+32|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[22692]=0;_(1918,a|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22692]=0;_(1944,b|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}f=v[a+24>>2];b=uc(e+8|0,b);v[22692]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ia(1986,f|0,e|0,c|0,d|0,1);c=v[22692];v[22692]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,5758,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break b}$();b=0}gb=e+16|0;break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return b|0}function joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-48|0;gb=c;d=c+24|0;f=mc(d+8|0);v[22692]=0;e=T(465,b|0)|0;g=v[22692];v[22692]=0;a:{b:{if((g|0)==1){break b}v[22692]=0;U(393,d|0,b|0,e|0);e=v[22692];v[22692]=0;if((e|0)==1){break b}d=v[d>>2];v[22692]=0;Q(318,b|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;gc(f);S(a|0);L()}v[22692]=0;Kr(c+16|0,c+24|0);b=v[22692];v[22692]=0;c:{if((b|0)==1){break c}v[22692]=0;b=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=b;R(635,a|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}zc(c+24|0);gb=c+48|0;return}a=P()|0;O()|0;zc(c+24|0);S(a|0);L()}function pj(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;t[a|0]=0;f=Xf(v[v[b>>2]-12>>2]+b|0);d=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){d=v[d+72>>2];if(d){Ys(d)}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}Fc(e+24|0,v[v[b>>2]-12>>2]+b|0);v[22692]=0;f=T(21,e+24|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}Wb(e+24|0);c=$i(e+16|0,b);d=Ui(e+8|0);d:{if(!gk(c,d)){break d}while(1){if(!kh(f,8192,gl(c))){break d}fl(c);if(gk(c,d)){continue}break}}if(!fk(c,d)){break c}fh(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Xf(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}fh(d,4)}gb=e+32|0;return a}a=P()|0;O()|0;Wb(e+24|0);S(a|0);L()}function gX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22692]=0;Ve(d+8|0,2,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(444,d|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}v[22692]=0;Q(401,d|0,d+24|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Fi(a,b,c,d);v[a>>2]=49892;c=mc(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Qb(a+4248|0,0,48);v[22692]=0;d=ga(1270)|0;e=v[22692];v[22692]=0;a:{if((e|0)==1){break a}v[22692]=0;d=T(1271,d|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break a}v[a+4296>>2]=d;Uy(a);Lt(a);v[22692]=0;W(1517,a+44|0,2,2)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}v[22692]=0;Uh(b);d=v[22692];v[22692]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;gc(c);jf(b);S(a|0);L()}function ZI(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Le(a)){ec(a,31);return 0}f=a,g=Le(a),t[f+1375|0]=g;d=uj(a);b=uj(a);uj(a);f=a,g=uj(a),v[f+1112>>2]=g;uj(a);c=Le(a);v[a+1116>>2]=c;if(!$x(a,a+1120|0,c)){ec(a,10);return 0}v[a+1404>>2]=-2;a:{if((b|0)==-1?(d|0)==-1:0){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){e=v[a+1116>>2];if((e|0)<1){b=27}else{c=0;b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}v[a- -64>>2]=d;v[a+60>>2]=v[a+56>>2]+(b+e|0)}v[a+1380>>2]=0;return 1}
function D2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=MG(b);_k(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Zk(k,a);jj(i,k);Ic(k);Oh(k,a);jj(h,k);Ic(k);l=d,m=nj(a),v[l>>2]=m;l=e,m=mj(a),v[l>>2]=m;Tg(k,a);Eb(f,k);vb(k);Ph(k,a);jj(g,k);Ic(k);a=Yk(a);break a}a=LG(b);_k(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Zk(k,a);jj(i,k);Ic(k);Oh(k,a);jj(h,k);Ic(k);l=d,m=nj(a),v[l>>2]=m;l=e,m=mj(a),v[l>>2]=m;Tg(k,a);Eb(f,k);vb(k);Ph(k,a);jj(g,k);Ic(k);a=Yk(a)}v[j>>2]=a;gb=k+16|0}function Kfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}CS(g+16|0,b);i=g,j=lC(g+16|0),v[i+8>>2]=j;i=g,j=zh(g+16|0),v[i>>2]=j;while(1){b:{v[22692]=0;b=Rl(g+8|0,g);h=v[22692];v[22692]=0;if((h|0)==1){break b}if(!b){kr(g+16|0);break a}v[22692]=0;b=Pl(g+8|0);h=v[22692];v[22692]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Oj(g+8|0);continue}break}a=P()|0;O()|0;kr(g+16|0);S(a|0);L()}gb=g+32|0}function OC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;hh(b,Gd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Nb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Je(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Lb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[nd(e+8|0,e+4|0)>>2];h=Lb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=e+16|0}function nt(a,b,c){var d=0,e=0;d=a,e=vj(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=vj(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function nR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-32|0;gb=d;k=d,l=Yq(b),v[k+16>>2]=l;c=gb-32|0;gb=c;h=bR(a,c+28|0,b);b=v[h>>2];t[c+27|0]=0;if(!b){f=gb-16|0;gb=f;b=fc(a);g=Pj(c+8|0,aR(),Qj(f+8|0,b));b=v[g>>2];v[22692]=0;b=b+16|0;e=v[22692];v[22692]=0;a:{if((e|0)!=1){e=gb-16|0;gb=e;v[e+8>>2]=v[d+16>>2];i=v[e+8>>2];j=v[i+4>>2];v[b>>2]=v[i>>2];v[b+4>>2]=j;cd(b+8|0);gb=e+16|0;k=fc(g),l=1,t[k+4|0]=l;gb=f+16|0;break a}a=P()|0;O()|0;GA(g);S(a|0);L()}zk(a,v[c+28>>2],h,v[c+8>>2]);b=ce(c+8|0);t[c+27|0]=1;GA(c+8|0)}Rj(d+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=te(d+24|0);gb=d+32|0;return a+8|0}function L2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=PG(b);_k(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Zk(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=nj(a),t[l|0]=m;l=e,m=mj(a),t[l|0]=m;Tg(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=Yk(a);break a}a=OG(b);_k(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Zk(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=nj(a),t[l|0]=m;l=e,m=mj(a),t[l|0]=m;Tg(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=Yk(a)}v[j>>2]=a;gb=k+16|0}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,24);gb=d+16|0;d=yb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;cc(c+16|0,a,c);e=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function gla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Kh(f+24|0,c);v[22692]=0;R(158,f+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22692]=0;R(142,f+48|0,e|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22692]=0;rs(f+16|0,f+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(144,a|0,b|0,f+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;Xk(f+24|0)}S(b|0);L()}Xk(f+24|0);gb=f- -64|0}function Loa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Kh(f+24|0,c);v[22692]=0;R(142,f+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22692]=0;R(142,f+48|0,e|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22692]=0;rs(f+16|0,f+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(144,a|0,b|0,f+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;Xk(f+24|0)}S(b|0);L()}Xk(f+24|0);gb=f- -64|0}function H0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Jn(f+24|0,c);v[22692]=0;R(158,f+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22692]=0;R(158,f+48|0,e|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22692]=0;rs(f+16|0,f+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(144,a|0,b|0,f+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;Xk(f+24|0)}S(b|0);L()}Xk(f+24|0);gb=f- -64|0}function sh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb+-64|0;gb=e;a:{b:{if(c-1>>>0>1023){break b}if(le(a,b)){break b}c:{d:{if(Qf(a)>>>0<=b>>>0){d=dz(e+8|0,a);v[22692]=0;U(1474,a|0,b+1|0,d|0);f=v[22692];v[22692]=0;if((f|0)==1){break d}Dm(d)}d=af(a,b);v[22692]=0;Q(1475,d|0,c|0)|0;c=v[22692];v[22692]=0;e:{if((c|0)!=1){c=af(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=af(a,b);v[22692]=0;_(1476,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){break e}}a=V(89088)|0;b=O()|0;break c}g=gi(af(a,b));break b}a=V(89088)|0;b=O()|0;Dm(d)}if((ea(89088)|0)!=(b|0)){break a}Z(a|0)|0;$()}gb=e- -64|0;return g|0}S(a|0);L()}function z$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22692]=0;_(1944,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break d}c=v[a+24>>2];e=uc(d+8|0,b);v[22692]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=kG(c,d,1);e=v[22692];v[22692]=0;c=jb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,5789,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break b}$();b=0;c=0}gb=d+16|0;a=c;break a}b=P()|0;O()|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}ma(a|0);return b|0}function wZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-32|0;gb=g;d=b;f=pc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>>0){bq(d,f);break d}e=wb(d);e=Yg(h+8|0,nh(d,pc(d)+f|0),pc(d),e);v[22692]=0;R(295,e|0,f|0);f=v[22692];v[22692]=0;if((f|0)==1){break c}v[22692]=0;R(296,d|0,e|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}be(e)}gb=h+32|0;break b}a=P()|0;O()|0;be(e);S(a|0);L()}break a}if(e>>>0<f>>>0){xm(d,e+v[d>>2]|0)}}c=Pb(a,c);if(c){FD(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;id(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-16|0;gb=d;b=x[b>>1];e=d;f=x[a+30>>1];if(f){b=ko(b<<16>>16,f<<16>>16)}u[e+14>>1]=b;a:{if(!ed(c)){bk(jN(a+52|0,d+14|0),c);break a}a=a+52|0;b=$y(a,d+14|0);v[d+8>>2]=b;l=d,m=Ah(a),v[l>>2]=m;if(!mg(d+8|0,d)){break a}e=gb-16|0;gb=e;k=e+8|0;b=v[yc(e,b)>>2];c=gb-16|0;gb=c;v[c+8>>2]=b;f=gb-16|0;gb=f;j=v[c+8>>2];h=j;i=yc(f+8|0,h);Oj(i);b=a;g=b;if(v[b>>2]==(h|0)){v[g>>2]=v[i>>2]}g=wb(b);v[g>>2]=v[g>>2]-1;ZM(v[fc(b)>>2],h);b=v[i>>2];gb=f+16|0;a=fc(a);yk(te(c+8|0));Qk(a,j,1);gb=c+16|0;yc(k,b);gb=e+16|0}gb=d+16|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{c:{if((e|0)==1){break c}v[22692]=0;_(1944,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}e=v[a+24>>2];b=uc(d+8|0,b);v[22692]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;Y(1985,e|0,d|0,(c|0)!=0|0,1);c=v[22692];v[22692]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,7229,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function PS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}_e(a);Au(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Fb(f+12|0,f+4|0)>>2];wp(a,zb(b)+g|0,h);ts(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[nc(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=nc(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Fb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}gb=f+16|0;return(d|0)!=0|0}function rJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{c:{c=a+8|0;d:{if(!ol(c)){if((b|0)<0|(cq(c)|0)<=(b|0)){break d}c=(w[Ml(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=ol(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}b=ba(8)|0;v[22692]=0;c=Q(70,d|0,3092)|0;a=v[22692];v[22692]=0;e:{if((a|0)!=1){qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;da(b|0)}S(a|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}gb=d+16|0;return c|0}L()}function Im(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;f=a+1074312|0;Db(e+8|0,f,84);a:{if(Cb(e+8|0)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Db(e+8|0,f,10);if(!Cb(e+8|0)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Db(e+8|0,f,10);if(!Cb(e+8|0)){break a}t[b+831|0]=0;u[b+778>>1]=0}gb=e+16|0}function Jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;td(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function kx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;Fc(f+8|0,b);v[22692]=0;b=T(2464,f+8|0)|0;g=v[22692];v[22692]=0;a:{if((g|0)==1){break a}v[22692]=0;Y(2476,b|0,83392,83424,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;b=T(2465,f+8|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}v[22692]=0;c=T(2477,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}v[d>>2]=c;v[22692]=0;c=T(2474,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}v[e>>2]=c;v[22692]=0;R(2475,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function P9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=gb-16|0;gb=e;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;a:{b:{c:{if((d|0)==1){break c}v[22692]=0;_(1944,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(e+8|0,b);v[22692]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Xa(1987,d|0,e|0,+c,1);d=v[22692];v[22692]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3018,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}gb=e+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function H$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Rg(a,v[b+8>>2],f)){Vw(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;Tw(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;Tw(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];f=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=g;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;g=a;e=fe(e);a:{if(D(e)<2147483648){h=~~e;break a}h=-2147483648}i=g,j=Uc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return f<<3}function Yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Fk(d,2,a+2|0);Bc(d+16|0,d);v[22692]=0;Q(301,b+492|0,d+16|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){vb(d+16|0);f=b+236|0;c=c+1|0;while(1){g=w[(a+e|0)+31|0];h=wd(f,e),i=c+g|0,u[h>>1]=i;e=e+1|0;if(e>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;IN(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);IN(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];g=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;a=d;f=ge(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Uc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return g<<2}function AS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;tc(a,65536);tc(a+4|0,64);tc(a+8|0,256);wg(a+28|0,16384);xf(a+30|0,128);xf(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}xf(a+19|0,64);xf(a+20|0,100);c=224;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<33){break a}}t[a+26|0]=c}xf(a+23|0,64);xf(a+24|0,64);bB(a+48|0,64);bB(a+68|0,64);bB(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[lc(c,b)|0]){if(w[lc(c,b)|0]<121){break b}}e=lc(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!rp(w[a+14|0])){t[a+14|0]=5}}function nx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;Fc(f+8|0,b);v[22692]=0;b=T(21,f+8|0)|0;g=v[22692];v[22692]=0;a:{if((g|0)==1){break a}v[22692]=0;Y(2456,b|0,83392,83424,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;b=T(2436,f+8|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}v[22692]=0;c=T(2457,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}t[d|0]=c;v[22692]=0;c=T(2448,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}t[e|0]=c;v[22692]=0;R(2449,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function tY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=iY(c,a,1);a=wb(a);e=v[d+4>>2];v[22692]=0;U(482,a|0,e|0,b|0);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=gY(c+8|0,hY(a,Tj(a)+1|0),Tj(a),e);f=v[a+8>>2];v[22692]=0;U(482,e|0,f|0,b|0);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[22692]=0;R(483,d|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}zv(a);gb=c+32|0;break b}b=P()|0;O()|0;zv(a);S(b|0);L()}}function yna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Qe(c+40|0,a,16);a=v[c+40>>2];v[22692]=0;d=Td(c+40|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22692]=0;Ve(c+8|0,3,d,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,c+24|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(680,c|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[22692]=0;Q(401,c|0,c+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function x_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Aw(c,a,1);a=wb(a);e=v[d+4>>2];v[22692]=0;U(278,a|0,e|0,b|0);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+36;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=KF(c+8|0,LF(a,Vk(a)+1|0),Vk(a),e);f=v[a+8>>2];v[22692]=0;U(278,e|0,f|0,b|0);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+36;v[22692]=0;R(208,d|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}is(a);gb=c+32|0;break b}b=P()|0;O()|0;is(a);S(b|0);L()}}function Q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-32|0;gb=c;d=He(b,-1);e=w[a+52|0];f=a;a:{b:{if(d){d=b;if(e){break a}b=v[a+48>>2];a=He(b,-1)^1;break b}if(e){g=c,h=th(v[a+48>>2]),t[g+19|0]=h;c:{d:{switch(Ts(v[a+36>>2],v[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break c}d=d-1|0;v[c+20>>2]=d;if((Qs(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break d}}d=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;d=b}gb=c+32|0;return d|0}function _Y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Qe(c+40|0,a,44);a=v[c+40>>2];v[22692]=0;d=Td(c+40|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22692]=0;Ve(c+8|0,2,d,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,c+24|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(450,c|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[22692]=0;Q(401,c|0,c+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function Fo(a){var b=0,c=0,d=0,e=0,f=0,g=0;e=x[a+24>>1];c=v[a+4>>2];d=!w[a+77|0]<<1;b=(e<<2)+(x[c+28>>1]>>>d|0)|0;v[a+40>>2]=((b&3)<<4)+34112;f=b>>>2|0;b=b>>>0<48;g=b?12-f|0:0;u[a+32>>1]=g;u[a+36>>1]=b?1:1<<f-12;u[a+34>>1]=-1<<g^-1;if((e|0)==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+52>>2]=((b&3)<<4)+34112;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+44>>1]=f;u[a+48>>1]=b?1:1<<e-12;u[a+46>>1]=-1<<f^-1;c=(x[a+30>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+64>>2]=((c&3)<<4)+34112;d=c>>>2|0;c=c>>>0<48;b=c?12-d|0:0;u[a+56>>1]=b;u[a+60>>1]=c?1:1<<d-12;u[a+58>>1]=-1<<b^-1}function T9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;a:{b:{c:{if((d|0)==1){break c}v[22692]=0;_(1944,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22692]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(1982,d|0,c|0,1);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3055,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}gb=c+16|0;return+e}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(jk(a)>>>0>=b>>>0){h=e,i=Qf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Fb(e+12|0,e+8|0)>>2];if(f){while(1){EN(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){cz(a,b-d|0,c);break a}vN(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){Qf(d);zO(d);sN(d);Sz(wb(d),v[d>>2],jk(d));h=wb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=uN(a,b);if(rN()>>>0<f>>>0){Sc();L()}wb(d);g=qN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=B(f,52)+g|0,v[h>>2]=i;pN(d,0);cz(a,b,c)}gb=e+16|0}function ypa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{d=gb+-64|0;gb=d;k=d;g=d+16|0;h=gb-16|0;gb=h;l=fU(h+8|0);while(1){e=gb-48|0;gb=e;b=l;c=v[b+4>>2]-v[b>>2]|0;b:{if(!c){b=v[b>>2];break b}c=c+1|0;if(!c){b=PT(RT(e+8|0,32));break b}f=E(c);f=RT(e+8|0,(c&-1>>>f+1?32:31)-f|0);while(1){j=PT(f);if(c>>>0<=j>>>0){continue}break}b=v[b>>2]+j|0}gb=e+48|0;m=Ri(g,i),n=b,v[m>>2]=n;i=i+1|0;if((i|0)!=12){continue}break}gb=h+16|0;b=oU(k,g,tU(g));v[22692]=0;HB(a,b,0);a=v[22692];v[22692]=0;if((a|0)!=1){Lc(b);gb=d- -64|0;break a}a=P()|0;O()|0;Lc(b);S(a|0);L()}}function kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46146>>1])+B(u[e-2>>1],u[f+46144>>1])|0)+B(u[e+2>>1],u[f+46148>>1])|0)+B(u[e+4>>1],u[f+46150>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function hq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;yi(e+16|0,b);c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;d=gb-32|0;gb=d;c=v[e+4>>2];f=v[e>>2];v[d+8>>2]=f;v[d+12>>2]=c;v[d+16>>2]=f;v[d+20>>2]=c;f=gb-16|0;gb=f;g=v[d+12>>2];c=f;h=v[d+8>>2];v[c>>2]=h;v[c+4>>2]=g;v[c+8>>2]=h;v[c+12>>2]=g;g=gb-16|0;gb=g;h=v[c>>2];i=v[c>>2];c=yb(c);v[22692]=0;eo(d+24|0,h,c+i|0);c=v[22692];v[22692]=0;a:{if((c|0)!=1){gb=g+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=f+16|0;c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;mJ(e+24|0,a,d);gb=d+32|0;yb(e+24|0);yi(e+8|0,b);yb(e+8|0);gb=e+32|0}function Rq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;g=Nb(a)-1|0;a:{if((Nb(a)|0)==1){break a}while(1){if(x[Cc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Nb(a)-1>>>0){continue}break}}h=x[Cc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Cc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Cc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Cc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}j=f,k=((B(((w[Cc(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,v[j+12>>2]=k}Sd(f+12|0,0,65536);gb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{c:{if((c|0)==1){break c}v[22692]=0;_(1944,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}c=v[a+24>>2];b=uc(d+8|0,b);v[22692]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(1980,c|0,d|0,1)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,7260,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;a:{b:{c:{if(He(b,-1)){break c}h=c,i=th(b),t[h+23|0]=i;if(w[a+44|0]){if((Dk(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=Ts(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Dk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((Dk(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Us(b);break a}a=-1}gb=c+32|0;return a|0}function Cg(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+29024>>3];a=a-(e+-26388279066624)-A[(b|8)+29024>>3];return aj(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function ska(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Kh(f+24|0,c);v[22692]=0;R(769,f+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22692]=0;R(769,f+48|0,e|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}c=f+24|0;v[f+16>>2]=c;v[f+20>>2]=c+36;v[22692]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(453,a|0,b|0,f+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;Xk(f+24|0)}S(b|0);L()}Xk(f+24|0);gb=f- -64|0}function oQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function nQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Fb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;i=f>>>1|0;j=v[Fb(e+8|0,e+4|0)>>2];c=zb(b);if(f>>>0>=2){g=v[a+20>>2];f=i;h=d;while(1){h=(zb(w[c|0])+h|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(zb(w[c|0])+d|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}gb=e+16|0;return h+i<<1}function lQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function kQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Fb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;i=f>>>1|0;j=v[Fb(e+8|0,e+4|0)>>2];c=zb(b);if(f>>>0>=2){g=v[a+20>>2];f=i;h=d;while(1){h=(zb(w[c+1|0])+h|0)+(zb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(zb(w[c+1|0])+d|0)+(zb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}gb=e+16|0;return h+i<<1}function sM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=Fi(a,b,c,d);t[a+4260|0]=e;v[a>>2]=50936;c=mc(a+4264|0);d=mc(a+4276|0);v[a+4232>>2]=1061997773;e=a+4224|0;v[e>>2]=1061158912;v[e+4>>2]=1059082943;e=a+4216|0;v[e>>2]=1038174126;v[e+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[a+4328>>2]=0;e=a+4320|0;v[e>>2]=0;v[e+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;v[22692]=0;W(1517,a+44|0,2,2)|0;e=v[22692];v[22692]=0;a:{if((e|0)==1){break a}v[22692]=0;Uh(b);e=v[22692];v[22692]=0;if((e|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);Lc(c);jf(b);S(a|0);L()}function UE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=w[a+8|0];f=v[a>>2];a=v[a+4>>2];d=Jb(b);b=Ab(b);c=gb-16|0;gb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Fb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=f;break b}b=e;a=f;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{d:{e:{switch(g-1|0){case 0:case 1:d=v[c+12>>2];t[c+7|0]=0;Do(a,((a+d|0)-e|0)+b|0,c+7|0);break d;case 2:case 3:break e;default:break c}}d=v[c+12>>2];t[c+6|0]=32;Do(a,((a+d|0)-e|0)+b|0,c+6|0)}f:{switch(g-1|0){case 0:case 3:break f;default:break c}}t[(v[c+12>>2]+f|0)-1|0]=0}gb=c+16|0}function V7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-32|0;gb=b;e=mc(a);Md(b+24|0);a=0;c=v[b+28>>2];d=v[b+24>>2];v[22692]=0;R(1405,e|0,yy(d,c)|0);c=v[22692];v[22692]=0;a:{if((c|0)!=1){b:{c:{c=v[b+24>>2];if((yy(c,v[b+28>>2])|0)>0){while(1){c=v[(a<<3)+c>>2];v[22692]=0;c=Q(70,b+8|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;R(1407,e|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}vb(c);c=v[b+24>>2];a=a+1|0;if((yy(c,v[b+28>>2])|0)>(a|0)){continue}break}}gb=b+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function YC(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=c;e=w[d+74|0];t[d+74|0]=e-1|e;e=v[d>>2];b:{if(e&8){v[d>>2]=e|32;d=-1;break b}v[d+4>>2]=0;v[d+8>>2]=0;e=v[d+44>>2];v[d+28>>2]=e;v[d+20>>2]=e;v[d+16>>2]=e+v[d+48>>2];d=0}if(d){break a}d=v[c+16>>2]}f=g;g=v[c+20>>2];if(f>>>0>d-g>>>0){return kb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]<0){d=0;break c}f=b;while(1){d=f;if(!d){d=0;break c}f=d-1|0;if(w[f+a|0]!=10){continue}break}f=kb[v[c+36>>2]](c,a,d)|0;if(f>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;g=v[c+20>>2]}hc(g,a,b);v[c+20>>2]=v[c+20>>2]+b;f=b+d|0}return f}function vla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;td(b,0);RC(d,a+1|0);Bc(d+16|0,d);v[22692]=0;Q(303,b+43|0,d+16|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){vb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=f>>>21&2040;e=(((B(t[e|0],u[f+46146>>1])+B(t[e-1|0],u[f+46144>>1])|0)+B(t[e+1|0],u[f+46148>>1])|0)+B(t[e+2|0],u[f+46150>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function UH(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Xf(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(tH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22692]=0;b=T(2299,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22692]=0;_(2300,a+b|0);a=v[22692];v[22692]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function e8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[22692]=0;R(2083,c|0,(d+(a<<5)|0)+480289|0);d=v[22692];v[22692]=0;if((d|0)==1){break e}v[22692]=0;U(2076,c+16|0,b|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}v[22692]=0;R(1407,f|0,c+16|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}vb(c+16|0);vb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+16|0)}vb(c)}yd(f);S(a|0);L()}function GU(a,b){var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Qe(c+40|0,a,4);a=v[c+40>>2];v[22692]=0;d=Td(c+40|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22692]=0;Ve(c+8|0,3,d,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,c+24|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(866,c|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[22692]=0;Q(401,c|0,c+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function ft(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;h=v[c>>2];v[g+232>>2]=h;c=v[c+4>>2];v[g>>2]=a;v[g+236>>2]=c;a:{b:{c:{d:{if((h|0)!=1){h=a;i=1;break d}h=a;i=1;if(c){break d}c=a;break c}while(1){c=h-v[(d<<2)+f>>2]|0;if((kb[b|0](c,a)|0)<1){c=h;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=h-4|0;if((kb[b|0](j,c)|0)>-1){break e}if((kb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+g>>2]=c;e=EI(g+232|0);gt(g+232|0,e);i=i+1|0;d=d+e|0;e=0;h=c;if(v[g+236>>2]|v[g+232>>2]!=1){continue}break b}break}c=h;break b}if(e){break a}}DI(g,i);Rx(c,b,d,f)}gb=g+240|0}function ey(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0);e=gb-32|0;gb=e;eJ(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),e+20|0);eJ(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){d=a<<2;g=d+c|0;h=z[g>>2];f=z[d+68240>>2];i=z[d+(e+20|0)>>2];j=z[d+(e+8|0)>>2];k=z[d+68252>>2];z[g>>2]=C(f*i)-C(j*k);g=b+d|0;l=z[(0-a<<2)+68248>>2];d=5-a<<2;m=z[d+68240>>2];f=C(C(f*j)+C(k*i));z[g>>2]=C(h*l)-C(m*f);z[b+d>>2]=C(m*h)+C(f*l);a=a+1|0;if((a|0)!=3){continue}break}gb=e+32|0}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb+-64|0;gb=e;k=e+8|0;f=b;d=gb-32|0;gb=d;CY(d+24|0,e+56|0);i=yb(d+24|0);h=v[d+28>>2];g=v[d+24>>2];v[d+8>>2]=g;v[d+12>>2]=h;v[d>>2]=g;v[d+4>>2]=h;h=b;cc(d+16|0,b,d);g=yb(d+16|0);if((g|0)==(i|0)){Rb(h,yb(d+24|0))}gb=d+32|0;if((g|0)==(i|0)){j=Zm(e+56|0)}ud(k,f,j);f=a;a=jc(e+32|0,e+8|0);f=Ul(f,e+56|0,a);xb(a);xb(e+8|0);a:{if(!c){break a}a=(j>>>0)%(c>>>0)|0;if(!a){break a}v[22692]=0;Q(318,b|0,c-a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Zd(f);S(a|0);L()}gb=e- -64|0}function dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Dg(c,a,1);a=wb(a);e=v[d+4>>2];v[22692]=0;gq(a,e,b);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=an(c+8|0,ch(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22692]=0;gq(e,f,b);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22692]=0;R(1486,d|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}bh(a);gb=c+32|0;break b}b=P()|0;O()|0;bh(a);S(b|0);L()}}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function Wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Ip(c,a,1);wb(a);a=v[d+4>>2];v[22692]=0;R(652,a|0,b|0);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=qs(c+8|0,Qw(a,Ec(a)+1|0),Ec(a),e);e=v[a+8>>2];v[22692]=0;R(652,e|0,b|0);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[22692]=0;Hn(d,a);b=v[22692];v[22692]=0;if((b|0)==1){break c}ps(a);gb=c+32|0;break b}b=P()|0;O()|0;ps(a);S(b|0);L()}}function PD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=ji(c,a,1);a=wb(a);e=v[d+4>>2];v[22692]=0;qn(a,e,b);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=yn(c+8|0,Nk(a,sc(a)+1|0),sc(a),e);f=v[a+8>>2];v[22692]=0;qn(e,f,b);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[22692]=0;R(313,d|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}Ih(a);gb=c+32|0;break b}b=P()|0;O()|0;Ih(a);S(b|0);L()}}function Nw(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[wb(a)>>2]){b=gb-16|0;gb=b;c=Aw(b,a,1);d=wb(a);e=v[c+4>>2];v[22692]=0;R(207,d|0,e|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+36;$b(c);gb=b+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}d=gb-32|0;gb=d;c=a;e=wb(a);b=KF(d+8|0,LF(a,Vk(a)+1|0),Vk(a),e);f=v[b+8>>2];v[22692]=0;R(207,e|0,f|0);e=v[22692];v[22692]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+36;v[22692]=0;R(208,c|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}is(b);gb=d+32|0;break b}a=P()|0;O()|0;is(b);S(a|0);L()}}hj(a)}function L4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=He(b,-1);e=w[a+52|0];f=a;a:{b:{if(d){d=b;if(e){break a}b=v[a+48>>2];a=He(b,-1)^1;break b}if(e){v[c+16>>2]=v[a+48>>2];c:{d:{switch(Ts(v[a+36>>2],v[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break c}d=d-1|0;v[c+20>>2]=d;if((Qs(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break d}}d=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;d=b}gb=c+32|0;return d|0}function h$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=c>>>0){break a}d=a+4|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>c>>>0|c-(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}e=1;if(pc(b)>>>0>=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}Gy(b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|0)}return e|0}function fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,26);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function y0(){var a=0;a:{if(t[465376]&1){break a}if(!Rd(465376)){break a}a=465088;while(1){a=Kb(a)+12|0;if((a|0)!=465376){continue}break}Qd(465376)}jd(465088,88392);jd(465100,88424);jd(465112,88460);jd(465124,88484);jd(465136,88508);jd(465148,88524);jd(465160,88544);jd(465172,88564);jd(465184,88592);jd(465196,88632);jd(465208,88664);jd(465220,88700);jd(465232,88736);jd(465244,88752);jd(465256,88768);jd(465268,88784);jd(465280,88508);jd(465292,88800);jd(465304,88816);jd(465316,88832);jd(465328,88848);jd(465340,88864);jd(465352,88880);jd(465364,88896)}function UC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Dg(c,a,1);a=wb(a);e=v[d+4>>2];v[22692]=0;Xo(a,e,b);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=an(c+8|0,ch(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22692]=0;Xo(e,f,b);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22692]=0;R(52,d|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}bh(a);gb=c+32|0;break b}b=P()|0;O()|0;bh(a);S(b|0);L()}}function Lz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}e=a+1074312|0;Db(c+8|0,e,21);d=Cb(c+8|0);f=a;a=w[b+821|0];a=Hz(f,w[b+828|0],d?a:a+16>>>2|0);Db(c+8|0,e,45);b:{if(!(!Cb(c+8|0)|w[b+828|0]!=3)){f=b;d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];d=d+1|0;break c}t[b+832|0]=a;d=1}t[f+821|0]=d;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}Db(c+8|0,e,47);if(!Cb(c+8|0)){break a}t[b+831|0]=a}if(a){g=b,h=Mb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}gb=c+16|0}function vP(a,b){var c=0,d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;a:{if(!w[b+846|0]|v[a+480180>>2]!=1){break a}c=v[b+104>>2];if(!c){break a}if(!Nd(c)){break a}d=x[c+34>>1];if(!(d&10)){break a}e=w[b+847|0]+w[(w[b+846|0]&15)+39664|0]|0;t[b+847|0]=e;if(e<<24>>24>-1){break a}t[b+847|0]=0;e=d&2;d=v[(e?4:12)+c>>2];g=v[b+760>>2]+1|0;v[b+760>>2]=g>>>0<v[(e?8:16)+c>>2]-d>>>0?g:0;e=gj(c);bc(f+8|0,zb(zb(v[c+20>>2]))+B(e,v[b+760>>2]+d|0)|0,e);b=v[f+8>>2];d=v[f+12>>2];if((b|0)!=(d|0)){while(1){t[b|0]=w[b|0]^-1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}_h(c,a,0)}gb=f+16|0}function qj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=gb-16|0;gb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);Kf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;gb=f+16|0}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function Zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=_D(c,a,1);a=wb(a);e=v[d+4>>2];v[22692]=0;ZC(a,e,b);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+20;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=JX(c+8|0,KX(a,$e(a)+1|0),$e(a),e);f=v[a+8>>2];v[22692]=0;ZC(e,f,b);b=v[22692];v[22692]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+20;v[22692]=0;XC(d,a);b=v[22692];v[22692]=0;if((b|0)==1){break c}uv(a);gb=c+32|0;break b}b=P()|0;O()|0;uv(a);S(b|0);L()}}function iW(a){var b=0,c=0;a:{if(rd(a,11441,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4294966507){break a}b=a+16|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=51){break a}}a=a+32|0;c=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return c}function F4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{b:{c:{if(He(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((Dk(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=Ts(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Dk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((Dk(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Us(b);break a}a=-1}gb=c+32|0;return a|0}function Dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-48|0;gb=e;v[22692]=0;c=Q(189,a|0,1)|0;d=v[22692];v[22692]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[22692]=0;_(677,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}v[22692]=0;c=T(374,a|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[22692]=0;d=Q(678,a|0,e+8|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}hc(uW(b,d),e+8|0,33)}if(c&255){continue}break}}xb(a);gb=e+48|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=rh(a);a:{if(b){v[22692]=0;R(930,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}e=gb-16|0;gb=e;d=Aw(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){c=Qb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0}return a|0}a=P()|0;O()|0;AB(c);S(a|0);L()}
function _5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=1073741807){i=d,j=Ab(a),v[i+8>>2]=j;e=sm(v[Mc(d+12|0,d+8|0)>>2]);if((e|0)!=(Yp(a)|0)){a:{f=1;g=Yp(a);h=Ab(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>g>>>0){b=Si(b,c);break c}v[22692]=0;b=Q(2281,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}f=De(a);c=Jb(a)}wi(b,c,Ab(a)+1|0);if(f){ai(a,c,g+1|0)}d:{if((e|0)!=1){pg(a,e+1|0);ee(a,h);cf(a,b);break d}Xe(a,h)}}}gb=d+16|0;return}$f();L()}function Au(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=4294967279){i=d,j=Ab(a),v[i+8>>2]=j;e=Pk(v[Mc(d+12|0,d+8|0)>>2]);if((e|0)!=(Kc(a)|0)){a:{f=Kc(a);g=Ab(a);b:{if((e|0)==10){h=1;b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>f>>>0){b=mi(b,c);break c}v[22692]=0;b=Q(67,b|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}h=De(a);c=Jb(a)}Og(b,c,Ab(a)+1|0);if(h){Uk(a,c,f+1|0)}d:{if((e|0)!=10){pg(a,e+1|0);ee(a,g);cf(a,b);break d}Xe(a,g)}}}gb=d+16|0;return}$f();L()}function zt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+12>>2]=b;u[f+10>>1]=0;u[f+8>>1]=65535;a:{if(!At(f+12|0,f+10|0,f+8|0)){break a}a=a+24|0;if(!le(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0|(x[v[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Wc(b,c,d&65535);b:{switch(e|0){case 0:g=w[a|0];break a;case 1:g=w[a+1|0];break a;case 2:g=w[a+2|0];break a;case 3:g=w[a+3|0];break a;case 4:g=w[a+4|0];break a;case 5:break b;default:break a}}g=w[a+5|0]}gb=f+16|0;return g|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){c=v[a+20>>2];a=g;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=c;f=ge(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=e,j=Uc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}gb=d+16|0;return g<<2}function pz(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;j=gb-16|0;gb=j;v[j+12>>2]=d;d=a+12|0;i=d;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}i=a+8|0;v[j+8>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);k=b,l=v[Fb(j+8|0,j+12|0)>>2],v[k>>2]=l;b=Gd(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24),v[b>>2],v[j+12>>2]);v[c>>2]=b;if(!(b>>>0>=y[j+12>>2]|h)){v[c>>2]=b+1}u[e>>1]=x[e>>1]|f;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=x[e>>1]|g}gb=j+16|0}function yf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Pc(28384,d+14|0)>>1];c=sc(a);a:{if(b>>>0>c>>>0){e=gb-32|0;gb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){pp(a,c,f);break d}b=wb(a);b=yn(e+8|0,Nk(a,sc(a)+c|0),sc(a),b);v[22692]=0;U(312,b|0,c|0,f|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}v[22692]=0;R(313,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}Ih(b)}gb=e+32|0;break b}a=P()|0;O()|0;Ih(b);S(a|0);L()}break a}if(b>>>0<c>>>0){rn(a,v[a>>2]+(b<<1)|0)}}gb=d+16|0}function r_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=16384;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Wk(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}_r(d+4|0,Wk(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}_r(d+4|0,e-c|0);break b}bF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}bF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}gb=d+16|0}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;Xm(c- -64|0,b);v[22692]=0;Vd(c+32|0,c- -64|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22692]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(201,c+40|0,c+16|0,c+8|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}a=cd(a);d=pc(c- -64|0);v[22692]=0;U(920,b|0,a|0,d>>>5|0);d=v[22692];v[22692]=0;if((d|0)==1){d=P()|0;O()|0;Mu(a);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;Xm(c- -64|0,b);v[22692]=0;Vd(c+32|0,c- -64|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22692]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(201,c+40|0,c+16|0,c+8|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}a=cd(a);d=pc(c- -64|0);v[22692]=0;U(921,b|0,a|0,d>>>2|0);d=v[22692];v[22692]=0;if((d|0)==1){d=P()|0;O()|0;ci(a);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;Xm(c- -64|0,b);v[22692]=0;Vd(c+32|0,c- -64|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22692]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(201,c+40|0,c+16|0,c+8|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}a=cd(a);d=pc(c- -64|0);v[22692]=0;U(922,b|0,a|0,d>>>8|0);d=v[22692];v[22692]=0;if((d|0)==1){d=P()|0;O()|0;Ku(a);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;Xm(c- -64|0,b);v[22692]=0;Vd(c+32|0,c- -64|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22692]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(201,c+40|0,c+16|0,c+8|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}a=cd(a);d=pc(c- -64|0);v[22692]=0;U(923,b|0,a|0,d>>>4|0);d=v[22692];v[22692]=0;if((d|0)==1){d=P()|0;O()|0;Ju(a);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function rl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb-16|0;gb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Vh(a,d+15|0);h=w[d+15|0];v[b>>2]=(h&252)>>>2;v[b+4>>2]=0;c=h&3;if(c){c=-1<<c;l=(c>>>0<4294967294?c:-2)^-1;while(1){t[d+15|0]=0;m=Vh(a,d+15|0);c=b;f=v[c>>2];n=v[c+4>>2];j=w[d+15|0];e=g;g=k+1|0;e=g>>>0<1?e+1|0:e;k=g;g=e;h=c;o=c;p=f;c=(k<<3)-2|0;f=c&31;if((c&63)>>>0>=32){e=j<<f;c=0}else{e=(1<<f)-1&j>>>32-f;c=j<<f}v[o>>2]=p|c;v[h+4>>2]=e|n;i=i&m;if((k|0)!=(l|0)|g){continue}break}}gb=d+16|0;return i|0}function qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;_e(b);Qe(d+56|0,a,c);a=v[d+56>>2];v[22692]=0;c=Td(d+56|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22692]=0;Ve(d+8|0,2,c,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;U(13,d+40|0,2,d+24|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}Eb(b,d+40|0);vb(d+40|0);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Fma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;_e(b);Qe(d+56|0,a,c);a=v[d+56>>2];v[22692]=0;c=Td(d+56|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22692]=0;Ve(d+8|0,3,c,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;U(13,d+40|0,5,d+24|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}Eb(b,d+40|0);vb(d+40|0);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22692]=0;Ve(d+8|0,1,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;Q(301,b|0,d+24|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22692]=0;Ve(d+8|0,3,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;Q(303,b|0,d+24|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22692]=0;Ve(d+8|0,2,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;Q(399,b|0,d+24|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];h=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;i=a;f=ge(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Uc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<2}function q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=32768;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Wk(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}_r(d+4|0,Wk(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}_r(d+4|0,e-c|0);break b}aF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}aF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}gb=d+16|0}function IR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=lq(b);d=a;e=rh(a);v[22692]=0;R(1104,a|0,2048);a=v[22692];v[22692]=0;a:{if((a|0)!=1){v[22692]=0;AR(d);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Lf(e);S(a|0);L()}a=0;b:{while(1){c=1;if((a|0)!=1024){v[22692]=0;c=+(a-1024|0);g=lq(K(c*c*-9.5367431640625e-7+1)*b);e=v[22692];v[22692]=0;if((e|0)==1){break b}c=c*.0372006759294457;c=g*qi(c)/(c*f)}h=xe(d,a),i=c*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Lf(d);S(a|0);L()}function AY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22692]=0;Ve(d+8|0,2,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;Q(301,b|0,d+24|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-16|0;gb=c;f=x[cj(a,b)>>1];a:{if(!Go(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=Vb(d),v[j+8>>2]=k;j=c,k=Zb(d),v[j>>2]=k;if(!Gb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=Tl(g);if(i){e=0;while(1){if(!(x[rc(g,e)>>1]!=(h|0)|((a|0)==(g|0)?(b|0)==(e|0):0))){d=tN(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}kS(c+8|0);if(Gb(c+8|0,c)){continue}break a}break}j=cj(a,b),k=d,u[j>>1]=k;f=d}gb=c+16|0;return f&65535}function fF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}d=b+80|0;f=a;c=v[b+84>>2];if(c>>>0<=15){c=v[d>>2]}else{v[e+12>>2]=c-16;c=v[Mc(d,e+12|0)>>2]}v[f+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+794|0]){break a}b:{c:{d:{if(!eF(b)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}g=a,h=v[a>>2]+B(gj(c),b)|0,v[g+4>>2]=h}gb=e+16|0}function B0(){var a=0;a:{if(t[465072]&1){break a}if(!Rd(465072)){break a}a=464784;while(1){a=Kb(a)+12|0;if((a|0)!=465072){continue}break}Qd(465072)}Vc(464784,2130);Vc(464796,2121);Vc(464808,8062);Vc(464820,7831);Vc(464832,2357);Vc(464844,8860);Vc(464856,2214);Vc(464868,2701);Vc(464880,6002);Vc(464892,5985);Vc(464904,5993);Vc(464916,6012);Vc(464928,7297);Vc(464940,10547);Vc(464952,6075);Vc(464964,4763);Vc(464976,2357);Vc(464988,6858);Vc(465e3,7702);Vc(465012,8074);Vc(465024,6360);Vc(465036,3517);Vc(465048,2584);Vc(465060,10456)}function m3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83429]|w[83430]<<8;v[a+24>>2]=w[83425]|w[83426]<<8|(w[83427]<<16|w[83428]<<24);al(a+24|1,7995,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=we();v[a>>2]=e;e=g>>>9&1;g=Ff(f,e+13|0,h,a+24|0,a)+f|0;h=Sg(f,g,c);e=f-((e<<3)+107&112)|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2485,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=Mn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function sP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074456|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Sd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}gb=d+16|0}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;f=dg(a,c);re(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{b:{if(!f){d=-1;if(!ld(a,5)){break b}break a}d=v[f+8>>2]}h=d;g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 3:VA(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=h;u[d+26>>1]=0;v[d+12>>2]=2;wj(d+16|0,g,d+26|0,v[Fb(d+28|0,d+12|0)>>2]);yb(d+16|0);v[d+16>>2]=2;Fb(d+28|0,d+16|0);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;gb=d+32|0}}Wf(a,f,c,e+24|0);gb=e+32|0}function a4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{if((a|0)!=(b|0)){g=v[115173];v[115173]=0;a=gH(a,e+12|0,d,we());d=jb;f=v[115173];f:{if(f){if(v[e+12>>2]!=(b|0)){break f}if((f|0)==68){break d}break e}v[115173]=g;if(v[e+12>>2]==(b|0)){break e}}}v[c>>2]=4;a=0;break a}if((d|0)<-1?1:(d|0)<=-1?a>>>0<=2147483647:0){v[c>>2]=4;break c}if((d|0)<0?1:(d|0)<=0?a>>>0<=2147483647:0){break a}}v[c>>2]=4;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break b}}a=-2147483648;break a}a=2147483647}gb=e+16|0;return a|0}function Yw(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Qb(d+24|0,0,39);a=a+f|0;a:{if(Rg(e,c,0)){v[d+56>>2]=1;kb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}kb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}gb=d- -64|0;return b}function YW(a,b){var c=0,d=0;c=(a|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}d=lg(v[b+8>>2]);c=v[b+8>>2];b:{if(d){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!lg(b)){b=v[b+8>>2];rr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;qr(a);return}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(lg(b)){b=v[b+8>>2];qr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;rr(a);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(a|0)==(b|0);t[c+12|0]=1;if((a|0)!=(b|0)){continue}break}}}function bk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!De(a)){if(!De(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;a:{if(b>>>0<=10){Xe(a,b);Og(a,e,b);t[d+15|0]=0;Bd(a+b|0,d+15|0);break a}c=w[a+11|0];qp(a,10,b-10|0,c,0,c,b,e)}gb=d+16|0;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;c=ak(a);b:{if(c>>>0>b>>>0){c=v[a>>2];ee(a,b);Og(c,e,b);t[d+15|0]=0;Bd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];qp(a,f,g,c,0,c,b,e)}gb=d+16|0}return a|0}function rba(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;a:{b:{if(!a){a=je(18699);break b}v[22692]=0;c=Q(70,b|0,a|0)|0;a=v[22692];v[22692]=0;c:{d:{if((a|0)!=1){v[22692]=0;R(1899,b+16|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}a=je(Jb(b+16|0));vb(b+16|0);vb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;vb(c)}Z(a|0)|0;a=0;v[22692]=0;Y(1895,8202,0,0,0);c=v[22692];v[22692]=0;if((c|0)==1){break a}$()}gb=b+32|0;return a|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;b=-1;a:{if(!Tf(a,8)){break a}c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;b=vd(c+8|0,c+24|0,8);e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;b=a;fd(c+16|0,a,c);e=(yb(c+16|0)|0)==8&(v[c+24>>2]==1096043343&v[c+28>>2]==1196314451);if(e){ad(b,8)}gb=c+32|0;b=0;if(!e){break a}b=-1;if(!_j(a,d+8|0)){break a}a=d+8|4;b=0;if(!Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}b=!(Yb(w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24))&-2139062144)}gb=d+16|0;return b|0}function Y9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22692]=0;_(1918,a|0);h=v[22692];v[22692]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22692]=0;ja(1976,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}b=je(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22692]=0;Y(1895,7905,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function X9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22692]=0;_(1918,a|0);h=v[22692];v[22692]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22692]=0;ja(1977,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}b=je(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22692]=0;Y(1895,7860,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83429]|w[83430]<<8;v[a+24>>2]=w[83425]|w[83426]<<8|(w[83427]<<16|w[83428]<<24);al(a+24|1,7995,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=we();v[a>>2]=e;g=Ff(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=Sg(f,g,c);e=f-32|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2478,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=on(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function bB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if(bd(a)){break a}u[v[a>>2]>>1]=0;xf(v[a>>2]+2|0,b);e=c,f=Vb(a),v[e>>2]=f;e=c,f=So(c,1),v[e+8>>2]=f;e=c,f=Zb(a),v[e>>2]=f;if(!Gb(c+8|0,c)){break a}while(1){d=v[c+8>>2];e=c,f=So(c+8|0,-1),v[e>>2]=f;d=Je(d,v[c>>2]);u[v[c+8>>2]>>1]=x[d>>1];xf(v[c+8>>2]+2|0,b);Oe(c+8|0);e=c,f=Zb(a),v[e>>2]=f;if(Gb(c+8|0,c)){continue}break}}xf(a+14|0,Nb(a)-1&255);xf(a+13|0,w[a+14|0]);xf(a+16|0,Nb(a)-1&255);xf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){xf(a+17|0,Nb(a)-1&255)}gb=c+16|0}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-32|0;gb=f;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;e=Q(189,b|0,8)|0;g=v[22692];v[22692]=0;if((g|0)==1){break b}if(e){v[22692]=0;U(1452,f|0,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}v[22692]=0;R(1453,a|0,f|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}Zd(f);e=HU(a);if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}gb=f+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(f);break a}b=P()|0;O()|0}Ed(a);S(b|0);L()}function J$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Rg(a,v[b+8>>2],e)){Uw(b,c,d);return}a:{if(Rg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];kb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;f=dg(a,c);re(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{b:{if(!f){d=-1;if(!ld(a,5)){break b}break a}d=v[f+8>>2]}h=d;g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:Wh(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=h;t[d+27|0]=0;v[d+12>>2]=1;wj(d+16|0,g,d+27|0,v[Fb(d+28|0,d+12|0)>>2]);yb(d+16|0);v[d+16>>2]=1;Fb(d+28|0,d+16|0);t[d+16|0]=w[d+27|0];t[b|0]=w[d+16|0];gb=d+32|0}}Wf(a,f,c,e+24|0);gb=e+32|0}function u3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83429]|w[83430]<<8;v[a+24>>2]=w[83425]|w[83426]<<8|(w[83427]<<16|w[83428]<<24);al(a+24|1,7995,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=we();v[a>>2]=e;g=Ff(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Sg(f,g,c);e=f-32|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2478,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=on(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function j3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83429]|w[83430]<<8;v[a+24>>2]=w[83425]|w[83426]<<8|(w[83427]<<16|w[83428]<<24);al(a+24|1,7995,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=we();v[a>>2]=e;g=Ff(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Sg(f,g,c);e=f-96|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2485,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=Mn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;c=Td(d+40|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22692]=0;Ve(d+8|0,1,c,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,d+24|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;Q(303,b|0,d+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}}function hm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function d3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-208|0;gb=a;u[a+204>>1]=w[83435]|w[83436]<<8;v[a+200>>2]=w[83431]|w[83432]<<8|(w[83433]<<16|w[83434]<<24);f=we();v[a>>2]=e;h=Ff(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=Sg(a+176|0,e,c);Fc(a+8|0,c);v[22692]=0;g=T(2464,a+8|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){Wb(a+8|0);aH(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=Mn(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)-688|0,b,c,d);gb=a+208|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function tZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if(!Tf(a,7)){break b}d=0;if(!XD(a,14886)){break a}if(!Tf(a,1)){break b}d=-1;if(!ad(a,Wv(a))){break a}c=gb-32|0;gb=c;g=e+8|0;mn(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,a,c);f=yb(c+16|0);if((f|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){Nv(g)}d=-1;if(!c){break a}d=0;if(!TD(e+8|0)){break a}d=Me(a,b,SD(e+8|0),jb);break a}d=-1}gb=e+16|0;return d|0}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Qe(c+40|0,a,31);a=v[c+40>>2];v[22692]=0;d=Td(c+40|0);e=v[22692];v[22692]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22692]=0;Ve(c+8|0,2,d,a);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;R(324,c+24|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}v[22692]=0;Q(303,b|0,c+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function KC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Nb(c);a:{if(d>>>0<b>>>0){f=gb-32|0;gb=f;b:{d=b-d|0;c:{if(d>>>0<=v[wb(c)>>2]-v[c+4>>2]>>2>>>0){pE(c,d,g);break c}b=wb(c);b=an(f+8|0,ch(c,Nb(c)+d|0),Nb(c),b);v[22692]=0;U(655,b|0,d|0,g|0);d=v[22692];v[22692]=0;if((d|0)==1){break b}v[22692]=0;R(52,c|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}bh(b)}gb=f+32|0;break a}a=P()|0;O()|0;bh(b);S(a|0);L()}if(b>>>0<d>>>0){ej(c,v[c>>2]+(b<<2)|0)}}Tz(a);gb=e+16|0}function Hz(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;Db(e+8|0,a+1074312|0,21);a:{if(Cb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+39872|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=jO(uo(a))+-64|0;break a}d=t[(c>>>1&31)+38368|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+39744|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+39808|0]}a=d;gb=e+16|0;return a}function yM(a){a=a|0;var b=0,c=0,d=0,e=0;b=v[a>>2];if(b){kb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;vr(a);c=gb-32|0;gb=c;a:{b:{c:{if(bg(a)>>>0<=pc(a)>>>0){break c}b=wb(a);d=pc(a);e=pc(a);v[22692]=0;b=ca(1619,c+8|0,d|0,e|0,b|0)|0;d=v[22692];v[22692]=0;d:{e:{if((d|0)!=1){v[22692]=0;R(396,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break e}be(b);break c}a=V(0)|0;O()|0;break d}a=V(0)|0;O()|0;be(b)}Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break b}}gb=c+32|0;break a}V(0)|0;O()|0;Bb();L()}}function vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=qD(c,a);rC(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=nD(f+8|0,oD(a,Ch(a)+1|0),Ch(a),c);rC(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;rC(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];mD(d);gb=f+32|0}function Dz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=qq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(qq(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=qq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!qq(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}gb=h+16|0}function sS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;n=c?0:e;f=v[a+12>>2];h=v[a>>2]+B(f,62)|0;d=b?1:-1;o=B(f,d)<<1;c=e;while(1){if((f|0)>0){g=B(c,f);p=v[a+4>>2];b=0;while(1){u[(b<<1)+h>>1]=x[p+(b+g<<1)>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}h=h+o|0;a:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break a}}b=c+d|0;c=!c&(d|0)<0;b=c?n:b;g=c?l:d}d=g;c=b;i=i+1|0;if((j|0)!=(i|0)){continue}break}}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];f=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=ge(e);a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=h,j=Uc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<2}function rS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=C(0);e=gb-32|0;gb=e;g=dg(a,c);re(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{if(!g){if(ld(a,5)){break a}}d=gb-32|0;gb=d;h=v[a+28>>2];rl(h,d+24|0);j=d,k=Qc(v[d+24>>2],v[d+28>>2]),v[j+16>>2]=k;v[d+12>>2]=256;wl(b,v[Fb(d+16|0,d+12|0)>>2]);if(Nb(b)){while(1){v[d+16>>2]=0;hq(h,d+16|0);i=z[d+16>>2];j=Lb(b,f),l=i,z[j>>2]=l;f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break}}gb=d+32|0}Wf(a,g,c,e+24|0);gb=e+32|0}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-4112|0;gb=d;Xm(a,b);if(pc(a)>>>0>4095){while(1){f=e<<12;b=0;c=0;while(1){b=zb(w[kc(a,c+f|0)|0])+b|0;g=zb(b&255);i=lc(d+16|0,c<<1|1),j=g,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}g=f|2048;c=0;while(1){b=zb(w[kc(a,c+g|0)|0])+b|0;h=zb(b&255);i=lc(d+16|0,c<<1),j=h,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}i=d,j=Vb(a),v[i+8>>2]=j;Lu(d+16|0,d+4112|0,ve(d+8|0,f));e=e+1|0;if(e>>>0<pc(a)>>>12>>>0){continue}break}}gb=d+4112|0}function t8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-32|0;gb=b;a:{b:{if(xj(a)){wh(b+24|0);break b}ho(b+8|0,a);v[22692]=0;c=T(2068,b+8|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break a}v[b+24>>2]=c;Vf(b+8|0)}if(xj(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=Vb(c),v[f+8>>2]=g;f=b,g=Zb(c),v[f>>2]=g;if(!Gb(b+8|0,b)){break c}while(1){d=A[v[b+8>>2]>>3]+d;XK(b+8|0);if(Gb(b+8|0,b)){continue}break}break c}d=A[Ol(c,a)>>3]}pl(b+24|0);gb=b+32|0;return+d}a=P()|0;O()|0;Vf(b+8|0);S(a|0);L()}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,16);gb=d+16|0;d=yb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;cc(c+16|0,a,c);e=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function Jo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){wS(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Um(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function HD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{b:{c:{if((f|0)==1){break c}e=zb(e);v[22692]=0;Ve(d+8|0,3,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break c}v[22692]=0;Q(301,b|0,d+24|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=Ab(a);e=Yp(a);g=gr(b,c);a:{if(!g){break a}if(WC(b,Jb(a),Jb(a)+(Ab(a)<<2)|0)){d=gb-16|0;gb=d;fH(f,b,c);gb=d+16|0;b=f;c=Jb(b);d=Ab(b);v[22692]=0;W(2505,a|0,c|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Ic(b);break a}a=P()|0;O()|0;Ic(b);S(a|0);L()}if(e-d>>>0<g>>>0){iI(a,e,(d+g|0)-e|0,d,d)}e=Jb(a)+(d<<2)|0;if((b|0)!=(c|0)){while(1){Fe(e,b);e=e+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f>>2]=0;Fe(e,f);gh(a,d+g|0)}gb=f+16|0}function _9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22692]=0;_(1918,a|0);g=v[22692];v[22692]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22692]=0;ka(1974,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}b=je(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22692]=0;Y(1895,9657,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Z9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22692]=0;_(1918,a|0);g=v[22692];v[22692]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22692]=0;ka(1975,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22692];v[22692]=0;if((b|0)==1){break c}b=je(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22692]=0;Y(1895,9557,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ig(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/6>>>0){JC(a,d,c);break c}b=wb(a);b=HW(e+8|0,uC(a,Ig(a)+d|0),Ig(a),b);v[22692]=0;U(638,b|0,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}HC(a);c=b+4|0;FW(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];wC(a,Ig(a));lv(b)}gb=e+32|0;break a}a=P()|0;O()|0;lv(b);S(a|0);L()}return}if(b>>>0<d>>>0){IC(a,v[a>>2]+B(b,6)|0)}}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-96|0;gb=a;u[a+92>>1]=w[83435]|w[83436]<<8;v[a+88>>2]=w[83431]|w[83432]<<8|(w[83433]<<16|w[83434]<<24);f=we();v[a>>2]=e;h=Ff(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=Sg(a- -64|0,e,c);Fc(a+8|0,c);v[22692]=0;g=T(21,a+8|0)|0;i=v[22692];v[22692]=0;if((i|0)!=1){Wb(a+8|0);cH(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=on(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)-48|0,b,c,d);gb=a+96|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Ie(d,2,a+6|0);Bc(d+16|0,d);v[22692]=0;Q(301,b+492|0,d+16|0)|0;e=v[22692];v[22692]=0;if((e|0)!=1){e=b+236|0;c=c+1|0;vb(d+16|0);while(1){g=w[(a+f|0)+38|0];h=wd(e,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if((f|0)!=128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;nz(a+180|0,b+48|0,0);nz(a+228|0,b+88|0,2);nz(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){qB(e)}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function T3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115173];v[115173]=0;a=qx(a,e+12|0,d,we());d=jb;e:{g=v[115173];if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68){break e}break b}v[115173]=h;if(v[e+12>>2]==(b|0)){break b}break c}v[c>>2]=4;a=-1;b=-1;break a}}v[c>>2]=4;a=0;b=0;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}gb=e+16|0;jb=b;return a|0}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22692]=0;Q(1161,f|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22692]=0;R(1162,e|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;Q(1161,f|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function oP(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}Db(e+8|0,a+1074312|0,3);if(Cb(e+8|0)){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){Db(e+8|0,a+1074312|0,3);if(!Cb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=hu(a,b);if(!d){break a}f=d;a=v[(B(b,872)+a|0)+1075648>>2];if(a){a=w[a+33|0]}else{a=13}kb[v[v[d>>2]+84>>2]](f,c,a<<24>>24,b)}gb=e+16|0}function Kf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;c=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(c){v[22692]=0;R(859,d|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break d}v[22692]=0;R(860,a|0,d|0);c=v[22692];v[22692]=0;if((c|0)==1){break c}Zd(d);c=HU(a);if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}gb=d+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(d);break a}b=P()|0;O()|0}Ed(a);S(b|0);L()}function Nz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=Yj(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;Xl(l+c|0,l,k);break b}Rm(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Er(f+h|0,c,d);d=b;b=c+g|0;gh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Tn();L()}m=e,n=zd(a),v[m+8>>2]=n;a=ve(e+8|0,j);gb=e+32|0;return a|0}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Dg(d,a,1);wb(a);XS(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}f=gb-32|0;gb=f;e=wb(a);d=ch(a,Nb(a)+1|0);i=Nb(a);g=gb-16|0;gb=g;v[g+12>>2]=0;c=f+8|0;hf(c+12|0,e);if(d){h=OW(d)}v[c>>2]=h;e=(i<<2)+h|0;v[c+8>>2]=e;v[c+4>>2]=e;j=dc(c),k=(d<<2)+h|0,v[j>>2]=k;gb=g+16|0;XS(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;WS(a,c);a=c;VS(c);b=v[c>>2];if(b){zC(v[a+16>>2],b,vk(a))}gb=f+32|0}function U$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22692]=0;Q(113,f|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22692]=0;R(173,e|0,d|0);d=v[22692];v[22692]=0;if((d|0)==1){break c}v[22692]=0;Q(113,f|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function Sx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=II(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}gb=e+16|0;return c}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!w[b+8|0]){while(1){if(!w[b+d|0]){aa(14513,6190,415,10446);L()}d=d+1|0;if((d|0)!=8){continue}break}v[c+24>>2]=0;v[c+28>>2]=0;d=vd(c+8|0,c+24|0,8);e=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=e;cc(c+16|0,a,c);d=0;if(!((yb(c+16|0)|0)!=8|(v[c+24>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|v[c+28>>2]!=(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))))){Rb(a,8);d=1}gb=c+32|0;break a}aa(14492,6190,413,10446);L()}return d|0}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;a:{if((d|0)==1){break a}v[22692]=0;_(1929,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22692]=0;b=Q(1930,d|0,b|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,7577,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Mn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((nn(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=gI(i,b,f);h=Jb(f);v[22692]=0;h=W(2487,a|0,h|0,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}Ic(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((nn(a,c,b)|0)!=(b|0)){break b}}IB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;Ic(f);S(a|0);L()}function cp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c);a:{if(!g){break a}tc(f+28|0,65535);yf(a,x[f+28>>1]);i=f,j=Vb(a),v[i+16>>2]=j;i=f,j=Zb(a),v[i+8>>2]=j;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Lg(b,c)){h=gb-16|0;gb=h;Hf(c);gb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}nf(f+16|0);if(Gb(f+16|0,f+8|0)){continue}break}}gb=f+32|0;return g|0}function k3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;al(a+24|1,7828,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=we();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=Ff(g,e+23|0,i,a+24|0,a)+g|0;h=Sg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2485,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=Mn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function i3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;al(a+24|1,7828,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=we();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=Ff(g,e+23|0,i,a+24|0,a)+g|0;h=Sg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2485,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=Mn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function V4(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=Tb(b,13818);v[22692]=0;U(136,b+16|0,a|0,c|0);a=v[22692];v[22692]=0;a:{b:{c:{if((a|0)!=1){vb(c);if(Ec(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;vb(c);break b}a=0;while(1){d:{c=Ad(b+16|0,d);v[22692]=0;c=T(137,c|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Ec(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;mm(b+16|0)}S(d|0);L()}mm(b+16|0);gb=b+32|0;return a|0}function GD(a,b,c){var d=0,e=0;d=gb+-64|0;gb=d;Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;c=Td(d+40|0);e=v[22692];v[22692]=0;a:{b:{c:{if((e|0)==1){break c}c=zb(c);v[22692]=0;Ve(d+8|0,3,c,a);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[22692]=0;R(324,d+24|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break c}v[22692]=0;Q(399,b|0,d+24|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function Y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115173];v[115173]=0;a=qx(a,e+12|0,d,we());d=jb;g=v[115173];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115173]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a&65535}function w_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=-1;c=gb-32|0;gb=c;g=d+8|0;as(c+24|0,g);h=yb(c+24|0);e=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=e;v[c>>2]=i;v[c+4>>2]=e;fd(c+16|0,a,c);e=yb(c+16|0);if((e|0)==(h|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(e|0)==(h|0);if(!a){tw(g)}a:{if(!a){break a}f=0;if(!iF(d+8|0)){break a}if(b){c=v[b>>2];a=d+12|0;if(!v[b+4>>2]&c>>>0<Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))-8>>>0){break a}}f=1}gb=d+48|0;return f|0}function qK(a){var b=0,c=0,d=0,e=0,f=0;if(v[a+16>>2]){while(1){c=Rz(v[a>>2]);d=jb;e=v[a+28>>2];if((d|0)==(e|0)&y[a+24>>2]<=c>>>0|d>>>0>e>>>0){continue}d=b;b=v[a+8>>2];b=(c&v[a+40>>2])+(b>>>0<32?d<<b:0)|0;c=v[a+16>>2];f=f+1|0;if(c>>>0>f>>>0){continue}break}}if(y[a+12>>2]>c>>>0){while(1){d=Rz(v[a>>2]);f=jb;e=v[a+36>>2];if((f|0)==(e|0)&y[a+32>>2]<=d>>>0|f>>>0>e>>>0){continue}e=b;b=v[a+8>>2];b=(d&v[a+48>>2])+(b>>>0<31?e<<b+1:0)|0;c=c+1|0;if(c>>>0<y[a+12>>2]){continue}break}}return b}function Oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){g=g<<8;h=h<<8;while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+B(h,t[e|0]);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function d$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=e;v[d+8>>2]=b;v[d+12>>2]=e;f=gb-16|0;gb=f;g=f+8|0;h=gb-16|0;gb=h;e=gb-16|0;gb=e;c=gb-16|0;gb=c;b=e;v[b+4>>2]=1;i=b,j=Nc(24,4),v[i+8>>2]=j;gb=c+16|0;c=v[b+8>>2];v[22692]=0;Q(212,c|0,d|0)|0;c=v[22692];v[22692]=0;a:{if((c|0)!=1){c=g;g=Fp(b);Ew(c,dc(g),g);TF(b);gb=e+16|0;break a}a=P()|0;O()|0;TF(b);S(a|0);L()}gb=h+16|0;Uf(a,f+8|0);Ld(f+8|0);gb=f+16|0;gb=d+16|0}function NE(a,b){a=a|0;b=b|0;var c=0,d=0;Qb(b,0,44);if(w[a+2|0]|w[a+3|0]<<8?1:w[a|0]|w[a+1|0]<<8){v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;c=b,d=Mb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[c+16>>2]=d;c=b,d=Mb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[c+12>>2]=d;c=b,d=Mb((w[a+2|0]|w[a+3|0]<<8)>>>11|0,0,23),v[c+8>>2]=d;c=b,d=Mb((w[a+2|0]|w[a+3|0]<<8)>>>5&63,0,59),v[c+4>>2]=d;c=b,d=Mb((w[a+2|0]|w[a+3|0]<<8)<<1&62,0,59),v[c>>2]=d}v[b+44>>2]=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-32|0;gb=f;d=Ab(a);e=Kc(a);g=Zh(b,c);a:{if(!g){break a}if(WC(b,Jb(a),Jb(a)+Ab(a)|0)){b=Kj(f+16|0,b,c);c=Jb(b);d=Ab(b);v[22692]=0;W(2283,a|0,c|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Rm(a,e,(d+g|0)-e|0,d,d,0,0)}e=Jb(a)+d|0;if((b|0)!=(c|0)){while(1){Bd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(e,f+15|0);gh(a,d+g|0)}gb=f+32|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=dg(a,c);re(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{b:{if(!g){d=-1;if(!ld(a,5)){break b}break a}d=v[g+8>>2]}h=v[a+28>>2];c:{if(!((d|0)!=-1?(d|0)!=4:0)){d=gb-16|0;gb=d;v[d+8>>2]=0;hq(h,d+8|0);z[b>>2]=z[d+8>>2];gb=d+16|0;break c}e=gb-32|0;gb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;wj(e+8|0,h,e+28|0,v[Fb(e+24|0,e+20|0)>>2]);v[b>>2]=0;gb=e+32|0}}Wf(a,g,c,f+24|0);gb=f+32|0}function XP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b|0]);d=zb(w[b+1|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+2|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+3|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+4|0])|(g|i);j=a,k=Jc(d,zb(w[b+5|0])<<8|g|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function WP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b+7|0]);d=zb(w[b+6|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+5|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+4|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+3|0])|(g|i);j=a,k=Jc(d,zb(w[b+2|0])<<8|g|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function S6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[ni(e+16|0,e+40|0)>>2];c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;v[22692]=0;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;ca(1916,a+8|0,e|0,b|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){IJ(a);b=HJ(a+88|0);v[a>>2]=59688;v[b>>2]=59776;cg(e+40|0);gb=e+48|0;return a|0}a=P()|0;O()|0;cg(e+40|0);S(a|0);L()}function BQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function AQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];h=v[Fb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Fb(e+8|0,e+4|0)>>2];c=zb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=zb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=zb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=zb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}gb=e+16|0;return h+i|0}function wO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;jb=v[e+4>>2];return v[e>>2]}function vZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c<<1);a:{if(!g){break a}tc(f+28|0,65535);yf(a,x[f+28>>1]);h=f,i=Vb(a),v[h+16>>2]=i;h=f,i=Zb(a),v[h+8>>2]=i;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;if(!yp(b,c)){ED(c)}c=w[f+24|0]|w[f+25|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}nf(f+16|0);if(Gb(f+16|0,f+8|0)){continue}break}}gb=f+32|0;return g|0}function _0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(!e|(c|0)==(d|0))){while(1){a:{g=1;f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];h=ui(f+8|0,f+12|0);v[22692]=0;i=hH(c,d-c|0,b);l=v[22692];v[22692]=0;b:{if((l|0)!=1){ff(h);gb=f+16|0;break b}a=P()|0;O()|0;ff(h);S(a|0);L()}c:{switch(i+2|0){default:g=i;break;case 0:case 1:break a;case 2:break c}}j=g+j|0;k=k+1|0;if(k>>>0>=e>>>0){break a}c=c+g|0;if((d|0)!=(c|0)){continue}}break}return j|0}return 0}function vU(a){var b=0,c=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}c=(w[a|0]|w[a+1|0]<<8)>>>0<129}return c}function on(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((nn(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=Ge(i,b,f);g=Jb(f);v[22692]=0;g=W(28,a|0,g|0,b|0)|0;h=v[22692];v[22692]=0;if((h|0)==1){break a}vb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((nn(a,c,b)|0)!=(b|0)){break b}}IB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;vb(f);S(a|0);L()}function jt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Z6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;my(b,c,yb(d));e=v[b+16>>2];a:{if(e>>>0<=c>>>0){hk(a,d,0);break a}v[f+28>>2]=e-c;i=f,j=yb(d),v[i+24>>2]=j;g=v[Fb(f+28|0,f+24|0)>>2];DB(f+16|0,d,0,g);e=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=e;e=gb-32|0;gb=e;b=b+4|0;i=e,j=Vb(b),v[i+24>>2]=j;h=ve(e+24|0,c);i=e,j=Vb(b),v[i+8>>2]=j;i=e,j=ve(e+8|0,c),v[i+16>>2]=j;b=f+8|0;Vi(h,ve(e+16|0,yb(b)),v[b>>2]);gb=e+32|0;DB(a,d,0,g)}gb=f+32|0}function Rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Nd(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;if((g|0)!=(d|0)){continue}break}Hl(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Jo(e,0,c)}gb=c+32|0;return f|0}function v3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;al(a+24|1,7828,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=we();v[a>>2]=e;v[a+4>>2]=f;f=Ff(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Sg(g,f,c);e=g-48|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2478,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=on(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function t3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;al(a+24|1,7828,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=we();v[a>>2]=e;v[a+4>>2]=f;f=Ff(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Sg(g,f,c);e=g-48|0;gb=e;Fc(a+8|0,c);v[22692]=0;ja(2478,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22692];v[22692]=0;if((f|0)!=1){Wb(a+8|0);b=on(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function Ffa(a,b){a=a|0;b=b|0;var c=0;b=38464;a=cd(a);a:{while(1){b:{if(!bd(a)){if(!sj(v[b+8>>2],v[oo(a)>>2])){break b}}v[22692]=0;R(1397,a|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=39028){continue}break}b=39040;while(1){c:{if(!bd(a)){if(!sj(v[b+8>>2],v[oo(a)>>2])){break c}}v[22692]=0;R(1397,a|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=39088){continue}break}return}b=P()|0;O()|0;Lc(a);S(b|0);L()}function kI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=sm(v[Mc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Si(l,k);if(e){wi(c,j,e)}if(g){wi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;wi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){ai(a,j,b)}cf(a,c);pg(a,k);b=a;a=d+(e+g|0)|0;ee(b,a);v[i+4>>2]=0;Fe(c+(a<<2)|0,i+4|0);gb=i+16|0;return}$f();L()}function ZF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;j=d,k=zd(a),v[j+8>>2]=k;h=Yj(d+24|0,d+8|0);f=h;b=Yj(d+16|0,d+24|0);a:{if(Ab(a)>>>0>=f>>>0){if((b|0)==-1){oE(a,f);break a}e=gb-16|0;gb=e;v[e+12>>2]=b;if(b){c=Ab(a);i=Jb(a);g=c-f|0;v[e+8>>2]=g;b=v[Fb(e+12|0,e+8|0)>>2];v[e+12>>2]=b;g=g-b|0;if(g){f=f+i|0;Xl(f,b+f|0,g);b=v[e+12>>2]}f=a;a=c-b|0;gh(f,a);t[e+7|0]=0;Bd(a+i|0,e+7|0)}gb=e+16|0;break a}Tn();L()}ve(d+8|0,h);gb=d+32|0}function Qi(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;if(!bd(a)){lS(b+32|0,Zb(a));lS(b+24|0,Vb(a));c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!mS(c,e)){break a}while(1){d=gb-16|0;gb=d;v[d+8>>2]=v[c+4>>2];f=eS(d+8|0);gb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}eS(c+4|0);if(mS(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=lD(Vb(a),v[b+44>>2])}gb=b+48|0;return c&65535}function CQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=th(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=th(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function Jaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22692]=0;_(1918,a|0);h=v[22692];v[22692]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22692]=0;b=sa(1935,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10240,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Gaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22692]=0;_(1918,a|0);h=v[22692];v[22692]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22692]=0;b=sa(1938,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10172,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function GV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!kf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!kf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}gb=f+16|0}function pf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=jqa(b,c,h,i);i=jb;j=h;h=jqa(d,e,f,g);e=j+h|0;d=jb+i|0;i=e;h=e>>>0<h>>>0?d+1|0:d;j=g;e=0;g=e;k=i;l=c;d=0;i=jqa(j,e,c,d);e=k+i|0;c=jb+h|0;k=e;e=e>>>0<i>>>0?c+1|0:c;h=f;c=0;i=b;f=jqa(h,c,i,0);b=jb;d=jqa(h,c,l,d);b=b+d|0;c=jb;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+k|0;d=c>>>0<h>>>0?e+1|0:e;h=c;c=d;d=jqa(i,m,j,g)+b|0;e=jb;e=b>>>0>d>>>0?e+1|0:e;b=h;h=e;e=b+e|0;v[a+8>>2]=e;v[a+12>>2]=e>>>0<h>>>0?c+1|0:c;v[a>>2]=f;v[a+4>>2]=d}function il(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[22597]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115173]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function dH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115173];v[115173]=0;a=qx(a,e+12|0,d,we());d=jb;g=v[115173];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115173]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a|0}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=rh(a);a:{if(b){v[22692]=0;R(893,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=d;v[c>>2]=a;e=v[a+4>>2];v[c+4>>2]=e;v[c+8>>2]=e+B(b,9);e=c;b=v[c+4>>2];c=v[c+8>>2];if((b|0)!=(c|0)){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[e+4>>2]=b;if((b|0)!=(c|0)){continue}break}}$b(e);gb=d+16|0}return a|0}a=P()|0;O()|0;GB(c);S(a|0);L()}function oc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return oc(a,24)+(oc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){d=mt(a);if((d|0)==-1){break b}e=v[a+1396>>2];c=e+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}v[a+1396>>2]=c-b;c=a;a=v[a+1392>>2];v[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}v[a+1396>>2]=-1;return 0}aa(7301,10482,1617,3884);L()}function dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[nc(b,0)|0]==(fg(43)&255)){break b}if(w[nc(b,0)|0]==(fg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=ve(d+8|0,e-c|0),v[i+16>>2]=j;Hd(d+24|0,d+16|0);Nz(b,v[d+24>>2],1,fg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function F9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22692]=0;_(1991,a|0);f=v[22692];v[22692]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22692]=0;b=Ua(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8542,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function RN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=Yj(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;Xl(l+c|0,l,k);break b}Rm(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Er(f+h|0,c,d);d=b;b=c+g|0;gh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Tn();L()}m=e,n=zd(a),v[m+8>>2]=n;ve(e+8|0,j);gb=e+32|0}function Nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[Jb(b)|0]==(fg(43)&255)){break b}if(w[Jb(b)|0]==(fg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=ve(d+8|0,e-c|0),v[i+16>>2]=j;Hd(d+24|0,d+16|0);RN(b,v[d+24>>2],1,fg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function rv(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{switch(w[a+3|0]){case 10:case 17:case 18:c=8;break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=w[a|0];if(!(c&7)){break d}case 11:c=b+1>>>1|0;b=(w[a+3|0]==11)<<4;break c;case 9:break e;default:break d}}c=16}c=B(c>>>3|0,b);b=(w[a+3|0]==11)<<4}c=b+B($o(a),c)|0}return c|0}function Ana(a,b){a=a|0;b=b|0;var c=0,d=0;c=$e(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/20>>>0){nE(a,c);break c}b=wb(a);b=JX(d+8|0,KX(a,$e(a)+c|0),$e(a),b);v[22692]=0;R(679,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;XC(a,b);a=v[22692];v[22692]=0;if((a|0)==1){break b}uv(b)}gb=d+32|0;break a}a=P()|0;O()|0;uv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,20)|0;$e(a);YD(a,b);Yl(a);$e(a)}}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a>>2]=51808;d=mc(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=vf(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[22692]=0;W(1517,a+44|0,2,2)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Uh(b);c=v[22692];v[22692]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);jf(b);S(a|0);L()}function mY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1064>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1072|0,g=Wk(a,7),t[f|0]=g;d=Wk(a,1);e=Wk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;mY(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function f7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;a:{if(w[b+8|0]){b=b+12|0;h=e,i=pc(b)-c|0,v[h+40>>2]=i;h=e,i=yb(d),v[h+32>>2]=i;f=v[Fb(e+40|0,e+32|0)>>2];h=e,i=Vb(b),v[h+40>>2]=i;g=ve(e+40|0,c);h=e,i=Vb(b),v[h+24>>2]=i;h=e,i=ve(e+24|0,c),v[h+32>>2]=i;Vi(g,ve(e+32|0,f),v[d>>2]);hk(a,d,f);break a}f=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=f;g=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=f;kb[g|0](a,b,c,e+8|0)}gb=e+48|0}function I9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22692]=0;_(1991,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22692]=0;b=ca(f|0,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8687,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function H9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22692]=0;_(1991,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22692]=0;b=ca(f|0,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8723,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function _K(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=gb-48|0;gb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=vd(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=_z(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;v[22692]=0;b=Q(70,b+16|0,5175)|0;c=v[22692];v[22692]=0;b:{if((c|0)!=1){qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0)}S(c|0);L()}gb=b+48|0;return a|0}L()}function $F(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1129474426|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1634291279){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22692]=0;_(1991,a|0);d=v[22692];v[22692]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22692]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3714,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22692]=0;_(1991,a|0);d=v[22692];v[22692]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22692]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3768,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function iP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}lk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}Db(d+8|0,a+1074312|0,7);if(Cb(d+8|0)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function EN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=gb-16|0;gb=e;g=v[d+4>>2];d=v[d>>2];f=(g-d|0)/6|0;a:{if(f>>>0<=Sj(c)>>>0){if(Ig(c)>>>0<f>>>0){v[e+12>>2]=d;h=Ig(c);v[e+12>>2]=v[e+12>>2]+B(h,6);h=d;d=v[e+12>>2];gz(h,d,v[c>>2]);ez(c,d,g,f-Ig(c)|0);break a}IC(c,gz(d,g,v[c>>2]));break a}yN(c);eX(c,uC(c,f));ez(c,d,g,f)}gb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];DN(a+24|0,b+24|0);bk(a+36|0,b+36|0)}function gf(a,b,c,d){var e=0,f=0;a:{if(!Ab(a)|(c-b|0)<5){break a}e=b;f=c;b:{if((e|0)==(f|0)){break b}f=f-4|0;if(f>>>0<=e>>>0){break b}while(1){xc(e,f);e=e+4|0;f=f-4|0;if(e>>>0<f>>>0){continue}break}}e=Jb(a);f=Ab(a);a=c-4|0;c:{if(a>>>0>b>>>0){c=e+f|0;while(1){f=w[e|0];if((f|0)!=v[b>>2]?(f-1&255)>>>0<=125:0){break c}e=(c-e|0)>1?e+1|0:e;b=b+4|0;if(a>>>0>b>>>0){continue}break}}b=w[e|0];if((b-1&255)>>>0>125|b>>>0>v[a>>2]-1>>>0){break a}}v[d>>2]=4}}function qP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}lk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}Db(d+8|0,a+1074312|0,7);if(Cb(d+8|0)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}
function mN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Nb(a);if(c>>>0<=127){e=gb-32|0;gb=e;a:{b:{d=128-c|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){Zy(a,d,b);break c}c=wb(a);c=an(e+8|0,ch(a,Nb(a)+d|0),Nb(a),c);v[22692]=0;U(1485,c|0,d|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(1486,a|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}bh(c)}gb=e+32|0;break a}a=P()|0;O()|0;bh(c);S(a|0);L()}return}if((c|0)!=128){ej(a,v[a>>2]+512|0)}}function fB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function QS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];a:{b:{if(!v[Fb(c+12|0,c+8|0)>>2]){break b}while(1){e=Vq(t[kc(a,d)|0]);f=Vq(t[kc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];d=d+1|0;if(d>>>0>=y[Fb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(v[a+4>>2]==v[b+4>>2]){break a}d=y[a+4>>2]<y[b+4>>2]?-1:1}gb=c+16|0;return d}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=-1;a:{if(!_j(a,d+8|0)){break a}c=d+8|0;b:{if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(tn(6094)|0)){break b}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<=255){break b}e=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<260}c=0;if(!e){break a}c=a;a=d+12|0;c=Me(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}gb=d+16|0;return c|0}function JN(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1095062050?(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;c=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return c}function voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=pc(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){wn(a,d,c);break c}b=wb(a);b=Yg(e+8|0,nh(a,pc(a)+d|0),pc(a),b);v[22692]=0;U(633,b|0,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(296,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}be(b)}gb=e+32|0;break a}a=P()|0;O()|0;be(b);S(a|0);L()}return}if(b>>>0<d>>>0){xm(a,v[a>>2]+b|0)}}function Kaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22692]=0;_(1918,a|0);f=v[22692];v[22692]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22692]=0;b=fa(1934,f|0,b|0,c|0,d|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6794,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Haa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22692]=0;_(1918,a|0);f=v[22692];v[22692]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22692]=0;b=fa(1937,f|0,b|0,c|0,d|0,e|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6722,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Goa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=c;c=Pb(b,c<<2);a:{if(!c){break a}tc(d+28|0,65535);yf(a,x[d+28>>1]);g=d,h=Vb(a),v[g+16>>2]=h;g=d,h=Zb(a),v[g+8>>2]=h;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];e=d+24|0;if(!gs(b,e)){f=gb-16|0;gb=f;Vj(e);gb=f+16|0}e=w[d+24|0]|w[d+25|0]<<8;u[a>>1]=e;if((e|0)==65535){u[a>>1]=65535}nf(d+16|0);if(Gb(d+16|0,d+8|0)){continue}break}}gb=d+32|0;return c|0}function z9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22692]=0;_(1991,a|0);d=v[22692];v[22692]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22692]=0;Wa(f|0,d|0,b|0,+c);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8886,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Me(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=qo(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=qo(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Mk(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}gb=e+16|0;return a}function w7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Wg(b,e,f)>>2];c=Ac(kqa(jqa(c,c>>31,g,h),jb,65536,0),jb);i=Wg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;YJ(a,d);gb=d+16|0}function Pr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14513,6190,415,10446);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=vd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;cc(c+16|0,a,c);b:{if((yb(c+16|0)|0)!=7){break b}if(rd(c+24|0,b,7)){break b}Rb(a,7);d=1}gb=c+32|0;break a}aa(14492,6190,413,10446);L()}return d|0}function Oda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){dN(a,c);break c}b=wb(a);b=an(d+8|0,ch(a,Nb(a)+c|0),Nb(a),b);v[22692]=0;R(1527,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(1524,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}bh(b)}gb=d+32|0;break a}a=P()|0;O()|0;bh(b);S(a|0);L()}return}if(b>>>0<c>>>0){ej(a,v[a>>2]+(b<<2)|0)}}function F7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Wg(b,e,f)>>2];c=Ac(kqa(jqa(c,c>>31,g,h),jb,65536,0),jb);i=Wg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;dK(a,d);gb=d+16|0}function je(a){var b=0,c=0,d=0;d=Rp(Mf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;e=Q(189,b|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(!e){break c}v[22692]=0;U(1452,d|0,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;R(1453,a|0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}Zd(d);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(d);break a}gb=d+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function X5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!dt(eb(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}gb=d+32|0;return e|0}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=Ao(a);a:{b:{c:{d:{while(1){v[22692]=0;e=Q(189,b|0,8)|0;f=v[22692];v[22692]=0;if((f|0)==1){break b}if(!e){break c}v[22692]=0;U(1154,d|0,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;R(1155,a|0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break d}Zd(d);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(d);break a}gb=d+32|0;return}b=P()|0;O()|0}Wm(a);S(b|0);L()}function Q5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g>>2;v[e+4>>2]=c-f;d=v[nd(e+12|0,nd(e+8|0,e+4|0))>>2];wi(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+(d<<2);b=(d<<2)+b|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}f=d+f|0;if((f|0)<(c|0)){continue}break}}gb=e+16|0;return f|0}function rE(a,b){a=a|0;b=b|0;var c=0,d=0;c=sc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){eE(a,c);break c}b=wb(a);b=yn(d+8|0,Nk(a,sc(a)+c|0),sc(a),b);v[22692]=0;R(338,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(313,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Ih(b)}gb=d+32|0;break a}a=P()|0;O()|0;Ih(b);S(a|0);L()}return}if(b>>>0<c>>>0){rn(a,v[a>>2]+(b<<1)|0)}}function U5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[nd(e+12|0,nd(e+8|0,e+4|0))>>2];Og(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+d;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=th(d),t[h|0]=i;d=1}b=b+d|0;f=d+f|0;if((f|0)<(c|0)){continue}break}}gb=e+16|0;return f|0}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,15);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function y8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22692]=0;c=Q(70,h|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,4);c=Ay(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=h+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,14);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function B8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22692]=0;c=Q(70,h|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,4);c=By(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=h+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function IT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;g=v[c>>2];v[d+8>>2]=6553600;e=b+4|0;h=d,i=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h+4>>2]=i;f=+(g>>>0)*1.52587890625e-7;e=dr(f*+y[Fb(d+8|0,d+4|0)>>2]);v[d+12>>2]=e;v[d+4>>2]=6553600;b=b+8|0;h=d,i=Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[h>>2]=i;h=d,i=dr(f*+y[Fb(d+4|0,d)>>2]),v[h+8>>2]=i;v[d+4>>2]=v[c>>2]-e;Hu(a,d+12|0,Fb(d+4|0,d+8|0));gb=d+16|0}function FZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;d=-1;a:{if(!Tf(a,7)){break a}d=0;if(!XD(a,8982)){break a}c=gb-32|0;gb=c;d=f;MD(c+24|0,f);h=yb(c+24|0);e=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=e;v[c>>2]=g;v[c+4>>2]=e;e=a;fd(c+16|0,e,c);g=yb(c+16|0);if((g|0)==(h|0)){ad(e,yb(c+24|0))}gb=c+32|0;e=(g|0)==(h|0);if(!e){LD(d)}d=-1;if(!e){break a}d=0;if(!WD(f)){break a}d=Me(a,b,VD(f),jb)}gb=f+16|0;return d|0}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22692]=0;R(e|0,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10042,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function UM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(vl(a)>>>0<=Sf(a)>>>0){break b}b=wb(a);d=Sf(a);e=Sf(a);v[22692]=0;b=ca(1521,c+8|0,d|0,e|0,b|0)|0;d=v[22692];v[22692]=0;c:{d:{if((d|0)!=1){v[22692]=0;R(1522,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}Mt(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Mt(b)}Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function TM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(ye(a)>>>0<=Nb(a)>>>0){break b}b=wb(a);d=Nb(a);e=Nb(a);v[22692]=0;b=ca(1523,c+8|0,d|0,e|0,b|0)|0;d=v[22692];v[22692]=0;c:{d:{if((d|0)!=1){v[22692]=0;R(1524,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break d}bh(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;bh(b)}Z(a|0)|0;v[22692]=0;X(20);a=v[22692];v[22692]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22692]=0;b=ca(1940,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10203,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22692]=0;b=ca(1942,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10129,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22692]=0;R(e|0,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6423,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22692]=0;b=ca(1933,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6562,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;f=c+8|0;d=b;if(lp(b,c+56|0)){if(Yb(w[c+60|0]|w[c+61|0]<<8|(w[c+62|0]<<16|w[c+63|0]<<24))){e=Yb(w[c+60|0]|w[c+61|0]<<8|(w[c+62|0]<<16|w[c+63|0]<<24))}else{e=-1}}ud(f,d,e);d=a;a=jc(c+32|0,c+8|0);d=Ul(d,c+56|0,a);xb(a);xb(c+8|0);a:{a=e&1;if(!a){break a}v[22692]=0;Q(318,b|0,2-a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Zd(d);S(a|0);L()}gb=c- -64|0}function Iaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22692]=0;b=ca(1936,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6531,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function G9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22692]=0;R(e|0,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8552,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22692]=0;b=ca(1939,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6755,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22692]=0;_(1918,a|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22692]=0;b=ca(1941,e|0,b|0,c|0,d|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6677,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22692]=0;ta(e|0,c|0,+b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22692]=0;Y(1895,8924,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);d=v[22692];v[22692]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Fj(C(C(vf(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Fj(C(C(b>>>0)*C(1.1892070770263672)));d=Fj(C(C(c>>>0)*C(1.1892070770263672)));g=Fj(C(C(d>>>0)*C(1.1892070770263672)));e=Fj(C(C(b+d>>>0)*C(.11546666920185089)));f=Fj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;PL(a);NL(a)}function v9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22692]=0;ta(e|0,c|0,+b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22692]=0;Y(1895,4826,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);d=v[22692];v[22692]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22692]=0;ta(e|0,c|0,+b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22692]=0;Y(1895,4774,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);d=v[22692];v[22692]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function OS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a=Kb(a);d=Ab(b);v[22692]=0;R(60,a|0,d|0);d=v[22692];v[22692]=0;if((d|0)!=1){a:{e=c,f=zd(b),v[e+8>>2]=f;e=c,f=ef(b),v[e>>2]=f;if(Gb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[22692]=0;R(61,a|0,10);break b}v[22692]=0;R(61,a|0,b<<24>>24)}b=v[22692];v[22692]=0;if((b|0)==1){break a}Ne(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0;return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function Cla(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;t[b+15|0]=128;d=Ev(a,127,b+15|0);v[22692]=0;t[b+14|0]=64;e=W(772,a+12|0,127,b+14|0)|0;c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;t[b+13|0]=0;W(861,a+24|0,127,b+13|0)|0;c=v[22692];v[22692]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;gb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;gc(e)}gc(d);S(a|0);L()}function x2(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[22692]=0;Q(152,a|0,2041)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22692]=0;Q(152,a|0,9732)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}}if(ed(a)){v[22692]=0;Q(152,a|0,7291)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22692]=0;Q(152,a|0,8274)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Fc(a,b);v[22692]=0;U(97,d+8|0,b|0,c|0);e=v[22692];v[22692]=0;a:{if((e|0)==1){break a}Wb(d+8|0);v[22692]=0;e=v[b+24>>2];f=v[22692];v[22692]=0;if((f|0)==1){break a}if(e){v[22692]=0;b=v[b+24>>2];e=v[22692];v[22692]=0;if((e|0)==1){break a}v[22692]=0;U(98,d|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}Wb(d)}gb=d+16|0;return}b=P()|0;O()|0;Wb(a);S(b|0);L()}function cr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[lc(a,0)|0]&15)<<8|w[lc(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=x[(c<<1)+39104>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+39102>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[lc(a,2)|0];g=b,h=w[lc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[lc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[lc(a,3)|0],t[g+5|0]=h}function A9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22692]=0;d=+Va(e|0,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8905,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Jn(e+24|0,c);v[22692]=0;R(142,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function woa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;VC(e+24|0,c);v[22692]=0;R(632,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function qp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)-17>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Pk(v[Mc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=mi(l,k);if(e){Og(c,j,e)}if(g){Og(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Og((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){Uk(a,j,b)}cf(a,c);pg(a,k);b=a;a=d+(e+g|0)|0;ee(b,a);t[i+7|0]=0;Bd(a+c|0,i+7|0);gb=i+16|0;return}$f();L()}function _oa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;VC(e+24|0,c);v[22692]=0;R(536,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Zpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Jn(e+24|0,c);v[22692]=0;R(158,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Kh(e+24|0,c);v[22692]=0;R(769,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(453,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function UO(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a=gb-16|0;gb=a;f=a,g=Vb(c),v[f+8>>2]=g;f=a,g=Zb(c),v[f>>2]=g;if(Gb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[22692]=0;_(b|0,d|0);b=v[22692];v[22692]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;zl(c);Bb();L()}Hb(b+20|0);Hb(b+8|0);Xb(b);Oe(a+8|0);if(Gb(a+8|0,a)){continue}break}}zl(c);gb=a+16|0;Xb(c)}}}function Gy(a,b){a=a|0;b=b|0;var c=0,d=0;c=pc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){bq(a,c);break c}b=wb(a);b=Yg(d+8|0,nh(a,pc(a)+c|0),pc(a),b);v[22692]=0;R(123,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(120,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}be(b)}gb=d+32|0;break a}a=P()|0;O()|0;be(b);S(a|0);L()}return}if(b>>>0<c>>>0){xm(a,v[a>>2]+b|0)}}function Gk(a,b){a=a|0;b=b|0;var c=0,d=0;c=pc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){bq(a,c);break c}b=wb(a);b=Yg(d+8|0,nh(a,pc(a)+c|0),pc(a),b);v[22692]=0;R(395,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(396,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}be(b)}gb=d+32|0;break a}a=P()|0;O()|0;be(b);S(a|0);L()}return}if(b>>>0<c>>>0){xm(a,v[a>>2]+b|0)}}function E9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22692]=0;b=Q(d|0,c|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3741,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function C9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22692]=0;_(1991,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22692]=0;b=Q(d|0,c|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3792,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function C$(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;v[22692]=0;a=lG(1909,a,b,c,d,e,f);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;ja(1906,5959,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function e5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Kh(e+24|0,c);v[22692]=0;R(142,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Vv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;DD(e+24|0,c);v[22692]=0;R(142,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function DZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;$v(e+24|0,c);v[22692]=0;R(365,e+36|0,d|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(e+16|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(144,a|0,b|0,e+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function wl(a,b){var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){dN(a,c);break c}b=wb(a);b=an(d+8|0,ch(a,Nb(a)+c|0),Nb(a),b);v[22692]=0;R(1487,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;R(1486,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}bh(b)}gb=d+32|0;break a}a=P()|0;O()|0;bh(b);S(a|0);L()}return}if(b>>>0<c>>>0){ej(a,v[a>>2]+(b<<2)|0)}}function bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(1145,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(1146,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function Xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(1152,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(1153,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function S5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+28>>2];g=v[a+24>>2];b:{if(d>>>0<=g>>>0){if(((i=a,j=Kg(t[b|0]),h=v[v[a>>2]+52>>2],kb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0;break b}v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[nd(e+12|0,e+8|0)>>2];Og(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=d+f|0;b=b+d|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;LW(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;gb=c+16|0}return a|0}function XD(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14513,6190,415,10446);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=vd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;fd(c+16|0,a,c);b:{if((yb(c+16|0)|0)!=7){break b}if(rd(c+24|0,b,7)){break b}ad(a,7);d=1}gb=c+32|0;break a}aa(14492,6190,413,10446);L()}return d}function $9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22692]=0;_(1918,a|0);f=v[22692];v[22692]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22692]=0;b=zt(f,b,c,d,e);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,9610,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(533,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(534,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(817,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(818,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function Hna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,6)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(675,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(676,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function Dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(859,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(860,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a>>2]=51196;c=mc(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22692]=0;W(1517,a+44|0,2,2)|0;d=v[22692];v[22692]=0;a:{if((d|0)==1){break a}v[22692]=0;Uh(b);d=v[22692];v[22692]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(c);jf(b);S(a|0);L()}function wz(a,b,c,d){var e=0,f=0,g=0;f=gb-48|0;gb=f;a:{if(!c){c=Tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;wz(a,b,g,e+16|0);Li(e+32|0,d,Tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;wz(a,b|c,g,e)}gb=f+48|0}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;bk(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Jb(c)+Ab(c)|0,v[d+44>>2]=e;Rn(a,Jb(c),Jb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Ab(c);d=a,e=b+Jb(c)|0,v[d+44>>2]=e;Fq(c,Kc(c));Dx(a,Jb(c),Jb(c)+Ab(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;Ws(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}Ws(a,b)}}function bZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22692]=0;d=Q(189,b|0,8)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}if(!d){break c}v[22692]=0;R(445,c|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(446,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)==1){break d}Zd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Zd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Ed(a);S(b|0);L()}function ZP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=gd(f|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[g>>1]=h;f=zb(w[b+4|0]);g=a,h=gd(f|zb(w[b+5|0])<<8|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function YP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+3|0]);g=a,h=gd(f|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+7|0]);g=a,h=gd(f|zb(w[b+6|0])<<8|zb(w[b+5|0])<<16|zb(w[b+4|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;xC(d+24|0,c);v[22692]=0;R(632,d+36|0,49052);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[22692]=0;pi(d+16|0,d+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){v[22692]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;U(144,a|0,b|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(d+24|0);break b}a=P()|0;O()|0;vb(d+24|0)}S(a|0);L()}Cf(d+24|0);gb=d+48|0}function Maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22692]=0;U(1932,d|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,7545,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function VI(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function Vha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;u[e+12>>1]=c;u[e+14>>1]=b;wg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=gb-16|0;gb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Ng(a)>>>0>=d>>>0){g=b,h=sc(a),v[g+8>>2]=h;hv(v[a>>2],v[Fb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){pp(a,d-f|0,c);break a}rn(a,v[a>>2]+(d<<1)|0);break a}oS(a);OB(a,Nk(a,d));pp(a,d,c)}gb=b+16|0;gb=e+16|0}function Paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22692]=0;e=+oa(1928,d|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2442,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function td(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Hl(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Tb(d,18699);v[22692]=0;Q(303,a+43|0,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){vb(b);wS(a);gb=d+16|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=b;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;b=iv(d,d+8|0);gb=d+16|0;a:{b=Lk(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[22692]=0;cn(c,d,f);c=v[22692];v[22692]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;Oe(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}Zc(b);gb=e+32|0;return}a=P()|0;O()|0;Zc(b);S(a|0);L()}function Qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function MC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=gb-16|0;gb=c;if(Pb(a,b)){while(1){t[c+11|0]=0;b:{if(b>>>0>d>>>0){Lg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;c=d;break a}c=qg(a);Rb(a,b-4|0)}t[f|0]=c}function B$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22692]=0;a=La(1910,a|0,b|0,c|0,d|0)|0;b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;ja(1906,8309,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function y9(a){a=a|0;var b=0,c=0,d=0;v[22692]=0;_(1991,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22692]=0;c=+pa(d|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8942,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w9(a){a=a|0;var b=0,c=0,d=0;v[22692]=0;_(1991,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22692]=0;c=+pa(d|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4843,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function u9(a){a=a|0;var b=0,c=0,d=0;v[22692]=0;_(1991,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22692]=0;c=+pa(d|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4791,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Hh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14513,6190,415,10446);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=vd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;cc(c+16|0,a,c);if(!((yb(c+16|0)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){Rb(a,4);d=1}gb=c+32|0;break a}aa(14492,6190,413,10446);L()}return d|0}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;_e(b);Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;c=Td(d+40|0);e=v[22692];v[22692]=0;b:{if((e|0)==1){break b}c=zb(c);v[22692]=0;Ve(d+8|0,1,c,a);a=v[22692];v[22692]=0;if((a|0)==1){break b}v[22692]=0;R(324,d+24|0,d+8|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Eb(b,d+24|0);vb(d+24|0);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;zc(d+40|0);S(a|0);L()}}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=gb-32|0;gb=d;e=gb-16|0;gb=e;f=e,g=Ib(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;iR(d+16|0,e+14|0);gb=e+16|0;v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(144,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Gna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Vb(b);f=Zb(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;if(Gb(c+24|0,c+16|0)){while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]!=(w[e|0]|w[e+1|0]<<8)){kp(c+24|0);if(Gb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[d+8>>2]=e;g=d,h=Zb(b),v[g>>2]=h;a:{if(Gb(d+8|0,d)){Pe(a,wb(v[d+8>>2]));break a}oi(a)}gb=d+16|0}function lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b>>2];f=_C(b);d=gb-16|0;gb=d;e=gr(c,f);a:{if(e>>>0<=ye(a)>>>0){if(Nb(a)>>>0<e>>>0){v[d+12>>2]=c;WV(d+12|0,Nb(a));b=v[d+12>>2];Qg(c,b,v[a>>2]);VV(a,b,f,e-Nb(a)|0);break a}ej(a,Qg(c,f,v[a>>2]));break a}UV(a);b=a;g=ch(a,e);if(g>>>0>aC(a)>>>0){Sc();L()}h=ME(wb(b),g);v[b>>2]=h;v[b+4>>2]=h;i=wb(b),j=(g<<2)+h|0,v[i>>2]=j;_m(b,0);VV(a,c,f,e)}gb=d+16|0}function Rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Vb(b);f=Zb(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Gb(c+24|0,c+16|0)){break a}while(1){if(cY(c+8|0,v[c+24>>2])){break a}v[c+24>>2]=v[c+24>>2]+28;if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=Zb(b),v[g>>2]=h;b:{if(Gb(d+8|0,d)){Pe(a,wb(v[d+8>>2]));break b}oi(a)}gb=d+16|0}function my(a,b,c){var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{if(w[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=ly(b,4096);JJ(a,b-c|0);b=vd(d+16|0,kc(a+4|0,v[a+16>>2]),b-v[a+16>>2]|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;kb[c|0](d+24|0,a,d+8|0);f=a,g=yb(d+24|0)+v[a+16>>2]|0,v[f+16>>2]=g;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}gb=d+32|0}function lj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(fk(a,g+8|0)){break b}f=4;h=gl(a);if(!kh(d,2048,h)){break b}b=Ln(d,h);fl(a);b=b-48|0;c:{if(!gk(a,g+8|0)|(e|0)<2){break c}while(1){f=gl(a);if(!kh(d,2048,f)){break a}f=Ln(d,f);fl(a);b=(f+B(b,10)|0)-48|0;if(!gk(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!fk(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function kj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(bl(a,g+8|0)){break b}f=4;h=om(a);if(!cl(d,2048,h)){break b}b=Kn(d,h);nm(a);b=b-48|0;c:{if(!pm(a,g+8|0)|(e|0)<2){break c}while(1){f=om(a);if(!cl(d,2048,f)){break a}f=Kn(d,f);nm(a);b=(f+B(b,10)|0)-48|0;if(!pm(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!bl(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function dga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=gb-880|0;gb=d;b=Qb(a,0,76);v[b+84>>2]=0;v[b+88>>2]=0;v[b+80>>2]=256;u[b+76>>1]=65535;v[b+92>>2]=0;v[b+96>>2]=0;t[b+100|0]=1;e=b+223848|0;c=b+616|0;a=c;while(1){a=yB(a)+872|0;if((e|0)!=(a|0)){continue}break}Qb(d+8|0,0,872);e=yB(d+8|0);a=c;c=((a+223232|0)-a|0)/872|0;if((c|0)>=1){while(1){iu(a,e);a=a+872|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}gb=d+880|0;return b|0}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){g=v[115173];v[115173]=0;d=gH(a,e+12|0,d,we());a=jb;f=v[115173];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[115173]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}gb=e+16|0;jb=a;return d|0}function Yx(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!kt(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}ec(a,32);return 0}aa(12831,10482,1549,3128);L()}function Fu(a,b){var c=0;c=gb-32|0;gb=c;oT(c+16|0,a,a+1|0,a+2|0,a+3|0);oT(c,b,b+1|0,b+2|0,b+3|0);gb=c+32|0;b=c+16|0;a=c;c=1;a:{if(w[v[b>>2]]<w[v[a>>2]]){break a}c=0;if(w[v[a>>2]]<w[v[b>>2]]){break a}c=1;b:{if(t[v[b+4>>2]]<t[v[a+4>>2]]){break b}c=0;if(t[v[a+4>>2]]<t[v[b+4>>2]]){break b}c=1;c:{if(w[v[b+8>>2]]<w[v[a+8>>2]]){break c}c=0;if(w[v[a+8>>2]]<w[v[b+8>>2]]){break c}c=w[v[b+12>>2]]<w[v[a+12>>2]]}}}return c}function z8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22692]=0;c=Q(70,f|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,2);c=Ay(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=f+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function wu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){CR(b,A[xe(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Vb(c),v[g+8>>2]=h;g=d,h=Zb(c),v[g>>2]=h;if(Gb(d+8|0,d)){while(1){e=v[d+8>>2];g=e,i=CR(b,A[e>>3]),A[g>>3]=i;vu(d+8|0);if(Gb(d+8|0,d)){continue}break}}EB(a,c);gb=d+16|0}function Jz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;t[e+15|0]=!d|y[c+20>>2]<2?0:v[b+480180>>2]==1;d=!v[c+52>>2]|d;t[e+14|0]=d;if(!(!x[b+480188>>1]|((d|0)!=1|v[b+480180>>2]!=2))){d=0;while(1){v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=v[c+52>>2];u[c+72>>1]=x[c+74>>1];t[a|0]=w[e+15|0];t[a+1|0]=w[e+14|0];gb=e+16|0}function C8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22692]=0;c=Q(70,f|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,2);c=By(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=f+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=Fi(a,b,c,d);v[a>>2]=50704;d=mc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22692]=0;W(1517,a+44|0,2,2)|0;b=v[22692];v[22692]=0;a:{if((b|0)==1){break a}v[22692]=0;Uh(c);b=v[22692];v[22692]=0;if((b|0)==1){break a}Ht(a);return a|0}a=P()|0;O()|0;Lc(d);jf(c);S(a|0);L()}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115173];v[115173]=0;we();d=gb-16|0;gb=d;Kx(d,a,e+12|0,0);f=pI(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115173];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115173]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return C(f)}function pba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;a:{b:{if(!a){break b}a=uc(b+8|0,a);v[22692]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=$K(b);c=v[22692];v[22692]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;Y(1895,9739,0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}a=0}gb=b+16|0;return a|0}function Waa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;R(1921,c|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8087,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;d=v[fc(a)>>2];i=v[b>>2];g=v[a>>2];f=(d|0)==2491;j=f?0:g;d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}h=d?d:4;d=Qp(j,h);if(d){if(!f){ce(a)}v[e+4>>2]=2440;d=he(e+8|0,d,e+4|0);Ee(a,ce(d));f=v[fc(d)>>2];k=fc(a),l=f,v[k>>2]=l;Hc(d);v[b>>2]=v[a>>2]+(i-g|0);v[c>>2]=v[a>>2]+(h&-4);gb=e+16|0;return}Ps();L()}function zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;d=Rc(c+8|0,16,1,1,0);v[c+4>>2]=0;td(a,0);vc(b);a:{b:{if(Pr(b,11035)){Yc(b,12);if(!Gr(b)){vp(d,2)}Yc(b,24);break b}if(Hh(b,10917)){vc(b);v[c+4>>2]=4;e=1;break a}Xi(d,8)}e=0}f=a,g=(mf(b)>>>0)/(B($o(d),w[d|0])>>>3>>>0)|0,v[f>>2]=g;b=Ag(d,a,b);if(!(!e|!b)){d=v[a+20>>2];f=c,g=Zi(a),v[f>>2]=g;Qb(d,0,v[Fb(c+4|0,c)>>2])}gb=c+16|0;return(b|0)!=0|0}function doa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;v[e+24>>2]=d;g=dg(a,c);re(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(ld(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=gb-16|0;gb=f;d=Kb(f);v[22692]=0;ca(625,b|0,h|0,d|0,i|0)|0;b=v[22692];v[22692]=0;b:{if((b|0)!=1){vb(d);gb=f+16|0;break b}a=P()|0;O()|0;vb(d);S(a|0);L()}}Wf(a,g,c,e+16|0);gb=e+32|0}function Kga(a){a=a|0;var b=0;a=Kb(a);v[22692]=0;R(60,a|0,4);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}v[22692]=0;R(61,a|0,32);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(61,a|0,10);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(61,a|0,13);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(61,a|0,9);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function kfa(a){a=a|0;var b=0,c=0,d=0;b=gb-48|0;gb=b;while(1){c=c+1|0;if((c|0)!=15){continue}break}t[b+39|0]=0;t[b+40|0]=0;t[b+41|0]=0;t[b+42|0]=0;t[b+43|0]=0;t[b+44|0]=0;t[b+45|0]=0;t[b+46|0]=0;v[b+32>>2]=0;v[b+36>>2]=0;c=vd(b+16|0,b+32|0,15);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;cc(b+24|0,a,b+8|0);c=0;a:{if((yb(b+24|0)|0)!=15){break a}if(rd(b+32|0,5657,15)){break a}Rb(a,15);c=1}gb=b+48|0;return c|0}function aA(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;dO(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(kb[v[v[b>>2]+136>>2]](b)|0){e=v[b+16>>2];b=e+1074332|0;c=C(C(c*C(y[e+480232>>2]))/C(z[b+8>>2]*z[b+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function P$(a){a=a|0;var b=0;a=Kb(a);v[22692]=0;R(65,a|0,4);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}v[22692]=0;R(66,a|0,32);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(66,a|0,10);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(66,a|0,13);b=v[22692];v[22692]=0;if((b|0)==1){break b}v[22692]=0;R(66,a|0,9);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function saa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;d=KK(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6488,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function raa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;d=JK(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3283,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;d=IK(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3184,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function paa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;d=HK(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3326,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function oaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;d=GK(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3228,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Tq(a,b,c){var d=0,e=0;a=Kb(a);d=Ab(b);v[22692]=0;R(62,a|0,d|0);d=v[22692];v[22692]=0;if((d|0)!=1){a:{if(Ab(b)){while(1){d=w[nc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[22692]=0;R(63,a|0,d|0);d=v[22692];v[22692]=0;if((d|0)!=1){break b}break a}v[22692]=0;R(63,a|0,65533);d=v[22692];v[22692]=0;if((d|0)==1){break a}}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Ic(a);S(b|0);L()}function NY(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;_e(b);Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{if((f|0)==1){break a}e=zb(e);v[22692]=0;Ve(d+8|0,2,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break a}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}Eb(b,d+24|0);vb(d+24|0);zc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(d+40|0);S(a|0);L()}function Kx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-160|0;gb=e;Qb(e+16|0,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;xi(e+16|0,0,0);rI(e,e+16|0,d,1);d=v[e+8>>2];g=v[e+12>>2];h=v[e>>2];i=v[e+4>>2];if(c){j=c;f=b;b=v[e+20>>2]-v[e+24>>2]|0;k=b;c=b+v[e+136>>2]|0;b=v[e+140>>2]+(b>>31)|0;b=c>>>0<k>>>0?b+1|0:b;v[j>>2]=!(b|c)?f:f+c|0}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=g;gb=e+160|0}function ID(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;_e(b);Qe(d+40|0,a,c);a=v[d+40>>2];v[22692]=0;e=Td(d+40|0);f=v[22692];v[22692]=0;a:{if((f|0)==1){break a}e=zb(e);v[22692]=0;Ve(d+8|0,3,e,a);e=v[22692];v[22692]=0;if((e|0)==1){break a}v[22692]=0;R(324,d+24|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}Eb(b,d+24|0);vb(d+24|0);zc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(d+40|0);S(a|0);L()}function mJ(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;e=d+24|0;yc(e,v[v[b>>2]-12>>2]+b|0);v[e+4>>2]=b;b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;v[d+16>>2]=c;v[d+20>>2]=b;b=d+8|0;dl(v[d+28>>2],zb(v[b>>2]),yb(b));c=gb-16|0;gb=c;v[c+12>>2]=v[v[d+28>>2]+4>>2];v[22692]=0;v[c+8>>2]=0;e=Gf(c+8|0,c+12|0);f=v[22692];v[22692]=0;a:{if((f|0)!=1){gb=c+16|0;c=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}hk(a,b,c);gb=d+32|0}function SY(){var a=0,b=0;a=gb-16|0;gb=a;a:{if(cb(a+12|0,a+8|0)|0){break a}b=Cd((v[a+12>>2]<<2)+4|0);v[115976]=b;if(!b){break a}b=Cd(v[a+8>>2]);if(b){v[v[115976]+(v[a+12>>2]<<2)>>2]=0;if(!(bb(v[115976],b|0)|0)){break a}}v[115976]=0}gb=a+16|0;b:{if(t[463888]&1){break b}if(!Rd(463888)){break b}v[22692]=0;X(2385);a=v[22692];v[22692]=0;if((a|0)!=1){Qd(463888);break b}a=P()|0;O()|0;Ye(463888);S(a|0);L()}YN()}function L9(a){a=a|0;var b=0;v[22692]=0;_(1991,a|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){kb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2147,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function bQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=gd(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;f=zb(w[b+3|0]);g=a,h=gd(zb(w[b+4|0])<<16|f<<8|zb(w[b+5|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function aQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=gd(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+5|0]);g=a,h=gd(zb(w[b+4|0])<<16|f<<8|zb(w[b+3|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function gV(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)>>>0<512|(w[b|0]|w[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>=256){break a}a=a+124|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return c}function vJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if(($n(a+8|0)|0)>(b|0)){break d}}b=ba(8)|0;v[22692]=0;c=Q(70,c|0,7947)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}gb=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function nU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14513,6190,415,10446);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=vd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;fd(c+16|0,a,c);if(!((yb(c+16|0)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){ad(a,4);d=1}gb=c+32|0;break a}aa(14492,6190,413,10446);L()}return d}function WI(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){ec(a,21);return-1}if(v[a+1396>>2]<=9){jl(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=vm(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>-1)){ec(a,21)}return c}aa(4595,10482,1778,2842);L()}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;VK(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2876,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Raa(a,b){a=a|0;b=+b;var c=0;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;b=+Ya(1926,c|0,+b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;Z(c|0)|0;v[22692]=0;Y(1895,4635,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115173];v[115173]=0;we();d=gb-16|0;gb=d;Kx(d,a,e+12|0,1);f=Vx(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115173];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115173]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return+f}function Ke(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Mp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(mG(a,b)&3){case 0:c=Mp(A[b>>3],A[b+8>>3]);break a;case 1:c=-Np(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Mp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Np(A[b>>3],A[b+8>>3],1)}a=c;gb=b+16|0;return a}function O5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if((c|0)<1){break a}while(1){e=v[a+24>>2];g=v[a+28>>2];b:{if(e>>>0>=g>>>0){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}f=f+1|0;b=b+4|0;break b}v[d+12>>2]=g-e>>2;v[d+8>>2]=c-f;e=v[nd(d+12|0,d+8|0)>>2];wi(v[a+24>>2],b,e);g=e<<2;v[a+24>>2]=g+v[a+24>>2];f=f+e|0;b=b+g|0}if((c|0)>(f|0)){continue}break}}gb=d+16|0;return f|0}function tJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if(($n(a+8|0)|0)>(b|0)){break d}}b=ba(8)|0;v[22692]=0;c=Q(70,c|0,7947)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}gb=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function Jr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Vb(b);f=Zb(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;if(Gb(c+24|0,c+16|0)){while(1){if((GY(v[c+24>>2])|0)!=v[v[c+8>>2]>>2]){kp(c+24|0);if(Gb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[d+8>>2]=e;g=d,h=Zb(b),v[g>>2]=h;a:{if(Gb(d+8|0,d)){Pe(a,wb(v[d+8>>2]));break a}oi(a)}gb=d+16|0}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+8>>2]=c;v[d+4>>2]=v[a>>2];e=v[Fb(d+8|0,d+4|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){j=d,k=th(w[b|0]),t[j+15|0]=k;t[d+14|0]=192;t[d+13|0]=63;h=d+13|0;i=gb-16|0;gb=i;f=d+15|0;g=d+14|0;if(!Ij(f,g)){g=Ij(h,f)?h:f}gb=i+16|0;t[a|0]=w[g|0]<<1;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function Nt(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=BU(a,b);v[22692]=0;e=Q(867,a+12|0,b+12|0)|0;d=v[22692];v[22692]=0;b:{c:{if((d|0)!=1){v[22692]=0;Q(868,a+24|0,b+24|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;gc(e)}gc(c);S(a|0);L()}}function naa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=T(1958,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4319,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function YY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+28>>2]=c;a:{if(!Pb(b,c<<1)){break a}tc(d+28|0,65535);yf(a,x[d+28>>1]);e=d,f=Vb(a),v[e+16>>2]=f;e=d,f=Zb(a),v[e+8>>2]=f;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];c=d+24|0;if(!yp(b,c)){ED(c)}c=Ib(w[d+24|0]|w[d+25|0]<<8);u[a>>1]=c;if((c|0)==65535){u[a>>1]=65535}nf(d+16|0);if(Gb(d+16|0,d+8|0)){continue}break}}gb=d+32|0}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22692]=0;c=Q(70,e|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,1);c=By(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22692]=0;c=Q(70,e|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,1);c=Ay(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=b;d=gb-16|0;gb=d;g=d+8|0;e=b+1074376|0;c=hc(rf(223848),e,614);b=0;while(1){f=B(b,872);iu((c+f|0)+616|0,(e+f|0)+616|0);b=b+1|0;if((b|0)!=256){continue}break}b=v[Wi(g,c)>>2];gb=d+16|0;v[a+4>>2]=b;b=Bk(a+8|0);d=cd(a+20|0);v[22692]=0;_(1240,a|0);c=v[22692];v[22692]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;fP(d);eP(b);dP(a+4|0);S(c|0);L()}function baa(a,b){a=a|0;b=b|0;var c=0;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;b=AK(c,b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6897,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function aaa(a,b){a=a|0;b=b|0;var c=0;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22692]=0;b=zK(c,b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3678,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Saa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;c=+pa(1925,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4707,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function J8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-32|0;gb=b;c=vd(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=_z(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;v[22692]=0;b=Q(70,b+8|0,5175)|0;c=v[22692];v[22692]=0;b:{if((c|0)!=1){qc(a,b);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0)}S(c|0);L()}gb=b+32|0;return a|0}L()}function Is(a){var b=0,c=0;bo(a,1,10854);v[22692]=0;b=ga(145)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22692]=0;b=ga(146)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22692]=0;b=ga(147)|0;c=v[22692];v[22692]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22692]=0;_(148,a+20|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function qna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;aW(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);f=yb(c+16|0);if((f|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){$V(g)}d=-1;a:{if(!c){break a}d=0;if(!iW(e+8|0)){break a}d=Me(a,b,hW(e+8|0),jb)}gb=e- -64|0;return d|0}function lda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;FM(c+8|0,a,0);if(yb(c+8|0)){a=v[a+20>>2];v[a+148>>2]=-1;d=gb-16|0;gb=d;b=v[c+8>>2];f=v[c+12>>2];e=Zh(b,f);a=a+4|0;a:{if(e>>>0<=bg(a)>>>0){if(pc(a)>>>0<e>>>0){v[d+12>>2]=b;uO(d+12|0,pc(a));g=b;b=v[d+12>>2];Qg(g,b,v[a>>2]);or(a,b,f,e-pc(a)|0);break a}xm(a,Qg(b,f,v[a>>2]));break a}wv(a);vn(a,nh(a,e));or(a,b,f,e)}gb=d+16|0}gb=c+16|0}function Vaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=v[b+8>>2];c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,8117,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22692]=0;c=Q(70,e|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,2);c=bL(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22692]=0;c=Q(70,e|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,4);c=bL(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22692]=0;c=Q(70,e|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,2);c=aL(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22692]=0;c=Q(70,e|0,5318)|0;b=v[22692];v[22692]=0;if((b|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}yj(a,b,4);c=aL(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function tR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a+4>>2]=0;a:{if(b){b:{if(Wu(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}wb(a);e=Xu(d+16|0);v[22692]=0;f=Q(823,a|0,b|0)|0;g=v[22692];v[22692]=0;if((g|0)==1){break a}v[22692]=0;R(824,e|0,f|0);f=v[22692];v[22692]=0;if((f|0)==1){break a}v[e+4>>2]=b;LB(a,e);Ce(e)}uk(d,a);sp(d,b,w[c|0])}gb=d+32|0;return}a=P()|0;O()|0;Ce(e);S(a|0);L()}function Yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-112|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;DX(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);f=yb(c+16|0);if((f|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){CX(g)}d=-1;a:{if(!c){break a}d=0;if(!GX(e+8|0)){break a}d=Me(a,b,FX(e+8|0),jb)}gb=e+112|0;return d|0}function c_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-512|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;AE(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);f=yb(c+16|0);if((f|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){zE(g)}d=-1;a:{if(!c){break a}d=0;if(!GE(e+8|0)){break a}d=Me(a,b,FE(e+8|0),jb)}gb=e+512|0;return d|0}function c1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[e>>2]=c;c=2;a=cx(f+12|0,0,b,v[a+8>>2]);a:{if(a+1>>>0<2){break a}c=1;b=v[e>>2];g=d-b|0;d=a-1|0;if(g>>>0<d>>>0){break a}c=0;if(!d){break a}d=w[f+12|0];v[e>>2]=b+1;t[b|0]=d;a=a-2|0;if(!a){break a}b=f+12|0;while(1){d=w[b+1|0];g=v[e>>2];v[e>>2]=g+1;t[g|0]=d;b=b+1|0;a=a-1|0;if(a){continue}break}}gb=f+16|0;return c|0}function Qaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;c=A[b+16>>3];b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4671,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function $y(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;i=f+8|0;d=gb-16|0;gb=d;c=a;j=b;e=Yd(a);g=fc(a);h=gb-16|0;gb=h;if(e){wb(c);while(1){c=$M(e+16|0,j);g=c?g:e;e=v[(c?4:0)+e>>2];if(e){continue}break}}c=v[yc(h+8|0,g)>>2];gb=h+16|0;v[d+8>>2]=c;k=d,l=zh(a),v[k>>2]=l;a:{if(Rl(d+8|0,d)){if(!aN(wb(a),b,te(d+8|0))){break a}}c=zh(a)}gb=d+16|0;a=v[yc(i,c)>>2];gb=f+16|0;return a}function qi(a){var b=0,c=0;b=gb-16|0;gb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Np(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(mG(a,b)&3){case 0:a=Np(A[b>>3],A[b+8>>3],1);break a;case 1:a=Mp(A[b>>3],A[b+8>>3]);break a;case 2:a=-Np(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Mp(A[b>>3],A[b+8>>3])}gb=b+16|0;return a}function z7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;_J(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){j=z[a+24>>2];f=er(h,d,i);z[f>>2]=j*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function yaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=RK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10060,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ze(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>5>>>0){ZA(a,d,c);break c}b=wb(a);b=_R(e+8|0,Wq(a,ze(a)+d|0),ze(a),b);v[22692]=0;U(1089,b|0,d|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}ZR(a,b);WA(b)}gb=e+32|0;break a}a=P()|0;O()|0;WA(b);S(a|0);L()}return}if(b>>>0<d>>>0){iS(a,v[a>>2]+(b<<5)|0)}}function $Z(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;jE(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);f=yb(c+16|0);if((f|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){iE(g)}d=-1;a:{if(!c){break a}d=0;if(!wE(e+8|0)){break a}d=Me(a,b,vE(e+8|0),jb)}gb=e+48|0;return d|0}function xaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=QK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6441,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function waa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=PK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,5912,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=NK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6862,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function uaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=MK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2411,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function taa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=LK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4164,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function mo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;a:{while(1){g=h&255;if(iz(b,c,g>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;$A(a,f+15|0,f+14|0);break a}Dh(b,d);Dh(c,e);h=h+1|0;if(g>>>0<3){continue}break}h=f;g=w[b|0];if(no(g)>>>0>no(w[d|0])>>>0){Dh(b,d);Dh(c,e);g=w[b|0]}t[h+11|0]=g;$A(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}gb=f+16|0}function maa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=$n(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4132,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function laa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=FK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3939,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=EK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4007,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=ol(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,3841,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function iaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=cq(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,4509,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Taa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;b=UK(b);c=v[22692];v[22692]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2908,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+5|0]){while(1){if(!w[b+d|0]){aa(14513,6190,415,10446);L()}d=d+1|0;if((d|0)!=5){continue}break}d=0;t[c+28|0]=0;v[c+24>>2]=0;e=vd(c+8|0,c+24|0,5);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;cc(c+16|0,a,c);b:{if((yb(c+16|0)|0)!=5){break b}if(rd(c+24|0,b,5)){break b}Rb(a,5);d=1}gb=c+32|0;break a}aa(14492,6190,413,10446);L()}return d}function fZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-1968|0;gb=f;c=gb-32|0;gb=c;g=f+8|0;zD(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);e=yb(c+16|0);if((e|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){yD(g)}d=-1;a:{if(!c){break a}d=0;if(!CD(f+8|0)){break a}d=Me(a,b,1024,0)}gb=f+1968|0;return d|0}function MB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=mc(a);f=d,g=Vb(b),v[f+8>>2]=g;f=d,g=Zb(b),v[f>>2]=g;a:{if(Gb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){v[22692]=0;R(535,e|0,wb(a)|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}}kp(d+8|0);if(Gb(d+8|0,d)){continue}break}}gb=d+16|0;return}a=P()|0;O()|0;hd(e);S(a|0);L()}function zaa(a){a=a|0;var b=0,c=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22692]=0;c=SK(b);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,7373,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;e=c+8|0;d=b;if(lW(b,c+56|0)){b=c+58|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}else{b=0}ud(e,d,b);d=jc(c+32|0,c+8|0);b=w[c+56|0]|w[c+57|0]<<8|(w[c+58|0]<<16|w[c+59|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=w[c+60|0]|w[c+61|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8;En(a+8|0,d);xb(d);xb(c+8|0);gb=c- -64|0}function gB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-32|0;gb=f;v[f+8>>2]=c;g=f,h=mf(b),v[g+28>>2]=h;Qe(f+8|0,b,v[Fb(f+8|0,f+28|0)>>2]);v[22692]=0;b=Td(f+8|0);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[22692]=0;a=fa(361,a|0,b|0,c|0,d|0,e|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}zc(f+8|0);gb=f+32|0;return a|0}a=P()|0;O()|0;zc(f+8|0);S(a|0);L()}function oV(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Qy(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(vf(v[a+16>>2])>>>0);c=C(C(kb[v[v[a>>2]+204>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(kb[v[v[a>>2]+196>>2]](a))),z[d+4248>>2]=e;d=a,f=Xh(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(kb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(kb[v[v[a>>2]+192>>2]](a)|0)){b=oG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function NB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Fi(a,b,c,d);v[a>>2]=49656;d=mc(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=vf(c),v[e+4232>>2]=f;PY(a+4260|0,80,150,80,255);v[22692]=0;W(1517,a+44|0,2,2)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Uh(b);c=v[22692];v[22692]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);jf(b);S(a|0);L()}function Mda(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22692]=0;R(440,b+4|0,8);b=v[22692];v[22692]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(89088)|0;if((O()|0)==(ea(89088)|0)){Z(b|0)|0;vr(v[a+20>>2]+4|0);$();return}S(b|0);L()}
function E0(){var a=0;a:{if(t[464776]&1){break a}if(!Rd(464776)){break a}a=464608;while(1){a=Kb(a)+12|0;if((a|0)!=464776){continue}break}Qd(464776)}jd(464608,88052);jd(464620,88080);jd(464632,88108);jd(464644,88140);jd(464656,88180);jd(464668,88216);jd(464680,88244);jd(464692,88280);jd(464704,88296);jd(464716,88312);jd(464728,88328);jd(464740,88344);jd(464752,88360);jd(464764,88376)}function xpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;c=gb-32|0;gb=c;g=f+8|0;JD(c+24|0,g);h=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);e=yb(c+16|0);if((e|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){Pv(g)}d=-1;a:{if(!c){break a}d=0;if(!UX(f+8|0)){break a}d=Me(a,b,72,0)}gb=f+32|0;return d|0}function gI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;h=c;d=gb-16|0;gb=d;c=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){Xe(c,b);e=c;break b}f=sm(b)+1|0;e=Si(c,f);cf(c,e);pg(c,f);ee(c,b)}c=e;f=b;c:{d:{if(b){v[22692]=0;xI(c,h,f);c=v[22692];v[22692]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}v[d+12>>2]=0;Fe((b<<2)+e|0,d+12|0);gb=d+16|0;break a}$f();L()}gb=g+16|0;return a}function _F(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=v[b>>2];g=v[b+8>>2];e=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=e;v[d+24>>2]=c;v[d+28>>2]=e;Sh(d+32|0,d+16|0);c=v[v[f>>2]+28>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;kb[c|0](d+40|0,f,g,d+8|0);c=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=c;Sh(a,d);h=b,i=yb(a)+v[b+8>>2]|0,v[h+8>>2]=i;gb=d+48|0}function Hs(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}b=c&16384;a:{b:{if((d|0)!=256){if((d|0)!=4){break b}c=b?70:102;break a}c=b?69:101;break a}c=b?65:97;if((d|0)==260){break a}c=b?71:103}t[a|0]=c;return(d|0)!=260}function Fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=b;wb(b);d=a;f=rh(a);b:{c:{e=sc(b);if(e){v[22692]=0;R(806,d|0,e|0);g=v[22692];v[22692]=0;if((g|0)==1){break c}$R(d,v[c>>2],v[c+4>>2],e)}break b}a=P()|0;O()|0;$r(f);S(a|0);L()}v[22692]=0;Q(4,a+12|0,b+12|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;We(d);S(a|0);L()}}function rH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;c=Tb(d,c);v[22692]=0;U(2417,d+16|0,b|0,c|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){v[22692]=0;Q(2418,a|0,d+16|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}vb(d+16|0);vb(c);v[a>>2]=79164;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;gb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d+16|0)}vb(c);S(a|0);L()}function nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-608|0;gb=f;c=gb-32|0;gb=c;e=f;sU(c+24|0,f);h=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);g=yb(c+16|0);if((g|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){rU(e)}e=-1;a:{if(!d){break a}e=0;if(!vU(f)){break a}e=Me(a,b,uU(f),jb)}gb=f+608|0;return e|0}function Soa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-576|0;gb=f;c=gb-32|0;gb=c;e=f;oX(c+24|0,f);h=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);g=yb(c+16|0);if((g|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){nX(e)}e=-1;a:{if(!d){break a}e=0;if(!rX(f)){break a}e=Me(a,b,qX(f),jb)}gb=f+576|0;return e|0}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-192|0;gb=f;c=gb-32|0;gb=c;e=f;Mr(c+24|0,f);h=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);g=yb(c+16|0);if((g|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){QW(e)}e=-1;a:{if(!d){break a}e=0;if(!mX(f)){break a}e=Me(a,b,lX(f),jb)}gb=f+192|0;return e|0}function CJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=4?b<=0:1){a=ba(8)|0;v[22692]=0;c=Q(70,c|0,4903)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=xh(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;tq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function AJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=4?b<=0:1){a=ba(8)|0;v[22692]=0;c=Q(70,c|0,4924)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=xh(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;tq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function iF(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>27}return c}function cba(a){a=a|0;var b=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Xb(Bt(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2174,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;UJ(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){f=Wg(h,d,i);z[f>>2]=z[f>>2]*z[a+24>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function pJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[22692]=0;c=Q(70,c|0,7947)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function iZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;e=a;if(!Pb(b,c)){c=mf(b)}v[e>>2]=c;c=v[b>>2];a:{if(kb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];f=c,g=(kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[f+4>>2]=g;break a}c=a+8|0;Gk(c,v[a>>2]);if(bd(c)){break a}Vd(d+24|0,c);a=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=a;cc(d+16|0,b,d+8|0)}gb=d+32|0}function fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-80|0;gb=f;c=gb-32|0;gb=c;e=f;ZV(c+24|0,f);h=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);g=yb(c+16|0);if((g|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){kC(e)}e=-1;a:{if(!d){break a}e=0;if(!cT(f)){break a}e=Me(a,b,bT(f),jb)}gb=f+80|0;return e|0}function HF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=gb-16|0;gb=f;e=gb-16|0;gb=e;b=gb-16|0;gb=b;c=e;v[c+4>>2]=1;g=d+8|0;h=c,i=Nc(16,4),v[h+8>>2]=i;gb=b+16|0;b=v[c+8>>2];v[22692]=0;GF(b);b=v[22692];v[22692]=0;a:{if((b|0)!=1){b=Fp(c);Ew(g,dc(b),b);FF(c);gb=e+16|0;break a}a=P()|0;O()|0;FF(c);S(a|0);L()}gb=f+16|0;Uf(a,d+8|0);Ld(d+8|0);gb=d+16|0;v[a+8>>2]=0;Ud(a+12|0)}function G8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-48|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+16>>2]=b;v[d+20>>2]=e;v[d+32>>2]=b;v[d+36>>2]=e;Sh(d+40|0,d+16|0);b=Uf(d+24|0,c);v[22692]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(206,a|0,d+8|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){Ld(c);gb=d+48|0;return}a=P()|0;O()|0;Ld(c);S(a|0);L()}function rX(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-128|0;gb=f;c=gb-32|0;gb=c;e=f;dV(c+24|0,f);h=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);g=yb(c+16|0);if((g|0)==(h|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){cV(e)}e=-1;a:{if(!d){break a}e=0;if(!gV(f)){break a}e=Me(a,b,256,0)}gb=f+128|0;return e|0}function oJ(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+60128>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+60128>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+60128>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+60128>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+60128>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function lpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=zi(d,a,1);wb(a);ep(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Yg(d+8|0,nh(a,pc(a)+1|0),pc(a),c);ep(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+1;v[22692]=0;R(396,a|0,c|0);a=v[22692];v[22692]=0;a:{if((a|0)!=1){be(c);gb=d+32|0;break a}a=P()|0;O()|0;be(c);S(a|0);L()}}function Gla(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!bD(a,b+16|0)){break a}c=0;if(!MU(b+16|0)){break a}c=-1;if(!_j(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+8|0;c=(c|0)==((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))&2139062143)}a=c;gb=b+32|0;return a|0}function aZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,10);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function iG(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=gb-16|0;gb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=op(d,g+i|0,f+15|0);if(!d){break a}if(!No(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}gb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function Yaa(a,b){a=a|0;b=b|0;var c=0;v[22692]=0;_(1918,a|0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2752,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;c=rf(64);v[22692]=0;e=T(1301,c|0)|0;f=v[22692];v[22692]=0;a:{if((f|0)!=1){c=ks(d,e);e=v[c>>2];v[22692]=0;a=W(1515,e|0,a|0,b|0)|0;b=v[22692];v[22692]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Wz(d+8|0);break b}a=P()|0;O()|0;Hg(c);break a}ni(d+8|0,c)}Hg(c);gb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Xb(c)}S(a|0);L()}function EH(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=gb-16|0;gb=c;b=ba(16)|0;a=gb-16|0;gb=a;a:{if(t[460776]&1){break a}if(!Rd(460776)){break a}Qd(460776)}sd(a+8|0,1,90444);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;gb=a+16|0;v[22692]=0;Q(2370,b|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){ia(b|0,78476,2371);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;wb(a);v[c+12>>2]=268435455;v[22692]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22692];v[22692]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}wb(a);c=b;if(c>>>0>268435455){pd(8399);L()}c=Nc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<4)|0,v[f>>2]=g;bI(a,0)}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=51432;v[22692]=0;W(1517,a+44|0,2,2)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Uh(b);c=v[22692];v[22692]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function Ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;GU(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))==1414807888){GU(a,c+11|0);t[b|0]=1;a=0}else{a=1}b=gb-16|0;gb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Tb(b,a);v[22692]=0;d=T(862,a|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break b}vb(a)}gb=b+16|0;break a}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=c+16|0;return d|0}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){pG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=qs(c+8|0,Qw(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22692]=0;In(d,f,b);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22692]=0;Hn(e,a);b=v[22692];v[22692]=0;if((b|0)==1){break b}ps(a);gb=c+32|0;break a}b=P()|0;O()|0;ps(a);S(b|0);L()}}function PQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){pG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=qs(c+8|0,Qw(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22692]=0;In(d,f,b);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22692]=0;Hn(e,a);b=v[22692];v[22692]=0;if((b|0)==1){break b}pu(a);gb=c+32|0;break a}b=P()|0;O()|0;pu(a);S(b|0);L()}}function vda(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Vca(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[v[a+20>>2]+148>>2]=-1;v[22692]=0;mn(c+8|0,a+4228|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){b=v[a+20>>2];d=v[c+8>>2];e=v[c+12>>2];v[22692]=0;U(1651,b+4|0,d|0,e|0);b=v[22692];v[22692]=0;if((b|0)!=1){break b}}b=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;vr(v[a+20>>2]+4|0);$()}gb=c+16|0;return}S(b|0);L()}function KJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;if(!w[a+20|0]){if(!(kb[v[v[a>>2]+40>>2]](a)|0)){d=a+4|0;while(1){JJ(a,65536);c=vd(b+16|0,kc(d,v[a+16>>2]),65536);e=v[v[a>>2]+44>>2];f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;kb[e|0](b+24|0,a,b+8|0);g=a,h=yb(b+24|0)+v[a+16>>2]|0,v[g+16>>2]=h;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){continue}break}}t[a+20|0]=1}gb=b+32|0}function Lq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;e=Vb(a);f=Zb(a);c=gb-16|0;gb=c;v[c>>2]=f;v[c+8>>2]=e;if(Gb(c+8|0,c)){while(1){d=A[v[c+8>>2]>>3]+d;vu(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0;g=b,h=Vb(a),v[g+8>>2]=h;g=b,h=Zb(a),v[g>>2]=h;if(Gb(b+8|0,b)){d=-d;while(1){a=v[b+8>>2];d=A[a>>3]+d;A[a>>3]=d;vu(b+8|0);if(Gb(b+8|0,b)){continue}break}}gb=b+16|0}function hB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+8>>2]=c;f=e,g=mf(b),v[f+28>>2]=g;Qe(e+8|0,b,v[Fb(e+8|0,e+28|0)>>2]);v[22692]=0;b=Td(e+8|0);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[22692]=0;ca(903,a|0,b|0,c|0,d|0)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}zc(e+8|0);gb=e+32|0;return 1}a=P()|0;O()|0;zc(e+8|0);S(a|0);L()}function Lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[22692]=0;vC(f,b,c);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}Zc(d);gb=e+16|0;return}a=P()|0;O()|0;Zc(d);S(a|0);L()}function I0(){var a=0;a:{if(t[464600]&1){break a}if(!Rd(464600)){break a}a=464432;while(1){a=Kb(a)+12|0;if((a|0)!=464600){continue}break}Qd(464600)}Vc(464432,2336);Vc(464444,2343);Vc(464456,2309);Vc(464468,2317);Vc(464480,2300);Vc(464492,2350);Vc(464504,2327);Vc(464516,6854);Vc(464528,7188);Vc(464540,8538);Vc(464552,10125);Vc(464564,2595);Vc(464576,8005);Vc(464588,3641)}function sna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,20);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[22692]=0;R(342,e|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[c>>2]+20|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}Zc(c);gb=d+16|0;return}a=P()|0;O()|0;Zc(c);S(a|0);L()}function eca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Hi(d+12|0);a:{b:{switch(b-1|0){default:c=z[d+12>>2];break a;case 0:c=ge(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4212>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b}}c=C(ge(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Qy(a)}gb=d+16|0}function Lca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Hi(d+12|0);a:{b:{switch(b-3|0){default:c=z[d+12>>2];break a;case 0:c=ge(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4220>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b}}c=C(ge(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Qy(a)}gb=d+16|0}function jA(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Fm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298260|0;if(!Dd(a)){break a}Ni(v[a>>2],b,0)}}function Zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-1120|0;gb=e;c=gb-32|0;gb=c;XU(c+24|0,e+8|0);g=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);f=yb(c+16|0);if((f|0)==(g|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=-1;a:{if((f|0)!=(g|0)){break a}d=0;if(!_U(e+8|0)){break a}d=Me(a,b,ZU(e+8|0),jb)}gb=e+1120|0;return d|0}function fq(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){jM(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=Yg(c+8|0,nh(a,pc(a)+1|0),pc(a),d);f=v[a+8>>2];v[22692]=0;kl(d,f,b);b=v[22692];v[22692]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+1;v[22692]=0;R(120,e|0,a|0);b=v[22692];v[22692]=0;if((b|0)==1){break b}be(a);gb=c+32|0;break a}b=P()|0;O()|0;be(a);S(b|0);L()}}function aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;a:{a=v[a+1298424>>2];b:{if(a){kb[v[v[a>>2]+8>>2]](a,b,c);break b}v[d+8>>2]=0;if(!zF(au(d+8|0),b)){break b}v[d+8>>2]=0;au(d+8|0);v[d+24>>2]=0;a=au(d+24|0);SO(d+8|0,6264,8078,133,42);v[22692]=0;ha(33,a|0,d+8|0,b|0,10538,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}}gb=d+32|0;return}a=P()|0;O()|0;S(a|0);L()}function Xaa(a){a=a|0;var b=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,6032,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function rA(a,b,c,d){var e=0,f=0;e=gb-32|0;gb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e+31|0]=0;u[a>>1]=w[(b&15)+39088|0];t[a+2|0]=w[e+31|0];break a}t[e+30|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+30|0]=1;f=f<<1}Db(e+16|0,b+1074312|0,66);if(!(!Cb(e+16|0)|!d)){u[e+14>>1]=0;mC(a,e+14|0,e+30|0);break a}u[e+12>>1]=f<<4;mC(a,e+12|0,e+30|0)}gb=e+32|0}function ml(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=gb-32|0;gb=c;f=uc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Gc(c+8|0,c);gb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=e+16|0;return a}function gN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!Xf(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Ak(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}wl(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;hq(a,c+8|0);f=z[c+8>>2];g=Lb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Xf(v[v[a>>2]-12>>2]+a|0)}d=e;gb=c+16|0;return d}function fN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!Xf(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;_f(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}wl(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;hq(a,c+8|0);f=z[c+8>>2];g=Lb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Xf(v[v[a>>2]-12>>2]+a|0)}a=e;gb=c+16|0;return a}function wm(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+69680|0]}if((a|0)<=511){return t[(a>>>5|0)+69680|0]+5|0}return t[(a>>>10|0)+69680|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+69680|0]+15|0}return t[(a>>>20|0)+69680|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+69680|0]+25|0}a=t[(a>>>30|0)+69680|0]+30|0}else{a=0}return a}function EU(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|(w[a+65|0]!=1?w[a+65|0]!=16:0))){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>=128){break a}c=gb-16|0;gb=c;d=kE(b,a);gb=c+16|0;a=d?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function Zaa(a){a=a|0;var b=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return je(a)|0}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,9383,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();return 0}return je(18699)|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+f;a:{a=v[d>>2];if((a|0)!=v[d+4>>2]){while(1){v[22692]=0;R(1473,a|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}a=v[d>>2]+52|0;v[d>>2]=a;if(v[d+4>>2]!=(a|0)){continue}break}}Zc(d);gb=e+16|0;return}a=P()|0;O()|0;Zc(d);S(a|0);L()}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Qp((f|0)==2491?0:v[a>>2],d);if(g){if((f|0)!=2491){ce(a)}v[e+4>>2]=2440;f=he(e+8|0,g,e+4|0);NG(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);gb=e+16|0;return}Ps();L()}function bW(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;v[f+12>>2]=a;d=B(B(a,d),2500);a:{if(!(!c|b)){break a}if(!(!b|!a)){tc(f+12|0,10);d=B(w[v[f+12>>2]+29008|0],1e4);break a}e=+(a>>>0);b:{if(a-1>>>0<=9){e=7338401.379310345/e;if(!(e<4294967296&e>=0)){break b}d=~~e>>>0;break a}e=e*37878.78787878787;if(!(e<4294967296&e>=0)){break b}d=~~e>>>0;break a}d=0}gb=f+16|0;return d}function yJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=1?b<0:1){a=ba(8)|0;v[22692]=0;c=Q(70,c|0,8960)|0;d=v[22692];v[22692]=0;if((d|0)==1){break c}qc(a,c);v[22692]=0;U(184,a|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=xh(b*256);v[v[a+32>>2]+1074456>>2]=d;gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function d7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Ep(a);v[a>>2]=59200;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=dc(a);Dp(c);v[c>>2]=59564;mc(c+4|0);t[c+20|0]=0;v[c+16>>2]=0;v[c>>2]=59364;b=v[d+4>>2];v[c+24>>2]=v[d>>2];v[c+28>>2]=b;b=v[d+12>>2];v[c+32>>2]=v[d+8>>2];v[c+36>>2]=b;t[c+40|0]=0;gb=d+16|0;return a|0}function LF(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=119304647;v[22692]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22692];v[22692]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Tk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=119304647;v[22692]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22692];v[22692]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=119304648){pd(8399);L()}c=Nc(B(c,36),4);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,36)|0,v[f>>2]=g}function hY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=89478485;v[22692]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22692];v[22692]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=gn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Bq(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function npa(a){a=a|0;var b=0,c=0,d=0,e=0;c=rh(a);v[22692]=0;_(514,a|0);d=v[22692];v[22692]=0;if((d|0)!=1){d=gb-16|0;gb=d;c=d;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+32768;b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return a|0}a=P()|0;O()|0;$C(c);S(a|0);L()}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Qp((f|0)==2491?0:v[a>>2],d);if(g){if((f|0)!=2491){ce(a)}v[e+4>>2]=2440;f=he(e+8|0,g,e+4|0);NG(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];gb=e+16|0;return}Ps();L()}function rka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=4925421;v[22692]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22692];v[22692]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=4925422){pd(8399);L()}c=Nc(B(c,872),8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,872)|0,v[f>>2]=g}function kL(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=Mf(e);if((f|0)==(Ab(c)|0)){v[22692]=0;c=fa(547,c|0,0,-1,e|0,f|0)|0;e=v[22692];v[22692]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Bb();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=d+16|0;return a}function Rka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=477218588;v[22692]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22692];v[22692]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=477218589){pd(8399);L()}c=Nc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,9)|0,v[f>>2]=g}function Fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=715827882;v[22692]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22692];v[22692]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=715827883){pd(8399);L()}c=Nc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,6)|0,v[f>>2]=g}function Ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Bg(c+24|0,a);YU(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;b=gb-16|0;gb=b;a=1;d=c;e=c+8|0;if(v[e+4>>2]==v[c+4>>2]){f=v[d+4>>2];a=b;d=v[d>>2];v[a>>2]=d;v[a+4>>2]=f;v[a+8>>2]=d;v[a+12>>2]=f;a=(EW(e,a)|0)!=0}gb=b+16|0;gb=c+32|0;return a|0}function KI(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function JE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<5){a:{if(!b){break a}if(!Pb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Lg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;return d}aa(8467,6190,136,11385);L()}function MY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=2147483647;v[22692]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22692];v[22692]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Ng(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function DJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-32>>>0>=481){b=ba(8)|0;v[22692]=0;c=Q(70,c|0,6474)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function oO(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075785|0];if((c|0)>=0){gP(a,b,(d|0)==32,((w[(B(b,872)+a|0)+1075836|0]<<5)+a|0)+901692|0,c&255);return}gP(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function oD(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=153391689;v[22692]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22692];v[22692]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Yi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-224|0;gb=e;c=gb-32|0;gb=c;vX(c+24|0,e);g=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;fd(c+16|0,d,c);f=yb(c+16|0);if((f|0)==(g|0)){ad(d,yb(c+24|0))}gb=c+32|0;d=-1;a:{if((f|0)!=(g|0)){break a}d=0;if(!zX(e)){break a}d=Me(a,b,yX(e),jb)}gb=e+224|0;return d|0}function FB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=357913941;v[22692]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22692];v[22692]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=sg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function at(a,b,c,d){var e=0,f=0;e=gb-160|0;gb=e;hc(e+8|0,74280,144);a:{b:{if(b-1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=QI(e+8|0,c,d,2272,2273);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[115173]=61;a=-1}gb=e+160|0;return a}function zz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=lq(b);while(1){j=a;k=c;g=((e<<12^-1)&28672)+(e>>>3|0)|0;if((g|0)!=16384){f=+(g-16384|0);d=f*.000244140625;f=lq(K(f*-152587890625e-16*d+1)*b);d=h*d;d=f*qi(d)/(d*i)}else{d=1}l=j,m=HT(k*d),u[l>>1]=m;a=a+2|0;e=e+1|0;if((e|0)!=32768){continue}break}}function VD(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=jqa(w[a+3|0],0,18,0);d=d+c|0;b=jb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}jb=a;return b}function hz(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function YK(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;f=d;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<=-1){break a}if((kb[c|0](b,0,0,2)|0)<=-1){break a}d=kb[a|0](b)|0;a=jb;kb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=CA(d,a)}return g}kb[c|0](b,e,f,0)|0;return 0}function EJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-1>>>0>=65535){b=ba(8)|0;v[22692]=0;c=Q(70,c|0,2940)|0;a=v[22692];v[22692]=0;if((a|0)==1){break c}qc(b,c);v[22692]=0;U(184,b|0,54920,1920);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074416>>2]=b;gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<11)+e;a:{if(v[c>>2]!=v[c+4>>2]){while(1){a=v[c>>2];v[22692]=0;Vy(a);a=v[22692];v[22692]=0;if((a|0)==1){break a}a=v[c>>2]+2048|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}Zc(c);gb=d+16|0;return}a=P()|0;O()|0;Zc(c);S(a|0);L()}function y7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Vg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;ZJ(a,c);gb=c+16|0}function v7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Vg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;XJ(a,c);gb=c+16|0}function sea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;u[a>>1]=0;c=mc(a+4|0);d=mc(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=Bk(a+52|0);Eg(c);u[a+28>>1]=65472;v[22692]=0;v[b+12>>2]=1065353216;R(1483,c|0,b+12|0);g=v[22692];v[22692]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Eg(d);gb=b+16|0;return a|0}a=P()|0;O()|0;UW(f);vb(e);Lc(d);Lc(c);S(a|0);L()}function p7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Vg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;TJ(a,c);gb=c+16|0}function jU(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if(w[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Vg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;cK(a,c);gb=c+16|0}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10331,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{e=Ae(a);b:{if(e>>>0>1){break b}c:{if(e){v[22692]=0;U(504,d|0,a|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){gp(b,d);gc(d);break c}a=V(27348)|0;if((O()|0)!=(ea(27348)|0)){break a}Z(a|0)|0;$();break b}if(!Pb(a,c)){break b}TX(a,b,c)}f=pc(b)>>>0>=c>>>0}gb=d+16|0;return f|0}S(a|0);L()}function hQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b|0])+g|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+2|0])+d|0)+(zb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function eQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b+1|0])+g|0)+(zb(w[b|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+3|0])+d|0)+(zb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function _na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b>>2];e=v[b>>2]+yb(b)|0;f=Gg(a);v[22692]=0;b=Zh(d,e);c=v[22692];v[22692]=0;a:{b:{if((c|0)==1){break b}if(!b){break a}v[22692]=0;R(515,a|0,b|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}v[22692]=0;Y(661,a|0,d|0,e|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;dm(f);S(a|0);L()}}function Rm(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;if(-17-b>>>0>=c>>>0){i=Jb(a);k=a;a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Pk(v[Mc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=mi(k,j);if(e){Og(c,i,e)}d=d-(e+f|0)|0;if(d){Og((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){Uk(a,i,b)}cf(a,c);pg(a,j);gb=h+16|0;return}$f();L()}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=52816;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22692]=0;W(1517,a+44|0,2,2)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Uh(b);c=v[22692];v[22692]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[nc(b,0)|0]!=(fg(43)&255)){if(w[nc(b,0)|0]!=(fg(45)&255)){break b}}c=c+1|0;Ne(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Hd(d,d+8|0);f=Ab(b);Nz(b,v[e>>2],c-f|0,fg(48))}Dc(a,b);gb=d+16|0}function cz(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){wb(a);v[22692]=0;R(1473,b|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=f+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function O_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;f=gb-16|0;gb=f;e=gb-16|0;gb=e;v[f+4>>2]=1;i=f,j=Nc(32,4),v[i+8>>2]=j;gb=e+16|0;e=f;h=v[e+8>>2];v[22692]=0;ca(223,h|0,b|0,c|0,d|0)|0;b=v[22692];v[22692]=0;a:{if((b|0)!=1){b=a;a=Fp(e);Ew(b,dc(a),a);sF(e);gb=f+16|0;break a}a=P()|0;O()|0;sF(e);S(a|0);L()}gb=g+16|0}function Nn(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;Fc(d+8|0,b);v[22692]=0;b=T(2465,d+8|0)|0;e=v[22692];v[22692]=0;a:{if((e|0)==1){break a}v[22692]=0;e=T(2474,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}v[c>>2]=e;v[22692]=0;R(2475,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}Wb(d+8|0);gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);S(a|0);L()}function Lda(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((pc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}Ry(a,b)}Nt(a)}function Bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22692]=0;_(771,a|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}a=a+24|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function $5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Ab(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Fb(f+12|0,f)>>2],v[g+4>>2]=h;b=No(Jb(a)+b|0,d,v[Fb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}gb=f+16|0;return b|0}Tn();L()}function bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=mc(a);e=d,f=Vb(b),v[e+8>>2]=f;e=d,f=Zb(b),v[e>>2]=f;a:{if(Gb(d+8|0,d)){while(1){b=v[d+8>>2];if((GY(b)|0)==(c|0)){v[22692]=0;R(535,a|0,wb(b)|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}}kp(d+8|0);if(Gb(d+8|0,d)){continue}break}}gb=d+16|0;return}b=P()|0;O()|0;hd(a);S(b|0);L()}function Pn(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;Fc(d+8|0,b);v[22692]=0;b=T(2436,d+8|0)|0;e=v[22692];v[22692]=0;a:{if((e|0)==1){break a}v[22692]=0;e=T(2448,b|0)|0;f=v[22692];v[22692]=0;if((f|0)==1){break a}t[c|0]=e;v[22692]=0;R(2449,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}Wb(d+8|0);gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);S(a|0);L()}function Aq(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function iI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;if(1073741807-b>>>0>=c>>>0){g=Jb(a);i=a;a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=sm(v[Mc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Si(i,h);if(e){wi(c,g,e)}d=d-e|0;if(d){e=e<<2;wi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){ai(a,g,b)}cf(a,c);pg(a,h);gb=f+16|0;return}$f();L()}function eg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;c=a;a:{if(!De(b)){v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;break a}g=v[b>>2];b:{c:{d=v[b+4>>2];d:{if(d>>>0<=10){b=c;Xe(c,d);break d}if(d>>>0>4294967279){break c}f=Pk(d)+1|0;b=mi(c,f);cf(c,b);pg(c,f);ee(c,d)}Og(b,g,d+1|0);break b}$f();L()}}gb=e+16|0;return a|0}function qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22692]=0;DT(a);e=v[22692];v[22692]=0;if((e|0)==1){break a}a=a+872|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function iQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+2|0])|zb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function fQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+3|0])|zb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Vw(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[Jb(b)|0]!=(fg(43)&255)){if(w[Jb(b)|0]!=(fg(45)&255)){break b}}c=c+1|0;Ne(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Hd(d,d+8|0);f=Ab(b);RN(b,v[e>>2],c-f|0,fg(48))}Dc(a,b);gb=d+16|0}function R8(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;a=mc(a);v[22692]=0;R(2052,b+16|0,0);c=v[22692];v[22692]=0;a:{b:{if((c|0)!=1){c=Vb(b+16|0);d=Zb(b+16|0);e=v[yc(b+8|0,a)>>2];v[22692]=0;U(2053,c|0,d|0,e|0);c=v[22692];v[22692]=0;if((c|0)==1){break b}Lc(b+16|0);gb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;Lc(b+16|0)}yd(a);S(c|0);L()}function Oq(a,b){var c=0,d=0;if(a-1>>>0<268435456){a=a+208|0;jqa(b,0,a,0);a=jb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[22692]=0;b=T(2416,a|0)|0;c=v[22692];v[22692]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;X(20);c=v[22692];v[22692]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}if(!b){break a}d=Qb(b,0,a)- -64|0}return d}function El(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c|0]&32)){break a}g=d,h=zd(b),v[g+8>>2]=h;g=d,h=ef(b),v[g>>2]=h;if(!Gb(d+8|0,d)){break a}while(1){e=v[d+8>>2];c=t[e|0];f=fg(97);b:{if((c|0)<(f|0)){break b}if((fg(122)|0)<(c|0)){break b}g=e,h=fg(65)+(c-f|0)|0,t[g|0]=h}Ne(d+8|0);if(Gb(d+8|0,d)){continue}break}}Dc(a,b);gb=d+16|0}function GE(a){var b=0,c=0,d=0,e=0,f=0;a:{if(w[a+110|0]>64|((w[a|0]|w[a+1|0]<<8)!=20042?(w[a|0]|w[a+1|0]<<8)!=26217:0)|(t[a+112|0]<0|w[a+111|0]>128)){break a}while(1){e=0;d=a+c|0;b=t[d+113|0];f=(b|0)>-1;if(!((b&255)>>>0<254?f:1)){break a}b=w[d+241|0];if(!b&f|b>>>0>15|w[d+369|0]>=64){break a}e=1;c=c+1|0;if((c|0)!=128){continue}break}}return e}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=53048;v[22692]=0;W(1517,a+44|0,2,2)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Uh(b);c=v[22692];v[22692]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function $U(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=jqa(w[a+30|0],0,37,0);c=jb;d=b;b=a+24|0;b=jqa(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=jb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}jb=a;return b}function aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22692]=0;_(1918,a|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1903;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,10361,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function U4(a){a=a|0;a:{v[22692]=0;T(2391,463032)|0;a=v[22692];v[22692]=0;b:{if((a|0)==1){break b}v[22692]=0;T(2392,463116)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}v[22692]=0;T(2391,463368)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}v[22692]=0;T(2392,463452)|0;a=v[22692];v[22692]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Bb();L()}}function Q$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb+-64|0;gb=d;e=1;a:{if(Rg(a,b,0)){break a}e=0;if(!b){break a}b=Yw(b,89628,89676);e=0;if(!b){break a}Qb(d+8|4,0,52);v[d+56>>2]=1;v[d+20>>2]=-1;v[d+16>>2]=a;v[d+8>>2]=b;kb[v[v[b>>2]+28>>2]](b,d+8|0,v[c>>2],1);a=v[d+32>>2];if((a|0)==1){v[c>>2]=v[d+24>>2]}e=(a|0)==1}a=e;gb=d- -64|0;return a|0}function K7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a:{b:{if((xy(a)|0)!=1){break b}if((vK(a)|0)!=(b|0)){break b}d=a+120|0;Ai(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[13838];v[a+8>>2]=v[13837];v[a+12>>2]=e;e=v[13836];v[a>>2]=v[13835];v[a+4>>2]=e;kb[v[Rh(a,Xg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break a}uK(a,1,b)}gb=c+16|0}function Iw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+8>>2]=b;v[d+12>>2]=e;v[d+16>>2]=b;v[d+20>>2]=e;Sh(d+24|0,d+8|0);v[22692]=0;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;R(211,a|0,d|0);b=v[22692];v[22692]=0;if((b|0)!=1){v[a+8>>2]=0;Uf(a+12|0,c);Ld(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Ld(c);S(a|0);L()}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;xU(c+24|0,f);g=yb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(g|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){wU(f)}if(a){e=EU(b+8|0)}gb=b+160|0;return e|0}function pK(a,b,c){var d=0,e=0,f=0;a:{d=v[c>>2];c=a;e=rh(c);b:{if(!d){break b}v[22692]=0;R(2093,c|0,d|0);f=v[22692];v[22692]=0;if((f|0)!=1){v[22692]=0;nK(c,d);d=v[22692];v[22692]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;zl(e);S(a|0);L()}v[22692]=0;b=mK(b);d=v[22692];v[22692]=0;if((d|0)!=1){v[a+12>>2]=b;break a}a=P()|0;O()|0;zl(c);S(a|0);L()}}function aqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-624|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;zY(c+24|0,f);g=yb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(g|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){yY(f)}if(a){e=BY(b+8|0)}gb=b+624|0;return e|0}function aj(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;f=dg(a,c);re(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!f){if(ld(a,5)){break a}}g=v[a+28>>2];d=0;rE(b,v[e+24>>2]);if(v[e+24>>2]){while(1){VA(g,rc(b,d));d=d+1|0;if(d>>>0<y[e+24>>2]){continue}break}}}Wf(a,f,c,e+16|0);gb=e+32|0}function q5(a,b){a=a|0;b=b|0;var c=0;c=v[a+24>>2];if(c>>>0>y[a+44>>2]){v[a+44>>2]=c}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(He(b,-1)){Rn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Us(b)|0}if(!(w[a+48|0]&16)){if(!He(th(b),t[v[a+12>>2]-1|0])){break a}}Rn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=th(b);t[v[a+12>>2]]=c;return b|0}return-1}function o2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=gb-16|0;gb=d;b=a;a:{if(!De(f)){v[b+8>>2]=v[f+8>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){Xe(a,c);break d}if(c>>>0>1073741807){break c}f=sm(c)+1|0;b=Si(a,f);cf(a,b);pg(a,f);ee(a,c)}wi(b,e,c+1|0);break b}$f();L()}}gb=d+16|0}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;vv(c+24|0,f);g=yb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(g|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){LX(f)}if(a){e=OX(b+8|0)}gb=b+32|0;return e|0}function OA(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;Qv(c+24|0,f);g=yb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(g|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){mW(f)}if(a){e=xW(b+8|0)}gb=b+16|0;return e|0}function E_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;a:{if(y[b+16>>2]<=c>>>0){hk(a,d,0);break a}f=v[b+4>>2];g=v[b+12>>2];h=e,i=yb(d),v[h+20>>2]=i;v[e+16>>2]=v[b+16>>2]-c;hk(e+24|0,d,v[Fb(e+20|0,e+16|0)>>2]);b=v[v[f>>2]+28>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kb[b|0](a,f,c+g|0,e+8|0)}gb=e+32|0}function Yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Uf(d+16|0,c);v[22692]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(764,a|0,d+8|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){Ld(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Ld(c);S(a|0);L()}function Nq(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;t[d+15|0]=b;a:{b:{c:{d:{if(De(a)){c=ak(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Rm(a,c,1,c,c,0,0);b=c;if(De(a)){break b}}c=a;Xe(a,b+1|0);break a}c=v[a>>2];ee(a,b+1|0)}a=b+c|0;Bd(a,d+15|0);t[d+14|0]=0;Bd(a+1|0,d+14|0);gb=d+16|0}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;xk(a);i=v[b+4>>2];f=b+4|0;wk(wb(a),v[a>>2],c,f);j=wb(a);g=b+8|0;d=g;h=v[a+4>>2];if((h|0)!=(c|0)){e=v[d>>2];while(1){cn(j,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((h|0)!=(c|0)){continue}break}}xc(a,f);xc(a+4|0,g);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_m(a,Nb(a));return i|0}function tu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=d+8|0;b=gb-16|0;gb=b;v[22692]=0;c=a;MQ(c+4|0);f=v[22692];v[22692]=0;a:{b:{c:{if((f|0)!=1){v[22692]=0;v[b+12>>2]=0;df(c+8|0,b+12|0,e);e=v[22692];v[22692]=0;if((e|0)!=1){break c}break b}break b}g=c,h=fc(c),v[g>>2]=h;gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=d+16|0;return a}function ls(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Uf(d+16|0,c);v[22692]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(206,a|0,d+8|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){Ld(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Ld(c);S(a|0);L()}function Y5(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(De(a)){c=ak(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=1;b=w[a+11|0];if((b|0)!=1){break c}}iI(a,c,1,c,c);b=c;if(De(a)){break b}}c=a;Xe(a,b+1|0);break a}c=v[a>>2];ee(a,b+1|0)}a=(b<<2)+c|0;Fe(a,d+12|0);v[d+8>>2]=0;Fe(a+4|0,d+8|0);gb=d+16|0}function SX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Uf(d+16|0,c);v[22692]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(513,a|0,d+8|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){Ld(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Ld(c);S(a|0);L()}function uH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;e=b+16|0;a:{while(1){c=v[a+36>>2];f=kb[v[v[c>>2]+20>>2]](c,v[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=v[b+4>>2]-(b+8|0)|0;if((d|0)!=(Dk(b+8|0,1,d,v[a+32>>2])|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}c=it(v[a+32>>2])?-1:0}gb=b+16|0;return c|0}function Sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb+-64|0;gb=d;g=d+8|0;e=b;if(lp(b,d+56|0)){f=Zm(d+56|0)}ud(g,e,f);e=a;a=jc(d+32|0,d+8|0);e=Ul(e,d+56|0,a);xb(a);xb(d+8|0);a:{a=(f>>>0)%(c>>>0)|0;if(!a){break a}v[22692]=0;Q(318,b|0,c-a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Zd(e);S(a|0);L()}gb=d- -64|0}function jf(a){a=a|0;var b=0,c=0;v[a>>2]=50124;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;b=a+44|0;Lc(b+36|0);Lc(b+24|0);Jt(b+12|0);Jt(b);return a|0}function Xr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;d=Jb(b);e=Jb(b);g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;Qg(d,e+v[Fb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Fb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Do(b+d|0,e+f|0,c+7|0);gb=c+16|0;return a|0}function IE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<3){a:{if(!b){break a}if(!Pb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Lg(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}gb=c+16|0;return d}aa(8467,6190,136,11385);L()}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;xC(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(144,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Jn(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(144,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Iq(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function fqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Kh(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function dK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14072];v[c+8>>2]=v[14071];v[c+12>>2]=g;g=v[14070];v[c>>2]=v[14069];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function cK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14076];v[c+8>>2]=v[14075];v[c+12>>2]=g;g=v[14074];v[c>>2]=v[14073];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=Pb(a,6);a:{if(!e){a=gb-16|0;gb=a;d=gb-16|0;gb=d;f=b+6|0;while(1){Hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,6);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return e|0}function ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-208|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;$T(c+24|0,b);f=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(f|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){_T(h)}if(a){e=hU(b)}gb=b+208|0;return e|0}function _J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14277];v[c+8>>2]=v[14276];v[c+12>>2]=g;g=v[14275];v[c>>2]=v[14274];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function ZJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14281];v[c+8>>2]=v[14280];v[c+12>>2]=g;g=v[14279];v[c>>2]=v[14278];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function YJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14484];v[c+8>>2]=v[14483];v[c+12>>2]=g;g=v[14482];v[c>>2]=v[14481];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function XJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14488];v[c+8>>2]=v[14487];v[c+12>>2]=g;g=v[14486];v[c>>2]=v[14485];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;tX(c+24|0,b);f=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(f|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){sX(h)}if(a){e=uX(b)}gb=b+160|0;return e|0}function UJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14691];v[c+8>>2]=v[14690];v[c+12>>2]=g;g=v[14689];v[c>>2]=v[14688];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function TJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ll(v[a+8>>2]);Ai(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14695];v[c+8>>2]=v[14694];v[c+12>>2]=g;g=v[14693];v[c>>2]=v[14692];v[c+4>>2]=g;kb[v[Rh(c,Xg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-48|0;gb=c;a:{if(Wu(a)>>>0<b>>>0){wb(a);d=Xu(c+32|0);v[22692]=0;R(827,d|0,b|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}uk(c+16|0,a);Ll(c+8|0,a);v[22692]=0;U(828,d|0,c+16|0,c+8|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}LB(a,d);Ce(d)}gb=c+48|0;return}a=P()|0;O()|0;Ce(d);S(a|0);L()}function HN(a,b,c,d){var e=0,f=0,g=0;e=gb-32|0;gb=e;g=v[a+20>>2];f=x[a+34>>1];v[22692]=0;f=f&65;v[e+16>>2]=f;v[e+8>>2]=f^65;ka(1457,d|0,a|0,b|0,c|0,e+16|0,e+8|0);d=v[22692];v[22692]=0;a:{if((d|0)==1){break a}v[a>>2]=c;v[a+20>>2]=b;v[22692]=0;Pq(g);a=v[22692];v[22692]=0;if((a|0)==1){break a}gb=e+32|0;return}a=P()|0;O()|0;S(a|0);L()}function $ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,40);gb=d+16|0;d=yb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;cc(c+16|0,a,c);e=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,40);gb=c+16|0}return a|0}function wG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Kh(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(144,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function uY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;DD(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(144,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function uX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>=10){break a}b=(w[a|0]|w[a+1|0]<<8)!=0}return b}function kX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,80);gb=d+16|0;d=yb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;cc(c+16|0,a,c);e=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,80);gb=c+16|0}return a|0}function XZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;$v(d+16|0,c);v[22692]=0;ij(d+8|0,d+16|0);c=v[22692];v[22692]=0;b:{if((c|0)==1){break b}v[22692]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(144,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function l7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=YK(d);Dp(a);t[a+8|0]=0;v[a+4>>2]=c;v[a>>2]=59148;mc(a+12|0);v[a>>2]=58956;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;gb=d+16|0;return a|0}function jQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+2|0])|zb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function gQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+3|0])|zb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function ZZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-48|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;hE(c+24|0,b);f=yb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(f|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){gE(h)}if(a){e=tE(b)}gb=b+48|0;return e|0}function OE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Rc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){vp(a,3)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=11;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){zf(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}zf(a,b)}}function cM(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;_e(b);v[d+12>>2]=0;a:{if(!Ak(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Vh(a,d+11|0)){break b}Nq(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}gb=d+16|0;return e|0}function Ac(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[22692]=0;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=Lr(c+24|0,c+8|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){break a}v[22692]=0;a=Cy(c+16|0,a);b=v[22692];v[22692]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;_e(b);t[d+15|0]=0;a:{if(!Vh(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Vh(a,d+14|0)){break b}Nq(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}gb=d+16|0;return e|0}function kM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=(vf(v[a+16>>2])|0)/5|0;b=Ac(b,b>>31);v[a+4272>>2]=b;v[22692]=0;v[c+12>>2]=0;U(1525,a+4256|0,b<<1,c+12|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){b=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;gb=c+16|0;return}S(b|0);L()}function dQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=gd(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function cQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=gd(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function Rx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((kb[b|0](a,f)|0)>=0){if((kb[b|0](a,e)|0)>-1){break a}}j=f;f=(kb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}DI(g,h);gb=g+240|0}function Jf(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(y[b+8>>2]<c>>>0){v[22692]=0;Y(2100,14429,6221,394,3435);a=v[22692];v[22692]=0;if((a|0)==1){break a}L()}v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;gb=d+16|0;return}V(0)|0;O()|0;Bb();L()}function DI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=gb-256|0;gb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;hc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;hc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}gb=e+256|0}function _P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=gd(zb(w[b+3|0])|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Ska(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Nd(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Hl(b);Uo(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Um(b)){break a}if(v[a>>2]!=(d|0)){tw(b+68|0)}hc(zb(v[b+20>>2]),zb(v[a+20>>2])+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function $P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=gd(zb(w[b|0])|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=33;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}sC(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);sC(d+24|0,b);Qb(v[d+24>>2]+c|0,0,33-c|0);Rb(a,v[d+44>>2]);gb=d+48|0;return c|0}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=eg(d,b);v[22692]=0;U(1158,d+16|0,b|0,c|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){v[22692]=0;U(71,a|0,d+16|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function $X(){var a=0,b=0;a=gb-240|0;gb=a;a:{b:{if(t[90928]&1){break b}if(!Rd(90928)){break b}v[22692]=0;X(43);b=v[22692];v[22692]=0;if((b|0)==1){break a}v[22692]=0;_(44,a+120|0);b=v[22692];v[22692]=0;if((b|0)==1){break a}hc(90808,hc(a,a+120|0,120),116);Qd(90928)}gb=a+240|0;return 90808}a=P()|0;O()|0;Ye(90928);S(a|0);L()}function n8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Gg(a);a:{c=v[b+4>>2];if(!c){break a}v[22692]=0;R(2071,a|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[22692]=0;Y(2072,a|0,c|0,e+f|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mF(d);S(a|0);L()}return a|0}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Lk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22692]=0;gq(d,f,c);d=v[22692];v[22692]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Zc(b);gb=e+16|0;return}a=P()|0;O()|0;Zc(b);S(a|0);L()}function Qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Lk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22692]=0;Xo(d,f,c);d=v[22692];v[22692]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Zc(b);gb=e+16|0;return}a=P()|0;O()|0;Zc(b);S(a|0);L()}function Mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=qy(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22692]=0;kl(d,f,c);d=v[22692];v[22692]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Zc(b);gb=e+16|0;return}a=P()|0;O()|0;Zc(b);S(a|0);L()}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=bu(a+60|0);v[a>>2]=78180;v[d>>2]=78200;v[22692]=0;e=a+8|0;W(106,a|0,78212,e|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){a:{v[a>>2]=78180;v[d>>2]=78200;v[22692]=0;W(107,e|0,b|0,c|8)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;lh(d);S(a|0);L()}function gu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;if(b){Db(e+8|0,a+1074312|0,73);k=Cb(e+8|0)?c- -64|0:c;i=mk(a);l=i^1;c=120;f=1;while(1){g=c>>>1|0;j=g+f|0;h=Zg(a,j,k,d);a:{if(!((h|0)!=0&l|b>>>0<=h>>>0?(h>>>0<=b>>>0|i)==1:0)){f=j+1|0;c=(g^-1)+c|0;break a}c=g}if(c){continue}break}}gb=e+16|0;return f}function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=xn(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22692]=0;qn(d,f,c);d=v[22692];v[22692]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Zc(b);gb=e+16|0;return}a=P()|0;O()|0;Zc(b);S(a|0);L()}function Wfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;d=a+1298260|0;if(!Dd(d)){f=b;c=gb-16|0;gb=c;e=rf(532);a=v[a+24620>>2];v[22692]=0;g=Q(1298,e|0,a|0)|0;a=v[22692];v[22692]=0;a:{if((a|0)!=1){a=v[Wi(c+8|0,g)>>2];gb=c+16|0;break a}a=P()|0;O()|0;Xb(e);S(a|0);L()}v[f+8>>2]=a;TO(d,ce(b+8|0));cu(b+8|0)}gb=b+16|0}function I$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Rg(a,v[b+8>>2],e)){Uw(b,c,d);return}a:{if(!Rg(a,v[b>>2],e)){break a}if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+28>>2]){break a}if((kb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}c=v[d>>2];f=yb(d);if(!f){break a}while(1){b:{e=kb[v[b+28>>2]](v[b+24>>2],c,f)|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;if(!e){break b}c=c+e|0;f=f-e|0;if(f){continue}}break}e=g}hk(a,d,e)}function Uz(a,b){var c=0,d=0,e=0;UV(a);dp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function K$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=eg(d,b);v[22692]=0;U(174,d+16|0,b|0,c|0);e=v[22692];v[22692]=0;a:{b:{if((e|0)!=1){v[22692]=0;U(5,a|0,d+16|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function fO(a,b,c,d,e){var f=0,g=0,h=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;g=d;break a}f=f-1|0;g=(d>>>0)/(e>>>0)|0;t[f|0]=w[(d-B(g,e)|0)+1991|0];h=d>>>0>=e>>>0;d=g;if(h){continue}}break}b:{if(!g){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=vh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}xA(a,b,c,d)}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+12;TT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Ou(d+8|0,FB(a,Ec(a)+1|0),Ec(a),c);TT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;cU(a,c);bU(c);gb=d+32|0}function ML(a){var b=0;t[a+4116|0]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;LL(a+4164|0);LL(a+4156|0);vq(a+54060|0);vq(a+62252|0);vq(a+70444|0);vq(a+78636|0);Qb(a+4332|0,0,32768);iB(a+37100|0);Qb(a+37612|0,0,16384)}function wn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=zi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22692]=0;kl(f,b,c);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function pp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=ji(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22692]=0;qn(f,b,c);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function pE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Dg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22692]=0;Xo(f,b,c);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function jd(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=jI(b);e=gb-16|0;gb=e;c=Yp(a);a:{if(c>>>0>=b>>>0){f=Jb(a);g=f;c=b;b:{c:{if(b){v[22692]=0;zI(g,d,c);d=v[22692];v[22692]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Fe((b<<2)+f|0,e+12|0);gh(a,b);break a}f=a;a=Ab(a);kI(f,c,b-c|0,a,0,a,b,d)}gb=e+16|0}function hU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==50}return c}function cO(a,b,c,d,e){var f=0,g=0;a:{f=a;if((e|0)!=10){a=c;while(1){b:{if((a|0)==(b|0)){a=b;break b}g=d&255;d=(g|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(g-B(d,e)|0)+1991|0];if(d&255){continue}}break}c:{if(!(d&255)){d=c-a|0;if(d){break c}}v[f+4>>2]=61;v[f>>2]=c;break a}a=vh(b,a,d);v[f+4>>2]=0;v[f>>2]=a+d;break a}TP(f,b,c,d)}}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=4896;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}yC(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);yC(d+24|0,b);Qb(v[d+24>>2]+c|0,0,4896-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function JC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=yr(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22692]=0;vC(f,b,c);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function lY(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=yr(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+4|0]=6;t[a+5|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=8;t[a+3|0]=4;a=a+6|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function gka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{b:{c:{d:{e:{f:{if((b|0)<=28590){if((b|0)==437){break c}if((b|0)==1252){break b}if((b|0)!=20127){break f}e=1;break a}if((b|0)==28591){break e}if((b|0)==28605){break d}e=0;if((b|0)==65001){break a}}e=c;break a}e=2;break a}e=3;break a}e=5;break a}e=8}zT(a,e,d)}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=Sl(a);d=Sl(b);b=gb-32|0;gb=b;v[b+24>>2]=c;b:{if((a|0)!=(d|0)){while(1){c=Tb(b+8|0,v[a>>2]);v[22692]=0;R(2101,b+24|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break b}vb(c);a=a+4|0;if((d|0)!=(a|0)){continue}break}}gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}}function nE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=_D(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=wb(a);v[22692]=0;R(342,e|0,b|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=263;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}YS(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);YS(d+24|0,b);Qb(v[d+24>>2]+c|0,0,263-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Uy(a){var b=0,c=0,d=0,e=0;b=Cg(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=Op(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Cg(c+d)*.5}A[e+4248>>3]=b}Lt(a)}function UX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=320012546|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=184619540|w[a+8|0]>1){break a}b=a+9|0;if(!w[b|0]|w[b|0]>8){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function oC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;gW(a,b);e=b+8|0;Yc(a,Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);fW(a,d);a:{b=b+32|0;if(!Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}if(!Yc(a,Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){break a}qC(a,c);return}Qb(c,0,80)}function mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=22;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}vv(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);vv(d+24|0,b);Qb(v[d+24>>2]+c|0,0,22-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=40;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}hC(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);hC(d+24|0,b);Qb(v[d+24>>2]+c|0,0,40-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Ypa(a,b){a=a|0;b=b|0;var c=0;av(a,b);Nf(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function hS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:VA(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;wj(d+16|0,a,d+26|0,v[Fb(d+28|0,d+12|0)>>2]);yb(d+16|0);v[d+16>>2]=2;Fb(d+28|0,d+16|0);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;gb=d+32|0}function V6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c>>2];e=yb(c);b:{if(!e){break b}while(1){f=kb[v[b+28>>2]](v[b+24>>2],d,e)|0;if(!f){t[b+40|0]=1;break b}d=d+f|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;e=e-f|0;if(e){continue}break}}d=g}hk(a,c,d)}function RZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=65;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}Yv(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);Yv(d+24|0,b);Qb(v[d+24>>2]+c|0,0,65-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=gb-16|0;gb=e;d=gb-16|0;gb=d;Xe(c,1);Er(c,1,b<<24>>24);t[d+15|0]=0;Bd(c+1|0,d+15|0);gb=d+16|0;gb=e+16|0;b=c;d=Jb(c);e=Ab(c);v[22692]=0;W(117,a|0,d|0,e|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){vb(b);gb=c+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function HB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=gb-96|0;gb=d;UU(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=v[d+e>>2];e=v[(e|4)+d>>2];v[f>>2]=g;v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;gb=d+96|0;v[a+112>>2]=0;return a|0}function CS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=Bk(a);a=b+236|0;b=Eu(a);a:{if((a|0)!=(b|0)){while(1){d=x[a>>1];u[c+14>>1]=d;if(d){v[22692]=0;U(1071,c|0,e|0,c+14|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}gb=c+16|0;return}a=P()|0;O()|0;kr(e);S(a|0);L()}function Tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;d=c+8|0;e=b;if(lp(b,c+56|0)){b=c+60|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=9){b=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-8|0}else{b=0}}else{b=0}ud(d,e,b);b=a;a=jc(c+32|0,c+8|0);Ul(b,c+56|0,a);xb(a);xb(c+8|0);gb=c- -64|0}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Ab(b);v[22692]=0;R(65,a|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){a:{if(Ab(b)){while(1){c=t[nc(b,d)|0];v[22692]=0;R(66,a|0,fg(c)|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}d=d+1|0;if(Ab(b)>>>0>d>>>0){continue}break}}return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function EW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;v[d+12>>2]=v[a+4>>2];c=v[b+4>>2];v[22692]=0;v[d+8>>2]=c;c=Fb(d+12|0,d+8|0);e=v[22692];v[22692]=0;if((e|0)!=1){c=No(v[a>>2],v[b>>2],v[c>>2]);a:{if(c){break a}c=0;if(v[a+4>>2]==v[b+4>>2]){break a}c=y[a+4>>2]<y[b+4>>2]?-1:1}gb=d+16|0;return c}V(0)|0;O()|0;Bb();L()}function CA(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[22692]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=Lr(c+24|0,c+8|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){break a}v[22692]=0;a=Cy(c+16|0,a);b=v[22692];v[22692]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function _aa(a){a=a|0;var b=0;v[22692]=0;_(1918,a|0);b=v[22692];v[22692]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,2782,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function XB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-1024|0;gb=f;d=gb-32|0;gb=d;SB(d+24|0,f);g=yb(d+24|0);e=v[d+28>>2];h=v[d+24>>2];v[d+8>>2]=h;v[d+12>>2]=e;v[d>>2]=h;v[d+4>>2]=e;cc(d+16|0,a,d);e=yb(d+16|0);if((e|0)==(g|0)){Rb(a,yb(d+24|0))}gb=d+32|0;if((e|0)==(g|0)){i=VB(f,c)>>>0<=b>>>0}gb=f+1024|0;return i}function KS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){if(c){while(1){f=gd((gd(0-d|0,31)&255)+d|0,8);j=gd((gd(0-e|0,31)&255)+e|0,8);h=g<<3;i=h+b|0;d=d-f|0;v[i>>2]=d+v[i>>2];f=(h|4)+b|0;e=e-j|0;v[f>>2]=e+v[f>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}v[a+96>>2]=e;v[a+92>>2]=d}}function DN(a,b){var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){d=gb-16|0;gb=d;c=v[b>>2];e=v[b+4>>2];b=gr(c,e);a:{if(b>>>0<=ye(a)>>>0){if(Nb(a)>>>0<b>>>0){v[d+12>>2]=c;WV(d+12|0,Nb(a));f=c;c=v[d+12>>2];Qg(f,c,v[a>>2]);fz(a,c,e,b-Nb(a)|0);break a}ej(a,Qg(c,e,v[a>>2]));break a}AN(a);aw(a,ch(a,b));fz(a,c,e,b)}gb=d+16|0}}function SM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22692]=0;v[c+12>>2]=0;U(1525,a+4208|0,b<<1,c+12|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){b=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;gb=c+16|0;return}S(b|0);L()}function Q2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=gb-128|0;gb=c;v[c+12>>2]=c+116;SG(a+8|0,c+16|0,c+12|0,e,f,g);e=v[c+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;d=c+16|0;if((e|0)!=(d|0)){while(1){MH(a+8|0,t[d|0]);d=d+1|0;if((e|0)!=(d|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=c+128|0;return b|0}function Mo(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];if(e|v[d>>2]){if(!b){break a}while(1){e=gd((gd(0-e|0,31)&255)+e|0,8);f=v[d>>2];f=gd((gd(0-f|0,31)&255)+f|0,8);v[c>>2]=v[c>>2]-e;v[d>>2]=v[d>>2]-f;e=g<<3;v[e+a>>2]=v[c>>2];v[(e|4)+a>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}e=v[c>>2];continue}}LS(a,b<<1)}}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;f=c+8|0;d=b;if(lp(b,c+56|0)){e=KY(c+56|0)}ud(f,d,e);d=a;a=jc(c+32|0,c+8|0);d=Ul(d,c+56|0,a);xb(a);xb(c+8|0);a:{if(!(e&1)){break a}v[22692]=0;Q(318,b|0,1)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Zd(d);S(a|0);L()}gb=c- -64|0}function sba(){var a=0,b=0;v[22692]=0;a=v[22692];v[22692]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;Y(1895,7121,0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();a=0}else{a=19923014}return a|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function dw(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,256)){a=gb-16|0;gb=a;d=gb-16|0;gb=d;e=b+256|0;while(1){Hf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,256);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0}function X2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=v[20907];v[g+24>>2]=v[20906];v[g+28>>2]=h;h=v[20905];v[g+16>>2]=v[20904];v[g+20>>2]=h;h=v[20903];v[g+8>>2]=v[20902];v[g+12>>2]=h;h=v[20901];v[g>>2]=v[20900];v[g+4>>2]=h;a=ck(a,b,c,d,e,f,g,g+32|0);gb=g+32|0;return a|0}function K9(a){a=a|0;var b=0;v[22692]=0;_(1991,a|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22692]=0;Y(1895,9182,a|0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;yC(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,4896);gb=c+16|0}return a|0}function h8(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(xj(a)){wh(b+24|0);break b}ho(b+8|0,a);v[22692]=0;c=T(2068,b+8|0)|0;d=v[22692];v[22692]=0;if((d|0)==1){break a}v[b+24>>2]=c;Vf(b+8|0)}if(xj(a)){a=a+36|0}else{a=v[b+24>>2]}a=co(a);pl(b+24|0);gb=b+32|0;return a|0}a=P()|0;O()|0;Vf(b+8|0);S(a|0);L()}function Ug(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);Kf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;gb=d+16|0}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{if((pc(v[a+20>>2]+4|0)|0)!=7){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=Vb(v[a+20>>2]+4|0);c=Zb(v[a+20>>2]+4|0);mn(d+8|0,a+4228|0);Vi(b,c,v[d+8>>2]);break a}Ry(a,b)}Ht(a);gb=d+16|0}function Eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{b=xT(d,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){v[22692]=0;R(1077,a|0,c|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=d+16|0;return}a=P()|0;O()|0;Zc(b);S(a|0);L()}function uba(){var a=0,b=0;v[22692]=0;a=v[22692];v[22692]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;Y(1895,7093,0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();a=0}else{a=393216}return a|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function QY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Pb(a,8);a:{if(!d){a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+8|0;while(1){Hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0;break a}CY(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function yQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;f=a,g=zb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function xQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=zb(w[b|0])+g|0;t[a|0]=g;d=zb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Zp(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22692]=0;xR(b);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function ql(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Yf(c,b);v[22692]=0;R(2025,c+16|0,c|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){v[22692]=0;U(2026,a|0,0,c+16|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Ic(c+16|0);vb(c);gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ic(c+16|0)}vb(c);S(a|0);L()}function nP(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+851|0]=w[b+851|0]|32;g=b;d=a?w[b+813|0]:0;h=v[b+852>>2]+((c|0)>-1?0-d|0:d)|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+852>>2]=h+d;c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+813|0]=a^a+c}function iN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(ye(a)>>>0>=b>>>0){f=d,g=Nb(a),v[f+8>>2]=g;hN(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){Zy(a,b-e|0,c);break a}ej(a,v[a>>2]+(b<<2)|0);break a}AN(a);aw(a,ch(a,b));Zy(a,b,c)}gb=d+16|0}function fK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;v[22692]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22692];v[22692]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=Nc(b,1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=b+c|0,v[f>>2]=g}function ZK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=v[a>>2];a:{if(!b){break a}d=v[a+8>>2];if(!d){break a}e=v[a+12>>2];if(!e){break a}f=kb[e|0](b)|0;a=jb;if((a|0)<0){break a}c=0;b:{if((kb[d|0](b,0,0,0)|0)<0){break b}c=0;if((kb[d|0](b,0,0,2)|0)<0){break b}kb[e|0](b)|0;c=(jb|0)>-1}kb[d|0](b,f,a,0)|0}return c|0}function JJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a+4|0;a:{if(pc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!pc(c)){Gk(c,ly(v[a+16>>2]+b|0,65536));break a}f=d,g=pc(c),v[f+12>>2]=g;e=wf(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Gk(c,ly(a,65536));break a}f=d,g=pc(c),v[f+8>>2]=g;Gk(c,wf(d+8|0))}gb=d+16|0}function zma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;b=-1;a:{if(!Tf(a,1084)){break a}Nl(a,1080);CV(a,c+60|0);d=BV(c+40|0);b=0;if(!AV(c+60|0,d)){break a}Nl(a,20);b=1;while(1){zV(a,c+8|0);e=ZB(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=y[d+4>>2]>=e>>>0}gb=c- -64|0;return b|0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-48|0;gb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;un(c+16|0,c+40|0);b=zb(v[c+16>>2]);un(c+8|0,c+40|0);b=Kj(c+24|0,b,zb(v[c+8>>2]+2|0));v[22692]=0;Q(1088,a|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function hba(){var a=0,b=0;v[22692]=0;a=v[22692];v[22692]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;Y(1895,8352,0,0,0);a=v[22692];v[22692]=0;if((a|0)==1){break a}$();a=0}else{a=2048}return a|0}a=P()|0;O()|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fH(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=gr(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Xe(a,e);d=a;break a}g=sm(e)+1|0;d=Si(a,g);cf(a,d);pg(a,g);ee(a,e)}if((b|0)!=(c|0)){while(1){Fe(d,b);d=d+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f+12>>2]=0;Fe(d,f+12|0);gb=f+16|0;return}$f();L()}function bx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;h=b;c=jI(b);d=gb-16|0;gb=d;b=a;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){Xe(b,c);e=b;break b}g=sm(c)+1|0;e=Si(b,g);cf(b,e);pg(b,g);ee(b,c)}wi(e,h,c);v[d+12>>2]=0;Fe((c<<2)+e|0,d+12|0);gb=d+16|0;break a}$f();L()}gb=f+16|0;return a|0}function ZA(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=sB(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){wb(a);v[22692]=0;R(1077,b|0,c|0);g=v[22692];v[22692]=0;if((g|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function ES(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=Zh(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Xe(a,e);d=a;break a}g=Pk(e)+1|0;d=mi(a,g);cf(a,d);pg(a,g);ee(a,e)}if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(d,f+15|0);gb=f+16|0;return}$f();L()}function eE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=ji(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22692]=0;Zv(b);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function bq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=zi(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22692]=0;Hf(b);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Qr(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;tc(f+12|0,256);tc(f+12|0,65535);h=x[f+12>>1];yf(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=cj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}gb=f+16|0}function $u(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=Vb(a);c=Zb(a);a=gb-16|0;gb=a;v[a>>2]=c;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}nf(a+8|0);if(Gb(a+8|0,a)){continue}break}}gb=a+16|0}gb=d+16|0}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(bg(a)>>>0>=b>>>0){f=d,g=pc(a),v[f+8>>2]=g;li(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){wn(a,b-e|0,c);break a}xm(a,b+v[a>>2]|0);break a}wv(a);vn(a,nh(a,b));wn(a,b,c)}gb=d+16|0}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Ab(b);f=Ab(c);b=Jb(b);v[22692]=0;Y(116,a|0,b|0,e|0,e+f|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){b=Jb(c);v[22692]=0;W(117,a|0,b|0,f|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function R6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;v[f+8>>2]=d;d=v[ni(f,f+8|0)>>2];v[22692]=0;fa(1917,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){IJ(a);b=HJ(a+88|0);v[a>>2]=59688;v[b>>2]=59776;cg(f+8|0);gb=f+16|0;return a|0}a=P()|0;O()|0;cg(f+8|0);S(a|0);L()}function oka(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Il(a,0,c);return;case 1:Il(a,1,c);return;case 2:Il(a,2,c);return;case 3:Il(a,3,c);return;case 4:Il(a,4,c);return;case 5:Il(a,5,c);return;case 6:zS(a,24976,c);return;case 7:zS(a,26e3,c);return;case 8:Il(a,6,c);return;default:break a}}Kb(a)}function Wf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=gb-48|0;gb=c;a:{if(!b){b=1;if(ld(a,5)){break a}b=GL(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;re(c,v[a+28>>2]);UL(c+16|0,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[c+24>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}gb=c+48|0;return b|0}function T_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;DF(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-36|0;CF(h,e-36|0,c);e=v[d>>2]-36|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Vk(a);Tk(a);Tk(a)}function OQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;fT(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;ru(h,e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Ch(a);Yi(a);Yi(a)}function HQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=zb(w[b|0])+d|0;d=g+zb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;wb(b);e=a;f=rh(a);a:{c=Nb(b);if(!c){break a}v[22692]=0;R(333,e|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22692]=0;Y(1482,e|0,b|0,d|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mv(f);S(a|0);L()}return a|0}function nI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=Ab(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Jb(a);h=e;f=d;if(d){Xl(c+e|0,e,f);b=b>>>0>=e>>>0?d+e>>>0>b>>>0?b+c|0:b:b}Xl(h,b,c);b=c+d|0;gh(a,b);t[g+15|0]=0;Bd(b+e|0,g+15|0);break a}qp(a,f,(c+d|0)-f|0,d,0,0,c,b)}gb=g+16|0;return a}function bR(a,b,c){var d=0,e=0,f=0;d=Yd(a);e=fc(a);a:{if(d){f=wb(a);b:{while(1){c:{a=d+16|0;d:{if(Fl(f,c,a)){if(!v[d>>2]){break a}a=d;break d}if(!Fl(f,a,c)){break b}a=d+4|0;if(!v[d+4>>2]){break c}d=a;a=d}e=a;d=v[d>>2];continue}break}v[b>>2]=d;return a}v[b>>2]=d;return e}d=fc(a)}v[b>>2]=d;return d}function Zy(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Dg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22692]=0;gq(f,b,c);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Br(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,128);tc(d+12|0,65535);f=x[d+12>>1];yf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==65535){e=65535;break a}if((e|0)!=65535){break a}e=65534}g=cj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function uv(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-20|0;v[b+8>>2]=d;v[22692]=0;R(348,c|0,d|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){ZD(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/20|0)}}function is(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-36|0;v[b+8>>2]=d;v[22692]=0;R(213,c|0,d|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){hs(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/36|0)}}function zQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=th(w[b|0]),t[f|0]=g;f=a,g=th(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function nN(a){var b=0,c=0,d=0,e=0;c=a;d=v[a+4>>2];a:{while(1){b=v[c+8>>2];if((b|0)==(d|0)){break a}e=v[c+16>>2];b=b-52|0;v[c+8>>2]=b;v[22692]=0;R(1310,e|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}c=v[a>>2];if(c){Sz(v[a+16>>2],c,(v[dc(a)>>2]-v[a>>2]|0)/52|0)}}function gM(a,b,c){var d=0,e=0,f=0,g=0;g=(b|0)<1;if(C(D(a))<C(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!(g|(e|0)<0)){while(1){d=b-1|0;e=e<<1;if((b|0)<2){break a}b=d;if((e|0)>-1){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function Am(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;mc(a+32|0);cd(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function ge(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function Zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:Wh(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+12>>2]=1;wj(d+16|0,a,d+27|0,v[Fb(d+28|0,d+12|0)>>2]);yb(d+16|0);v[d+16>>2]=1;Fb(d+28|0,d+16|0);t[d+16|0]=w[d+27|0];t[b|0]=w[d+16|0];gb=d+32|0}function OX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<14){break a}if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=257){break a}a=a+8|0;c=!Ib(w[a|0]|w[a+1|0]<<8)}return c}function OD(a,b,c){var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=192;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}Mr(d+24|0,b);e=vd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;cc(d+16|0,a,d+8|0);Mr(d+24|0,b);Qb(v[d+24>>2]+c|0,0,192-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Em(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=xP(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return wP(a,b,d)}e=wP(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=xP(a,b,d)}return e}function AP(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}Lo(b,e,a);Db(f+8|0,a+1074312|0,10);if(!Cb(f+8|0)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}gb=f+16|0}function _d(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;Dn(a);a=Wi(d+8|0,a);a:{if(Nb(465792)>>>0<=b>>>0){v[22692]=0;_(2544,b+1|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}}c=v[Lb(465792,b)>>2];if(c){Gn(c)}c=ce(a);e=Lb(465792,b),f=c,v[e>>2]=f;GG(a);gb=d+16|0;return}b=P()|0;O()|0;GG(a);S(b|0);L()}function EX(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,256);tc(d+12|0,65535);f=x[d+12>>1];yf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=cj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function EE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,128);tc(d+12|0,65535);f=x[d+12>>1];yf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=cj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function jB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Ab(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=No(Jb(a),v[c+8>>2],v[Fb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}gb=c+16|0;return a|0}function hI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Mf(b);f=Ab(c);v[22692]=0;Y(2282,a|0,b|0,e|0,e+f|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){b=Jb(c);v[22692]=0;W(2283,a|0,b|0,f|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=52296;v[22692]=0;W(1517,a+44|0,2,2)|0;c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;Uh(b);c=v[22692];v[22692]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function Hn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Vp(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;In(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Pw(a,Ec(a))}function tL(a,b){var c=0;c=gb-32|0;gb=c;Yf(c,b);v[22692]=0;U(2031,c+16|0,0,c|0);b=v[22692];v[22692]=0;a:{b:{if((b|0)!=1){v[22692]=0;R(2032,a|0,c+16|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Ic(c+16|0);vb(c);gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ic(c+16|0)}vb(c);S(a|0);L()}function Wv(a){var b=0,c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;b=gb-32|0;gb=b;Sr(b+24|0,d+15|0);e=yb(b+24|0);c=v[b+28>>2];f=v[b+24>>2];v[b+8>>2]=f;v[b+12>>2]=c;v[b>>2]=f;v[b+4>>2]=c;fd(b+16|0,a,b);c=yb(b+16|0);if((c|0)==(e|0)){ad(a,yb(b+24|0))}gb=b+32|0;gb=d+16|0;return((c|0)==(e|0)?w[d+15|0]:0)&255}function vQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function rQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function jz(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=a-12|0;c:{if(c>>>0>31){break c}a=1;d=1<<c;if(d&-2145904587){break a}if(d&65792){break b}if((c|0)!=7){break c}b=b&240;if(!b|(b|0)==96|(b|0)==224){break a}}a=0;break a}a=0;b=(b&240)-96|0;if(b>>>0>=144){break a}return 297>>>(b>>>4)&1}return a|0}function jP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}lk(a,b,b+700|0,c<<2,0)}}function bM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22692]=0;v[c+12>>2]=0;U(1525,a+4208|0,b<<2,c+12|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){b=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;gb=c+16|0;return}S(b|0);L()}function LX(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Iz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[_b(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Db(d+8|0,a+1074312|0,63);if(!Cb(d+8|0)){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}gb=d+16|0}function Cw(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function k4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a:{if((d|0)!=(e|0)){f=d;a=b;while(1){g=-1;if((a|0)==(c|0)){break a}h=t[a|0];i=t[f|0];if((h|0)<(i|0)){break a}if((h|0)>(i|0)){return 1}a=a+1|0;f=f+1|0;if((f|0)!=(e|0)){continue}break}}g=((e-d|0)+b|0)!=(c|0)}return g|0}function dN(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Dg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22692]=0;Qo(b);f=v[22692];v[22692]=0;if((f|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Ge(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){Xe(d,b);f=d;break b}h=Pk(b)+1|0;f=mi(d,h);cf(d,f);pg(d,h);ee(d,b)}Er(f,b,c);t[e+15|0]=0;Bd(b+f|0,e+15|0);gb=e+16|0;break a}$f();L()}gb=g+16|0;return a|0}function uQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b|0])+d|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function qQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b+1|0])+d|0)+(zb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function Rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;a=qD(d,a);dY(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=d+16|0;return}e=gb-32|0;gb=e;d=wb(a);d=nD(e+8|0,oD(a,Ch(a)+1|0),Ch(a),d);dY(v[d+8>>2],b,c);v[d+8>>2]=v[d+8>>2]+28;JY(a,d);mD(d);gb=e+32|0}function Ona(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Lk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22692]=0;Vj(b);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=c+16|0;return}b=P()|0;O()|0;Zc(a);S(b|0);L()}function wy(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=qy(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22692]=0;Hf(b);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a>>2]+1|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=c+16|0;return}b=P()|0;O()|0;Zc(a);S(b|0);L()}function pP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}lk(a,b,b+700|0,c,0)}}function i_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Lk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22692]=0;Ur(b);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=c+16|0;return}b=P()|0;O()|0;Zc(a);S(b|0);L()}function cN(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Lk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22692]=0;Qo(b);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=c+16|0;return}b=P()|0;O()|0;Zc(a);S(b|0);L()}function Un(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);Kf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;gb=c+16|0}function On(a,b){var c=0,d=0;c=gb-16|0;gb=c;Fc(c+8|0,a);v[22692]=0;a=T(2464,c+8|0)|0;d=v[22692];v[22692]=0;a:{b:{if((d|0)==1){break b}v[22692]=0;Y(2476,a|0,83392,83418,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Wb(c+8|0);gb=c+16|0;break a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}return b}function LZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=xn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22692]=0;Zv(b);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=c+16|0;return}b=P()|0;O()|0;Zc(a);S(b|0);L()}function JZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=xn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22692]=0;Hk(b);b=v[22692];v[22692]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=c+16|0;return}b=P()|0;O()|0;Zc(a);S(b|0);L()}function cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,1030);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,1030)}return a|0}function Jc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}e=b;d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=e-d|0;jb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function DH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=$s(a);v[a+32>>2]=b;v[a>>2]=78740;Vs(d+8|0,e);v[22692]=0;b=T(2389,d+8|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Qn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);rm(e);S(a|0);L()}function CH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=aI(a);v[a+32>>2]=b;v[a>>2]=78844;Vs(d+8|0,e);v[22692]=0;b=T(2390,d+8|0)|0;f=v[22692];v[22692]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Qn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);Xp(e);S(a|0);L()}function JF(a){a=a|0;var b=0,c=0;b=Kb(a);v[22692]=0;T(214,a+12|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){b=gb-16|0;gb=b;v[b+12>>2]=0;v[22692]=0;df(a+32|0,b+12|0,b+8|0);c=v[22692];v[22692]=0;a:{if((c|0)!=1){gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function fD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[Bf(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[Bf(d+13|0,d+12|0)|0]}gb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,225);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,225)}return a|0}function Xma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,422);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,422)}return a|0}function XC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;lE(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-20|0;En(e-20|0,c);e=v[d>>2]-20|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];$D(a,$e(a))}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,326);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,326)}return a|0}function Rma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,826);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,826)}return a|0}function Ppa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bY(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=sB(d,a,1);wb(a);XA(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=_R(d+8|0,Wq(a,ze(a)+1|0),ze(a),c);XA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;ZR(a,c);WA(c);gb=d+32|0}function oZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,120);a:{if(!d){a=gb-16|0;gb=a;e=b+120|0;while(1){Hf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}bc(c+24|0,b,120);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function Jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,71);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,71)}return a|0}
function wQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function tQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,73);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,73)}return a|0}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,60);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,60)}return a|0}function Ue(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;BE(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];gb=b+32|0}function Mf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function Fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,91);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,91)}return a|0}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=Zh(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Ab(a);Rm(a,g,h,d,0,d,0)}d=Jb(a);if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Bd(d,e+15|0);gh(a,f);gb=e+16|0}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[b>>2]){if(!ed(c)){gx(c,14837)}e=v[b+4>>2];kb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[22692]=0;Q(1161,c|0,d|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}vb(d)}Dc(a,c);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function vO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=Zh(b,c);a:{if(e>>>0<=bg(a)>>>0){if(pc(a)>>>0<e>>>0){v[d+12>>2]=b;uO(d+12|0,pc(a));Qg(b,v[d+12>>2],v[a>>2]);or(a,v[d+12>>2],c,e-pc(a)|0);break a}xm(a,Qg(b,c,v[a>>2]));break a}wv(a);vn(a,nh(a,e));or(a,b,c,e)}gb=d+16|0}function lX(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=rh(a);a:{b=b+4|0;c=tf(b);if(!c){break a}v[22692]=0;R(2027,a|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22692]=0;Y(2028,a|0,b|0,d|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Ft(e);S(a|0);L()}}function Vga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,8)){u[c+16>>1]=0;b=4;while(1){d=w[c+16|0]|w[c+17|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;a=a+2|0;b=b-1|0;if(b){continue}break}break a}Bp(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;id(c+16|0,b,c+8|0)}gb=c+32|0}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,64);a:{if(!d){a=gb-16|0;gb=a;e=b- -64|0;while(1){Hk(b);b=b+2|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}kD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function Sh(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;d=gb-16|0;gb=d;b=c+8|0;e=v[b>>2];b=v[b>>2]+yb(b)|0;v[22692]=0;eo(a,e,b);a=v[22692];v[22692]=0;a:{if((a|0)!=1){gb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=c+32|0}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;v[d+44>>2]=b;ql(d+8|0,c);b=d+24|0;v[b>>2]=v[d+44>>2];Dc(b+4|0,d+8|0);v[22692]=0;R(2030,a+4|0,d+24|0);a=v[22692];v[22692]=0;if((a|0)!=1){yk(d+24|0);vb(d+8|0);gb=d+48|0;return}a=P()|0;O()|0;yk(d+24|0);vb(d+8|0);S(a|0);L()}function b1(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[22692]=0;b=T(2558,b|0)|0;c=v[22692];v[22692]=0;a:{if((c|0)!=1){b:{if(b){a=-1}else{a=v[a+8>>2];if(a){break b}a=1}return a|0}v[22692]=0;a=T(2559,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Bb();L()}return(a|0)==1|0}function J4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if(((g=a,h=Kg(t[b|0]),f=v[v[a>>2]+52>>2],kb[f](g|0,h|0)|0)|0)==-1){return d|0}b=b+1|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Dk(b,1,c,v[a+32>>2])|0}function ET(a,b,c){a:{switch(b|0){case 0:tk(a,0,c);return;case 1:tk(a,1,c);return;case 2:tk(a,2,c);return;case 3:tk(a,3,c);return;case 4:tk(a,4,c);return;case 5:tk(a,5,c);return;case 6:vS(a,24976,c);return;case 7:vS(a,26e3,c);return;case 8:tk(a,6,c);return;default:break a}}Kb(a)}function $j(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){g=v[a+8>>2];c=v[a>>2];while(1){a:{if(c){d=v[a+4>>2];break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=8}c=c-1|0;v[a>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function ae(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function VZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Yv(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,65)}return a|0}function Uc(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[22692]=0;v[b+4>>2]=32767;a=nd(b+12|0,b+4|0);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;a=Gf(b+8|0,a);c=v[22692];v[22692]=0;if((c|0)==1){break a}gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function Qs(a,b){var c=0,d=0;c=-1;a:{if((a|0)==-1){break a}d=v[b+76>>2]>=0;b:{c:{c=v[b+4>>2];d:{if(!c){vI(b);c=v[b+4>>2];if(!c){break d}}if(v[b+44>>2]-8>>>0<c>>>0){break c}}c=-1;if(d){break b}break a}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a;if(!d){break a}}}return c}function ov(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;g=dg(a,c);re(e+8|0,v[a+28>>2]);f=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!ld(a,5)){break b}break a}f=v[g+8>>2]}kb[d|0](v[a+28>>2],b,f)}a=Wf(a,g,c,e+24|0);gb=e+32|0;return a|0}function Wn(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=mqa(a,b,10,0);e=jb;f=e;e=jqa(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0;b=gb-16|0;gb=b;c=-1;a:{if(!_j(a,b+8|0)){break a}c=0;if(!ST(b+8|0)){break a}c=-1;if(!Tf(a,4)){break a}c=gb-16|0;gb=c;if(CT(a,c+8|0)){a=c+8|0;d=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=c+16|0;c=d>>>31|0}gb=b+16|0;return c|0}function vM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[v[a+16>>2]+1074404>>2];v[22692]=0;v[c+12>>2]=0;U(1525,a+4208|0,B(b,254)|0,c+12|0);b=v[22692];v[22692]=0;a:{if((b|0)==1){b=V(89088)|0;if((O()|0)!=(ea(89088)|0)){break a}Z(b|0)|0;$()}v[a+4220>>2]=0;gb=c+16|0;return}S(b|0);L()}function mX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>=256){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function m7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Ep(a);v[a>>2]=58792;v[22692]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Q(2104,dc(a)|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function kn(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=qD(c,a);pD(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=nD(d+8|0,oD(a,Ch(a)+1|0),Ch(a),c);pD(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;JY(a,c);mD(c);gb=d+32|0}function P_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-32|0;gb=e;v[e+24>>2]=d;v[e+28>>2]=c;v[22692]=0;Y(222,e+8|0,b|0,e+28|0,e+24|0);c=v[22692];v[22692]=0;if((c|0)!=1){ww(e+16|0,e+8|0);Uf(a,e+16|0);Ld(e+16|0);Ld(e+8|0);Ld(b);gb=e+32|0;return}a=P()|0;O()|0;Ld(b);S(a|0);L()}function Opa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=rh(a);a:{if(!b){break a}v[22692]=0;R(484,c|0,b|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;lY(c,b);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dD(d);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;sC(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){tC(b)}return a|0}function bF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;u[(v[a+1068>>2]<<1)+d>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=dd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function N_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;Ep(a);v[a>>2]=28032;f=dc(a);b=bm(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Dp(f);v[f>>2]=28168;b=e+8|0;bm(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;Ld(b);gb=e+32|0;return a|0}function Fm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Ej(f)){break a}e=w[f+34|0];if(e-251>>>0<5|!e){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}kb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;KR(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){OA(b)}return a|0}function sE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;hE(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){gE(b)}return a|0}function pu(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22692]=0;R(279,c|0,d|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){fm(v[a+16>>2],v[a>>2],Hp(a))}}function ps(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22692]=0;R(179,c|0,d|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){fm(v[a+16>>2],v[a>>2],Hp(a))}}function Xv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;MD(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){LD(b)}return a|0}function Vu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;NU(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){OU(b)}return a|0}function NQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-28|0;v[b+8>>2]=d;v[22692]=0;R(944,c|0,d|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){lB(v[a+16>>2],v[a>>2],HY(a))}}function EV(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[22692]=0;v[b+4>>2]=127;a=nd(b+12|0,b+4|0);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;a=Gf(b+8|0,a);c=v[22692];v[22692]=0;if((c|0)==1){break a}gb=b+16|0;return t[a|0]}V(0)|0;O()|0;Bb();L()}function wf(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;b=gb-16|0;gb=b;d=2;e=v[a>>2];if(e>>>0>=2){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Fb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Fb(b+12|0,b+8|0)>>2]}gb=b+16|0;gb=c+16|0;return d|0}function fR(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-12|0;v[b+8>>2]=c;v[22692]=0;R(1120,e|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){fm(v[a+16>>2],b,Hp(a))}}function ZR(a,b){var c=0,d=0,e=0,f=0,g=0;_u(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;XA(e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];YA(a,ze(a))}function WA(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-32|0;v[b+8>>2]=c;v[22692]=0;R(1090,e|0,c|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Qk(v[a+16>>2],b,rB(a))}}function Iha(a,b){a=a|0;b=b|0;var c=0;c=gb-48|0;gb=c;t[c+40|0]=w[b|0];Sr(c+16|0,c+40|0);b=zb(v[c+16>>2]);Sr(c+8|0,c+40|0);b=Kj(c+24|0,b,zb(v[c+8>>2]+1|0));v[22692]=0;Q(1088,a|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;ho(c,a);a=b;if(v[a>>2]){Pd(a);uy(v[a>>2],cv(a));d=wb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=wb(c);d=wb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Vf(c);gb=c+16|0}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Nc(52,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22692]=0;Q(2102,e|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){b=a;a=Fp(d);SJ(b,dc(a),a);RJ(d);gb=c+16|0;break a}a=P()|0;O()|0;RJ(d);S(a|0);L()}}function K8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Nc(56,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22692]=0;Q(2103,e|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){b=a;a=Fp(d);SJ(b,dc(a),a);NJ(d);gb=c+16|0;break a}a=P()|0;O()|0;NJ(d);S(a|0);L()}}function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wb(b);d=rh(a);a:{c=pc(b);if(c){v[22692]=0;R(486,a|0,c|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}d=v[b>>2];e=v[b+4>>2];b=gb-16|0;gb=b;c=zi(b,a,c);wb(a);fv(d,e,c+4|0);$b(c);gb=b+16|0}return a|0}a=P()|0;O()|0;dm(d);S(a|0);L()}function fe(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function ei(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[22692]=0;v[b+4>>2]=255;a=nd(b+12|0,b+4|0);c=v[22692];v[22692]=0;a:{if((c|0)==1){break a}v[22692]=0;a=Gf(b+8|0,a);c=v[22692];v[22692]=0;if((c|0)==1){break a}gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(!Nd(b)){break a}if(v[b+20>>2]==(zb(v[a+20>>2])|0)){v[a+20>>2]=0}tc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Um(a)){break a}hc(zb(v[a+20>>2]),v[b+20>>2],Zi(a));d=1}return d|0}function Tx(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}kb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;kb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function Tda(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+8>>2]=b;b=0;a:{if(Nb(a)>>>0>511){break a}if(!Dd(c+8|0)){break a}b=v[c+8>>2];v[22692]=0;R(1513,a|0,c+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Hg(c+8|0);S(a|0);L()}Hg(c+8|0);gb=c+16|0;return b|0}function lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,274);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,274)}}function hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,106);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,106)}}function eqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,136);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,136)}}function az(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Qf(a)){break a}while(1){if(!gi(af(a,e))){break a}d=d+1|0;e=d&65535;if(Qf(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=sh(a,d&65535,b)?d:-1}return c&65535}function MT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-16|0;gb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jb(d);Kj(b,a,Ab(d)+a|0);break c}ET(e,c,d);v[22692]=0;U(57,a|0,b|0,e|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Ic(e)}gb=e+16|0;break a}a=P()|0;O()|0;Ic(e);S(a|0);L()}}function gca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;sM(a,b,c,d,e^1);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=52036;return a|0}function fW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,284);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,284)}}function aF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=dd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function _g(a,b){var c=0,d=0,e=0,f=0;c=Ab(a);a:{if((c|0)!=(Ab(b)|0)){break a}d=Jb(a);b=Jb(b);b:{if(!De(a)){if(c){break b}return 1}return!No(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function _S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=zd(b);e=ef(b);f=zd(b);c=gb-32|0;gb=c;v[c+16>>2]=e;v[c+24>>2]=d;v[c+8>>2]=f;if(Gb(c+24|0,c+16|0)){while(1){d=Vq(t[v[c+24>>2]]);t[v[c+8>>2]]=d;Ne(c+24|0);Ne(c+8|0);if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;Dc(a,b)}function Np(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(e*.16666666666666632+(d*(b*.5-e*f)-b))}function mm(a){var b=0,c=0,d=0,e=0;Vp(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=wb(d);v[22692]=0;b=b-12|0;R(179,c|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[d+4>>2]=e;fm(wb(a),v[a>>2],sg(a))}}function h4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+4|0;d=d+4|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,42);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,42)}}function gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,72);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,72)}}function cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,34);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,34)}}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=zu(a+8|0,d);v[22692]=0;Q(1635,a+20|0,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Ht(a){var b=0,c=C(0),d=0;if(w[a+4232|0]>=5){t[a+4232|0]=0}if(t[a+4233|0]<=-1){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<=-1){t[a+4234|0]=127;b=127}d=a;a:{if((xM(a)|0)==3){c=C(C(1)-ne(C(2),C(-C((b&255)+1|0))));break a}c=ne(C(2),C(-C((b&255)>>>0)))}z[d+4224>>2]=c}function wD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,50);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,50)}}function vK(a){var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;b=a+120|0;Ai(b);c=gb-16|0;gb=c;v[c+8>>2]=d+8;a=gb-16|0;gb=a;e=v[13834];v[a+8>>2]=v[13833];v[a+12>>2]=e;e=v[13832];v[a>>2]=v[13831];v[a+4>>2]=e;b=kb[v[Rh(a,Xg(b))>>2]](c+8|0,b)|0;gb=a+16|0;gb=c+16|0;gb=d+16|0;return b}function TZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,59);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,59)}}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=rh(a);a:{d=qf(b);if(d){v[22692]=0;R(1104,a|0,d|0);e=v[22692];v[22692]=0;if((e|0)==1){break a}c=gb-16|0;gb=c;e=v[b>>2];f=v[b+4>>2];b=ds(c,a,d);fv(e,f,b+4|0);$b(b);gb=c+16|0}return a|0}a=P()|0;O()|0;Lf(c);S(a|0);L()}function al(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function PN(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){Ch(c);eT(c);Yi(c);Ch(c);lB(wb(c),v[c>>2],Yi(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}dp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function KK(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function IF(a,b){var c=0,d=0;c=gb-16|0;gb=c;Fc(c+8|0,a);v[22692]=0;a=T(21,c+8|0)|0;d=v[22692];v[22692]=0;a:{if((d|0)==1){break a}v[22692]=0;a=Q(22,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}Wb(c+8|0);gb=c+16|0;return a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}function FQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function BR(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[e+16>>2]=b;b=JT(c-+(b<<2));v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=b;v[a+12>>2]=jb}function uka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){t[c+16|0]=0;a=4;while(1){t[b|0]=w[c+16|0];b=b+1|0;a=a-1|0;if(a){continue}break}break a}eC(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function uh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function WM(a,b,c){var d=0;d=gb-32|0;gb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;wj(d+16|0,a,d+24|0,v[Fb(d+28|0,d+12|0)>>2]);yb(d+16|0);v[d+16>>2]=4;Fb(d+28|0,d+16|0);v[d+16>>2]=v[d+24>>2];a=d+16|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=d+32|0}function mF(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(e);v[22692]=0;b=b-12|0;R(279,c|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[e+4>>2]=d;fm(wb(a),v[a>>2],sg(a))}}function Xpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,64)){a=gb-16|0;gb=a;d=b- -64|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}kD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0}function LM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){d=b;if(b>>>0>2097151){pd(8399);L()}f=Nc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<11)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function jl(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=mt(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=th(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function EQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=zb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f|0}function zV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;nV(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){oV(b)}return a}function xY(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Av(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){cD(b)}return a}function kU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;AX(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){BX(b)}return a}function gW(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;aW(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){$V(b)}return a}function dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;OV(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Hk(b)}}function bD(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;XX(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){YX(b)}return a}function aG(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;NF(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Cw(b)}return a}function _j(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Bp(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){cm(b)}return a}function SC(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;AX(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){BX(b)}return a}function RU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;NU(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){ad(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){OU(b)}return a}function Os(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=ba(16)|0;sH();a=sd(c+8|0,a,90744);v[22692]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2419,d|0,c|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){ia(d|0,79200,2420);L()}a=P()|0;O()|0;da(d|0);S(a|0);L()}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,27)){a=gb-16|0;gb=a;d=b+27|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}KR(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0}function zv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-48;v[22692]=0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){eY(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/48|0)}}function fV(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,32)){a=gb-16|0;gb=a;d=b+32|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}bV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0}function _B(a){var b=0,c=0,d=0;if(v[a>>2]){c=a;b=v[a+4>>2];d=v[a>>2];if((b|0)!=(d|0)){while(1){b=b-24|0;xb(b);if((b|0)!=(d|0)){continue}break}}v[c+4>>2]=d;c=v[a>>2];a=cv(a);v[22692]=0;Oc(c,B(a,24),4);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Zu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bV(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){NB(b)}}function RT(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=90776;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function Qha(a){a=a|0;var b=0,c=0,d=0;c=gb-32|0;gb=c;b=255;a:{if(Oi(a)>>>0<=49){b=_A(c,v[a+12>>2]);v[22692]=0;R(1078,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)==1){break a}Sm(b);Pi(a,Oi(a)-1&255);b=Oi(a)-1|0}gb=c+32|0;return b&255}a=P()|0;O()|0;Sm(b);S(a|0);L()}function M$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Rg(a,v[b+8>>2],0)){Xw(b,c,d);return}e=v[a+12>>2];f=a+16|0;qG(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){qG(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function aO(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=c;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=f;v[a+8>>2]=e;v[a+12>>2]=d;v[a>>2]=b;v[a+4>>2]=f;d=!QS(a+8|0,a)}gb=c+32|0;return d}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Yp(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);wi(d+(e<<2)|0,b,c);b=c+e|0;gh(a,b);v[f+12>>2]=0;Fe(d+(b<<2)|0,f+12|0);break a}kI(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,1100);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,2)){a=gb-16|0;gb=a;d=b+2|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}OV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0}function lv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-6;v[22692]=0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){AC(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/6|0)}}function id(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b>>2];g=v[b+8>>2];f=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=f;h=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=f;kb[h|0](a,e,g,d);i=b,j=yb(a)+v[b+8>>2]|0,v[i+8>>2]=j;gb=d+16|0}function ut(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=12;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){e=so(a);v[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}}gb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function Mt(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-2048;v[22692]=0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){IM(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]>>11)}}function Mq(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=Gl(a,b);if((e|0)==255){break a}if(qk(a)){break a}b=QA(a+314|0,e);e=PR(e);if(f=1,g=t[lc(b,10)|0]&1,h=d,h?f:g){Yh(v[a>>2],e- -64&65535,OR(c,w[lc(b,2)|0]))}if(d){break a}Yh(v[a>>2],e+67&65535,OR(c,w[lc(b,3)|0]))}}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;Xm(a,b);d=c,e=Vb(a),v[d+8>>2]=e;d=c,e=Zb(a),v[d>>2]=e;if(Gb(c+8|0,c)){b=0;while(1){a=v[c+8>>2];b=zb(w[a|0])+(b&255)|0;d=a,e=zb(b&255),t[d|0]=e;Ne(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0}function Iu(a){var b=0,c=0;a:{if(w[a+4|0]|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1414687062){break a}b=a+6|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function BG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83712;b=v[a+8>>2];v[22692]=0;c=ga(2460)|0;d=v[22692];v[22692]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[22692]=0;tx(b);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Bb();L()}return a|0}function zK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;u[c+10>>1]=0;u[c+8>>1]=65535;a:{if(At(c+12|0,c+10|0,c+8|0)){a=a+24|0;d=0;if(!le(v[a>>2]+484344|0,b&65535)){break a}d=v[_b(v[a>>2]+484344|0,b)+12>>2];break a}d=0}a=d;gb=c+16|0;return a|0}function vka(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=vd(b+8|0,b+24|0,6);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;cc(b+16|0,a,b);a:{if((yb(b+16|0)|0)!=6){break a}if(rd(b+24|0,1024,6)){break a}Rb(a,6);e=1}gb=b+32|0;return e|0}function uE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,37);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,37)}}function V2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22692]=0;b=T(2464,g|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){Wb(g);VG(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function T2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22692]=0;b=T(2464,g|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){Wb(g);UG(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function SD(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}jb=a;return b}function JI(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=JI(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function Hoa(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;t[b+30|0]=0;u[b+28>>1]=0;c=vd(b+8|0,b+28|0,3);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;cc(b+16|0,a,b);a:{if((yb(b+16|0)|0)!=3){break a}if(rd(b+28|0,11898,3)){break a}Rb(a,3);e=1}gb=b+32|0;return e|0}function sz(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;d=tf(a);e=b,f=Vb(a),v[e+8>>2]=f;e=b,f=Zb(a),v[e>>2]=f;if(Gb(b+8|0,b)){c=+(d>>>0);while(1){a=v[b+8>>2];A[a>>3]=A[a>>3]/c;A[a+8>>3]=A[a+8>>3]/c;Ro(b+8|0);if(Gb(b+8|0,b)){continue}break}}gb=b+16|0}function Pna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-2496|0;gb=c;UU(b,c,c+2496|0);b=hc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}gb=c+2496|0;return a|0}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22692]=0;R(806,a|0,b|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;U(807,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$r(d);S(a|0);L()}return a|0}function ax(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[22692]=0;c=ga(2460)|0;d=v[22692];v[22692]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[22692]=0;tx(b);b=v[22692];v[22692]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Bb();L()}return a|0}function a3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22692]=0;b=T(21,g|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){Wb(g);YG(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;hC(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Hga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,16);a:{if(!d){a=b+16|0;while(1){t[b|0]=0;b=b+1|0;if((a|0)!=(b|0)){continue}break}break a}_v(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=dg(a,c);re(d+8|0,v[a+28>>2]);e=v[d+20>>2];v[d+24>>2]=v[d+16>>2];v[d+28>>2]=e;a:{b:{if(!f){e=-1;if(!ld(a,5)){break b}break a}e=v[f+8>>2]}BO(v[a+28>>2],b,e)}Wf(a,f,c,d+24|0);gb=d+32|0}function $2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22692]=0;b=T(21,g|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){Wb(g);XG(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function wP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075080>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,872)+a|0)+1075778>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function uT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<8)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){qB(a);a=v[c>>2]+256|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}Zc(c);gb=d+16|0}function sW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,33)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){tC(a);a=v[c>>2]+33|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}Zc(c);gb=d+16|0}function s5(a){a=a|0;var b=0,c=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<c>>>0){Rn(a,v[a+8>>2],v[a+12>>2],c)}b=v[a+16>>2];a=v[a+12>>2];if(b>>>0<=a>>>0){break a}return Kg(t[a|0])|0}return-1}function hX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22692]=0;R(613,a|0,b|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;U(614,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pv(d);S(a|0);L()}return a|0}function UZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22692]=0;R(333,a|0,b|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;U(334,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mv(d);S(a|0);L()}return a|0}function ND(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22692]=0;R(389,a|0,b|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;U(390,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dm(d);S(a|0);L()}return a|0}function Gz(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=ew(f,c);d=a+1074312|0;Db(e+8|0,d,31);a=0;if(!Cb(e+8|0)){Db(e,d,93);a=Cb(e)^1}if(!(t[iO(b,c)+6|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=bd(f)^1}gb=e+16|0;return d}function Ev(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22692]=0;R(486,a|0,b|0);e=v[22692];v[22692]=0;if((e|0)!=1){v[22692]=0;U(487,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dm(d);S(a|0);L()}return a|0}function vI(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){kb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function be(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-1;v[22692]=0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Uk(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]|0)}}function $m(a){var b=0,c=0,d=0,e=0;_u(a);if(v[a>>2]){c=a;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}wb(c);v[22692]=0;b=b-32|0;e=v[22692];v[22692]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[c+4>>2]=d;kV(wb(a),v[a>>2],bi(a))}}function zw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<3)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){cm(a);a=v[c>>2]+8|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}Zc(c);gb=d+16|0}function poa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;PE(d+8|0,a);DW(c+24|0,d+8|0);gb=d+16|0;Bg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function nT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Kj(b,a,Ab(c)+a|0);break c}hT(d,c);v[22692]=0;U(57,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Ic(d)}gb=d+16|0;break a}a=P()|0;O()|0;Ic(d);S(a|0);L()}}function kqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=b^d;h=e>>31;f=b>>31;a=a^f;i=a-f|0;g=b;b=b>>31;g=(g^b)-((a>>>0<f>>>0)+b|0)|0;a=d>>31;b=c^a;c=d>>31;e=e>>31;a=mqa(i,g,b-a|0,(c^d)-((a>>>0>b>>>0)+c|0)|0)^e;b=a-e|0;jb=(h^jb)-((a>>>0<e>>>0)+h|0)|0;return b}function NW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,48)+e;if(v[c>>2]!=v[c+4>>2]){while(1){MW(v[c>>2]);a=v[c>>2]+48|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}Zc(c);gb=d+16|0}function VB(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[lc(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;e=$s(a);v[a>>2]=77300;f=Kb(a+32|0);v[a+48>>2]=c;v[a+44>>2]=0;v[22692]=0;R(108,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){gb=d+16|0;return a|0}a=P()|0;O()|0;vb(f);rm(e);S(a|0);L()}function JY(a,b){var c=0,d=0,e=0,f=0,g=0;f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;pD(e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function BD(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,512)){a=gb-16|0;gb=a;d=b+512|0;while(1){Vj(b);b=b+4|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}Lv(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0}function zT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Kj(b,a,Ab(c)+a|0);break c}ET(d,b,c);v[22692]=0;R(58,a|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}Ic(d)}gb=d+16|0;break a}a=P()|0;O()|0;Ic(d);S(a|0);L()}}function ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,256);tc(d+12|0,65535);e=x[d+12>>1];yf(a,e);if(e){c=0;while(1){f=w[b+c|0];g=cj(a,c),h=f,u[g>>1]=h;c=c+1|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0}function coa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=dg(a,c);re(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(ld(a,5)){break a}}dX(v[a+28>>2],b,v[e+24>>2],0)}Wf(a,d,c,e+16|0);gb=e+32|0}function EY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=xn(d+8|0,a+8|0,lD(b,c));c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Cr(c,v[d+24>>2]);v[a>>2]=v[a>>2]+2;Jv(d+24|0);c=v[a>>2];if((c|0)!=v[a+4>>2]){continue}break}}Zc(a);gb=d+32|0}function wp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Kc(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Og(d+e|0,b,c);b=c+e|0;gh(a,b);t[f+15|0]=0;Bd(b+d|0,f+15|0);break a}qp(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function tV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;nV(c+24|0,b);e=yb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){oV(b)}}function cX(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=zb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+18824|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Bt(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22692]=0;T(1277,c|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){yd(a+68|0);Vf(a+36|0);dq(a+32|0);Di(b);Ci(a+4|0);cg(a);return a}V(0)|0;O()|0;yd(a+68|0);Vf(a+36|0);dq(a+32|0);Di(b);Ci(a+4|0);cg(a);Bb();L()}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=dg(a,c);re(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(ld(a,5)){break a}}eN(v[a+28>>2],b,v[e+24>>2])}Wf(a,d,c,e+16|0);gb=e+32|0}function QE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0<32){break a}}h=v[a>>2];v[(f>>>0<33?h:(g>>>3&536870908)+h|0)>>2]=0}tp(d+8|0,a,e);sp(d+8|0,b,c);gb=d+16|0}function FP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=Uc(Jm(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=ok(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Uc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function nO(a,b){var c=0,d=0,e=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}d=b;c=v[c>>2];b:{if(c){e=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[e+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[d>>2]=a}}function S2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22692]=0;b=T(2464,a|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){Wb(a);TG(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function G4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}b=b+4|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Dk(b,4,c,v[a+32>>2])|0}function FC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=mc(a+8|0);v[22692]=0;d=T(465,b|0)|0;e=v[22692];v[22692]=0;b:{if((e|0)==1){break b}v[22692]=0;U(393,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;gc(c);S(a|0);L()}}function SA(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(w[a+530|0]){while(1){d=c&65535;Ni(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;li(a+4|0,18,b+15|0);hv(a+22|0,18,35482);t[b+14|0]=255;li(a+58|0,256,b+14|0);gb=b+16|0}function Du(a){a=a|0;var b=0,c=0,d=0,e=0;c=SS(a);if((c|0)!=(a|0)){while(1){b=0;e=a;bX(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Qb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function Bpa(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!bD(a,b+16|0)){break a}c=0;if(!_X(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!ad(a,4)){break a}}c=-1;if(!_j(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}gb=b+32|0;return c|0}function xF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function g7(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=a;if(!w[c+8|0]){d=c+12|0;Gk(d,v[c+4>>2]);Vd(b+24|0,d);d=v[v[c>>2]+40>>2];e=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=e;kb[d|0](b+16|0,c,0,b+8|0);t[c+8|0]=1}gb=b+32|0;return v[a+12>>2]}function Z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22692]=0;b=T(21,a|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){Wb(a);WG(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function Mp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function wL(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;v[b>>2]=0;t[c+15|0]=0;Vh(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;d=d&3;if(d){while(1){t[c+15|0]=0;Vh(a,c+15|0);e=e+1|0;v[b>>2]=v[b>>2]|w[c+15|0]<<(e<<3)-2;if((d|0)!=(e|0)){continue}break}}gb=c+16|0}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=ui(e,e+12|0);v[22692]=0;a=W(2481,a|0,c|0,v[e+8>>2])|0;c=v[22692];v[22692]=0;if((c|0)!=1){ff(b);gb=e+16|0;return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function YM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){Xe(a,c);d=a;break a}f=Pk(d)+1|0;d=mi(a,f);cf(a,d);pg(a,f);ee(a,c)}Og(d,b,c);t[e+15|0]=0;Bd(c+d|0,e+15|0);gb=e+16|0;return}$f();L()}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){vO(e,v[d+4>>2],v[d+8>>2])}hc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function yF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,20);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function we(){var a=0,b=0;a:{b:{if(t[464164]&1){break b}if(!Rd(464164)){break b}v[22692]=0;a=W(2462,2147483647,11457,0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}v[116040]=a;Qd(464164)}return v[116040]}a=P()|0;O()|0;Ye(464164);S(a|0);L()}function nD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if(b>>>0>=153391690){pd(8399);L()}f=Nc(B(d,28),4)}v[a>>2]=f;c=B(c,28)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,28)+f|0,v[g>>2]=h;gb=e+16|0;return a}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22692]=0;R(515,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(516,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dm(c);S(a|0);L()}return a|0}function kW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,18);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Pma(a,b){a=a|0;b=b|0;var c=0,d=0;c=rh(a);a:{if(!b){break a}v[22692]=0;R(767,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(768,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;_B(c);S(a|0);L()}return a|0}function Ou(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if(b>>>0>=357913942){pd(8399);L()}f=Nc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function MP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Mc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=BP(c&255),v[e+44>>2]=f}gb=d+16|0}function jX(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22692]=0;R(486,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(602,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dm(c);S(a|0);L()}return a|0}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22692]=0;R(335,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(336,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mE(c);S(a|0);L()}return a|0}function KF(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){d=b;if(b>>>0>119304647){pd(8399);L()}f=Nc(B(d,36),4)}v[a>>2]=f;c=B(c,36)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,36)+f|0,v[g>>2]=h;gb=e+16|0;return a}function HE(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,1);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=gb-32|0;gb=e;c=b+4|0;b=v[c+48>>2];a:{if(b&16){b=v[c+44>>2];d=v[c+24>>2];if(b>>>0<d>>>0){v[c+44>>2]=d;b=d}Kj(a,v[c+20>>2],b);break a}if(b&8){Kj(a,v[c+8>>2],v[c+16>>2]);break a}Kb(a)}gb=e+32|0}function gY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){d=b;if(b>>>0>89478485){pd(8399);L()}f=Nc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,48)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Qe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a+8|0);v[22692]=0;U(393,a|0,b|0,c|0);c=v[22692];v[22692]=0;a:{if((c|0)!=1){a=v[a>>2];v[22692]=0;Q(318,b|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;gc(d);S(a|0);L()}}function IQ(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function zI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function yp(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;un(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function mV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;lV(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function lW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;IX(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function kY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Av(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function gs(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;yi(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function gF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;as(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function cs(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Bp(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function aY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;_v(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function _V(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;ZV(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function WX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;XX(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function VX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;kD(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function TQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if(b>>>0>=613566757){pd(8399);L()}f=Nc(B(d,7),1)}v[a>>2]=f;c=B(c,7)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,7)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Rv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Qv(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=-1;a:{if(!aG(a,c+8|0)){break a}d=0;if(!JN(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}gb=c+32|0;return d|0}function PX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=qy(d+8|0,a+8|0,QX(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){ep(v[a>>2],v[d+24>>2]);v[a>>2]=v[a>>2]+1;Ne(d+24|0);if(v[a>>2]!=v[a+4>>2]){continue}break}}Zc(a);gb=d+32|0}function PV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;eC(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Mv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;mn(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function MF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;NF(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function M7(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=v[v[b>>2]+(a<<2)>>2]+(c<<3)|0;v[d>>2]=0;v[d+4>>2]=0;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function Lg(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Sr(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function KD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;JD(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;cc(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function CT(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;eC(c+24|0,b);b=yb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fd(c+16|0,a,c);d=yb(c+16|0);if((b|0)==(d|0)){ad(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Kq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-fe(A[xe(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Ri(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function JG(a){var b=0,c=0,d=0;d=gb-16|0;gb=d;b=d;v[b>>2]=465792;c=v[116449];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);c=b;a=v[b+4>>2];b=v[b+8>>2];if((a|0)!=(b|0)){while(1){Qo(a);a=a+4|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(c);gb=d+16|0}function __(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[b+8>>2];if(f>>>0>c>>>0){v[e+12>>2]=f-c;h=e,i=yb(d),v[h+8>>2]=i;f=Fb(e+12|0,e+8|0);b=v[b+4>>2]+c|0;g=v[f>>2];Qg(b,b+g|0,v[d>>2])}hk(a,d,g);gb=e+16|0}function Qt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;a:{e=!b|!c;if(!e){b=Tb(d,b);v[22692]=0;U(1460,d+16|0,b|0,c|0);c=v[22692];v[22692]=0;if((c|0)==1){break a}Eb(a+36|0,d+16|0);vb(d+16|0);vb(b)}gb=d+32|0;return!e}a=P()|0;O()|0;vb(b);S(a|0);L()}function bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=0;a:{if(!Nb(a)){break a}while(1){eg(d,v[Lb(a,e)>>2]+40|0);c=sr(d,b);vb(d);if(c){c=v[Lb(a,e)>>2];break a}e=e+1|0;if(Nb(a)>>>0>e>>>0){continue}break}c=0}gb=d+16|0;return c|0}function Cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;fY(a);wb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Tj(a);gn(a);gn(a)}function gO(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ac(kqa(jqa(d,d>>31,g,h),jb,256,0),jb);v[a+4>>2]=f-d;v[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function aka(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22692]=0;R(333,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;$S(a,b);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mv(c);S(a|0);L()}return a|0}function _ma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(bg(a)>>>0<b>>>0){d=wb(a);b=Yg(c+8|0,b,pc(a),d);v[22692]=0;R(296,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}be(b)}gb=c+32|0;return}a=P()|0;O()|0;be(b);S(a|0);L()}
function Sma(a,b){a=a|0;b=b|0;var c=0,d=0;c=rh(a);a:{if(!b){break a}v[22692]=0;R(765,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;ir(a,b);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ci(c);S(a|0);L()}return a|0}function MI(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-16;v[22692]=0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Sn(v[a+16>>2],b,Hx(a))}}function spa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(bg(a)>>>0<b>>>0){d=wb(a);b=Yg(c+8|0,b,pc(a),d);v[22692]=0;R(396,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}be(b)}gb=c+32|0;return}a=P()|0;O()|0;be(b);S(a|0);L()}function Sg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function IA(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-8;v[22692]=0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){HA(v[a+16>>2],b,tF(a))}}function cW(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Ng(a)>>>0<b>>>0){d=wb(a);b=yn(c+8|0,b,sc(a),d);v[22692]=0;R(313,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}Ih(b)}gb=c+32|0;return}a=P()|0;O()|0;Ih(b);S(a|0);L()}function gg(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Ri(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function an(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=Si(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function _O(a,b){a=a|0;b=b|0;WO(a);WO(a+368680|0);if(b){_N(a,1);return a|0}YN();Wt(222048,287584,a+131112|0);Wt(287584,353120,a+196648|0);Wt(353120,418656,a+262184|0);Wt(90960,222048,a+24|0);hc(a+327720|0,418656,40960);return a|0}function ZG(){var a=0,b=0,c=0;b=gb-16|0;gb=b;a=Tb(b,12462);a:{if(!Ab(a)){break a}c=1;if((tg(a,11794)|0)!=-1){break a}if((tg(a,13846)|0)!=-1){break a}if((tg(a,10986)|0)!=-1){break a}c=(tg(a,11029)|0)!=-1}vb(a);gb=b+16|0;return c|0}function Nba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=12){Hi(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(ge(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}gb=d+16|0}function Jd(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>2047){u[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function tD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if((b|0)<=-1){pd(8399);L()}f=Nc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function yU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=SU(c+8|0,c);gb=c+32|0;return a}function Vc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Mf(b);e=gb-16|0;gb=e;c=Kc(a);a:{if(c>>>0>=d>>>0){c=Jb(a);Xl(c,b,d);t[e+15|0]=0;Bd(d+c|0,e+15|0);gh(a,d);break a}f=c;g=d-c|0;c=Ab(a);qp(a,f,g,c,0,c,d,b)}gb=e+16|0;return a|0}function Tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Bp(c+24|0,b);e=yb(c+24|0);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;cc(c+16|0,a,c);if((yb(c+16|0)|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0}function Rd(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;a=_w(c,a);d=gb-16|0;gb=d;if(!w[v[yc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}gb=d+16|0;gb=c+16|0;return b}function RB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);h=b,i=yb(a)+v[b+12>>2]|0,v[h+12>>2]=i;gb=d+16|0}function FR(a,b){var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22692]=0;R(1106,a|0,b|0);d=v[22692];v[22692]=0;if((d|0)!=1){v[22692]=0;R(1107,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;yR(c);S(a|0);L()}return a}function xfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(sg(a)>>>0<b>>>0){d=wb(a);b=qs(c+8|0,b,Ec(a),d);v[22692]=0;Hn(a,b);a=v[22692];v[22692]=0;if((a|0)==1){break a}pu(b)}gb=c+32|0;return}a=P()|0;O()|0;pu(b);S(a|0);L()}function ts(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;if(b){e=Kc(a);d=Ab(a);g=d+b|0;if(e-d>>>0<b>>>0){Rm(a,e,g-e|0,d,d,0,0)}e=d;d=Jb(a);Er(e+d|0,b,c);gh(a,g);t[f+15|0]=0;Bd(d+g|0,f+15|0)}gb=f+16|0;return a|0}function nA(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[a+104>>2];if(d){v[a+88>>2]=v[a+88>>2]&-131|128;d=v[d>>2];v[a+76>>2]=d;v[c+12>>2]=b<<8;v[c+8>>2]=d-1;b=d+(v[Fb(c+12|0,c+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}gb=c+16|0}function jO(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){d=so(a);v[b+12>>2]=7;v[b+8>>2]=32;c=c+15|0;if(c>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}gb=b+16|0;return c}function HK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function GK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function gD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=0;a:{if(!a){break a}e=a|-16;if(b>>>0>1?a>>>0<16&c:1){break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[Bf(d+15|0,d+14|0)|0]}a=e;gb=d+16|0;return a&255}function GN(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=Vb(a),v[e+8>>2]=f;b=b+B(Rt(d+24|0,d+8|0),6)|0;if(Gb(d+24|0,d+16|0)){IC(a,gz(b+B(Rt(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}Fg(b);gb=d+32|0}function l4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=at(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Cd(c);v[f>>2]=a;if(!a){break a}e=at(a,c,b,v[d+12>>2])}gb=d+16|0;return e|0}function _X(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function $t(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=49500;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=49516;break a;case 2:c=49512;break a;case 1:break b;case 0:break c}}c=49508;break a}c=49504}v[a>>2]=v[c>>2]}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[a+480180>>2]=b;bA(c,uq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;$t(a+8|0,uq(a));gb=c+16|0}function JK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function IK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function rma(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+30>>1]=0;c=vd(b+8|0,b+30|0,2);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;cc(b+16|0,a,b);if(!((yb(b+16|0)|0)!=2|x[b+30>>1]!=21584)){Rb(a,2);e=1}gb=b+32|0;return e|0}function DO(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function bP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;b=ds(d,a,b);a=v[b+4>>2];e=v[b+8>>2];if((a|0)!=(e|0)){while(1){f=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=f;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(e|0)){continue}break}}$b(b);gb=d+16|0}function LU(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){LY(c);rD(v[c>>2],Yi(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);d=wb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function us(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){Xe(a,c);e=a;break a}f=Pk(c)+1|0;e=mi(a,f);cf(a,e);pg(a,f);ee(a,c)}Og(e,b,c);t[d+15|0]=0;Bd(c+e|0,d+15|0);gb=d+16|0;return}$f();L()}function mt(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!Yx(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Le(a)}return b}aa(12779,10482,1563,2521);L()}function lU(a,b,c){var d=0;d=gb-16|0;gb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|b>>>0>=c>>>0|b>>>0>=109|c>>>0>=109)){t[d+14|0]=(x[(b<<1)+39054>>1]-x[(c<<1)+39054>>1]|0)/5;a=w[ac(d+15|0,d+14|0)|0]}gb=d+16|0;return a&255}function hu(a,b){var c=0,d=0;c=B(b,872)+a|0;a:{if(v[c+1075080>>2]&134218752){break a}if(!nk(c+1074992|0)){break a}b=w[v[(B(b,872)+a|0)+1075648>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function bT(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function Yg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=mi(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=b+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Kca(a){a=a|0;var b=0;kb[v[v[a>>2]+128>>2]](a);Qy(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=kb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function It(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(bg(a)>>>0<b>>>0){d=wb(a);b=Yg(c+8|0,b,pc(a),d);v[22692]=0;R(120,a|0,b|0);a=v[22692];v[22692]=0;if((a|0)==1){break a}be(b)}gb=c+32|0;return}a=P()|0;O()|0;be(b);S(a|0);L()}function jW(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function NV(a){var b=0,c=0;a:{if(rd(a,12153,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function IG(){var a=0;a:{b:{if(t[464176]&1){break b}if(!Rd(464176)){break b}v[22692]=0;X(2546);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116043]=464168;Qd(464176)}return v[116043]}a=P()|0;O()|0;Ye(464176);S(a|0);L()}function D1(){var a=0;a:{b:{if(t[464188]&1){break b}if(!Rd(464188)){break b}v[22692]=0;X(2547);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116046]=464180;Qd(464188)}return v[116046]}a=P()|0;O()|0;Ye(464188);S(a|0);L()}function z0(a){a=a|0;a:{b:{if(t[464280]&1){break b}if(!Rd(464280)){break b}v[22692]=0;X(2569);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116069]=465088;Qd(464280)}return v[116069]}a=P()|0;O()|0;Ye(464280);S(a|0);L()}function v0(a){a=a|0;a:{b:{if(t[464288]&1){break b}if(!Rd(464288)){break b}v[22692]=0;X(2571);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116071]=465392;Qd(464288)}return v[116071]}a=P()|0;O()|0;Ye(464288);S(a|0);L()}function s0(a){a=a|0;a:{b:{if(t[464296]&1){break b}if(!Rd(464296)){break b}v[22692]=0;X(2573);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116073]=465424;Qd(464296)}return v[116073]}a=P()|0;O()|0;Ye(464296);S(a|0);L()}function qY(a,b,c){var d=0;d=gb-32|0;gb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){if(!cY(d+8|0,v[d+24>>2])){kp(d+24|0);if(Gb(d+24|0,d+16|0)){continue}}break}a=v[d+24>>2]}gb=d+32|0;return a}function pU(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function Rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Gb(d+16|0,d+24|0)){while(1){v[d+12>>2]=v[v[d+16>>2]>>2];UC(a,d+12|0);Oe(d+16|0);if(Gb(d+16|0,d+24|0)){continue}break}}gb=d+32|0}function RR(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function J0(a){a=a|0;a:{b:{if(t[464256]&1){break b}if(!Rd(464256)){break b}v[22692]=0;X(2563);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116063]=464432;Qd(464256)}return v[116063]}a=P()|0;O()|0;Ye(464256);S(a|0);L()}function F0(a){a=a|0;a:{b:{if(t[464264]&1){break b}if(!Rd(464264)){break b}v[22692]=0;X(2565);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116065]=464608;Qd(464264)}return v[116065]}a=P()|0;O()|0;Ye(464264);S(a|0);L()}function C0(a){a=a|0;a:{b:{if(t[464272]&1){break b}if(!Rd(464272)){break b}v[22692]=0;X(2567);a=v[22692];v[22692]=0;if((a|0)==1){break a}v[116067]=464784;Qd(464272)}return v[116067]}a=P()|0;O()|0;Ye(464272);S(a|0);L()}function rk(a){a=a|0;tc(a+16|0,v[a>>2]);tc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cd(a);e=Bk(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22692]=0;R(1111,a|0,1);b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;qR(e);vR(d);S(a|0);L()}function jqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;jb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function eT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22692]=0;b=b-28|0;R(944,c|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function c6(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{if(ur(b,7489)){hI(c,14651,b);a=Jb(c);v[22692]=0;R(2276,44,a|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);S(a|0);L()}gb=c+16|0;return a|0}L()}function YF(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22692]=0;b=b-36|0;R(213,c|0,b|0);c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function Vz(a,b,c){var d=0;a:{if(x[a+480192>>1]){if(!ue(b)|x[a+480192>>1]<c>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[wd(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function tA(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(Op(b)+-4.8737671609324025),A[d+8>>3]=e;SP(c+8|0,127);a=bn(A[c+8>>3]);gb=c+16|0;return a|0}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=Re(b);c=jT(d+8|0,c);v[22692]=0;Y(943,a|0,b|0,e-1&65535,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){Ce(c);gb=d+32|0;return}a=P()|0;O()|0;Ce(c);S(a|0);L()}function Zx(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!kt(a)){break a}if(!(t[a+1375|0]&1)){continue}break}ec(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Sca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){v[d+8>>2]=0;v[d+4>>2]=1065353216;e=(a+b|0)+4232|0,f=gA(C(z[Zf(d+12|0,d+8|0,d+4|0)>>2]*C(127))),t[e|0]=f;Ht(a)}gb=d+16|0}function Lo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;Db(d+8|0,c+1074312|0,102);a:{if(!Cb(d+8|0)){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;gb=d+16|0}function JT(a){a=+a;a=a*4294967296;if(D(a)<0x8000000000000000){jb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0|0}jb=-2147483648;return 0}function CR(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function CL(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=rf(12);b=v[b>>2];a=v[a>>2];v[22692]=0;a=BL(d,a,b);b=v[22692];v[22692]=0;if((b|0)!=1){a=v[Wi(c+8|0,a)>>2];gb=c+16|0;return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Vn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function N7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=er(b,a,c),e=0,v[d>>2]=e;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function MX(a){var b=0,c=0,d=0;b=v[a>>2];c=_C(a);d=gb-16|0;gb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=sn(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}gb=d+16|0;return v[b>>2]}function Aoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,12);a:{if(!d){t[c+16|0]=0;li(b,12,c+16|0);break a}LW(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function pG(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Ip(d,a,1);a=wb(a);e=v[c+4>>2];v[22692]=0;In(a,e,b);a=v[22692];v[22692]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function n0(a){a=a|0;a:{b:{if(t[464328]&1){break b}if(!Rd(464328)){break b}v[22692]=0;Q(2576,464316,83876)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464328)}return 464316}a=P()|0;O()|0;Ye(464328);S(a|0);L()}function i0(a){a=a|0;a:{b:{if(t[464360]&1){break b}if(!Rd(464360)){break b}v[22692]=0;Q(2576,464348,83912)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464360)}return 464348}a=P()|0;O()|0;Ye(464360);S(a|0);L()}function e0(a){a=a|0;a:{b:{if(t[464392]&1){break b}if(!Rd(464392)){break b}v[22692]=0;Q(2576,464380,83948)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464392)}return 464380}a=P()|0;O()|0;Ye(464392);S(a|0);L()}function a0(a){a=a|0;a:{b:{if(t[464424]&1){break b}if(!Rd(464424)){break b}v[22692]=0;Q(2576,464412,84032)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464424)}return 464412}a=P()|0;O()|0;Ye(464424);S(a|0);L()}function WQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=xn(d,a+8|0,Xq(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){Ko(v[a>>2],b);c=v[a>>2]+2|0;v[a>>2]=c;b=b+2|0;if(v[a+4>>2]!=(c|0)){continue}break}}Zc(a);gb=d+16|0}function Uv(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function LP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Db(d+8|0,a+1074312|0,80);if(!(!Cb(d+8|0)|!e)){t[b+824|0]=w[b+824|0]<<2}gb=d+16|0}function LH(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=kb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!He(b,-1)){break a}v[a>>2]=0}return a|0}function nW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Dg(d,a,1);a=wb(a);e=v[c+4>>2];v[22692]=0;cn(a,e,b);a=v[22692];v[22692]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function jM(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=zi(d,a,1);a=wb(a);e=v[c+4>>2];v[22692]=0;kl(a,e,b);a=v[22692];v[22692]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Oz(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}hc(a+24604|0,b,40);qO(a,c)}function GC(a,b){var c=0,d=0,e=0,f=0;c=a<<8&16711680|a<<24;d=b<<24|a>>>8;e=d&65280;d=b<<8|a>>>24;c=d&255|e|c;a=((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|f;jb=c;return a}function vw(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,3)){t[c+16|0]=0;li(a,3,c+16|0);break a}d=gb-16|0;gb=d;bc(c+24|0,a,3);gb=d+16|0;a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;id(c+16|0,b,c+8|0)}gb=c+32|0}function ok(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=v[a+24>>2];d=v[a+40>>2];v[22692]=0;v[b+12>>2]=1;a=Mc(a+20|0,b+12|0);e=v[22692];v[22692]=0;if((e|0)!=1){gb=b+16|0;return B(v[a>>2],c+d|0)}V(0)|0;O()|0;Bb();L()}function n2(){var a=0;a=gb-16|0;gb=a;v[116448]=0;v[116449]=0;v[a+12>>2]=0;Qo(465808);t[465952]=0;gb=a+16|0;v[22692]=0;X(2542);a=v[22692];v[22692]=0;if((a|0)!=1){JG(30);return}a=P()|0;O()|0;fx(465792);S(a|0);L()}function k0(a){a=a|0;a:{b:{if(t[464344]&1){break b}if(!Rd(464344)){break b}v[22692]=0;Q(70,464332,10979)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464344)}return 464332}a=P()|0;O()|0;Ye(464344);S(a|0);L()}function g0(a){a=a|0;a:{b:{if(t[464376]&1){break b}if(!Rd(464376)){break b}v[22692]=0;Q(70,464364,10773)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464376)}return 464364}a=P()|0;O()|0;Ye(464376);S(a|0);L()}function sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=ik(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=kb[e|0](a,c)|0}else{a=1}gb=c+16|0;return a|0}function p0(a){a=a|0;a:{b:{if(t[464312]&1){break b}if(!Rd(464312)){break b}v[22692]=0;Q(70,464300,2361)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464312)}return 464300}a=P()|0;O()|0;Ye(464312);S(a|0);L()}function c0(a){a=a|0;a:{b:{if(t[464408]&1){break b}if(!Rd(464408)){break b}v[22692]=0;Q(70,464396,6364)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(464408)}return 464396}a=P()|0;O()|0;Ye(464408);S(a|0);L()}function Mz(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;pO(a+24648|0);IO(a)}function it(a){var b=0;if(a){if(v[a+76>>2]<=-1){return Tx(a)}return Tx(a)}if(v[22684]){b=it(v[22684])}a=v[115172];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=Tx(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function fS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e>>2]=c;v[e+8>>2]=b;if(Gb(e+8|0,e)){while(1){qn(a,v[d>>2],v[e+8>>2]);nf(e+8|0);v[d>>2]=v[d>>2]+2;if(Gb(e+8|0,e)){continue}break}}gb=e+16|0}function bo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{if(c){Tb(d,c);break a}Kb(d)}v[22692]=0;U(13,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function Xw(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function CU(a){var b=0,c=0,d=0;c=a;b=v[a+8>>2];d=v[a+4>>2];if((b|0)!=(d|0)){while(1){b=b-56|0;v[c+8>>2]=b;Tu(b);b=v[c+8>>2];if((d|0)!=(b|0)){continue}break}}c=v[a>>2];if(c){Ru(c,(v[dc(a)>>2]-v[a>>2]|0)/56|0)}}function xd(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Lg(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}gb=c+16|0;break a}aa(8467,6190,136,11385);L()}return d}function ug(a){var b=0;v[22692]=0;a=T(1276,a|0)|0;b=v[22692];v[22692]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;X(20);b=v[22692];v[22692]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Bb();L()}function l8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Ip(e,a,d);wb(a);v[22692]=0;U(2073,b|0,c|0,d+4|0);a=v[22692];v[22692]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function KE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Lg(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}gb=c+16|0;break a}aa(8467,6190,136,11385);L()}return d}function H6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;kb[g|0](a,b,e,d);gb=e+16|0}function AR(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=ds(c,a,2048);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;v[a+4>>2]=0;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function iD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=d,f=qY(Vb(b),Zb(b),d+12|0),v[e+8>>2]=f;e=d,f=Zb(b),v[e>>2]=f;a:{if(Gb(d+8|0,d)){Pe(a,wb(v[d+8>>2]));break a}oi(a)}gb=d+16|0}function aP(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function WB(a,b,c){var d=0;d=gb-16|0;gb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Gb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}nf(d+8|0);if(Gb(d+8|0,d)){continue}break}}gb=d+16|0;return v[d+8>>2]}function Pv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function IO(a){var b=0,c=0;b=gb-544|0;gb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){BR(b,vf(a));c=a+1298224|0;a=a+1074992|0;while(1){hc(a+112|0,b,538);a=a+872|0;if((c|0)!=(a|0)){continue}break}}gb=b+544|0}function Bx(a){a=a|0;var b=0;v[a>>2]=78412;v[22692]=0;R(2369,a|0,0);b=v[22692];v[22692]=0;if((b|0)!=1){Wb(a+28|0);Xb(v[a+32>>2]);Xb(v[a+36>>2]);Xb(v[a+48>>2]);Xb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Bb();L()}function yO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22692]=0;c=c-52|0;R(1310,d|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function qs(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=bG(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function jR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22692]=0;c=c-12|0;R(1120,d|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function cS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22692]=0;c=c-32|0;R(1090,d|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function SG(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-16|0;gb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Dh(g+13|0,g+14|0)}h=c,i=(ab(b|0,nS(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;gb=g+16|0}function JX(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=aE(v[a+16>>2],b)}v[a>>2]=f;c=B(c,20)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,20)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Cv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Mb(128/(B(v[Gf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[Bf(c+7|0,c+6|0)|0];gb=c+16|0;return a|b<<4&240}function y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){while(1){a=d;if(y[b>>2]<=127){e=x[Tp()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function tfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){bO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=po(d+8|0,hr(a,Nb(a)+1|0),Nb(a),c);sq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;QN(a,c);yz(c);gb=d+32|0}function iu(a,b){a=hc(a,b,88);v[a+88>>2]=v[b+88>>2];hc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];hc(a+672|0,b+672|0,52);ro(a+724|0,b+724|0);ro(a+732|0,b+732|0);ro(a+740|0,b+740|0);hc(a+748|0,b+748|0,123)}function dla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;YU(c+24|0,a);Bg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function YD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22692]=0;c=c-20|0;R(348,d|0,c|0);d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function UA(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){Fo(d);SR(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function Efa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){bO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=po(d+8|0,hr(a,Nb(a)+1|0),Nb(a),c);sq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;WS(a,c);yz(c);gb=d+32|0}function yn(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=ZE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function xi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function up(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=ME(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function ag(a,b,c,d,e){var f=0;f=gb-256|0;gb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Qb(f,b&255,d?c:256);if(!d){while(1){sf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}sf(a,f,c)}gb=f+256|0}function Sba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;b=Ac(kqa(jqa(d,d>>31,b,0),jb,1e3,0),jb);v[a+16>>2]=0;v[a+12>>2]=b+c;YL(a,e);b=v[a+12>>2];v[f+12>>2]=0;iN(a,b,f+12|0);gb=f+16|0}function NS(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Bg(c+24|0,a);Bg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=QS(c+8|0,c);gb=c+32|0;return a|0}function HW(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;yh(a+12|0,d);if(b){f=IW(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,6)+f|0,v[g>>2]=h;gb=e+16|0;return a}function wN(a){var b=0,c=0,d=0;if(Qf(a)){while(1){b=a;d=c&65535;if(Qf(b)>>>0>d>>>0){b=af(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;FN(b);_e(b+36|0)}c=c+1|0;if(Qf(a)>>>0>(c&65535)>>>0){continue}break}}}function qX(a){var b=0,c=0;b=a+36|0;c=jqa(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}jb=a;return b}function qU(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;if((w[a|0]|w[a+1|0]<<8)!=2?(w[a|0]|w[a+1|0]<<8)!=1:0){break a}b=1}return b}function nK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Dg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;Ui(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function hP(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22692]=0;v[c>>2]=2147483647;v[c+4>>2]=0;a=Mk(c+8|0,c);b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function aC(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=1073741823;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function _E(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=2147483647;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function BN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=yr(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);Eh(b);b=b+6|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function $d(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Cd(b)}return c}function $S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Dg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);Qo(b);b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function w1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]>127){break a}if(!(x[Tp()+(v[c>>2]<<1)>>1]&b)){break a}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=Zp(e,a,d);v[22692]=0;U(2029,b|0,c|0,a+4|0);b=v[22692];v[22692]=0;if((b|0)!=1){$b(a);gb=e+16|0;return}b=P()|0;O()|0;$b(a);S(b|0);L()}function cG(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=357913941;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function bE(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=214748364;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function YN(){var a=0;a:{b:{if(t[459640]&1){break b}if(!Rd(459640)){break b}v[22692]=0;Q(1399,90936,1)|0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(459640)}return}a=P()|0;O()|0;Ye(459640);S(a|0);L()}function JW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=715827882;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function fp(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=1073741823;v[22692]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function a9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=v[a+24>>2];tL(d,c);v[22692]=0;U(556,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function a1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=ui(b+8|0,b+12|0);v[22692]=0;c=oI(0,0,4);d=v[22692];v[22692]=0;if((d|0)!=1){ff(a);gb=b+16|0;return c|0}b=P()|0;O()|0;ff(a);S(b|0);L()}function PU(a){var b=0,c=0,d=0,e=0;jb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function Ooa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=rf(2500);v[22692]=0;a=Q(48,c|0,a|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){a=v[Wi(b+8|0,a)>>2];gb=b+16|0;return a|0}a=P()|0;O()|0;Xb(c);S(a|0);L()}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=LE(a);if(d>>>0>=b>>>0){a=Wu(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Mc(c+12|0,c+8|0)>>2]}gb=c+16|0;return d|0}Sc();L()}function yw(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=536870911;v[22692]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function yT(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=134217727;v[22692]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function cR(a){var b=0,c=0,d=0;c=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;b=b-8|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=c}function _M(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22692]=0;c=v[22692];v[22692]=0;if((c|0)==1){break b}yk(b+16|0)}if(b){Qk(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function JO(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break a}kb[v[v[b>>2]+96>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function GA(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22692]=0;c=v[22692];v[22692]=0;if((c|0)==1){break b}hR(b+16|0)}if(b){hs(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function DV(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=178956970;v[22692]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function CI(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=268435455;v[22692]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function rN(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=82595524;v[22692]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function BO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-16|0;gb=c;_f(a,c+14|0);KC(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Ak(a,Lb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}Tz(b);gb=c+16|0}function qL(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=rf(1298432);v[22692]=0;c=T(2035,b|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){b=v[Wi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function Kd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function DR(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function xP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075648>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,872)+a|0)+1075096>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function vj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function pF(a){var b=0;if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>=7))){b=(w[a+7|0]-9&255)>>>0<7}return b}function Rs(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Mx(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Mx(a)}return a}function yv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function jS(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[a+16|0]=0;c=_A(b,v[a+12>>2]);v[22692]=0;R(1076,a|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){Sm(c);gb=b+32|0;return}a=P()|0;O()|0;Sm(c);S(a|0);L()}function ih(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[22692]=0;T(283,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ia(a|0,28288,204);L()}function aK(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=-1;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Qc(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22692]=0;v[c>>2]=-1;v[c+4>>2]=0;a=Mk(c+8|0,c);b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function $0(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=ui(b+8|0,b+12|0);v[22692]=0;c=iH();d=v[22692];v[22692]=0;if((d|0)!=1){ff(a);gb=b+16|0;return c|0}b=P()|0;O()|0;ff(a);S(b|0);L()}function zG(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=e;e=ui(f+8|0,f+12|0);v[22692]=0;a=Wp(a,b,c,d);b=v[22692];v[22692]=0;if((b|0)!=1){ff(e);gb=f+16|0;return a}a=P()|0;O()|0;ff(e);S(a|0);L()}function c$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Ep(a);v[a>>2]=27464;e=dc(a);d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;SF(e,c+8|0);gb=c+32|0;return a|0}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<pc(a)>>>0){a=io(d,kc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=Ky(c,a);Hb(a);e=b^1}gb=d+16|0;return e|0}function Nh(a,b){var c=0,d=0;a=v[a>>2];b=Wd(b);c=b;d=a+16|0;if(Nb(d)>>>0>b>>>0){c=v[Lb(d,c)>>2]!=0}else{c=0}if(!c){a=ba(4)|0;ym(a);v[a>>2]=89532;ia(a|0,89580,2304);L()}return v[Lb(a+16|0,b)>>2]}function NK(a){a=a|0;var b=0;a=a+24|0;b=OK(v[a>>2]);if(Qi(Sb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074446>>1]}b=x[rc(Sb(v[a>>2]+484360|0),b)>>1];return(Wl(v[a>>2]+484344|0,b)?b:-1)|0}function xg(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb+-64|0;gb=c;d=dz(c+8|0,a);v[22692]=0;U(1474,a|0,b|0,d|0);a=v[22692];v[22692]=0;if((a|0)!=1){Dm(d);gb=c- -64|0;return}a=P()|0;O()|0;Dm(d);S(a|0);L()}function x1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]<=127){if(x[Tp()+(v[c>>2]<<1)>>1]&b){break a}}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function po(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=Pz(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function lha(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=VT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){eR(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function ir(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Dg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){Vj(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function apa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,6)){t[c+16|0]=0;li(a,6,c+16|0);break a}IX(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;id(c+16|0,b,c+8|0)}gb=c+32|0}function _f(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;u[c+30>>1]=0;wj(c+16|0,a,c+30|0,2);a=yb(c+16|0);u[c+14>>1]=x[c+30>>1];d=b;b=c+14|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;gb=c+32|0;return(a|0)==2|0}function _R(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=aS(b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<5)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Ty(a){var b=0,c=0,d=0,e=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=so(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}A[c+4280>>3]=C(C(a|0)*C(-4.656612873077393e-10))}function SI(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=SH(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<4)+f|0,v[g>>2]=h;gb=e+16|0;return a}function KA(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=zR(b)}v[a>>2]=f;c=(c<<3)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<3)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Hla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,5)){t[c+16|0]=0;li(a,5,c+16|0);break a}Qv(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;id(c+16|0,b,c+8|0)}gb=c+32|0}function xO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];if((b|0)>=11){e=a;b=378;while(1){wO(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}b=0}v[d+112>>2]=b+1;a=wO(a);return a|0}function wT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=sI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){yv(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function pn(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,4)){t[c+16|0]=0;li(a,4,c+16|0);break a}yi(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;id(c+16|0,b,c+8|0)}gb=c+32|0}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4332);if(!d){return 0}v[22692]=0;a=fa(1785,d|0,a|0,b|0,c|0,0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4332);if(!d){return 0}v[22692]=0;a=fa(1785,d|0,a|0,b|0,c|0,1)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function cU(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function XT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=VT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){UT(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function PI(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=sI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){WH(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4332);if(!d){return 0}v[22692]=0;a=fa(1680,d|0,a|0,b|0,c|0,0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Ki(a){var b=0,c=0,d=0,e=0;e=Ae(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=Ae(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function BT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=xT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){NB(a);a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function vC(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function uD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function gv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Lk(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Vj(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function cc(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;g=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=b;kb[g|0](a,e,f,d);gb=d+16|0}function QV(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=xn(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Hk(a);a=v[b>>2]+2|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Zc(b);gb=c+16|0}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(86224);if(!d){return 0}v[22692]=0;a=ca(1871,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4304);if(!d){return 0}v[22692]=0;a=ca(1579,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4276);if(!d){return 0}v[22692]=0;a=ca(1738,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function uR(a,b){var c=0,d=0;c=v[a+24>>2];v[22692]=0;c=le(c+484344|0,b);d=v[22692];v[22692]=0;if((d|0)!=1){if(c){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}V(0)|0;O()|0;Bb();L()}function oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4268);if(!d){return 0}v[22692]=0;a=ca(1761,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function cx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=ui(e+8|0,e+12|0);v[22692]=0;a=il(a,b,c);b=v[22692];v[22692]=0;if((b|0)!=1){ff(d);gb=e+16|0;return a}a=P()|0;O()|0;ff(d);S(a|0);L()}function bw(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,2)){t[c+16|0]=0;fE(a,c+16|0);break a}un(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;id(c+16|0,b,c+8|0)}gb=c+32|0}function b9(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=v[a+24>>2];tL(c,b);v[22692]=0;U(556,a|0,1,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function ap(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){BW(b);break a}yi(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;id(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function Yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4236);if(!d){return 0}v[22692]=0;a=ca(1649,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4268);if(!d){return 0}v[22692]=0;a=ca(1516,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function SQ(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Rz(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;yc(b+8|0,a+116|0);v[22692]=0;c=Na(1312,a|0)|0;a=O()|0;c=c|0;d=v[22692];v[22692]=0;if((d|0)!=1){gb=b+16|0;jb=a;return c}a=P()|0;O()|0;S(a|0);L()}function Rba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(5048);if(!d){return 0}v[22692]=0;a=ca(1821,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Lpa(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=rf(1);v[22692]=0;c=T(39,b|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){b=v[Wi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function KM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-2048|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4276);if(!d){return 0}v[22692]=0;a=ca(1848,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Dca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4280);if(!d){return 0}v[22692]=0;a=ca(1714,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function $ba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4228);if(!d){return 0}v[22692]=0;a=ca(1798,d|0,a|0,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function zX(a){var b=0,c=0;a:{if(rd(a,18688,11)){break a}b=a+215|0;a=a+63|0;while(1){if(w[a+16|0]>3|w[a+17|0]>3|w[a+18|0]>=16){break a}a=a+19|0;if((b|0)!=(a|0)){continue}break}c=1}return c}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;d=c+8|0;e=b;if(lp(b,c+56|0)){b=Zm(c+56|0)}else{b=0}ud(d,e,b);b=a;a=jc(c+32|0,c+8|0);Ul(b,c+56|0,a);xb(a);xb(c+8|0);gb=c- -64|0}function pH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function efa(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!_j(a,b+8|0)){break a}c=0;if(!LN(b+8|0)){break a}c=b;a=CT(a,b);if(!a){Vj(c)}c=-1;if(!a){break a}c=KN(b)}gb=b+16|0;return c|0}function UL(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4228|0,c,yb(b));Ht(a)}}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4260|0,c,yb(b));Nt(a)}}function xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;QT(b,c);if(Pb(a,c<<8)){bc(d+24|0,v[b>>2],ah(b)<<8);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;id(d+16|0,a,d+8|0)}gb=d+32|0}function u1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Bs()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function tpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=Tb(b,7489);v[22692]=0;a=Q(46,a|0,c|0)|0;d=v[22692];v[22692]=0;if((d|0)!=1){vb(c);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(c);S(a|0);L()}function s1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[As()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function kca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Hi(d+12|0);c=z[d+12>>2];if((b|0)==4){c=ge(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;cM(a)}gb=d+16|0}function jY(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-48|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function bz(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Wba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=1){Hi(d+12|0);c=z[d+12>>2];if((b|0)==1){c=ge(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;ZL(a)}gb=d+16|0}function US(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>=3){break a}b=131842>>>(a<<3)|0}return b&255}function Ti(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22692]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function OY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;d=c+8|0;e=b;if(lp(b,c+56|0)){b=KY(c+56|0)}else{b=0}ud(d,e,b);b=a;a=jc(c+32|0,c+8|0);Ul(b,c+56|0,a);xb(a);xb(c+8|0);gb=c- -64|0}function GI(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-16|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function zU(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-4|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function yt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=gb-16|0;gb=a;if(Nb(b)){while(1){v[a+8>>2]=0;Ui(a+8|0);d=Lb(b,c),e=v[a+8>>2],v[d>>2]=e;c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}gb=a+16|0}function oK(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-1|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;wF(b,c);c=Pb(a,c<<3);if(c){vF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;id(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function bH(a){var b=0;a:{b:{a=v[a>>2];if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a|0)!=(a&-256)}return b}function Xu(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22692]=0;df(a+8|0,b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Xh(a){var b=0;a=ge(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function SW(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-6|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Gg(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22692]=0;Of(a+8|0,b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function $pa(){var a=0;a:{b:{if(t[90804]&1){break b}if(!Rd(90804)){break b}v[22692]=0;X(34);a=v[22692];v[22692]=0;if((a|0)==1){break a}Qd(90804)}return}a=P()|0;O()|0;Ye(90804);S(a|0);L()}function $E(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22692]=0;c=c-2|0;d=v[22692];v[22692]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function sj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function q4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=jt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;hc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function mD(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-28|0;v[b+8>>2]=c;Zd(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){rD(b,HY(a))}}function gba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=AL(f,b,c,d,0,0,0,0,e);gb=f+16|0;return a|0}function YE(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-2;v[22692]=0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function WT(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-12|0;v[b+8>>2]=c;YT(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){Nu(b,Hp(a))}}function VS(a){var b=0,c=0;c=v[a+4>>2];a:{while(1){b=v[a+8>>2];if((b|0)==(c|0)){break a}v[a+8>>2]=b-4;v[22692]=0;b=v[22692];v[22692]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function UB(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-4;v[22692]=0;c=v[22692];v[22692]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function Bm(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Nb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Nb(c)<<16)-65536>>16<(b|0)){break a}d=z[Lb(c,b-u[a+28>>1]|0)>>2]}return d}function oe(a,b){var c=0;a:{c=Mf(b);if((c|0)==(Ab(a)|0)){v[22692]=0;a=fa(547,a|0,0,-1,b|0,c|0)|0;b=v[22692];v[22692]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Bb();L()}function JL(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=Ke(31415.926535897932/+b);d=Io((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function XQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Rc(a,8,1,0,11);return}d=a;a=b+31|0;Rc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function TX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;Gk(b,c);c=Pb(a,c);if(c){FD(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;id(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function Lx(a,b,c,d,e,f,g,h,i){var j=0;j=gb-16|0;gb=j;vg(j,b,c,d,e,f,g,h,i^-2147483648);b=v[j+4>>2];v[a>>2]=v[j>>2];v[a+4>>2]=b;b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;gb=j+16|0}function Fda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=gb-16|0;gb=d;e=d,f=C(C(kb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Hi(d+12|0);kb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);gb=d+16|0}function z_(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a=Cn(c+8|0,a);v[22692]=0;a=W(272,a|0,b|0,10389)|0;b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Bs()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function lN(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22692]=0;v[b+8>>2]=32767;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function k1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[As()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Fv(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22692]=0;v[b+8>>2]=65535;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return x[a>>1]}V(0)|0;O()|0;Bb();L()}function xv(a){var b=0,c=0;b=gb-16|0;gb=b;u[b+14>>1]=a;v[22692]=0;u[b+12>>1]=255;a=Pc(b+14|0,b+12|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function uC(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=JW(a);if(d>>>0<=b>>>0){a=Sj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function u0(){var a=0;a:{if(t[465416]&1){break a}if(!Rd(465416)){break a}a=465392;while(1){a=Kb(a)+12|0;if((a|0)!=465416){continue}break}Qd(465416)}Vc(465392,11110);Vc(465404,11089)}function r0(){var a=0;a:{if(t[465448]&1){break a}if(!Rd(465448)){break a}a=465424;while(1){a=Kb(a)+12|0;if((a|0)!=465448){continue}break}Qd(465448)}jd(465424,88912);jd(465436,88924)}function nh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=aK(a);if(d>>>0<=b>>>0){a=bg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function fd(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);gb=d+16|0}function ch(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=aC(a);if(d>>>0<=b>>>0){a=ye(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Qw(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=cG(a);if(d>>>0<=b>>>0){a=sg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Nk(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=_E(a);if(d>>>0<=b>>>0){a=Ng(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function KX(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=bE(a);if(d>>>0<=b>>>0){a=Yl(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function EL(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=DL(f,b,c,d,e,0,0,0,0);gb=f+16|0;return+c}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(DV()>>>0<b>>>0){Sc();L()}c=b;if(c>>>0>=178956971){pd(8399);L()}c=Nc(B(c,24),4);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+B(b,24)|0,v[d>>2]=e}function uN(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=rN();if(d>>>0<=b>>>0){a=jk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function roa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;gX(b,c,32);fX(a,c);gb=c+32|0}function hr(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=fp();if(d>>>0<=b>>>0){a=ye(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function fs(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=yw();if(d>>>0<=b>>>0){a=rg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function _n(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(lK(a)){break a}v[22692]=0;R(2095,b+8|0,a|0);c=v[22692];v[22692]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Bb();L()}t[a+20|0]=255;gb=b+16|0}function Wx(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=CI();if(d>>>0<=b>>>0){a=vi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Wq(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=yT();if(d>>>0<=b>>>0){a=bi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function W_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=kb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function PO(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;MO(c,b+80|0);v[22692]=0;U(13,a|0,0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function Ls(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=Ab(b);if(d>>>0<c>>>0){Tn();L()}b=Jb(b);v[e+4>>2]=d-c;us(a,b+c|0,v[Fb(e+12|0,e+4|0)>>2]);gb=e+16|0}function LQ(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[fc(a)+4|0]){v[22692]=0;a=v[22692];v[22692]=0;if((a|0)==1){break b}Lm(b+16|0)}if(b){AA(b)}break a}V(0)|0;O()|0;Bb();L()}}}function L7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){v[d>>2]=v[a>>2];eg(d+4|0,a+4|0);d=v[c>>2]+16|0;v[c>>2]=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}}function KN(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function GO(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function yL(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22692]=0;T(1919,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return}ia(a|0,54704,1920);L()}function pS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=ji(e,a,d);a=wb(a);v[22692]=0;fS(a,b,c,d+4|0);a=v[22692];v[22692]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function _l(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22692]=0;v[b+8>>2]=255;a=Fb(b+12|0,b+8|0);c=v[22692];v[22692]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Jy(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22692]=0;T(1931,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return}ia(a|0,54760,1920);L()}function FG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83640;b=a+16|0;if(Nb(b)){while(1){d=v[Lb(b,c)>>2];if(d){Gn(d)}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}vb(a+192|0);fx(b);return a|0}function xN(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function hJ(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}function um(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=(a&-252645136)>>>4|(a&252645135)<<4;a=(a&-858993460)>>>2|(a&858993459)<<2;return(a&-1431655766)>>>1|(a&1431655765)<<1}function jj(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){ai(a,v[a>>2],ak(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Xe(b,0);v[c+12>>2]=0;Fe(b,c+12|0);gb=c+16|0}function ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=yr(e,a,d);wb(a);a=c-b|0;if((a|0)>=1){hc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}$b(d);gb=e+16|0}function c3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;a=dk(a,b,c,d,e,f,g+8|0,g+16|0);gb=g+16|0;return a|0}function QU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>=33){break a}c=w[a+4|0]>95}return c}function HS(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=ei(w[a+797|0]-u[a+770>>1]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[lc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function v4(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;nT(b,0,a);v[22692]=0;a=T(141,b|0)|0;c=v[22692];v[22692]=0;if((c|0)!=1){vb(b);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function tE(a){var b=0,c=0;a:{if(rd(a,11374,3)){break a}b=a+3|0;if((w[b|0]!=1?w[b|0]<=7:0)|w[b|0]>14){break a}a=a+40|0;if(!(w[b|0]>8?w[a|0]<33?w[a|0]:0:1)){break a}c=1}return c}function Iy(a,b){var c=0,d=0;c=gb-16|0;gb=c;u[b>>1]=0;t[c+15|0]=0;Vh(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Vh(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}gb=c+16|0}function GX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(rd(a+44|0,14894,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Eb(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){Uk(a,v[a>>2],ak(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Xe(b,0);t[c+15|0]=0;Bd(b,c+15|0);gb=c+16|0}function D4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;kb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(He(v[a+4>>2],v[c+4>>2])){a=v[a>>2]==v[c>>2]}else{a=0}gb=d+16|0;return a|0}function Ak(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;wj(c,a,c+12|0,4);a=yb(c);v[c>>2]=v[c+12>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gb=c+16|0;return(a|0)==4}function tN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!le(a,b)){break a}c=az(a,v[af(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=af(a,b);EN(af(a,c),b);d=c}return d|0}function qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Nb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=kN(a,b,c,d+8|0);gb=d+16|0;return a|0}function fpa(a,b){a=a|0;b=b|0;if(!WX(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function f4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return a|0}function X6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;my(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+8|0,d+12|0)>>2]}gb=d+16|0;return c|0}function H7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[13842];v[c+8>>2]=v[13841];v[c+12>>2]=d;d=v[13840];v[c>>2]=v[13839];v[c+4>>2]=d;kb[v[Rh(c,Xg(b))>>2]](a,b);gb=c+16|0}function Gq(a,b){var c=0;a:{if(b){Gq(a,v[b>>2]);Gq(a,v[b+4>>2]);a=fc(a);v[22692]=0;c=v[22692];v[22692]=0;if((c|0)==1){break a}hR(b+16|0);hs(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function CC(a,b){var c=0;a:{if(b){CC(a,v[b>>2]);CC(a,v[b+4>>2]);a=fc(a);v[22692]=0;c=v[22692];v[22692]=0;if((c|0)==1){break a}yk(b+16|0);Qk(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function ni(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=ce(b),v[d+12>>2]=e;v[22692]=0;df(a,c+12|0,b);b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function dR(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;if(c){a=wb(a);while(1){f=Fl(a,c+16|0,b);d=f?d:c;c=v[(f?4:0)+c>>2];if(c){continue}break}}a=v[yc(e+8|0,d)>>2];gb=e+16|0;return a}function Dba(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=zo(C(C(C(vf(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;RL(a);QL(a)}function Pp(a){var b=0,c=0;b=v[22688];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Sw()>>>0<a>>>0){if(!(va(a|0)|0)){break a}}v[22688]=a;return b}v[115173]=48;return-1}function Ft(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;yk(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;tK(v[a>>2],vi(a))}}function FU(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;Tu(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;Ru(v[a>>2],DU(a))}}function ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;wF(b,c);if(Pb(a,c<<3)){vF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;id(d+16|0,a,d+8|0)}gb=d+32|0}function c5(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;rH(a,c,6059);v[a>>2]=78392;gb=c+16|0;return a|0}function rr(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){_o(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(lg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;_o(a,c)}function qr(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){_o(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(lg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;_o(a,c)}function kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+8>>2]=b;d=c,e=Vb(a),v[d>>2]=e;b=iv(c+8|0,c);b=v[a>>2]+(b<<2)|0;ej(a,Qg(b+4|0,v[a+4>>2],b));Fg(b);gb=c+16|0}function Sha(a,b){a=a|0;b=b|0;var c=0;c=cd(a);t[a+16|0]=0;v[a+12>>2]=b;v[22692]=0;_(1075,a|0);b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Bu(c);S(a|0);L()}function Rp(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=jqa(a,0,b,0);e=jb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Cd(b);if(!(!a|!(w[a-4|0]&3))){Qb(a,0,b)}return a}function DA(a,b){var c=0;c=gb-16|0;gb=c;Bg(c+8|0,b);v[22692]=0;a=jB(a,c+8|0);b=v[22692];v[22692]=0;a:{if((b|0)!=1){gb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}return a>>>31|0}function zB(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/872|0;v[22692]=0;Oc(b,B(a,872),8);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function p1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function X_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Ul(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;En(a+8|0,c);return a}function zW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];UC(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}gb=d+16|0}function rW(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-33>>>0)/33^-1,33)+c}b=v[a>>2];if(b){qW(b,(v[dc(a)>>2]-v[a>>2]|0)/33|0)}}function qA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[b+56>>2]=0;d=b,e=Jm(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(v[a+480180>>2]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function Yu(a){var b=0,c=0,d=0;d=a+32|0;a:{while(1){c=w[a|0];if(!((c-1&255)>>>0<31|((b^1)&1?0:c))){b=!c|b;a=a+1|0;if((d|0)!=(a|0)){continue}break a}break}b=0}return b&1}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Ti(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Wj(c+12|0,c+8|0,49640)>>2],v[d+36>>2]=e;iq(a);gb=c+16|0}function l_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;df(a+8|0,d+12|0,d+8|0);if(b){Vr(a,b);QE(a,b,w[c|0])}gb=d+16|0;return a|0}function kt(a){var b=0,c=0;b=a;a:{if((Le(b)|0)!=79){break a}if((Le(b)|0)!=103){break a}if((Le(b)|0)!=103){break a}c=(Le(b)|0)==83}if(!c){ec(a,30);return 0}return ZI(a)}function ima(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=qg(b);qg(b);break a}a=Mg(b);Mg(b)}if(a){while(1){if(a&1){Rb(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function iJ(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function h1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Gc(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;d=!EW(a,c)}gb=c+16|0;return d}function AK(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Qi(Sb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[rc(Sb(v[a>>2]+484360|0),b)>>1]}return c|0}function $4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Up(d,a);EG(a,c);v[22692]=0;R(2369,b|0,1);a=v[22692];v[22692]=0;if((a|0)==1){a=P()|0;O()|0;Wb(d);S(a|0);L()}}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}HL(a,i,h,g,e,f,b,c,d)}function rd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function qG(a,b,c,d){var e=0,f=0,g=0;f=v[a+4>>2];e=0;a:{if(!c){break a}g=f>>8;e=g;if(!(f&1)){break a}e=Ww(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function Bj(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function sl(a,b,c){var d=0;d=gb-16|0;gb=d;tl(d+8|0,a+24|0,b);a=v[d+12>>2];a:{if(c){b=v[d+8>>2];v[b>>2]=a|v[b>>2];break a}b=v[d+8>>2];v[b>>2]=v[b>>2]&(a^-1)}gb=d+16|0}function rf(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Cd(a);if(!b){b=v[116498];if(!b){break a}kb[b|0]();continue}break}return b|0}a=ba(4)|0;gm(a);ia(a|0,89088,1912);L()}function UD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Lg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=ID(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function ST(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1299020115){a=a+4|0;a=(Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}else{a=0}return a}function Ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=mc(a+8|0);v[22692]=0;U(393,a|0,b|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gc(d);S(a|0);L()}}function GB(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/9|0;v[22692]=0;Oc(b,B(a,9),1);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function C_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Lg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=HD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function zx(a,b){var c=0;c=zH(a+4|0);v[a>>2]=77264;v[c>>2]=77284;v[22692]=0;R(2388,c|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){return}a=P()|0;O()|0;lh(c);S(a|0);L()}function yX(a){var b=0,c=0;c=jqa(w[a+217|0],0,9,0);b=w[a+216|0];a=b>>>31|0;b=b<<1;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;if(b>>>0<11){a=a+1|0}jb=a;return b}function k6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=dt(Qa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);gb=e+16|0;jb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function Y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;my(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function RS(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function RQ(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-7>>>0)/7^-1,7)+c}b=v[a>>2];if(b){JQ(b,(v[dc(a)>>2]-v[a>>2]|0)/7|0)}}function Qfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[22692]=0;a=Q(1299,a|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function MU(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function Ee(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[fc(a)>>2];v[22692]=0;_(a|0,c|0);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Ax(a,b){var c=0;c=bu(a+4|0);v[a>>2]=77216;v[c>>2]=77236;v[22692]=0;R(2387,c|0,b|0);a=v[22692];v[22692]=0;if((a|0)!=1){return}a=P()|0;O()|0;lh(c);S(a|0);L()}function xA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=9){if((wA(d)|0)>(e|0)){break b}}g=a,h=vA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function oA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=4){if((wA(d)|0)>(e|0)){break b}}g=a,h=vA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function XH(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Kg(b),d=v[v[a>>2]+52>>2],kb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Kg(b)}function TP(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=2){if((wA(d)|0)>(e|0)){break b}}g=a,h=vA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function yS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=hn(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function yB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;BR(a+112|0,48e3);v[a+668>>2]=0;xB(a+724|0);xB(a+732|0);xB(a+740|0);_i(a+788|0);return a}function gp(a,b){var c=0,d=0,e=0;wv(a);dp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Zt(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Qb(a+32|0,0,40);ex(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function Rb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Pb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function Qu(a,b){var c=0,d=0,e=0;wb(b);c=rh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[wb(b)>>2];d=wb(c),e=a,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Cha(a,b){a=a|0;b=b|0;var c=0;c=wh(a);t[a+530|0]=0;v[22692]=0;R(1091,a|0,b|0);b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;fn(c);S(a|0);L()}function Sq(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function E$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=v[c>>2];a=kb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}gb=d+16|0;return a|0}function BA(a,b){a:{if(b){BA(a,v[b>>2]);BA(a,v[b+4>>2]);fc(a);v[22692]=0;a=v[22692];v[22692]=0;if((a|0)==1){break a}Lm(b+16|0);AA(b)}return}V(0)|0;O()|0;Bb();L()}function h2(){var a=0,b=0;a:{Xd(465504);v[116376]=83712;v[22692]=0;a=ga(2460)|0;b=v[22692];v[22692]=0;if((b|0)!=1){v[116378]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function Vh(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+31|0]=0;wj(c+16|0,a,c+31|0,1);a=yb(c+16|0);t[c+8|0]=w[c+31|0];t[b|0]=w[c+8|0];gb=c+32|0;return(a|0)==1|0}function $la(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-80|0;gb=d;c=-1;a:{if(!xY(a,d+8|0)){break a}c=0;if(!aV(d+8|0)){break a}c=Me(a,b,$U(d+8|0),jb)}gb=d+80|0;return c|0}function x4(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){sH();c=90744;break a}b:{if(t[463892]&1){break b}if(!Rd(463892)){break b}Qd(463892)}c=90740}sd(a,b,c)}function tT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-256>>>8^-1)<<8)+c}b=v[a>>2];if(b){tB(b,v[dc(a)>>2]-v[a>>2]>>8)}}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a);v[22692]=0;U(47,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Lc(d);S(a|0);L()}function Oj(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!lg(a)){while(1){a=v[a+8>>2];if(!lg(a)){continue}break}}a=v[a+8>>2];break a}a=RV(b)}v[c>>2]=a}function Be(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function BM(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Fb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);gb=c+16|0}function vA(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=Px(b,a);break a}c=(a>>>0)/1e8|0;d=a-B(c,1e8)|0;a=(d>>>0)/1e4|0;a=rj(rj(BI(b,c),a),d-B(a,1e4)|0)}return a}function sK(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function r4(a,b){a=a|0;b=b|0;ym(a);v[a>>2]=89128;b=Jb(b);v[22692]=0;Q(2431,a+4|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function oF(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=zb((kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0);a=v[b>>2];vd(c,d,(kb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function oE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(De(a)){d=v[a>>2];t[c+15|0]=0;Bd(b+d|0,c+15|0);ee(a,b);break a}t[c+14|0]=0;Bd(a+b|0,c+14|0);Xe(a,b)}gb=c+16|0}function lqa(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;hqa(e-d|0,(b^a)-((d>>>0>e>>>0)+a|0)|0,c,0);jb=ib;b=d^hb;c=b-d|0;jb=(a^jb)-((b>>>0<d>>>0)+a|0)|0;return c}function ks(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[22692]=0;df(a,c+12|0,c+8|0);b=v[22692];v[22692]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function CV(a,b){var c=0;c=gb-32|0;gb=c;a:{if(!Tf(a,4)){BW(b);break a}yi(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;RB(c+16|0,a,c+8|0)}gb=c+32|0}function QL(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function Gs(a){a=a|0;var b=0;b=ba(8)|0;v[22692]=0;Q(1965,b|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){ia(b|0,89436,204);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function EB(a,b){var c=0,d=0,e=0,f=0;d=rh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);e=wb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Bda(a,b){a=a|0;b=b|0;var c=0;JM(a);c=b+4|0;wk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Sf(a);vl(a);vl(a)}function W2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return ck(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0)|0}function U6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){Yf(d,a);d=v[c>>2]+12|0;v[c>>2]=d;a=a+12|0;if((b|0)!=(a|0)){continue}break}}}function eB(a,b,c,d,e){var f=0;if(d){while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function am(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;gb=d+16|0}function $l(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;gb=d+16|0}function xS(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}YW(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function si(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function pA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=Jm(a,x[b+70>>1],v[b+48>>2],c,0)}return d|0}function Y7(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=eg(a,b);v[22692]=0;Q(69,a+12|0,c|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);S(a|0);L()}}function Wz(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;v[22692]=0;df(a,b+12|0,b+8|0);a=v[22692];v[22692]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function HT(a){var b=0;a=fe(a);b=32767;a:{if(!(a<32767)){break a}b=-32768;if(!(a>-32768)){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b}function Fj(a){var b=0;a=ge(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function D_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function tt(a){var b=0,c=0,d=0;c=v[a+4>>2];b=((c<<2)+(jw(v[a>>2],1)^270549120)|0)+2019860093|0;d=jw(b,16);v[a>>2]=b;b=a;a=B(d,5)+c|0;v[b+4>>2]=a;return a}function koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=JE(a,b);break a}c=qg(a);Rb(a,b-4|0)}v[d>>2]=c}function hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=1){c=IE(a,1);break a}c=Mg(a);Rb(a,b-2|0)}u[d>>1]=c}function hg(a,b,c){a:{switch(b-1|0){case 0:if(c){return Dj(a,1)}return Dj(a,0);case 1:if(c){return Dj(a,3)}return Dj(a,2);default:break a}}return Dj(a,4)}function fy(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+62800>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function a5(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];if(c){while(1){c=c-1|0;d=c<<2;kb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);if(c){continue}break}}}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Dk(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=YC(a,e,d);break a}a=YC(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function qv(a){var b=0;b=gb-16|0;gb=b;sd(b+8|0,a,0);v[22692]=0;sp(b+8|0,114,0);a=v[22692];v[22692]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function Xn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Cd(b)}return c}function OI(a){var b=0,c=0,d=0;if(Qh(t[v[a>>2]])){while(1){b=v[a>>2];d=t[b|0];v[a>>2]=b+1;c=(B(c,10)+d|0)-48|0;if(Qh(t[b+1|0])){continue}break}}return c}function dU(a,b){a=a|0;b=b|0;var c=0,d=0;u[a+34>>1]=0;c=gb-16|0;gb=c;t[c+15|0]=0;d=a+43|0;Do(d,d+22|0,c+15|0);gb=c+16|0;v[a+20>>2]=0;td(a,b);return a|0}function b3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return dk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0)|0}function Z0(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[22692]=0;a=T(2559,a|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Bb();L()}function Yc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(kb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function T4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Cx(b);v[a+36>>2]=b;c=a,d=qo(b),v[c+44>>2]=d;c=a,d=Qn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Gs(2655);L()}}function O4(a,b){a=a|0;b=b|0;var c=0,d=0;b=yx(b);v[a+36>>2]=b;c=a,d=qo(b),v[c+44>>2]=d;c=a,d=Qn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Gs(2655);L()}}function NR(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function zk(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=a;d=v[v[a>>2]>>2];if(d){v[b>>2]=d}YW(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function yE(a,b){a=a|0;b=b|0;var c=0;zp(a);c=b+4|0;wk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Yr(a,sc(a))}function qH(a,b){a=a|0;b=b|0;ym(a);v[a>>2]=89128;v[22692]=0;Q(2431,a+4|0,b|0)|0;b=v[22692];v[22692]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function fr(a,b){a=a|0;b=b|0;var c=0;xk(a);c=b+4|0;wk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_m(a,Nb(a))}function Qd(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;a=_w(b,a);c=gb-16|0;gb=c;d=v[yc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;gb=c+16|0;gb=b+16|0}function Ny(a,b){a=a|0;b=b|0;var c=0;rt(a);c=b+4|0;wk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];pt(a,pc(a))}function zca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=5){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];lM(a)}gb=d+16|0}function xba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=3){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];PL(a)}gb=d+16|0}function s4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Mf(b);d=rf(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=hc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function rca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];fM(a)}gb=d+16|0}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(cG(a)>>>0<b>>>0){Sc();L()}c=bG(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,12)+c|0,v[d>>2]=e;Pw(a,0)}function ao(a){var b=0;b=ba(8)|0;v[22692]=0;Q(126,b|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){ia(b|0,89368,24);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function Vr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(LE(a)>>>0<b>>>0){Sc();L()}b=(b-1>>>5|0)+1|0;c=Si(wb(a),b);v[a+4>>2]=0;v[a>>2]=c;d=wb(a),e=b,v[d>>2]=e}function NO(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=wb(a);c=po(d+8|0,hr(a,Nb(a)+1|0),Nb(a),c);sq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Rk(a,c);rO(c);gb=d+32|0}function MZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(bE(a)>>>0<b>>>0){Sc();L()}c=aE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,20)+c|0,v[d>>2]=e;$D(a,0)}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=d;b=ui(c,c+12|0);a=oH(a,6373,v[c+8>>2]);ff(b);gb=c+16|0;return a|0}function Eba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];RL(a)}gb=d+16|0}function $i(a,b){var c=0;c=v[v[b>>2]-12>>2];v[22692]=0;b=v[(b+c|0)+24>>2];c=v[22692];v[22692]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function zZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Lg(a,d+8|0)){v[d+4>>2]=w[d+8|0];GD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function pd(a){var b=0;b=ba(8)|0;v[22692]=0;Q(23,b|0,a|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){ia(b|0,89316,24);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function pV(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878?(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165:0}function nka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!kU(a,d)){break a}c=0;if(!mT(d)){break a}c=Me(a,b,lT(d),jb)}gb=d+48|0;return c|0}function jla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!RU(a,d)){break a}c=0;if(!qU(d)){break a}c=Me(a,b,pU(d),jb)}gb=d+96|0;return c|0}function gA(a){var b=0;a=ge(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function eX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(JW(a)>>>0<b>>>0){Sc();L()}c=IW(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,6)+c|0,v[d>>2]=e;wC(a,0)}function cla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!kU(a,d)){break a}c=0;if(!jU(d)){break a}c=Me(a,b,iU(d),jb)}gb=d+48|0;return c|0}function aw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aC(a)>>>0<b>>>0){Sc();L()}c=Si(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e;_m(a,0)}function _e(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(De(a)){c=v[a>>2];t[b+15|0]=0;Bd(c,b+15|0);ee(a,0);break a}t[b+14|0]=0;Bd(a,b+14|0);Xe(a,0)}gb=b+16|0}function ZB(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;a=a+22|0;return c+(Ib(w[b|0]|w[b+1|0]<<8)>>>0>Ib(w[a|0]|w[a+1|0]<<8)<<1>>>0)|0}function UY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(HE(a,d+8|0)){v[d+4>>2]=w[d+8|0];NY(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function P1(){var a=0;a:{Xd(465728);v[22692]=0;T(2545,465736)|0;a=v[22692];v[22692]=0;if((a|0)!=1){v[116432]=86416;break a}a=P()|0;O()|0;S(a|0);L()}}function OB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(_E(a)>>>0<b>>>0){Sc();L()}c=ZE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<1)+c|0,v[d>>2]=e;Yr(a,0)}function N1(){var a=0;a:{Xd(465744);v[22692]=0;T(2545,465752)|0;a=v[22692];v[22692]=0;if((a|0)!=1){v[116436]=86572;break a}a=P()|0;O()|0;S(a|0);L()}}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!RU(a,d)){break a}c=0;if(!QU(d)){break a}c=Me(a,b,PU(d),jb)}gb=d+96|0;return c|0}function LO(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))}function yR(a){var b=0;if(v[a>>2]){aX(a);wb(a);b=v[a>>2];a=vi(a);v[22692]=0;Oc(b,a<<4,8);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function G$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Rg(a,v[b+8>>2],f)){Vw(b,c,d,e);return}a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function Cn(a,b){var c=0;v[a>>2]=27748;v[a>>2]=27600;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function dy(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function YX(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function W7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-32|0;gb=h;xK(h+8|0,b,c,d,e,f,g);Dc(a,h+20|0);Lm(h+8|0);gb=h+32|0}function RA(a,b,c){var d=0,e=0,f=0;d=Gl(a,b);if((d|0)!=255){e=wd(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=lc(a,b),f=255,t[e|0]=f;e=lc(a,c),f=d,t[e|0]=f}}function P7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;us(a,v[c+8>>2],v[c+12>>2]);gb=c+32|0;return a|0}function r1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function ix(a,b,c){a:{if((a|0)==(b|0)){break a}c=v[c>>2];while(1){if((c|0)==v[a>>2]){break a}a=a+4|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function bU(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-12>>>0)/12^-1,12)+c}b=v[a>>2];if(b){Nu(b,Hp(a))}}function ZL(a){var b=0;b=(vf(v[a+16>>2])>>>0)/(Fj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;tc(a+4224|0,b)}function X7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-32|0;gb=h;xK(h+8|0,b,c,d,e,f,g);Dc(a,h+8|0);Lm(h+8|0);gb=h+32|0}function MN(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Rc(a,8,1,0,11);return}c=a;a=b+14|0;Rc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function LD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function y5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Xf(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){VH(b)}t[a|0]=1}return a|0}function j1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function ex(a){var b=0,c=0;v[22692]=0;c=ga(2548)|0;b=v[22692];v[22692]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Dn(a);return}V(0)|0;O()|0;Bb();L()}function aq(a,b){var c=0;a:{if(!iJ(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;Zt(v[v[a>>2]-12>>2]+a|0,c);return a|0}function RX(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;vw(b+8|0,a);a=w[lc(b+8|0,0)|0];c=w[lc(b+8|0,1)|0];d=lc(b+8|0,2);gb=b+16|0;return a|c<<8|w[d|0]<<16}function N5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Xf(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){Ys(b)}t[a|0]=1}return a|0}function Mx(a){var b=0,c=0;b=gb-16|0;gb=b;c=-1;a:{if(vI(a)){break a}if((kb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}gb=b+16|0;return c}function JA(a,b){var c=0;oR(a);wb(a);c=b+4|0;hl(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];qf(a);rg(a);rg(a)}function AB(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=Tk(a);v[22692]=0;Oc(b,B(a,36),4);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function vn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aK(a)>>>0<b>>>0){Sc();L()}c=mi(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=b+c|0,v[d>>2]=e;pt(a,0)}function pk(a,b){var c=0,d=0;a:{b=Gl(a,b);if((b|0)==255){break a}if(qk(a)){break a}c=lc(a+4|0,b);d=w[c|0]&223;t[c|0]=d;Yh(v[a>>2],yu(b)|176,d)}}function im(a,b){a:{if((a|0)==(b|0)){break a}b=b-1|0;if(b>>>0<=a>>>0){break a}while(1){Dh(a,b);a=a+1|0;b=b-1|0;if(a>>>0<b>>>0){continue}break}}}function hx(a,b){a:{if((a|0)==(b|0)){break a}b=b-4|0;if(b>>>0<=a>>>0){break a}while(1){wc(a,b);a=a+4|0;b=b-4|0;if(a>>>0<b>>>0){continue}break}}}function dD(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=Sj(a);v[22692]=0;Oc(b,B(a,6),1);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function bn(a){a=+a;var b=0;a=fe(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function aV(a){var b=0;a:{if(rd(a,11078,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>=33){break a}b=w[a|0]!=0}return b}function Qpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;u[b+14>>1]=1;c=b,d=Tl(a),u[c+12>>1]=d;a=x[Je(b+14|0,b+12|0)>>1];gb=b+16|0;return a-1&65535}function Qm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function LA(a){var b=0,c=0,d=0;c=w[a+32|0];d=Oi(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Sb(b)}return Nj(b,w[a+32|0])}function BW(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+4|0;while(1){Hf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function UI(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function vT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-16>>>4^-1)<<4)+c}b=v[a>>2];if(b){vB(b,Hx(a))}}function a6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;hc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function TL(a){a=a|0;var b=0,c=0;v[a>>2]=52528;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Lc(b);if((b|0)!=(c|0)){continue}break}jf(a);return a|0}function Lf(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=rg(a);v[22692]=0;Oc(b,a<<3,8);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Gr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(gs(a,b+8|0)){c=Yb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}gb=b+16|0;return c|0}function AT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-32>>>5^-1)<<5)+c}b=v[a>>2];if(b){wB(b,rB(a))}}function $C(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=ye(a);v[22692]=0;Oc(b,a<<2,2);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function uF(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-8>>>3^-1)<<3)+c}b=v[a>>2];if(b){AF(b,tF(a))}}function mp(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-2>>>1^-1)<<1)+c}b=v[a>>2];if(b){FY(b,ow(a))}}function Wr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Qm(d,d+e|0,c+15|0);Kj(a,v[b>>2],d);gb=c+16|0}function KB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Fl(a,b,c){var d=0,e=0;a=x[b>>1];e=x[c>>1];d=1;a:{if(a>>>0<e>>>0){break a}d=0;if(a>>>0>e>>>0){break a}d=y[b+4>>2]<y[c+4>>2]}return d}function FE(a){var b=0,c=0;c=jqa(w[a+111|0],0,1536,0);b=jb;a=jqa(w[a+110|0],0,25,0);c=c+a|0;b=jb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;jb=b;return a}function DW(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Qm(d,d+e|0,c+15|0);e=a;a=v[b>>2];sd(e,a,d-a|0);gb=c+16|0}function $O(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function _da(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!ld(a,4)){Hy(a)}c=b,d=Zb(a+44|0),v[c>>2]=d;a=v[Hd(b+8|0,b)>>2];gb=b+16|0;return a|0}function Tm(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function Lt(a){var b=0;b=A[a+4248>>3]/+(vf(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function Bb(){var a=0;a=v[22687];v[22692]=0;X(a|0);a=v[22692];v[22692]=0;if((a|0)!=1){v[22692]=0;L()}a=V(0)|0;O()|0;Z(a|0)|0;v[22692]=0;L()}function $da(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!ld(a,4)){Hy(a)}c=b,d=Vb(a+44|0),v[c>>2]=d;a=v[Hd(b+8|0,b)>>2];gb=b+16|0;return a|0}function ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(ye(a)>>>0<b>>>0){d=wb(a);e=a;a=po(c+8|0,b,Nb(a),d);QN(e,a);yz(a)}gb=c+32|0}function ty(a){var b=0;if(v[a>>2]){Pd(a);b=v[a>>2];a=bg(a);v[22692]=0;Oc(b,a,1);a=v[22692];v[22692]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(rg(a)>>>0<b>>>0){d=wb(a);e=a;a=KA(c+8|0,b,qf(a),d);JA(e,a);IA(a)}gb=c+32|0}function oU(a,b,c){var d=0;d=mc(a);v[22692]=0;U(55,a|0,b|0,c|0);b=v[22692];v[22692]=0;if((b|0)!=1){return a}a=P()|0;O()|0;Lc(d);S(a|0);L()}function g1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gb-16|0;gb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Fb(a+12|0,a+8|0);gb=a+16|0;return v[b>>2]}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(sg(a)>>>0<b>>>0){d=wb(a);e=a;a=Ou(c+8|0,b,Ec(a),d);cU(e,a);bU(a)}gb=c+32|0}function WS(a,b){var c=0;xk(a);wb(a);c=b+4|0;hl(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_m(a,Nb(a))}function QN(a,b){var c=0;xk(a);wb(a);c=b+4|0;hl(v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_m(a,Nb(a))}function LY(a){var b=0,c=0;c=a;b=v[a+4>>2];a=v[a>>2];if((b|0)!=(a|0)){while(1){b=b-28|0;Zd(b);if((a|0)!=(b|0)){continue}break}}v[c+4>>2]=a}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(zA(a)>>>0<b>>>0){d=wb(a);e=a;a=TQ(c+8|0,b,EA(a),d);SQ(e,a);RQ(a)}gb=c+32|0}function ri(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function i6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+15&-16;v[c>>2]=b+16;d=a,e=Vx(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function _t(a,b){a=a|0;b=b|0;var c=0;c=b>>>0>126;if(!c){Ue(((b<<5)+a|0)+480280|0);Vm((B(b,872)+a|0)+1074992|0,7,a,b,134217728)}return c|0}function Wga(a){a=a|0;var b=0;b=v[a>>2];if(kb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=kb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Ni(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((Gl(a,b)|0)==255){break a}pk(a,b);Mq(a,b,0,0);if(!c){break a}a=lc(a+58|0,b);t[a|0]=w[a|0]|128}}function NT(a){var b=0,c=0;b=gb-16|0;gb=b;if(PV(a,b+8|0)){a=b+8|0;c=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=b+16|0;return c}function BP(a){a=50-(B(w[(a>>>4|0)+37776|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ac((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function yI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function vea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;Ot(a,b,c);gb=c+32|0}function pea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;Ot(a,b,c);gb=c+32|0}function oea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Ot(a,b,c);gb=c+32|0}function noa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Ot(a,b,c);gb=c+32|0}function lla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Tv(a,b,c);gb=c+32|0}function Z7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;yK(g+8|0,b,c,d,e,f);Dc(a,g+20|0);Lm(g+8|0);gb=g+32|0}function Wja(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;JV(a,b,c);gb=c+32|0}function KL(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C(Cg(b-J(b+.5)))}else{c=C(0)}return c}function A1(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}kb[a|0](d)}function pZ(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Tv(a,b,c);gb=c+32|0}function l5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Dw(a,b,c);gb=c+32|0}function eda(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=0;c=b+12|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;zM(a,b+12|0);gb=b+16|0}function bC(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;JV(a,b,c);gb=c+32|0}function ad(a,b){var c=0,d=0,e=0;c=Tf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function _7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;yK(g+8|0,b,c,d,e,f);Dc(a,g+8|0);Lm(g+8|0);gb=g+32|0}function Ox(a,b){var c=0;if(b>>>0<=99){return BI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return bt(AI(c,a),b-B(a,100)|0)}return rj(a,b)}function Ok(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(yw()>>>0<b>>>0){Sc();L()}c=zR(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<3)+c|0,v[d>>2]=e}function r5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;Dw(a,b,c);gb=c+32|0}function oda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!ue(c&255)|!d)){HM(a,8,C(0))}a=ik(a);if(a){kb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function m6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;Dw(a,b,c);gb=c+32|0}function jw(a,b){var c=0,d=0;if((b|0)<=-1){b=0-b|0;c=0-b&31;d=(a&-1>>>c)<<c;c=a;a=b&31;return d|(c&-1<<a)>>>a}return nqa(a,(b|0)%32|0)}function gt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function TI(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}aa(11404,10482,1165,2826);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(b>>>0>=114){ao(9350);L()}Db(d+8|0,a,b);Af(d+8|0,c);gb=d+16|0;return a|0}function Ns(a,b){ym(a);v[a>>2]=89108;v[22692]=0;Q(2431,a+4|0,b|0)|0;a=v[22692];v[22692]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function Kb(a){var b=0,c=0;b=gb-16|0;gb=b;v[22692]=0;c=v[22692];v[22692]=0;if((c|0)!=1){FA(a);gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function $Y(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;Tv(a,b,c);gb=c+32|0}function qg(a){var b=0,c=0;b=gb-16|0;gb=b;if(gs(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=b+16|0;return c}function mI(a){var b=0,c=0,d=0;c=Jb(a);b=Ab(a);a=gb-16|0;gb=a;t[a+15|0]=0;d=-1;if(b){b=op(c,b,a+15|0);d=b?b-c|0:-1}gb=a+16|0;return d}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(CI()>>>0<b>>>0){Sc();L()}c=SH(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<4)+c|0,v[d>>2]=e}function Xz(a,b){a=a|0;b=b|0;var c=0;c=18699;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c|0}function Tw(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=Ww(v[d>>2],h)}a=v[a>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function IV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fp()>>>0<b>>>0){Sc();L()}c=XV(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function I7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fp()>>>0<b>>>0){Sc();L()}c=Pz(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function AG(a){a=a|0;var b=0;a=Kb(a);v[22692]=0;Q(155,a|0,10937)|0;b=v[22692];v[22692]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);S(b|0);L()}}function _ga(a,b){a=a|0;b=b|0;a=Mv(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function Or(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function Ff(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=ui(f,f+12|0);a=at(a,b,d,v[f+8>>2]);ff(c);gb=f+16|0;return a}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];Zt(v[v[a>>2]-12>>2]+a|0,c);return a|0}function yb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22692]=0;a=Zh(a,b);b=v[22692];v[22692]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function ss(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22692]=0;a=Kp(a,b);b=v[22692];v[22692]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function kpa(a){a=a|0;var b=0,c=0,d=0;if(fp()>>>0<=8191){Sc();L()}b=Nc(32768,2);v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+32768|0,v[c>>2]=d}function et(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function Gx(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Kg(t[b|0])|0}function C1(){var a=0,b=0;a=gb-16|0;gb=a;v[a+8>>2]=19923014;a:{if(bH(a+8|0)){break a}if($G()){break a}b=ZG()^1}gb=a+16|0;return b|0}function BB(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22692]=0;a=Xq(a,b);b=v[22692];v[22692]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function PM(a){a=a|0;a=gb-16|0;gb=a;v[a+12>>2]=1869112133;gb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function ys(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=Ww(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function ada(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;if(ye(a)>>>0<=12){c=wb(a);d=a;a=po(b+8|0,13,Nb(a),c);Rk(d,a);rO(a)}gb=b+32|0}function pL(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=rf(8);eL(b);v[b+4>>2]=a;v[b>>2]=55380;a=v[Wi(c+8|0,b)>>2];gb=c+16|0;return a|0}function Pj(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;Fe(a,d+12|0);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;gb=d+16|0;return a}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zt(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+49568|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function N6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zt(a+8|0,b,c,d,3);if(a>>>0<=44){a=w[a+49520|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function JB(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=wb(b),d=0,v[c>>2]=d}function ik(a){var b=0,c=0;b=Ok(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function XG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ks(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function UG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Js(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function Ld(a){var b=0;a=v[a+4>>2];if(a){if(Gn(a)){a:{b=a+8|0;if(v[b>>2]){if((Gw(b)|0)!=-1){break a}}kb[v[v[a>>2]+16>>2]](a)}}}}function JS(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=jqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(kqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function IS(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=jqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(kqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function $x(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}hc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function YR(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){ee(b,a)}if(c){ee(c,a)}if(d){ee(d,a)}if(e){ee(e,a)}}function Pf(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;if(b>>>0>=114){ao(9315);L()}Db(c+8|0,a,b);Af(c+8|0,0);gb=c+16|0;return a|0}function Bk(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;tr(a+4|0);v[b+12>>2]=0;Fe(a+8|0,b+12|0);c=a,d=fc(a),v[c>>2]=d;gb=b+16|0;return a}function $G(){var a=0,b=0,c=0;a=gb-16|0;gb=a;b=Tb(a,12462);if(Ab(b)){c=(tg(b,11111)|0)!=-1}else{c=0}vb(b);gb=a+16|0;return c|0}function T5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Kg(t[a|0])|0}function Nl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(kb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function N$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Rg(a,v[b+8>>2],0)){Xw(b,c,d);return}a=v[a+8>>2];kb[v[v[a>>2]+28>>2]](a,b,c,d)}function Cl(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];sd(a,c,v[Fb(d+12|0,d+8|0)>>2]);gb=d+16|0}function xt(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=zi(c,a,b);b=v[a+8>>2];if((b|0)!=v[a+4>>2]){v[a+4>>2]=b}$b(a);gb=c+16|0}function wj(a,b,c,d){var e=0;e=gb-16|0;gb=e;bc(e+8|0,zb(c),d);c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;mJ(a,b,e);gb=e+16|0}function s6(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}kb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function og(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=ih(d,a);return((ih(d,a+1|0)<<8|e<<16|ih(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function iU(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;jb=c;return a}function aI(a){v[a>>2]=77060;ex(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function YG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ks(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function VG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Js(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Ub(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function LN(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){a=Zm(a)>>>0>80}else{a=0}return a}function $s(a){v[a>>2]=76996;ex(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function lq(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function jq(a){a=a|0;var b=0,c=0;b=Re(a);while(1){c=b;if(c&65535){b=c-1|0;if(!le(a,b&65535)){continue}}break}return c&65535}function ff(a){a:{a=v[a>>2];if(a){v[22692]=0;sx(a);a=v[22692];v[22692]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function xI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function dB(a){a=a|0;v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function ZT(a,b){var c=0;c=v[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-12|0;YT(c);if((b|0)!=(c|0)){continue}break}}v[a+4>>2]=b}function ZN(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function PB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Gfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=sQ(d);b=b+1|0}fO(a,b,c,d,e)}function wi(a,b,c){a:{if(c){v[22692]=0;yI(a,b,c);a=v[22692];v[22692]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function ue(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=a;t[b+14|0]=1;t[b+13|0]=120;a=Bv(b+15|0,b+14|0,b+13|0);gb=b+16|0;return a}function ke(a,b){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function cT(a){var b=0,c=0;b=a+68|0;if(!(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>=128)){c=!rd(a,14751,17)}return c}function XS(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function Sd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Ap(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function yl(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;uz(a,c)}function uS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){sS(a,1);sS(a,0)}}function tS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){rS(a,1);rS(a,0)}}function sZ(a){a=a|0;var b=0;a:{if(!He(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=IF(a,32);v[b+76>>2]=a}return a<<24>>24}function QH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function P5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function $v(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=gb-16|0;gb=c;t[c+15|0]=w[b|0];pR(a,c+15|0);gb=c+16|0;gb=d+16|0}function VQ(a){var b=0;a:{if(w[a|0]<24){break a}b:{if(!w[a+3|0]){b=16;break b}b=15;if(w[a+3|0]!=3){break a}}t[a+3|0]=b}}function Do(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function BY(a){var b=0,c=0;a:{if(rd(a,28548,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>=9){break a}c=t[a+47|0]>-1}return c}function mk(a){var b=0,c=0;b=gb-16|0;gb=b;Db(b+8|0,a+1074312|0,7);if(Cb(b+8|0)){c=v[a+480180>>2]!=4}gb=b+16|0;return c}function Nma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(yp(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}gb=b+16|0;return c|0}function Le(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function qc(a,b){var c=0;ym(a);v[a+4>>2]=0;v[a>>2]=54884;c=a;a=Cd(Ab(b)+1|0);v[c+4>>2]=a;if(a){hc(a,Jb(b),Ab(b)+1|0)}}function ega(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=Rz(a),v[d>>2]=e;so(c);gb=b+16|0;return v[c>>2]}function Ov(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){bc(a,c,v[b>>2]);return}b=b+8|0;if(!bd(b)){Vd(a,b);return}Ud(a)}function no(a){var b=0;a:{while(1){if(w[b+49584|0]==(a|0)){break a}b=b+1|0;if((b|0)!=45){continue}break}b=0}return b}function hV(a){var b=0,c=0;b=gb-16|0;gb=b;c=a+512|0;while(1){Hf(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}gb=b+16|0}function ZU(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;jb=b;return a}function GF(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;Ep(a);v[a>>2]=27796;c=dc(a);Dp(c);v[c>>2]=27928;gb=b+16|0;return a|0}function uI(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function or(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=zi(e,a,d);CW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function fz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Dg(e,a,d);CW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function lB(a,b,c){a:{v[22692]=0;Oc(b,B(c,28),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function kga(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;if(b>>>0>=250){ao(9350);L()}Db(c+8|0,a,b);ar(c+8|0);gb=c+16|0}function hs(a,b,c){a:{v[22692]=0;Oc(b,B(c,36),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fm(a,b,c){a:{v[22692]=0;Oc(b,B(c,12),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function eY(a,b,c){a:{v[22692]=0;Oc(b,B(c,48),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function br(a,b,c){if(v[b>>2]<=(Ib(w[a|0]|w[a+1|0]<<8)|0)){a=(Ib(w[a|0]|w[a+1|0]<<8)|0)<=v[c>>2]}else{a=0}return a}function ZD(a,b,c){a:{v[22692]=0;Oc(b,B(c,20),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Uh(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function Sz(a,b,c){a:{v[22692]=0;Oc(b,B(c,52),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Rk(a,b){var c=0;c=b+4|0;hl(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function PY(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Jda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=gA(C(c*C(255))),t[d|0]=e;Nt(a)}}function yN(a){var b=0,c=0;if(v[a>>2]){FN(a);AC(wb(a),v[a>>2],Sj(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function wv(a){var b=0,c=0;if(v[a>>2]){vr(a);Uk(wb(a),v[a>>2],bg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function oS(a){var b=0,c=0;if(v[a>>2]){Vl(a);pw(wb(a),v[a>>2],Ng(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function eM(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function bO(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=Qz(d,a);wb(a);sq(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0}function UV(a){var b=0,c=0;if(v[a>>2]){Eg(a);fw(wb(a),v[a>>2],ye(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function MH(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!He(XH(c,b),-1)){break a}v[a>>2]=0}return a|0}function KP(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function Al(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function AN(a){var b=0,c=0;if(v[a>>2]){Eg(a);ai(wb(a),v[a>>2],ye(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function AC(a,b,c){a:{v[22692]=0;Oc(b,B(c,6),1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function uy(a,b){a:{v[22692]=0;Oc(a,B(b,24),8);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function rD(a,b){a:{v[22692]=0;Oc(a,B(b,28),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function qW(a,b){a:{v[22692]=0;Oc(a,B(b,33),1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function de(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=1;t[b+14|0]=120;a=Bv(a,b+15|0,b+14|0);gb=b+16|0;return a|0}function Ru(a,b){a:{v[22692]=0;Oc(a,B(b,56),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function RF(a,b){a:{v[22692]=0;Oc(a,B(b,24),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function QJ(a,b){a:{v[22692]=0;Oc(a,B(b,52),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Nu(a,b){a:{v[22692]=0;Oc(a,B(b,12),4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function NN(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function LI(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function IM(a,b,c){a:{v[22692]=0;Oc(b,c<<11,4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function zC(a,b,c){a:{v[22692]=0;Oc(b,c<<2,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function tn(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function qu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=sQ(d);b=b+1|0}xA(a,b,c,d)}function pw(a,b,c){a:{v[22692]=0;Oc(b,c<<1,2);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ou(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function kV(a,b,c){a:{v[22692]=0;Oc(b,c<<5,8);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fw(a,b,c){a:{v[22692]=0;Oc(b,c<<2,2);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function dE(a,b,c){a:{v[22692]=0;Oc(b,c<<1,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ai(a,b,c){a:{v[22692]=0;Oc(b,c<<2,4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Sn(a,b,c){a:{v[22692]=0;Oc(b,c<<4,4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Qk(a,b,c){a:{v[22692]=0;Oc(b,c<<5,4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Mh(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function K4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Cx(b);v[a+36>>2]=b;c=a,d=Qn(b),t[c+44|0]=d}function JQ(a,b){a:{v[22692]=0;Oc(a,B(b,7),1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Ir(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(yp(a,b+8|0)){c=Ib(w[b+8|0]|w[b+9|0]<<8)}gb=b+16|0;return c|0}function HA(a,b,c){a:{v[22692]=0;Oc(b,c<<3,8);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function H4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=yx(b);v[a+36>>2]=b;c=a,d=Qn(b),t[c+44|0]=d}function mS(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Gb(c+8|0,c);gb=c+16|0;return a}function mK(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=xO(a),v[d>>2]=e;so(c);gb=b+16|0;return v[c>>2]}function bba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,9713);qc(a,c);vb(c);v[a>>2]=54844;gb=b+16|0;return a|0}function Rg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!sj(v[a+4>>2],v[b+4>>2])}function Naa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,5309);qc(a,c);vb(c);v[a>>2]=54864;gb=b+16|0;return a|0}function Dv(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Sd(c+12|0,0,15);gb=c+16|0;return w[c+12|0]}function Af(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function xq(a){a=a|0;var b=0;b=v[19507];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19510];Yt(a+4|0);lh(a+56|0);return a|0}function wB(a,b){a:{v[22692]=0;Oc(a,b<<5,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function vB(a,b){a:{v[22692]=0;Oc(a,b<<4,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function uf(a){a=a|0;var b=0;b=v[19552];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19555];Yt(a+8|0);lh(a+60|0);return a|0}function uV(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function tK(a,b){a:{v[22692]=0;Oc(a,b<<4,4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function tB(a,b){a:{v[22692]=0;Oc(a,b<<8,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function p9(a,b){a=a|0;b=b|0;if(a){b=kb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=je(b);break a}b=je(18699)}v[a>>2]=b}}function jC(a,b){a:{v[22692]=0;Oc(a,b<<2,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function iO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function cP(a,b){a:{v[22692]=0;Oc(a,b<<3,4);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ZS(a,b){var c=0;c=v[a+4>>2]+b|0;v[a+4>>2]=c&31;v[a>>2]=v[a>>2]+(((b|0)>=0?c>>>5|0:(c-31|0)/32|0)<<2)}function FY(a,b){a:{v[22692]=0;Oc(a,b<<1,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function AF(a,b){a:{v[22692]=0;Oc(a,b<<3,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function iC(a){var b=0,c=0;c=a;b=v[a+8>>2];a=v[a+4>>2];if((b|0)!=(a|0)){v[c+8>>2]=(((b-a|0)-4>>>2^-1)<<2)+b}}function dr(a){if(!(a<4294967295)){return-1}if(!(a>0)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function dW(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;if((Tl(a)|0)!=65535){PD(a,c+14|0)}gb=c+16|0}function YH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return Kg(t[b|0])}function WG(a,b,c,d,e){b=lj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Uk(a,b,c){a:{v[22692]=0;Oc(b,c,1);a=v[22692];v[22692]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function TG(a,b,c,d,e){b=kj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function SR(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+22>>1]<<4|x[b+20>>1]>>>6)&65535)+35344|0]>>>x[a+68>>1]}function Go(a,b){a=a|0;b=b|0;if(sc(a)>>>0>b>>>0){a=le(v[a+24>>2]+484344|0,x[cj(a,b)>>1])}else{a=0}return a|0}function CN(a){a=a|0;var b=0;b=v[v[a>>2]-12>>2]+a|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;return a|0}function nna(a,b){a=a|0;b=b|0;if(!lW(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function eJ(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function Wj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!lt(a,b)){b=lt(c,a)?c:a}gb=d+16|0;return b|0}function Th(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Cc(c,(b>>31&a)+b|0)>>2]}function Px(a,b){var c=0;if(b>>>0<=9999){return Ox(a,b)}c=a;a=(b>>>0)/1e4|0;return rj(Ox(c,a),b-B(a,1e4)|0)}function J1(){var a=0;if(fp()>>>0<=29){Sc();L()}a=uG($w(465792),30);v[116448]=a;v[116449]=a;v[116452]=a+120}function $W(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){UW(c+52|0);vb(c+40|0);Lc(c+16|0);Lc(c+4|0);Xb(c)}}}function so(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=zb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function lJ(a){var b=0;b=v[(w[a+2|0]&12)+61696>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function iy(a,b){var c=0;c=(B(B(gy(a),hy(a)),125)>>>0)/(lJ(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function ew(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function ana(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(_j(a,b+8|0)){c=NV(b+8|0)}gb=b+16|0;return c|0}function Wpa(a,b){a=a|0;b=b|0;var c=0;b=gb-80|0;gb=b;c=-1;if(xY(a,b+8|0)){c=wY(b+8|0)}gb=b+80|0;return c|0}function St(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=251;t[b+14|0]=255;a=Bv(a,b+15|0,b+14|0);gb=b+16|0;return a}function wY(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179468868&(w[a+4|0]-1&255)>>>0<10}function l$(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;if(aG(a,b+8|0)){c=$F(b+8|0)}gb=b+32|0;return c|0}function kw(a,b){a=a|0;b=b|0;if((a&4088)>>>0>=520){b=jw(0-nqa(b^1230262859,25)|0,4)^1247037516}return b|0}function dz(a,b){mc(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Ao(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function dZ(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(_j(a,b+8|0)){c=xD(b+8|0)}gb=b+16|0;return c|0}function dL(a){var b=0;while(1){if(!v[(b<<2)+a>>2]){return b}b=b+1|0;if((b|0)!=4){continue}break}return 4}function b6(a){a=a|0;a=gb-16|0;gb=a;if(fb(a+12|0,4)|0){Os(v[115173],9905);L()}gb=a+16|0;return v[a+12>>2]}function av(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;pn(c+8|0,a);v[c+4>>2]=v[c+8>>2];cr(c+4|0,b);gb=c+16|0}function Tp(){var a=0;v[22692]=0;a=v[22692];v[22692]=0;if((a|0)!=1){return v[19878]}V(0)|0;O()|0;Bb();L()}function RH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function NP(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=0-(d&65535)&65535;b=b+1|0}oA(a,b,c,d&65535)}function Mg(a){var b=0,c=0;b=gb-16|0;gb=b;if(yp(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}gb=b+16|0;return c}function CG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function Bs(){var a=0;v[22692]=0;a=v[22692];v[22692]=0;if((a|0)!=1){return v[20460]}V(0)|0;O()|0;Bb();L()}function B_(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(_j(a,b+8|0)){c=pF(b+8|0)}gb=b+16|0;return c|0}function As(){var a=0;v[22692]=0;a=v[22692];v[22692]=0;if((a|0)!=1){return v[20072]}V(0)|0;O()|0;Bb();L()}function sO(a,b){v[22692]=0;Oc(a,b<<2,4);a=v[22692];v[22692]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function eq(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=ce(b),v[d+12>>2]=e;Fe(a,c+12|0);gb=c+16|0;return a}function Pg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];jb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Li(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];Om(a,d*e-f*g,e*f+d*g)}function xc(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];gb=c+16|0}function OO(a,b){var c=0;c=gb-16|0;gb=c;a=Qz(c,a);sq(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;$b(a);gb=c+16|0}function Ez(a,b){var c=0;c=gb-16|0;gb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];gb=c+16|0}function Ew(a,b,c){var d=0;d=gb-16|0;gb=d;a=Ud(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;gb=d+16|0}function BK(a,b){var c=0;c=y[b>>2]>y[a>>2];a=v[a+4>>2];b=v[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function yq(a,b,c){a=ok(a+1074376|0)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function wS(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function sx(a){a=a|0;var b=0;b=v[22597];if(a){v[22597]=(a|0)==-1?460752:a}return((b|0)==460752?-1:b)|0}function DB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=v[b>>2]+c|0;if((d|0)==-1){d=yb(b)-c|0}vd(a,e,d)}function rh(a){var b=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Qo(a+8|0);gb=b+16|0;return a}function hy(a){var b=0;b=w[a+1|0];return w[(B(b>>>3&1,45)+B(b>>>1&3,15)+(w[a+2|0]>>>4)|0)+61697|0]<<1}function SP(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(b>=c){break a}}A[a>>3]=d}}function sT(a){v[22692]=0;Oc(a,48,4);a=v[22692];v[22692]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function gT(a){Wm(a+140|0);xb(a+120|0);xb(a+100|0);xb(a+80|0);xb(a+60|0);xb(a+40|0);xb(a+20|0);xb(a)}function ev(a){v[22692]=0;Oc(a,20,4);a=v[22692];v[22692]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function cm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function XN(a){v[22692]=0;Oc(a,28,4);a=v[22692];v[22692]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function WW(a){v[22692]=0;Oc(a,32,4);a=v[22692];v[22692]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Tca(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])*C(.007874015718698502)):C(0))}function Nv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Kda(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function AA(a){v[22692]=0;Oc(a,40,4);a=v[22692];v[22692]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function vE(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}jb=a;return b}function mda(a,b,c){a=a|0;b=b|0;c=c|0;a=ik(a);if(!a){return 0}return kb[v[v[a>>2]+100>>2]](a,b,c)|0}function j_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Kk(c+8|0,a,22);Xr(c+8|0,b);gb=c+16|0;return a|0}function iw(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function hZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Kk(c+8|0,a,20);Xr(c+8|0,b);gb=c+16|0;return a|0}function Md(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=54960;v[b+8>>2]=55064;Hu(a,b+12|0,b+8|0);gb=b+16|0}function LR(a,b,c){if((b|0)!=(c|0)){while(1){JR(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function z1(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[Tp()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function v$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return kb[a|0](b,c,d,e,f,g)|0}function tma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(bD(a,b)){c=pV(b)}gb=b+16|0;return c|0}function n9(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Jb(b);if(c){kb[c|0](b,v[a+8>>2]);return}Gt(b,a)}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Up(d,a);EG(a,c)}function f_(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=HE(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Um(a){a=a|0;var b=0;Hl(a);b=Oq(v[a>>2],gj(a));v[a+20>>2]=b;if(!b){return 0}return Zi(a)|0}function Hi(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(b<=C(1)){break a}}z[a>>2]=c}}function yg(a){a=a|0;var b=0,c=0;while(1){c=b&65535;_t(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function mr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;hv(a+236|0,128,c+14|0);gb=c+16|0}function lI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ab(a);if(d>>>0<b>>>0){ts(a,b-d|0,c);return}oE(a,b)}function _fa(a,b){a=a|0;b=b|0;$s(a);v[a>>2]=77300;Kb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function KQ(a,b,c){a=a|0;b=b|0;c=c|0;Fe(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function Dh(a,b){var c=0;c=gb-16|0;gb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];gb=c+16|0}function xX(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];wX(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function ve(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];cw(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function sR(a,b){var c=0;c=gb-16|0;gb=c;a=v[yc(c+8|0,dR(a,b,Yd(a),fc(a)))>>2];gb=c+16|0;return a}function o_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;VE(c+8|0,a);Xr(c+8|0,b);gb=c+16|0;return a|0}function lT(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}jb=a;return b}function eV(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function So(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];SV(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function Qq(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=0;Do(a,a+32|0,b+15|0);gb=b+16|0;return a|0}function MA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=Rw(A[b>>3]);e=qi(c);Om(a,d*Ke(c),d*e)}function K5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function I5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function G5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function E5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function C5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function A5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function wfa(a,b){a=a|0;b=b|0;Ki(a);Ki(a);a:{if(b>>>0>=60){Rb(a,4);break a}Ki(a)}return Ki(a)|0}function s8(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[Wi(b+8|0,EB(rf(12),a))>>2];gb=b+16|0;return a|0}function qq(a,b,c){a=v[a>>2]+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function oN(a,b){b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Qo(a+8|0);gb=b+16|0;return a}function mZ(a,b){a=a|0;b=b|0;if(!Rv(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function m5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function kda(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;Vd(b,v[a+20>>2]+4|0);EM(a,me(b+8|0,b),0);gb=b+16|0}function jca(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=vf(v[a+16>>2]),v[b+4256>>2]=c;cM(a);bM(a)}function g_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Lg(a,b+8|0)){c=w[b+8|0]}gb=b+16|0;return c|0}function aJ(a){var b=0;b=+((a&2097151)>>>0);return C(aj(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function Vna(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=gs(a,b+8|0);gb=b+16|0;return C(a?z[b+8>>2]:C(0))}function Ida(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=vf(v[a+16>>2]),v[b+4232>>2]=c;Nt(a);SM(a)}function F$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Rg(a,v[b+8>>2],f)){Vw(b,c,d,e)}}function wA(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+27024>>2]>a>>>0)|0)+1|0}function pY(a,b){return(Mb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Mb((B(a&15,b)>>>0)/15|0,1,15))&255}function lD(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=np(c,c+8|0);gb=c+16|0;return a}function T6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function QX(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=Yj(c,c+8|0);gb=c+16|0;return a}function Ho(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=xh(Cg(b)*+(c>>>0)),v[d+24>>2]=e}function xW(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1279544644&w[a+4|0]<32}function ti(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+(Ab(a)<<2)|0)>>2];gb=b+16|0;return a}function o$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb[a|0](b,c,d,e)|0;ma(jb|0);return a|0}function VT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Df(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=a;a=Tb(c,b);Dc(d,a);vb(a);gb=c+16|0}function C4(a,b,c){a=a|0;b=b|0;c=c|0;if(He(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function xn(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function xT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function v5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return kb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function sI(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function qE(a){var b=0;b=gb-16|0;gb=b;a=Lg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function jI(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function Lk(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function DG(a){a=a|0;var b=0;v[a>>2]=83660;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Xb(b)}return a|0}function Ama(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;c=a;a=oi(b+8|0);MV(c,a,0,0);xb(a);gb=b+32|0}function xD(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==810369604&w[a+4|0]<4}function sr(a,b){var c=0;c=Ab(a);if((c|0)==(Ab(b)|0)){a=No(Jb(a),Jb(b),c)}else{a=1}return!a}function nd(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=lt(b,a);gb=c+16|0;return(d?b:a)|0}function mA(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function jba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;HL(a,b,c,d,e,0,0,f,g)}function dma(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=cs(a,b+8|0);gb=b+16|0;return+(a?A[b+8>>3]:0)}function ac(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=iL(b,a);gb=c+16|0;return(d?b:a)|0}function YL(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function WO(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function VV(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=Dg(e,a,d);wb(a);fv(b,c,d+4|0);$b(d);gb=e+16|0}function Pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=zn(b,a);gb=c+16|0;return(d?b:a)|0}function Pb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return kb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Mk(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=iw(b,a);gb=c+16|0;return(d?b:a)|0}function Mc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=sn(a,b);gb=c+16|0;return(d?b:a)|0}function Lr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=BK(b,a);gb=c+16|0;return(d?b:a)|0}function Je(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=zn(a,b);gb=c+16|0;return(d?b:a)|0}function Gf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=lt(a,b);gb=c+16|0;return(d?b:a)|0}function Fb(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=sn(b,a);gb=c+16|0;return(d?b:a)|0}function Cy(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=BK(a,b);gb=c+16|0;return(d?b:a)|0}function Bf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=iL(a,b);gb=c+16|0;return(d?b:a)|0}function BL(a,b,c){a=a|0;b=b|0;c=c|0;Ey(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=54780;return a|0}function $R(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=ji(e,a,d);wb(a);fv(b,c,d+4|0);$b(d);gb=e+16|0}function xoa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13263);Dc(c,a);vb(a);gb=b+16|0}function toa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1580);Dc(c,a);vb(a);gb=b+16|0}
function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ik(a);if(a){kb[v[v[a>>2]+76>>2]](a,b,c,d)}}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ik(a);if(a){kb[v[v[a>>2]+84>>2]](a,b,c,d)}}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ik(a);if(a){kb[v[v[a>>2]+88>>2]](a,b,c,d)}}function oz(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+18800>>2]}else{b=6838}Tb(a,b)}function dh(a){var b=0;b=a+44|0;Jx(b);if(v[b>>2]){aX(b);Sn(wb(b),v[b>>2],vi(b))}gc(a+32|0)}function WN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){Hb(b+16|0)}if(b){XN(b)}}}function SF(a,b){var c=0,d=0;Dp(a);v[a>>2]=27600;v[a+4>>2]=v[b>>2];c=a,d=yb(b),v[c+8>>2]=d}function Pk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Kj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;ES(a,b,c);gb=d+16|0;return a|0}function Hv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ie(c,1,a);UE(c,b);gb=c+16|0;return a|0}function HH(a){var b=0;b=v[a>>2];if(b){if(!He(YH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function GH(a){var b=0;b=v[a>>2];if(b){if(!He(RH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function Fr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Dr(c,1,a);UE(c,b);gb=c+16|0;return a|0}function FW(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function Dma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13866);Dc(c,a);vb(a);gb=b+16|0}function Dc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];FA(b)}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){Ak(a,b);return}WM(a,b,c)}function qZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1467);Dc(c,a);vb(a);gb=b+16|0}
function p$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;kb[a|0](b,c,d,e,f,g)}function opa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1040);Dc(c,a);vb(a);gb=b+16|0}function nqa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function ld(a,b){var c=0;c=gb-16|0;gb=c;tl(c+8|0,a+24|0,b);a=Cb(c+8|0);gb=c+16|0;return a}function ht(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function hla(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1274);Dc(c,a);vb(a);gb=b+16|0}function dY(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;e=a;a=jc(d+8|0,c);Ul(e,b,a);xb(a);gb=d+32|0}function Z$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13893);Dc(c,a);vb(a);gb=b+16|0}function Wma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1983);Dc(c,a);vb(a);gb=b+16|0}function Vma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1031);Dc(c,a);vb(a);gb=b+16|0}function Nx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;a=at(a,b,c,d);gb=e+16|0;return a}function GM(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];A[a+4256>>3]=b-J(b)}function Fy(a){a=a|0;var b=0;v[a>>2]=54884;b=v[a+4>>2];if(b){Xb(b);v[a+4>>2]=0}return a|0}function Ema(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1116);Dc(c,a);vb(a);gb=b+16|0}function tda(a,b){a=a|0;b=b|0;a=ik(a);if(!a){return 1}return kb[v[v[a>>2]+68>>2]](a,b)|0}function m0(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1628);Dc(c,a);vb(a);gb=b+16|0}function lP(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|32;v[a+852>>2]=v[a+852>>2]+b}}function hv(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function he(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;_G(a,d+12|0,c);gb=d+16|0;return a}function hN(a,b,c){if(b){while(1){z[a>>2]=z[c>>2];a=a+4|0;b=b-1|0;if(b){continue}break}}}function ef(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+Ab(a)|0)>>2];gb=b+16|0;return a}function d8(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;hw(c+8|0,b,20);Wr(a,c+8|0);gb=c+16|0}function d5(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){xx(a,c);return}Tb(a,5003)}function Mw(){var a=0,b=0;a=gb-16|0;gb=a;b=ks(a+8|0,mc(rf(12)));gb=a+16|0;return v[b>>2]}function Ai(a){if(lK(a)){a=ba(4)|0;v[a>>2]=0;ym(a);v[a>>2]=79388;ia(a|0,79424,1912);L()}}function Ae(a){var b=0;b=gb-16|0;gb=b;a=Lg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)&255}function qy(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function cn(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function cY(a,b){return v[v[a>>2]>>2]==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function _i(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function Zf(a,b,c){var d=0;d=gb-16|0;gb=d;if(!bv(a,b)){b=bv(c,a)?c:a}gb=d+16|0;return b}function Xt(a,b){if(!(v[a+480180>>2]==8?t[b+851|0]&1:0)){Fz(a,b,0);Fz(a,b,1);Fz(a,b,2)}}function LT(a,b,c){var d=0;d=v[b>>2];if((c|0)==-1){c=Zq(b)}v[a>>2]=d;v[a+4>>2]=(c<<2)+d}function Gn(a){var b=0;b=Gw(a+4|0);if((b|0)==-1){kb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function G_(a){a=a|0;var b=0;b=v[a+4>>2];return(kb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function EI(a){var b=0;b=iqa(v[a>>2]-1|0);if(!b){a=iqa(v[a+4>>2]);b=a?a+32|0:0}return b}function $g(a,b,c){var d=0;d=gb-16|0;gb=d;if(!dT(a,b)){b=dT(c,a)?c:a}gb=d+16|0;return b}function nH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a=oH(a,8305,b);gb=c+16|0;return a}function li(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function hl(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>=1){hc(c,a,b)}}function gU(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function eH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;_G(a,c+12|0,b);gb=c+16|0;return a}function eG(a){var b=0;b=a+48|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Ye(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=v[_w(b,a)+8>>2],d=0,t[c|0]=d;gb=b+16|0}function Xk(a){var b=0;b=a+36|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function XO(a){Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function XA(a,b){Qu(a,b);Dc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function Tb(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;us(a,b,Mf(b));gb=c+16|0;return a|0}function OR(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Cf(a){var b=0;b=a+24|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function BE(a){var b=0,c=0;b=gb-16|0;gb=b;c=Sp(a);t[b+15|0]=0;Do(a,c,b+15|0);gb=b+16|0}function AD(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+28496|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function w0(a){a=a|0;a=465376;while(1){a=Ic(a-12|0);if((a|0)!=465088){continue}break}}function t0(a){a=a|0;a=465416;while(1){a=vb(a-12|0);if((a|0)!=465392){continue}break}}function sm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function q0(a){a=a|0;a=465448;while(1){a=Ic(a-12|0);if((a|0)!=465424){continue}break}}function o6(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function n6(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function m_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;mw(c+8|0,b);Wr(a,c+8|0);gb=c+16|0}function Su(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function K2(a,b){a=a|0;b=b|0;var c=0;c=Gx(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function Gt(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;v[b>>2]=a;RI(14902,b);it(90072);gb=b+16|0}function G0(a){a=a|0;a=464600;while(1){a=vb(a-12|0);if((a|0)!=464432){continue}break}}function D0(a){a=a|0;a=464776;while(1){a=Ic(a-12|0);if((a|0)!=464608){continue}break}}function A0(a){a=a|0;a=465072;while(1){a=vb(a-12|0);if((a|0)!=464784){continue}break}}function uG(a,b){a:{if(!(w[a+128|0]|b>>>0>30)){t[a+128|0]=1;break a}a=Pz(b)}return a}function n1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Bs()+((b&255)<<2)>>2]}return b<<24>>24}function mf(a){a=a|0;var b=0;b=v[a>>2];return(kb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function l1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[As()+((b&255)<<2)>>2]}return b<<24>>24}function dba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zL(a,b,c,d,0,0,0,0,e)|0}function Xja(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;us(a,b,12);gb=c+16|0;return a|0}function Wi(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;sq(a,c+12|0);gb=c+16|0;return a}function TT(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Fg(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,a)>>2];gb=b+16|0;return a|0}function Eh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;_i(a)}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kb[a|0](b,c,d)|0;ma(jb|0);return a|0}function Uf(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function wh(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;sq(a,b+12|0);gb=b+16|0;return a}function qT(a,b,c,d,e,f){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e);yc(a+16|0,f)}function lC(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,v[a>>2])>>2];gb=b+16|0;return a}function cj(a,b){a=a|0;b=b|0;if(sc(a)>>>0<=b>>>0){Qx();L()}return v[a>>2]+(b<<1)|0}function bJ(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function ZW(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;VW(c,a);gb=b+16|0;return v[c>>2]}function Td(a){a=a|0;var b=0;b=gb-16|0;gb=b;Kr(b+8|0,a);gb=b+16|0;return v[b+8>>2]}function Si(a,b){a=a|0;b=b|0;if(b>>>0>1073741823){pd(8399);L()}return Nc(b<<2,4)|0}function JP(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function ww(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){Dn(a)}}function iY(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function _D(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function Uo(a,b){a=hc(a,b,34);u[a+34>>1]=x[b+34>>1];hc(a+36|0,b+36|0,68);return a}function Ip(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function Aw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,36);return a}function zh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,fc(a))>>2];gb=b+16|0;return a}function zd(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a))>>2];gb=b+16|0;return a}function yr(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function sB(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function lr(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,lC(a))>>2];gb=b+16|0;return a}function ji(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function ds(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function Zp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function ZO(a){a=a|0;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;BE(a+9|0);return a|0}function RI(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;QI(90072,a,b,0,0);gb=c+16|0}function KY(a){a=a+4|0;return Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function IY(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;En(a+8|0,b+8|0)}function Dg(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function CF(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c);En(b+12|0,c+12|0);ni(b+32|0,c+32|0)}function Ah(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,zh(a))>>2];gb=b+16|0;return a}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[a|0](b,c,d,e,f)}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-16|0;gb=b;fH(a,c,d);gb=b+16|0}function cg(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){kb[v[v[b>>2]+4>>2]](b)}}}function Zca(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[wb(a)>>2]){OO(a,b);return}NO(a,b)}function JR(a,b){var c=0;c=a;a=v[a>>2];v[c>>2]=a<<8^v[((a>>>24^b)<<2)+35484>>2]}function FJ(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function x6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return qJ(a-88|0,b,c,d,e)|0}function u$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kb[a|0](b,c,d,e)|0}function mT(a){if((w[a+14|0]-49&255)>>>0<4){a=rd(a,12640,14)}else{a=1}return!a}function mP(a,b){a=a|0;b=b|0;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[b>>2];return a|0}function Ufa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[wb(a)>>2]){OO(a,b);return}NO(a,b)}function To(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function Oba(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function Cu(a,b){return xh(Cg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function yba(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function y4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,4969);return}xx(a,c)}function tj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Xb(b)}function sca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function sA(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function lca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function lF(a,b){var c=0;c=gb-16|0;gb=c;b=bm(c+8|0,b);UF(b,a);Ld(b);gb=c+16|0}function ko(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function bm(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){Dn(b)}return a}function _y(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function _Q(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function Xba(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function VF(a,b){var c=0;c=gb-16|0;gb=c;b=Uf(c+8|0,b);UF(b,a);Ld(b);gb=c+16|0}function Oy(a){a=a|0;v[a>>2]=50936;Lc(a+4276|0);Lc(a+4264|0);jf(a);return a|0}function O$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Rg(a,v[b+8>>2],0)){Xw(b,c,d)}}function Mca(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function Fba(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function CB(a){return(+y[a>>2]+ +v[a+4>>2]*4294967296)*2.3283064365386963e-10}function Aca(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function A4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,5039);return}xx(a,c)}function zm(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=bv(b,a);gb=c+16|0;return d?b:a}function wk(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function ud(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Rb(b,c);Jw(a,b,d,c)}function sH(){a:{if(t[463896]&1){break a}if(!Rd(463896)){break a}Qd(463896)}}function rj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return bt(bt(c,a),b-B(a,100)|0)}function nL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){_n(c+120|0);Xb(c)}}}function cH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function aH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function Zm(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function Yz(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:18699)|0}function Yq(a){var b=0;b=gb-16|0;gb=b;a=v[pT(b+8|0,a)>>2];gb=b+16|0;return a}function Sy(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=bv(a,b);gb=c+16|0;return d?b:a}function Sl(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0;return v[b+8>>2]}function NG(a,b){var c=0,d=0;Ee(a,ce(b));b=v[fc(b)>>2];c=fc(a),d=b,v[c>>2]=d}function CW(a,b,c,d){a=c-b|0;if((a|0)>=1){hc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function zi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function ns(a,b){a=a|0;b=b|0;a=v[a>>2];return kb[v[v[a>>2]+32>>2]](a,0,b)|0}function lz(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function kz(a,b){a=a|0;b=b|0;return(b>>>0<=44?t[v[a+84>>2]+b|0]:63)<<24>>24}function jT(a,b){AU(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function hw(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12799,6164,85,7760);L()}}function Ts(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function RV(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Lu(a,b,c){var d=0;d=gb-16|0;gb=d;yc(d+8|0,Fn(a,b,Sl(c)));gb=d+16|0}function Kk(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12799,6164,48,7760);L()}}function KH(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function v1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Bs()+(b<<2)>>2]}return b|0}function t1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[As()+(b<<2)>>2]}return b|0}function qD(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function oh(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function ng(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function le(a,b){a=a|0;b=b|0;if(Wl(a,b)){a=gi(af(a,b))}else{a=0}return a|0}function jo(a,b){a=v[a+4316>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function fv(a,b,c){b=b-a|0;if((b|0)>=1){hc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function bt(a,b){b=x[(b<<1)+74080>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function _w(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function YQ(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;ZS(a,c)}function z5(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+32>>2]](a,b,c)|0}function vV(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function nn(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+48>>2]](a,b,c)|0}function hda(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function eF(a){return(v[a+88>>2]&2050)==2?(w[v[a+104>>2]+34|0]&8)>>>3|0:0}function cl(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+12>>2]](a,b,c)|0}function YU(a,b){var c=0;c=gb-16|0;gb=c;mw(c+8|0,b);DW(a,c+8|0);gb=c+16|0}function Rc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function R_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Sn(b+8|0,a,1);gb=b+16|0}function Qz(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function Ql(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function PP(a,b){var c=0;c=gb-16|0;gb=c;tl(c+8|0,a,b);ar(c+8|0);gb=c+16|0}function L_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Qk(b+8|0,a,1);gb=b+16|0}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;if(Ab(b)>>>0>c>>>0){Fq(b,c)}Dc(a,b)}function Bl(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a,b);ar(c+8|0);gb=c+16|0}function $Q(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function mz(a,b){a=a|0;b=b|0;return(b>>>0<=15?w[v[a+88>>2]+b|0]!=63:0)|0}function kq(a,b){a=a|0;b=b|0;return(b>>>0<=44?w[v[a+84>>2]+b|0]!=63:0)|0}function kE(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function eI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;oh(a,-1,-1)}function GY(a){return Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function zJ(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function uc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Mf(b),v[c+4>>2]=d;return a}function qd(a,b){VF(a,b);v[a+8>>2]=v[b+8>>2];VF(a+12|0,b+12|0);return a}function kh(a,b,c){return(c|0)>=0?(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function dx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Xx(a){return((mh(a)+(mh(a)<<8)|0)+(mh(a)<<16)|0)+(mh(a)<<24)|0}function XR(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Vf(a){var b=0;b=a;if(v[b>>2]){Pd(b);uy(v[b>>2],cv(b))}return a}function Pe(a,b){bm(a,b);v[a+8>>2]=v[b+8>>2];bm(a+12|0,b+12|0);return a}function PR(a){if(a>>>0<=8){return w[a+35472|0]}return w[a+35463|0]|256}function GL(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function BV(a){v[a+8>>2]=0;v[a>>2]=0;v[a+4>>2]=40;u[a+12>>1]=0;return a}function xz(a,b){if(b){xz(a,v[b>>2]);xz(a,v[b+4>>2]);Hb(b+16|0);XN(b)}}function uz(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function ro(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function nF(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function bG(a,b){if(b>>>0>357913941){pd(8399);L()}return Nc(B(b,12),4)}function aE(a,b){if(b>>>0>214748364){pd(8399);L()}return Nc(B(b,20),4)}function Y4(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){ua();L()}}function Uw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function TO(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){fn(c);Xb(c)}}}function Cc(a,b){if(Nb(a)>>>0<=b>>>0){Qx();L()}return v[a>>2]+(b<<2)|0}function BC(a,b){if(b){BC(a,v[b>>2]);BC(a,v[b+4>>2]);yk(b+16|0);WW(b)}}function $k(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function $h(a){a=a|0;a=mB(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function xC(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;iR(a,b);gb=c+16|0}function SO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function Mj(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function Kh(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Yf(a,b);gb=c+16|0}function IW(a,b){if(b>>>0>715827882){pd(8399);L()}return Nc(B(b,6),1)}function I1(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;NH(a,b);gb=c+16|0}function FD(a,b){var c=0;c=gb-16|0;gb=c;bc(a,v[b>>2],pc(b));gb=c+16|0}function D$(a){a=a|0;if(!a){return 0}return(Yw(a,89628,89772)|0)!=0|0}function yz(a){var b=0;VS(a);b=v[a>>2];if(b){ai(v[a+16>>2],b,vk(a))}}function vs(a,b,c,d,e){b=Fa(a|0,b|0,c|0,d|0,e|0)|0;jb=O()|0;return b}function t$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kb[a|0](b,c,d)|0}function sG(a,b,c){a:{if((a|0)==(b|0)){t[a+128|0]=0;break a}sO(b,c)}}function rC(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];En(a+8|0,b+8|0)}function qN(a){if(a>>>0>=82595525){pd(8399);L()}return Nc(B(a,52),4)}function p2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;eg(a,f)}function lm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function gz(a,b,c){b=b-a|0;if(b){vh(c,a,b)}return B((b|0)/6|0,6)+c|0}function dC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fc(a);if(b){ev(b)}}}function _A(a,b){mc(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function ZE(a,b){if(b>>>0>2147483647){pd(8399);L()}return Nc(b<<1,2)}function XF(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(gc(c))}}}function ME(a,b){if(b>>>0>1073741823){pd(8399);L()}return Nc(b<<2,2)}function LB(a,b){xc(a,b);xc(a+4|0,b+4|0);xc(wb(a),wb(b));wb(a);wb(b)}function B1(a){a=a|0;var b=0;b=v[116048]+1|0;v[116048]=b;v[a+4>>2]=b}function oT(a,b,c,d,e){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e)}function mW(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function lG(a,b,c,d,e,f,g){return Ma(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function kP(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|32}function ioa(a,b){a=a|0;b=b|0;Kj(a,zb(v[b>>2]),zb(v[b>>2])+pc(b)|0)}function gC(a,b){if(b){gC(a,v[b>>2]);gC(a,v[b+4>>2]);Sn(fc(a),b,1)}}function by(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function a$(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);RF(a,1);gb=b+16|0}function XV(a){if(a>>>0>=1073741824){pd(8399);L()}return Nc(a<<2,1)}function Pz(a){if(a>>>0>=1073741824){pd(8399);L()}return Nc(a<<2,4)}function MO(a,b){var c=0;c=gb-16|0;gb=c;Dr(c,1,b);Bc(a,c);gb=c+16|0}function Cfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fO(a,b,c,d,e)}function zR(a){if(a>>>0>=536870912){pd(8399);L()}return Nc(a<<3,8)}function q1(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function pl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Xb(Vf(b))}}}function iT(a,b){JB(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function hja(a,b){a=a|0;b=b|0;if(!v[22692]){v[22693]=b;v[22692]=a}}function hH(a,b,c){a=a|0;b=b|0;c=c|0;return Wp(0,a,b,c?c:463920)|0}function aS(a){if(a>>>0>=134217728){pd(8399);L()}return Nc(a<<5,4)}function Zn(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function Wc(a,b,c){a=a|0;b=b|0;c=c|0;return $c(a,B(Ji(a),b)+c|0)|0}function SH(a){if(a>>>0>=268435456){pd(8399);L()}return Nc(a<<4,4)}function OW(a){if(a>>>0>1073741823){pd(8399);L()}return Nc(a<<2,1)}function xJ(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function ui(a,b){var c=0,d=0;c=a,d=sx(v[b>>2]),v[c>>2]=d;return a}function uU(a){a=a+34|0;a=jqa(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function mE(a){if(v[a>>2]){YD(a,v[a>>2]);ZD(wb(a),v[a>>2],Yl(a))}}function hp(a){a=a|0;return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function gy(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function Oc(a,b,c){a=a|0;b=b|0;c=c|0;if(WE(c)){Xb(a);return}Xb(a)}function I_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+12>>2]](a)|0}function H_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+16>>2]](a)|0}function Gp(a,b){a=a|0;b=b|0;jc(a,b);Qb(a+20|0,0,1040);return a|0}function Gj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function FX(a){jb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function uM(a){a=a|0;v[a>>2]=50704;Lc(a+4208|0);jf(a);return a|0}function kba(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function iM(a){a=a|0;v[a>>2]=51196;Lc(a+4256|0);jf(a);return a|0}function gd(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function eu(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function aM(a){a=a|0;v[a>>2]=51808;Lc(a+4208|0);jf(a);return a|0}function _$(a){a=a|0;var b=0,c=0;b=a,c=we(),v[b>>2]=c;return a|0}function ZQ(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function RM(a){a=a|0;v[a>>2]=49656;Lc(a+4208|0);jf(a);return a|0}function NX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(c)}}}function J_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function DM(a){a=a|0;v[a>>2]=49892;gc(a+4208|0);jf(a);return a|0}function At(a,b,c){a=v[a>>2];return(a|0)>=x[b>>1]&(a|0)<=x[c>>1]}function xw(a,b,c){Uf(a,b);v[a+8>>2]=0;Uf(a+12|0,c);Ld(c);Ld(b)}function w$(a,b){a=a|0;b=b|0;a=kb[a|0](b)|0;ma(jb|0);return a|0}function vx(a,b){a=a|0;b=b|0;return(Qh(a)|0)!=0|(a|32)-97>>>0<6}function vR(a){Vp(a);if(v[a>>2]){kR(a);fm(wb(a),v[a>>2],sg(a))}}function ox(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+12>>2]](a,b)|0}function oM(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function kg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function jn(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+28>>2]](a,b)|0}function ifa(a,b){a=a|0;b=b|0;a=aY(a,b);if(!a){yv(b)}return a|0}function em(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+24>>2]](a)|0}function eA(a){fY(a);if(v[a>>2]){sY(a);eY(wb(a),v[a>>2],gn(a))}}function di(a){xk(a);if(v[a>>2]){_q(a);zC(wb(a),v[a>>2],ye(a))}}function cA(a){AO(a);if(v[a>>2]){zO(a);Sz(wb(a),v[a>>2],jk(a))}}function aha(a,b){a=a|0;b=b|0;a=kW(a,b);if(!a){jW(b)}return a|0}function Zz(a){DF(a);if(v[a>>2]){YF(a);hs(wb(a),v[a>>2],Tk(a))}}function Wo(a){xk(a);if(v[a>>2]){_q(a);fw(wb(a),v[a>>2],ye(a))}}function Wm(a){fT(a);if(v[a>>2]){eT(a);lB(wb(a),v[a>>2],Yi(a))}}function Vi(a,b,c){a=a|0;b=b|0;c=c|0;return Fn(Sl(a),Sl(b),c)|0}function Ss(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+44>>2]](a,b)|0}function MV(a,b,c,d){Pe(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Jt(a){JM(a);if(v[a>>2]){NM(a);IM(wb(a),v[a>>2],vl(a))}}function Ik(a){zp(a);if(v[a>>2]){qw(a);dE(wb(a),v[a>>2],Ng(a))}}function Hq(a){oR(a);if(v[a>>2]){cR(a);HA(wb(a),v[a>>2],rg(a))}}function HR(a,b){b=1/(564505.8718779281/b+1);DR(a,b,0,0,b+-1,0)}function Bu(a){_u(a);if(v[a>>2]){dS(a);Qk(wb(a),v[a>>2],bi(a))}}function yC(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4896);gb=c+16|0}function xr(a,b){a=a|0;b=b|0;a=WX(a,b);if(!a){YX(b)}return a|0}function x$(a,b){a=a|0;b=+b;a=kb[a|0](b)|0;ma(jb|0);return a|0}function uw(a,b){lF(a,b);v[a+8>>2]=v[b+8>>2];lF(a+12|0,b+12|0)}function tv(a){a=a|0;a=w[a|0];return ue(a)^1|(a-49&255)>>>0<36}function rL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function nC(a,b){a=a|0;b=b|0;a=PV(a,b);if(!a){Vj(b)}return a|0}function hF(a,b){a=a|0;b=b|0;a=gF(a,b);if(!a){tw(b)}return a|0}function dj(a){UB(a);if(v[a>>2]){fw(v[a+16>>2],v[a>>2],vk(a))}}function cE(a){YE(a);if(v[a>>2]){dE(v[a+16>>2],v[a>>2],ow(a))}}function bs(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function bh(a){UB(a);if(v[a>>2]){ai(v[a+16>>2],v[a>>2],vk(a))}}function _r(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function Yt(a){a=a|0;v[a>>2]=77300;vb(a+32|0);rm(a);return a|0}function Yb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Tf(a,b){return kb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function TB(a,b){a=a|0;b=b|0;a=VX(a,b);if(!a){aD(b)}return a|0}function RD(a,b){a=a|0;b=b|0;a=Mv(a,b);if(!a){Nv(b)}return a|0}function PW(a){UB(a);if(v[a>>2]){zC(v[a+16>>2],v[a>>2],vk(a))}}function Ow(a,b){a=a|0;b=b|0;a=MF(a,b);if(!a){Cw(b)}return a|0}function Kw(a,b){a=a|0;b=b|0;a=yF(a,b);if(!a){xF(b)}return a|0}function Jh(a,b){a=a|0;b=b|0;a=cs(a,b);if(!a){cm(b)}return a|0}function Ih(a){YE(a);if(v[a>>2]){pw(v[a+16>>2],v[a>>2],ow(a))}}function Hw(a,b){Uf(a,b);v[a+8>>2]=v[b+8>>2];Uf(a+12|0,b+12|0)}function Gl(a,b){a=t[lc(a+58|0,b)|0];return((a|0)>-1?a:-1)&255}function Bv(a,b,c){a=w[a|0];return a>>>0>=w[b|0]&a>>>0<=w[c|0]}function p_(a,b){a=a|0;b=b|0;Ns(a,b);v[a>>2]=89284;return a|0}function me(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function ly(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function lR(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function kG(a,b,c){b=Ja(1981,a|0,b|0,c|0)|0;jb=O()|0;return b}function g8(a,b){a=a|0;b=b|0;Ns(a,b);v[a>>2]=89336;return a|0}function ena(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,nI(c,Jb(b),Ab(b)))}function eO(a){a=a|0;v[a+12>>2]=1065353216;dO(a,4);return a|0}function ct(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function Pi(a,b){a=a|0;b=b|0;if(ze(a)>>>0>b>>>0){t[a+16|0]=b}}function Nm(a,b,c){u[a>>1]=x[b>>1];v[a+4>>2]=v[c>>2];return a}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;return ov(a,b,c,1083)|0}function MS(a,b){a=a|0;b=b|0;Ns(a,b);v[a>>2]=89148;return a|0}function Hu(a,b,c){v[a>>2]=v[b>>2];v[a+4>>2]=v[c>>2];return a}function Fea(a,b,c){a=a|0;b=b|0;c=c|0;return ov(a,b,c,1470)|0}function Cr(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function $8(a,b,c){a=a|0;b=b|0;c=c|0;MT(a,0,Ck(v[b+24>>2]),c)}function wc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function op(a,b,c){if(!b){return 0}return jt(a,Kg(t[c|0]),b)}function nda(a){a=a|0;a=ik(a);if(a){kb[v[v[a>>2]+96>>2]](a)}}function jF(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,36);gb=c+16|0}function foa(a,b,c){a=a|0;b=b|0;c=c|0;return ov(a,b,c,639)|0}function YO(a){v[a>>2]=0;mc(a+4|0);Qb(a+16|0,0,144);return a}function Wy(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Ps(){var a=0;a=ba(4)|0;gm(a);ia(a|0,89088,1912);L()}function LW(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,12);gb=c+16|0}function BJ(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function yi(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4);gb=c+16|0}function un(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,2);gb=c+16|0}function sF(a){var b=0;b=v[a+8>>2];if(b){Qk(a,b,v[a+4>>2])}}function pB(a,b){if(b){pB(a,v[b>>2]);pB(a,v[b+4>>2]);sT(b)}}function oB(a,b){if(b){oB(a,v[b>>2]);oB(a,v[b+4>>2]);ev(b)}}function i1(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function fu(a,b){if(b){fu(a,v[b>>2]);fu(a,v[b+4>>2]);ev(b)}}function fC(a,b){if(b){fC(a,v[b>>2]);fC(a,v[b+4>>2]);ev(b)}}function aU(a){if(v[a>>2]){ZT(a,v[a>>2]);Nu(v[a>>2],sg(a))}}function aB(a){cd(a);v[a+12>>2]=0;u[a+16>>1]=65280;return a}function Sr(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,1);gb=c+16|0}function Gw(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function FF(a){var b=0;b=v[a+8>>2];if(b){Sn(a,b,v[a+4>>2])}}function CY(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,8);gb=c+16|0}function BI(a,b){if(b>>>0<=9){return AI(a,b)}return bt(a,b)}function rG(a){a=v[a>>2]-12|0;if((Gw(a+8|0)|0)<=-1){Xb(a)}}function mB(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function kF(a){var b=0;b=gb-16|0;gb=b;Qb(a,0,36);gb=b+16|0}function jg(a,b){a=kqa(v[a>>2],v[a+4>>2],b,b>>31);return a}function ar(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function _8(a){a=a|0;sL(a,2,100);Pi(v[a+24>>2]+484360|0,0)}function Zfa(a){a=a|0;Ns(a,18699);v[a>>2]=89228;return a|0}function X4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb=0;return 0}function Vd(a,b){a=a|0;b=b|0;sd(a,v[b>>2],v[b>>2]+pc(b)|0)}function Rn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function QK(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function Ab(a){if(De(a)){return v[a+4>>2]}return w[a+11|0]}function tp(a,b,c){sd(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function t_(a){a=a|0;WF(a,10619);v[a>>2]=28308;return a|0}function rO(a){var b=0;iC(a);b=v[a>>2];if(b){tO(b,vk(a))}}function pv(a){if(v[a>>2]){TW(a);AC(wb(a),v[a>>2],Sj(a))}}function pe(a,b,c){sd(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function nk(a){a=v[a+656>>2];if(!a){return 0}return Ej(a)}function mv(a){if(v[a>>2]){_q(a);ai(wb(a),v[a>>2],ye(a))}}function mL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){vL(c)}}function iX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){JU(c)}}function fx(a){if(v[a>>2]){Pd(a);sG($w(a),v[a>>2],tG(a))}}function dm(a){if(v[a>>2]){BF(a);Uk(wb(a),v[a>>2],bg(a))}}function ay(a,b){return v[((a>>>24^b)<<2)+459648>>2]^a<<8}function YV(a){var b=0;iC(a);b=v[a>>2];if(b){jC(b,vk(a))}}function Wg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Vq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Vg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function TF(a){var b=0;b=v[a+8>>2];if(b){RF(b,v[a+4>>2])}}function RJ(a){var b=0;b=v[a+8>>2];if(b){QJ(b,v[a+4>>2])}}function NJ(a){var b=0;b=v[a+8>>2];if(b){Ru(b,v[a+4>>2])}}function Mpa(a,b,c){a=a|0;b=b|0;c=c|0;return HD(a,b,c)|0}
function FV(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function FK(a){a=a|0;return Qi(Sb(v[a+24>>2]+484360|0))|0}function Dx(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function DD(a,b){var c=0;c=gb-16|0;gb=c;pR(a,b);gb=c+16|0}function Ce(a){if(v[a>>2]){ai(wb(a),v[a>>2],v[wb(a)>>2])}}function $r(a){if(v[a>>2]){qw(a);pw(wb(a),v[a>>2],Ng(a))}}function $I(a){while(1){if((mt(a)|0)!=-1){continue}break}}function zb(a){var b=0;b=gb-16|0;gb=b;gb=b+16|0;return a}function yG(a){a=a|0;v[a>>2]=83760;vb(a+12|0);return a|0}function xG(a){a=a|0;v[a>>2]=83800;vb(a+16|0);return a|0}function v6(a,b,c){a=a|0;b=b|0;c=c|0;return Cd(B(b,c))|0}function uj(a){return Le(a)|Le(a)<<8|Le(a)<<16|Le(a)<<24}function m$(a){a=a|0;MS(a,5074);v[a>>2]=27308;return a|0}function lA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xA(a,b,c,d)}function jv(a){Wo(a+88|0);Wo(a+68|0);Wo(a+48|0);return a}function h9(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,nI(c,b,Mf(b)))}function goa(a,b){a=a|0;b=b|0;Tb(a,b?b:18699);return a|0}function g$(a,b,c){a=a|0;b=b|0;c=c|0;Jw(a,b,v[b+8>>2],c)}function e$(a){a=a|0;WF(a,5820);v[a>>2]=27416;return a|0}function dI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;oh(a,-1,-1)}function Vj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function Ve(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;of(a,c,d,b)}function Vba(a){a=a|0;ZL(a);t[a+4202|0]=1;v[a+4224>>2]=0}function PC(a){a=a|0;if(!w[a|0]){return 1}return de(a)|0}function OJ(a){a=a|0;v[a>>2]=59148;gc(a+12|0);return a|0}function NA(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function EG(a,b){Dn(v[b>>2]);Gn(v[a>>2]);v[a>>2]=v[b>>2]}function Bn(a,b,c){a=kqa(v[a>>2],v[a+4>>2],b,c);return a}function zs(a){a=a|0;v[a>>2]=89128;rG(a+4|0);return a|0}function zj(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){vL(b)}}function sv(a,b,c){a=a|0;b=b|0;c=c|0;return jt(a,b,c)|0}function rm(a){a=a|0;v[a>>2]=76996;Wb(a+4|0);return a|0}function qF(a){a=a|0;v[a>>2]=28168;Ld(a+4|0);return a|0}function lH(a){return(a|0)!=0&(a|0)!=74832&(a|0)!=74856}function kJ(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function gH(a,b,c,d){a=wI(a,b,c,0,-2147483648);return a}function fG(a,b,c){a=a|0;b=b|0;c=c|0;return ts(a,b,c)|0}function f5(a,b){a=a|0;b=b|0;return OF(a,Jb(b),Ab(b))|0}function er(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(c<<2)|0}function df(a,b,c){a=a|0;b=b|0;c=c|0;Fe(a,b);return a|0}function dP(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){JU(b)}}function Zw(a){a=a|0;v[a>>2]=89108;rG(a+4|0);return a|0}function Xp(a){a=a|0;v[a>>2]=77060;Wb(a+4|0);return a|0}function WL(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function VL(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function Ms(a,b,c){return iG(Jb(a),Ab(a),Jb(b),c,Ab(b))}function LJ(a){a=a|0;v[a>>2]=59564;gc(a+4|0);return a|0}function LC(a,b,c){a=a|0;b=b|0;c=c|0;return ID(a,b,c)|0}function Kv(a,b,c){a=a|0;b=b|0;c=c|0;return NY(a,b,c)|0}function Kc(a){if(De(a)){a=ak(a)-1|0}else{a=10}return a}function Gd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function GG(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Gn(b)}}function Fp(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Fn(a,b,c){b=b-a|0;if(b){vh(c,a,b)}return b+c|0}function Dt(a){a=a|0;v[a>>2]=55108;Ft(a+4|0);return a|0}function sw(a,b){a=jqa(v[a>>2],v[a+4>>2],b,0);return a}function q$(a){a=a|0;a=kb[a|0]()|0;ma(jb|0);return a|0}function oj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function mh(a){var b=0;b=mt(a);v[a+1396>>2]=0;return b}function mM(a){a=a|0;return Fj(C(z[a+4224>>2]*C(4)))|0}function k5(a){a=a|0;return xq(v[v[a>>2]-12>>2]+a|0)|0}function j4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Kj(a,c,d)}function i5(a){a=a|0;return uf(v[v[a>>2]-12>>2]+a|0)|0}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function Yp(a){if(De(a)){a=ak(a)-1|0}else{a=1}return a}function VK(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function Tg(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+20>>2]](a,b)}function TR(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;TA(a)}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b+4228|0,7)}function Q_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hk(a,d,0)}function Ph(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+24>>2]](a,b)}function PH(a){a=a|0;return Xs(v[v[a>>2]-12>>2]+a|0)|0}function Oh(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+28>>2]](a,b)}function OP(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function Mb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b+4260|0,8)}function Dq(a,b){v[a>>2]=b;v[a+4>>2]=b+223232;return a}function C2(a,b){a=a|0;b=b|0;sd(a,QH(v[b>>2]),v[b>>2])}function $p(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function $H(a){a=a|0;return Zs(v[v[a>>2]-12>>2]+a|0)|0}function vb(a){if(De(a)){Uk(a,v[a>>2],ak(a))}return a}function uda(a){a=a|0;t[a+4202|0]=1;Lt(a);Ty(a);GM(a)}function rs(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function qo(a){a=a|0;return kb[v[v[a>>2]+24>>2]](a)|0}function pi(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function of(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function nj(a){a=a|0;return kb[v[v[a>>2]+12>>2]](a)|0}function mj(a){a=a|0;return kb[v[v[a>>2]+16>>2]](a)|0}function ij(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function ama(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Wl(a,b){a=a|0;b=b|0;return Re(a)>>>0>b>>>0|0}function Of(a,b,c){a=a|0;b=b|0;c=c|0;Qo(a);return a|0}function Ln(a,b){return kb[v[v[a>>2]+36>>2]](a,b,0)|0}function Kn(a,b){return kb[v[v[a>>2]+52>>2]](a,b,0)|0}function Ic(a){if(De(a)){ai(a,v[a>>2],ak(a))}return a}function Eca(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function EK(a){a=a|0;return jq(v[a+24>>2]+484344|0)|0}function ED(a){var b=0;b=gb-16|0;gb=b;Hk(a);gb=b+16|0}function qn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function nM(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function iqa(a){if(a){return 31-E(a-1^a)|0}return 32}function gq(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function aca(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function Xo(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function RK(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function MK(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function Dea(a,b){a=a|0;b=b|0;a=a+24|0;DN(a,b);Tz(a)}function zl(a){if(v[a>>2]){Pd(a);tO(v[a>>2],ye(a))}}function z6(a,b,c){a=a|0;b=b|0;c=c|0;sJ(a-88|0,b,c)}function yo(a){a=a|0;return ku(w[a+3|0],w[a+5|0])|0}function xB(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function vd(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function pX(a){a=a|0;return jz(w[a+3|0],w[a+5|0])|0}function ol(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function lka(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,Ds(b,c))}function l9(a){a=a|0;a=v[a+4>>2];return(a?a:2107)|0}function js(a){if(v[a>>2]){Pd(a);AF(v[a>>2],rg(a))}}function fP(a){if(v[a>>2]){Pd(a);cP(v[a>>2],rg(a))}}function eD(a,b){Pe(a,b);Qb(a+20|0,0,1040);return a}function dt(a){if(!a){return 0}v[115173]=a;return-1}function cq(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function ci(a){if(v[a>>2]){Pd(a);jC(v[a>>2],ye(a))}}function ce(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function au(a){v[a>>2]=38348;v[a>>2]=18708;return a}function Yo(a){if(v[a>>2]){Pd(a);qW(v[a>>2],oW(a))}}function YT(a){if(v[a>>2]){Pd(a);Nu(v[a>>2],sg(a))}}function W5(a,b){a=a|0;b=b|0;return OF(a,b,Mf(b))|0}function Up(a,b){b=v[b>>2];v[a>>2]=b;Dn(b);return a}function UK(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function Spa(a){a=a|0;fn(90800);hD(90792);vb(90780)}function QQ(a){if(v[a>>2]){Pd(a);JQ(v[a>>2],zA(a))}}function No(a,b,c){if(!c){return 0}return rd(a,b,c)}function Mu(a){if(v[a>>2]){Pd(a);wB(v[a>>2],bi(a))}}function LK(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function Ku(a){if(v[a>>2]){Pd(a);tB(v[a>>2],uB(a))}}function Ju(a){if(v[a>>2]){Pd(a);vB(v[a>>2],vi(a))}}function Jea(a,b){a=a|0;b=b|0;bk(a+36|0,b);return 1}function Gv(a){if(v[a>>2]){Pd(a);FY(v[a>>2],Ng(a))}}function Ed(a){if(v[a>>2]){LY(a);rD(v[a>>2],Yi(a))}}function ER(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function Ds(a,b){a=a|0;b=b|0;return wp(a,b,Mf(b))|0}function Db(a,b,c){sd(a,(c>>>3&536870908)+b|0,1<<c)}function Cq(a){a=a|0;return ku(w[a+2|0],w[a+4|0])|0}function Cp(a){a=a|0;a=dc(a);kb[v[v[a>>2]>>2]](a)|0}function B6(a,b,c){a=a|0;b=b|0;c=c|0;uJ(a-88|0,b,c)}function $n(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function y6(a,b){a=a|0;b=b|0;return rJ(a-88|0,b)|0}function mC(a,b,c){u[a>>1]=x[b>>1];t[a+2|0]=w[c|0]}function kl(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function hn(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function bp(a){return(v[a+480180>>2]&740327453)!=0}function WC(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function Vt(a){a=a|0;oi(a);v[a+20>>2]=0;return a|0}function Rj(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function Kt(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,HG(b,c))}function Jl(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function IP(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function Hj(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function Gm(a){Cj(a+724|0);Cj(a+732|0);Cj(a+740|0)}function D6(a,b,c){a=a|0;b=b|0;c=+c;wJ(a-88|0,b,c)}function Bo(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function A6(a,b){a=a|0;b=b|0;return tJ(a-88|0,b)|0}function zna(a,b){a=a|0;b=b|0;if(!kW(a,b)){jW(b)}}function zN(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function xp(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,26,b)}function wW(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,16,b)}function wE(a){return!rd(a,28386,25)&w[a+34|0]<65}function tg(a,b){return iG(Jb(a),Ab(a),b,0,Mf(b))}function sg(a){return(v[wb(a)>>2]-v[a>>2]|0)/12|0}function sd(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function oW(a){return(v[wb(a)>>2]-v[a>>2]|0)/33|0}function mma(a,b){a=a|0;b=b|0;if(!Mv(a,b)){Nv(b)}}function jk(a){return(v[wb(a)>>2]-v[a>>2]|0)/52|0}function jfa(a,b){a=a|0;b=b|0;if(!MF(a,b)){Cw(b)}}function gn(a){return(v[wb(a)>>2]-v[a>>2]|0)/48|0}function gh(a,b){if(De(a)){ee(a,b);return}Xe(a,b)}function cv(a){return(v[wb(a)>>2]-v[a>>2]|0)/24|0}function cna(a,b){a=a|0;b=b|0;if(!gF(a,b)){tw(b)}}function Yl(a){return(v[wb(a)>>2]-v[a>>2]|0)/20|0}function Yi(a){return(v[wb(a)>>2]-v[a>>2]|0)/28|0}function Uj(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,20,b)}function Tk(a){return(v[wb(a)>>2]-v[a>>2]|0)/36|0}function TC(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,40,b)}function Om(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Kpa(a,b){a=a|0;b=b|0;if(!aY(a,b)){yv(b)}}function Jk(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,22,b)}function Ie(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,32,b)}function Hr(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,30,b)}function Hp(a){return(v[dc(a)>>2]-v[a>>2]|0)/12|0}function He(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function HY(a){return(v[dc(a)>>2]-v[a>>2]|0)/28|0}function HI(a,b){if(!a){return 0}return il(a,b,0)}function Fk(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,28,b)}function Ek(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,12,b)}function Dr(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,64,b)}function DU(a){return(v[wb(a)>>2]-v[a>>2]|0)/56|0}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function zr(a,b){a=a|0;b=b|0;if(!cs(a,b)){cm(b)}}function zA(a){return(v[wb(a)>>2]-v[a>>2]|0)/7|0}function wR(a){return(v[a+4>>2]-v[a>>2]|0)/872|0}function vy(a,b){v[a>>2]=v[b>>2];Dc(a+4|0,b+4|0)}function vY(a,b){a=kY(a,b);if(!a){cD(b)}return a}function rz(a){return B(Hj(a),Jl(a))+7>>>3&65535}function ry(a,b,c){return er(a,b,v[a+12>>2]+c|0)}function qx(a,b,c,d){a=wI(a,b,c,-1,-1);return a}
function qC(a,b){a=a|0;b=b|0;if(!_V(a,b)){kC(b)}}function oy(a,b,c){return Wg(a,b,v[a+12>>2]+c|0)}function nr(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function ki(a){return(Sf(a)|0)!=(0-Sf(a+12|0)|0)}function fX(a,b){a=a|0;b=b|0;return Qt(a,b,32)|0}function d4(a,b){a=a|0;b=b|0;return kb[b|0](a)|0}function cca(a){a=a|0;return z[a+4212>>2]<C(1)|0}function ZX(a,b){a=a|0;b=b|0;if(!VX(a,b)){aD(b)}}function Yn(a,b,c){return FV(a,b,v[a+12>>2]+c|0)}function Xg(a){a=w[a+20|0];return(a|0)==255?-1:a}function TA(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Sj(a){return(v[wb(a)>>2]-v[a>>2]|0)/6|0}function SJ(a,b,c){a=Ud(a);v[a+4>>2]=c;v[a>>2]=b}function QD(a,b){a=a|0;b=b|0;if(!yF(a,b)){xF(b)}}function Mi(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function Jb(a){if(De(a)){return v[a>>2]}return a}function Hl(a){a=a|0;Pq(v[a+20>>2]);v[a+20>>2]=0}function Gca(a){a=a|0;return z[a+4220>>2]<C(1)|0}function FA(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Dpa(a,b,c){a=a|0;b=b|0;c=c|0;hc(b,c,48)}function DY(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function CZ(a,b){a=a|0;b=b|0;if(!KD(a,b)){Pv(b)}}function C6(a,b){a=a|0;b=b|0;return+vJ(a-88|0,b)}function BS(a,b){yc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function $A(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function zu(a,b){a=a|0;b=b|0;eg(a,b);return a|0}function yca(a){a=a|0;t[a+4202|0]=1;kM(a);lM(a)}function wr(a,b,c){b=b-a|0;if(b){vh(c-b|0,a,b)}}function qca(a){a=a|0;t[a+4202|0]=1;fM(a);eM(a)}function kv(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function gl(a){a=a|0;return YH(v[a>>2])<<24>>24}function en(a,b,c){v[a>>2]=b;v[a+4>>2]=(c<<1)+b}function co(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function Yk(a){return kb[v[v[a>>2]+36>>2]](a)|0}function Vk(a){return(v[a+4>>2]-v[a>>2]|0)/36|0}function UQ(a,b){a=a|0;b=b|0;jc(a,b);return a|0}function Tj(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function Rf(a,b){a=a|0;b=b|0;return Wc(a,b,0)|0}function Qn(a){return kb[v[v[a>>2]+28>>2]](a)|0}function Qf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function Pm(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Mba(a){a=a|0;XL(a);Ly(a);t[a+4202|0]=1}function Kp(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function KV(a){var b=0;b=v[a>>2];Ne(a);return b}function Fh(a,b){a=a|0;b=b|0;Pe(a,b);return a|0}function Ec(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function Ch(a){return(v[a+4>>2]-v[a>>2]|0)/28|0}function $q(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function $e(a){return(v[a+4>>2]-v[a>>2]|0)/20|0}function yu(a){return(a>>>0<9?a:a-9|256)&65535}function sf(a,b,c){if(!(w[a|0]&32)){YC(b,c,a)}}function nl(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function eo(a,b,c){a=a|0;b=b|0;c=c|0;sd(a,b,c)}function bc(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b,c)}function _C(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function WR(a,b){RR(v[a>>2],b);RR(v[a+4>>2],b)}function T8(a,b){a=a|0;b=b|0;Dc(a,Ds(b,14711))}function Rt(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function Qj(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function Nd(a){return v[a+20>>2]!=0&v[a>>2]!=0}function Ml(a,b){return(B(b,104)+a|0)+484380|0}function MR(a){OA(a);Qb(a+27|0,0,255);return a}function Ji(a){a=a|0;return x[lo(a)+480188>>1]}function Ig(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function Ep(a){QF(a);v[a+8>>2]=0;v[a>>2]=79004}function EA(a){return(v[a+4>>2]-v[a>>2]|0)/7|0}function E4(a,b,c){a=a|0;b=b|0;c=c|0;sd(a,c,b)}function $o(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function yW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function wg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function vl(a){return v[wb(a)>>2]-v[a>>2]>>11}function tc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function rF(a){a=a|0;v[a>>2]=28032;return a|0}function pm(a,b){a=a|0;b=b|0;return TH(a,b)^1}function nY(a){t[a+12|0]=w[a+12|0]|2;return a}function mqa(a,b,c,d){a=hqa(a,b,c,d);return a}function mi(a,b){a=a|0;b=b|0;return Nc(b,1)|0}function mg(a,b){a=a|0;b=b|0;return Rl(a,b)|0}function j5(a){a=a|0;JH(v[v[a>>2]-12>>2]+a|0)}function hi(a,b){a=a|0;b=b|0;return ew(a,b)|0}function h5(a){a=a|0;IH(v[v[a>>2]-12>>2]+a|0)}function gx(a,b){a=a|0;b=b|0;return Ds(a,b)|0}function gk(a,b){a=a|0;b=b|0;return ZH(a,b)^1}function fk(a,b){a=a|0;b=b|0;return ZH(a,b)|0}function bl(a,b){a=a|0;b=b|0;return TH(a,b)|0}function _H(a){a=a|0;Ix(v[v[a>>2]-12>>2]+a|0)}function Zj(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function Zh(a,b){a=a|0;b=b|0;return nS(a,b)|0}function Ud(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Rl(a,b){a=a|0;b=b|0;return Zo(a,b)^1}function QP(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function Pt(a,b){a=a|0;b=b|0;return HG(a,b)|0}function PJ(a){a=a|0;v[a>>2]=58792;return a|0}function PF(a){a=a|0;v[a>>2]=27464;return a|0}function OH(a){a=a|0;Ex(v[v[a>>2]-12>>2]+a|0)}function MJ(a){a=a|0;v[a>>2]=59200;return a|0}function KG(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Ey(a){a=a|0;v[a>>2]=54940;return a|0}function Ej(a){return(w[a+31|0]-1&255)>>>0<17}function EF(a){a=a|0;v[a>>2]=27796;return a|0}function DP(a){fP(a+20|0);eP(a+8|0);dP(a+4|0)}function zF(a,b){a=a|0;b=b|0;return(b|0)<6|0}function ye(a){return v[wb(a)>>2]-v[a>>2]>>2}function vk(a){return v[dc(a)>>2]-v[a>>2]>>2}function vi(a){return v[wb(a)>>2]-v[a>>2]>>4}function vL(a){if(a){kb[v[v[a>>2]+4>>2]](a)}}function uB(a){return v[wb(a)>>2]-v[a>>2]>>8}function tF(a){return v[dc(a)>>2]-v[a>>2]>>3}function ru(a,b,c){a=a|0;b=b|0;c=c|0;IY(b,c)}function rg(a){return v[wb(a)>>2]-v[a>>2]>>3}function rB(a){return v[dc(a)>>2]-v[a>>2]>>5}function ow(a){return v[dc(a)>>2]-v[a>>2]>>1}function lg(a){return v[v[a+8>>2]>>2]==(a|0)}function jG(a){a=Ha(a|0)|0;jb=O()|0;return a}function h6(a){a=a|0;return Ea(v[a+60>>2])|0}function bi(a){return v[wb(a)>>2]-v[a>>2]>>5}function bca(a){a=a|0;return C(z[a+4220>>2])}function _6(a){a=a|0;KJ(a);return v[a+16>>2]}function ZC(a,b,c){a=a|0;b=b|0;c=c|0;Pe(b,c)}function Xy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function TD(a){return w[a+1|0]==2?w[a|0]<3:0}function PK(a){a=a|0;return OK(v[a+24>>2])|0}function Oo(a){a=a|0;iB(a+288|0);Po(a+800|0)}function Ng(a){return v[wb(a)>>2]-v[a>>2]>>1}function My(a){return C(C(a*C(7900))+C(100))}function In(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c)}function If(a){return v[a+8>>2]-v[a+12>>2]|0}function Hx(a){return v[dc(a)>>2]-v[a>>2]>>4}function Fca(a){a=a|0;return C(z[a+4212>>2])}function zH(a){QO(a);v[a>>2]=77436;return a}function xf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function tG(a){return v[a+16>>2]-v[a>>2]>>2}function rM(a){a=a|0;kb[v[v[a>>2]+4>>2]](a)}function pM(a){a=a|0;return C(z[a+4208>>2])}function nm(a){a=a|0;QH(v[a>>2]);return a|0}function kK(a,b){a=a|0;b=b|0;return pc(b)|0}function jK(a,b){a=a|0;b=b|0;return Nb(b)|0}function g6(a,b){a=a|0;b=b|0;return Qh(a)|0}function fl(a){a=a|0;Gx(v[a>>2]);return a|0}function dda(a,b,c){a=a|0;b=b|0;c=c|0;Ud(a)}function cL(a){t[a+4|0]=0;t[a|0]=0;return a}function bu(a){QO(a);v[a>>2]=77364;return a}function bg(a){return v[wb(a)>>2]-v[a>>2]|0}function Zq(a){return gr(v[a>>2],v[a+4>>2])}function Wt(a,b,c){b=b-a|0;if(b){vh(c,a,b)}}function Vo(a,b){return v[a>>2]<v[b>>2]?b:a}function VR(a,b){u[a+22>>1]=b&7;TA(a);UA(a)}function U_(a,b){a=a|0;b=b|0;JF(Qb(b,0,36))}function Sf(a){return v[a+4>>2]-v[a>>2]>>11}function Ii(a,b){a=a|0;b=b|0;return C(C(0))}function IL(a){return Xh(C(KL(a)*C(32768)))}function Eda(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function $6(a){a=a|0;KJ(a);return v[a+4>>2]}function ze(a){return v[a+4>>2]-v[a>>2]>>5}function yx(a){a=a|0;return Nh(a,464212)|0}function yea(a,b){a=a|0;b=b|0;eg(a,b+36|0)}function w5(a){a=a|0;return Nh(a,464032)|0}function tf(a){return v[a+4>>2]-v[a>>2]>>4}function sc(a){return v[a+4>>2]-v[a>>2]>>1}function sD(a){a=a|0;return Nh(a,465984)|0}function qf(a){return v[a+4>>2]-v[a>>2]>>3}function px(a){a=a|0;return Nh(a,464236)|0}function np(a,b){return v[a>>2]-v[b>>2]>>1}function n7(a,b){a=a|0;b=b|0;PQ(v[a>>2],b)}function lx(a){a=a|0;return Nh(a,464244)|0}function iv(a,b){return v[a>>2]-v[b>>2]>>2}function iH(){return(v[v[22597]>>2]?4:1)|0}function ak(a){return v[a+8>>2]&2147483647}function ah(a){return v[a+4>>2]-v[a>>2]>>8}function _k(a,b){kb[v[v[b>>2]+44>>2]](a,b)}function Zk(a,b){kb[v[v[b>>2]+32>>2]](a,b)}function Xq(a,b){a=a|0;b=b|0;return b-a>>1}function UR(a,b){t[a+21|0]=b&3;TA(a);UA(a)}function Tu(a){Ce(a+24|0);gc(a+12|0);gc(a)}function SK(a){a=a|0;return+LO(v[a+24>>2])}function Ofa(a,b){a=a|0;b=b|0;bk(a+40|0,b)}function OL(a){return C(C(a*C(96))+C(-96))}function Nb(a){return v[a+4>>2]-v[a>>2]>>2}function L5(a){a=a|0;return Nh(a,464016)|0}function KT(a,b){return v[a>>2]+B(b,872)|0}function Fx(a){a=a|0;return Nh(a,464196)|0}function Es(a,b){kb[v[v[b>>2]+40>>2]](a,b)}function Dm(a){vb(a+36|0);Lc(a+24|0);dn(a)}function Cx(a){a=a|0;return Nh(a,464204)|0}function Bw(a){ms(a+32|0);xb(a+12|0);vb(a)}function $_(a){a=a|0;return v[a+4>>2]!=0|0}function zo(a,b,c){return a<b?b:C(F(a,c))}function w6(a,b){a=a|0;b=b|0;pJ(a-88|0,b)}function uW(a,b){return v[a>>2]+B(b,33)|0}function pc(a){return v[a+4>>2]-v[a>>2]|0}function om(a){a=a|0;return RH(v[a>>2])|0}function nf(a){v[a>>2]=v[a>>2]+2;return a}function lo(a){return v[v[a+48>>2]+12>>2]}function ky(a){a=a|0;Bt(a+8|0);return a|0}function io(a,b,c){Kj(a,b,b+c|0);return a}function ika(a){a=a|0;return bs(a+20|0)|0}function fi(a){return x[a+480190>>1]<3999}function eS(a){v[a>>2]=v[a>>2]-2;return a}function dF(a){return(w[a+24|0]&16)>>>4|0}function cy(a){a=a|0;if(a){dJ(a);ie(a,a)}}function af(a,b){return v[a>>2]+B(b,52)|0}function Zs(a){a=a|0;lh(a+8|0);return a|0}function ZY(a,b){a=a|0;b=b|0;bk(a+12|0,b)}function Ym(a,b){return v[a>>2]+B(b,56)|0}function Yj(a,b){return v[a>>2]-v[b>>2]|0}function Xs(a){a=a|0;lh(a+4|0);return a|0}function Ut(a,b){return v[a>>2]+B(b,28)|0}function UN(a,b){Om(a,A[b>>3],-A[b+8>>3])}function Rca(a){a=a|0;t[a+4202|0]=1;vM(a)}function Ol(a,b){return v[a>>2]+B(b,24)|0}function O0(a,b){a=a|0;b=b|0;eg(a,b+16|0)}function NL(a){a=a|0;Qb(a+4296|0,0,81928)}function M6(a,b){a=a|0;b=b|0;EJ(a-88|0,b)}function Lj(a,b){return v[a>>2]+B(b,36)|0}function L6(a,b){a=a|0;b=b|0;DJ(a-88|0,b)}function Kba(a){a=a|0;return v[a+4260>>2]}function Jg(a,b){return v[a>>2]+B(b,20)|0}function Hd(a,b){v[a>>2]=v[b>>2];return a}function HG(a,b){return wp(a,Jb(b),Ab(b))}function Fc(a,b){a=a|0;b=b|0;Up(a,b+28|0)}function DK(a,b){a=a|0;b=b|0;eg(a,b+12|0)}function An(a,b){return v[a>>2]+(b<<11)|0}function Ad(a,b){return v[a>>2]+B(b,12)|0}function AI(a,b){t[a|0]=b+48;return a+1|0}function zg(a){a=a|0;return CP(w[a|0])|0}function xna(a,b){a=a|0;b=b|0;Qt(a,b,17)}function xe(a,b){return v[a>>2]+(b<<3)|0}function tm(a){return(a|0)==32|a-9>>>0<5}function rna(a,b){a=a|0;b=b|0;Kk(a,b,17)}function rc(a,b){return v[a>>2]+(b<<1)|0}function pg(a,b){v[a+8>>2]=b|-2147483648}function oba(a){a=a|0;return(a|0)==277|0}function lL(a){return(Jb(a)+Ab(a)|0)-1|0}function gj(a){return B(fj(a),dd(a))&255}function cqa(a,b){a=a|0;b=b|0;Kk(a,b,44)}function bd(a){return v[a>>2]==v[a+4>>2]}function Zo(a,b){return v[a>>2]==v[b>>2]}function Xf(a){a=a|0;return!v[a+16>>2]|0}function Ws(a,b){v[a+24>>2]=v[a+24>>2]+b}function UF(a,b){xc(a,b);xc(a+4|0,b+4|0)}function Tc(a,b){return v[a>>2]+(b<<4)|0}function QF(a){v[a+4>>2]=0;v[a>>2]=78948}function Q6(a){a=a|0;return ky(a-88|0)|0}function Pl(a){a=a|0;return v[a>>2]+14|0}function M0(a,b){a=a|0;b=b|0;bx(a,83832)}function Lb(a,b){return v[a>>2]+(b<<2)|0}function Kl(a,b){return v[a>>2]+(b<<8)|0}function K6(a,b){a=a|0;b=+b;CJ(a-88|0,b)}function K0(a,b){a=a|0;b=b|0;bx(a,83852)}function I6(a,b){a=a|0;b=+b;AJ(a-88|0,b)}function Gb(a,b){return v[a>>2]!=v[b>>2]}function F6(a,b){a=a|0;b=+b;yJ(a-88|0,b)}function Dda(a){a=a|0;return w[a+4201|0]}function Cj(a){u[a+4>>1]=65535;v[a>>2]=0}function Cda(a){a=a|0;return w[a+4202|0]}function CE(a,b){return v[a>>2]+(b<<5)|0}function Bla(a,b){a=a|0;b=b|0;Kk(a,b,10)}function AM(a){return(w[a+24|0]&8)>>>3|0}function $c(a,b){return v[a>>2]+B(b,6)|0}function $b(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function zn(a,b){return x[a>>1]<x[b>>1]}function zP(a,b){return(Gl(a,b)|0)!=255}function xZ(a,b){a=a|0;b=b|0;Qt(a,b,11)}function wX(a,b){v[a>>2]=v[a>>2]+B(b,6)}function vba(a){a=a|0;return-2013527448}function vF(a,b){bc(a,v[b>>2],qf(b)<<3)}function sn(a,b){return y[a>>2]<y[b>>2]}function pla(a,b){a=a|0;b=b|0;Kk(a,b,5)}function pW(a,b){a=a|0;b=b|0;return b|0}function mw(a,b){a=a|0;b=b|0;hw(a,b,32)}function lt(a,b){return v[a>>2]<v[b>>2]}function ie(a,b){if(!v[a+80>>2]){Xb(b)}}function gZ(a,b){a=a|0;b=b|0;Kk(a,b,11)}function gS(a,b){v[a>>2]=v[a>>2]+(b<<1)}function dT(a,b){return A[a>>3]<A[b>>3]}function bv(a,b){return z[a>>2]<z[b>>2]}function VN(a){v[a+4>>2]=v[a+4>>2]|8192}function VE(a,b){a=a|0;b=b|0;Kk(a,b,32)}function SV(a,b){v[a>>2]=v[a>>2]+(b<<2)}function RG(a,b){a=a|0;b=b|0;Ge(a,1,45)}function QG(a,b){a=a|0;b=b|0;gI(a,1,45)}function Pq(a){a=a|0;if(a){Xb(a+-64|0)}}function N0(a,b){a=a|0;b=b|0;Tb(a,8524)}function L0(a,b){a=a|0;b=b|0;Tb(a,8641)}function Jj(a,b){return u[a>>1]<u[b>>1]}function Ib(a){return(a<<8|a>>>8)&65535}function Er(a,b,c){if(b){Qb(a,Kg(c),b)}}function Ena(a,b){a=a|0;b=b|0;GD(a,b,8)}function Bi(a,b,c){Dc(a,b);Dc(a+12|0,c)}function xh(a){a=+a;return dr(fe(a))|0}function xca(a){a=a|0;return-285139079}function wK(a){return a?(a|0)==2?3:2:1}function uA(a,b,c){return a<b?b:F(a,c)}function sk(a,b){return Jb(a)+(b<<2)|0}function q8(a){a=a|0;return+A[a+16>>3]}function pca(a){a=a|0;return-284078960}function os(a){Vk(a);YF(a);Tk(a);Vk(a)}function mn(a,b){a=a|0;b=b|0;bc(a,b,7)}function mba(a,b){a=a|0;b=b|0;return 3}function lba(a,b){a=a|0;b=b|0;return 2}function lS(a,b){v[a+4>>2]=b;v[a>>2]=b}function jZ(a){a=a|0;return v[a+12>>2]}function ida(a){a=a|0;return 542066252}function ica(a){a=a|0;return-281111764}function hT(a,b){a=a|0;b=b|0;tk(a,0,b)}function dd(a){return w[a+34|0]&64?2:1}function dca(a){a=a|0;return-271958638}function _G(a,b,c){Fe(a,b);Fe(a+4|0,c)}function Zr(a){a=a|0;return 2147483647}function Zi(a){return B(v[a>>2],gj(a))}function Zc(a){v[v[a+8>>2]>>2]=v[a>>2]}function WY(a){a=a|0;return v[a+24>>2]}function WF(a,b){qH(a,b);v[a>>2]=89388}function Vja(a){a=a|0;TS(a);return a|0}function Uba(a){a=a|0;return-620920304}function Py(a,b){a=a|0;b=b|0;hN(a,3,b)}function Lba(a){a=a|0;return-275227023}function LE(a){wb(a);return 2147483647}function J6(a){a=a|0;return+BJ(a-88|0)}function Hca(a){a=a|0;return-270114148}function G6(a){a=a|0;return+zJ(a-88|0)}function Fq(a,b){a=a|0;b=b|0;lI(a,b,0)}function F_(a){a=a|0;return v[a+16>>2]}function E6(a){a=a|0;return+xJ(a-88|0)}function Cba(a){a=a|0;return 302837129}function xl(a){return(w[a+16|0]&5)!=0}function wx(a){a=a|0;zs(a);return a|0}function wt(a){a=a|0;return v[a+4>>2]}function tx(a){a=a|0;if(lH(a)){Xb(a)}}function oi(a){a=a|0;HF(a);return a|0}function nv(a){a=a|0;return Pb(a,1)^1}function lw(a){return w[a+21|0]>>>7|0}function lh(a){a=a|0;Bx(a);return a|0}function jy(a){a=a|0;return v[a+8>>2]}function ip(a,b){u[a+8>>1]=b;return a}function iL(a,b){return w[a|0]<w[b|0]}function fj(a){return t[a+34|0]&1?2:1}function es(a,b){a=a|0;b=b|0;return 1}function _s(a,b){a=a|0;b=b|0;return-1}function ZH(a,b){return HH(a)^HH(b)^1}function W6(a){a=a|0;return w[a+40|0]}function TH(a,b){return GH(a)^GH(b)^1}function Se(a,b){v[a+4>>2]=b;return a}function Sb(a){return CE(a,w[a+16|0])}function S4(a){a=a|0;return xH(a,0)|0}function RE(a){return w[a+22|0]>>>7|0}function R4(a){a=a|0;return xH(a,1)|0}function OK(a){return x[a+1074448>>1]}function N4(a){a=a|0;return vH(a,0)|0}function MQ(a){a=a|0;tr(a);return a|0}function M4(a){a=a|0;return vH(a,1)|0}function Ij(a,b){return t[a|0]<t[b|0]}function HJ(a){v[a>>2]=60052;return a}function FL(a,b){a=a|0;b=b|0;return 0}function FH(a){a=a|0;wx(a);return a|0}function De(a){return w[a+11|0]>>>7|0}function Ck(a){return v[a+1298364>>2]}function $ca(a,b){a=a|0;b=b|0;zu(a,b)}function zfa(a){a=a|0;return Ki(a)|0}function yV(a,b){if(!mV(a,b)){QB(b)}}function xm(a,b){pc(a);oK(a,b);iK(a)}function vpa(a){a=a|0;return RX(a)|0}function vN(a,b){Qf(a);yO(a,b);sN(a)}function rn(a,b){sc(a);$E(a,b);xE(a)}function md(a,b){return An(a+12|0,b)}function iS(a,b){ze(a);cS(a,b);bS(a)}function hj(a){return v[a+4>>2]-36|0}function h7(a){a=a|0;return w[a+8|0]}function gG(a,b){a=a|0;b=b|0;Au(a,b)}function fh(a,b){a=a|0;b=b|0;RY(a,b)}function eoa(a){a=a|0;return Ck(a)|0}function ej(a,b){Nb(a);zU(a,b);gw(a)}function e_(a,b){a=a|0;b=b|0;Nq(a,b)}function Yf(a,b){a=a|0;b=b|0;eg(a,b)}function Wu(a){return v[wb(a)>>2]<<5}function Tba(a){a=a|0;v[a+4224>>2]=0}function TK(a){return v[a+4>>2]-48|0}function Rr(a,b){a=a|0;b=b|0;vw(a,b)}function Q0(a){a=a|0;return t[a+8|0]}function P0(a){a=a|0;return t[a+9|0]}function OM(a,b,c){a=a|0;b=b|0;c=c|0}function Nka(a){a=a|0;return NT(a)|0}function LL(a){v[a>>2]=0;v[a+4>>2]=0}function Kr(a,b){a=a|0;b=b|0;Ov(a,b)}function KU(a){return v[a+4>>2]-56|0}function IC(a,b){Ig(a);SW(a,b);GW(a)}function HU(a){return v[a+4>>2]-28|0}function Gga(a){a=a|0;return em(a)|0}function GR(a,b){a=a|0;b=b|0;Yf(a,b)}function FO(a){return v[a+4>>2]-32|0}function Dn(a){v[a+4>>2]=v[a+4>>2]+1}function CP(a){return(a+5&255)>>>0<2}function CK(a){return v[a+4>>2]-12|0}function zea(a){a=a|0;Qt(a,18699,1)}function zda(a,b){a=a|0;b=b|0;Vy(b)}function yc(a,b){v[a>>2]=b;return a}function vf(a){return v[a+24620>>2]}function sha(a,b){a=a|0;b=b|0;xR(b)}function qz(a){a=a|0;return xl(a)|0}function oo(a){return v[a+4>>2]-4|0}function n_(a){a=a|0;return rf(a)|0}function mha(a,b){a=a|0;b=b|0;Ce(b)}function l2(){_d(465464,Wd(464008))}function kc(a,b){return v[a>>2]+b|0}function k2(){_d(465472,Wd(465984))}function ju(a){return so(a)<<24>>24}function j2(){_d(465488,Wd(464196))}function j$(a){a=a|0;return qg(a)|0}function i2(){_d(465496,Wd(464204))}function hka(a,b){a=a|0;b=b|0;Zd(b)}function gc(a){rt(a);dm(a);return a}function g2(){_d(465504,Wd(464212))}function f2(){_d(465520,Wd(464220))}function f$(a){a=a|0;return v[a>>2]}function e2(){_d(465528,Wd(464228))}function d2(){_d(465536,Wd(464236))}function cF(a){a=a|0;return Mg(a)|0}function c2(){_d(465568,Wd(464244))}function b2(){_d(465600,Wd(464016))}function a2(){_d(465608,Wd(464024))}function _x(a){return!rd(a,90060,6)}function _1(){_d(465624,Wd(464040))}function Zb(a){return Fg(v[a+4>>2])}function Z1(){_d(465632,Wd(464080))}function Y1(){_d(465640,Wd(464088))}function Xl(a,b,c){if(c){vh(a,b,c)}}function XY(a){a=a|0;return bs(a)|0}function X1(){_d(465648,Wd(464096))}function WZ(a){a=a|0;return qE(a)|0}function W8(a){a=a|0;return te(a)|0}function W1(){_d(465656,Wd(464104))}function V1(){_d(465664,Wd(464112))}function Ur(a){t[a+2|0]=0;u[a>>1]=0}function U1(){_d(465672,Wd(464120))}function TE(a){return w[a+21|0]&127}function T1(){_d(465680,Wd(464128))}function SE(a){return w[a+22|0]&127}function S1(){_d(465688,Wd(464136))}function RY(a,b){EH(a,v[a+16>>2]|b)}function R1(){_d(465696,Wd(464048))}function Qg(a,b,c){return Fn(a,b,c)}function QC(a,b){return xX(a,0-b|0)}function QA(a,b){return B(b,12)+a|0}function Q1(){_d(465712,Wd(464056))}function Og(a,b,c){if(c){hc(a,b,c)}}function O1(){_d(465728,Wd(464064))}function Nr(a){a=a|0;return Ae(a)|0}function Nna(a,b){a=a|0;b=b|0;Vj(b)}function M1(){_d(465744,Wd(464072))}function LV(a,b){return ve(a,0-b|0)}function L1(){_d(465760,Wd(464144))}function K1(){_d(465768,Wd(464152))}function Jfa(a,b){a=a|0;b=b|0;Dm(b)}function J7(a){a=a|0;return mK(a)|0}function Ifa(a,b){a=a|0;b=b|0;Hg(b)}function Gha(a,b){a=a|0;b=b|0;Sm(b)}function $1(){_d(465616,Wd(464032))}function yh(a,b){Qo(a);cf(a+4|0,b)}function xj(a){return bd(a+36|0)^1}function u6(a,b){a=a|0;b=b|0;Xb(b)}function te(a){return v[a>>2]+16|0}function sy(a,b){a=a|0;b=b|0;Hf(b)}function qh(a,b){v[a>>2]=v[a>>2]|b}function qS(a,b){t[v[a>>2]]=w[b|0]}function ot(a){a=a|0;t[a+6152|0]=0}function m2(){_d(465456,Wd(464e3))}function lK(a){return(Xg(a)|0)==-1}function hk(a,b,c){vd(a,v[b>>2],c)}function hf(a,b){Qo(a);yc(a+4|0,b)}function h_(a,b){a=a|0;b=b|0;Ur(b)}function hK(a,b){a=a|0;b=b|0;ty(b)}function hG(a,b){a=a|0;b=b|0;vb(b)}function gm(a){ym(a);v[a>>2]=89016}function gK(a,b){a=a|0;b=b|0;zl(b)}function fo(a,b){v[a+1298424>>2]=b}function fU(a){sd(a,0,-1);return a}function f3(a){a=a|0;bo(a,1,10732)}function cw(a,b){v[a>>2]=v[a>>2]+b}function bN(a,b){a=a|0;b=b|0;Qo(b)}function Xd(a){QF(a);v[a>>2]=84088}function V_(a,b){a=a|0;b=b|0;Bw(b)}function Us(a){return He(a,-1)?0:a}function PG(a){return Nh(a,464088)}function OG(a){return Nh(a,464080)}function MG(a){return Nh(a,464104)}function Ll(a,b){tp(a,b,v[b+4>>2])}function Lh(a,b){a=a|0;b=b|0;Kb(a)}function LG(a){return Nh(a,464096)}function KZ(a,b){a=a|0;b=b|0;Zv(b)}function IZ(a,b){a=a|0;b=b|0;Hk(b)}function Hk(a){t[a|0]=0;t[a+1|0]=0}function HZ(a,b){a=a|0;b=b|0;oi(b)}function Gi(a){a=a|0;t[a+4202|0]=0}function GZ(a,b){a=a|0;b=b|0;xb(b)}function Dj(a,b){return(b<<13)+a|0}function Bg(a,b){sd(a,Jb(b),Ab(b))}function zy(a){return a+1298368|0}function yla(a){a=a|0;dW(a,65535)}function xy(a){return Xg(a+120|0)}function xM(a){return w[a+4232|0]}function wq(a){gc(a+4|0);return a}function wd(a,b){return(b<<1)+a|0}function ur(a,b){return oe(a,b)^1}function uo(a){return a+1074328|0}function su(a,b,c){return DA(b,c)}function rw(a){return t[a+24|0]&1}function qV(a,b){return(b<<4)+a|0}function pr(a){v[a>>2]=v[a>>2]+12}function pT(a,b){nB(a,b);return a}function nc(a,b){return Jb(a)+b|0}function kp(a){v[a>>2]=v[a>>2]+28}function kS(a){v[a>>2]=v[a>>2]+32}function jp(a){v[a>>2]=2;return a}function jc(a,b){Hw(a,b);return a}function aN(a,b,c){return Jj(b,c)}function Yd(a){return v[fc(a)>>2]}function XK(a){v[a>>2]=v[a>>2]+24}function Ww(a,b){return v[a+b>>2]}function WD(a){return w[a+1|0]==1}function Vp(a){sg(a);Ec(a);sg(a)}
function Vfa(a){a=a|0;yf(a,Qi(a))}function Vb(a){return Fg(v[a>>2])}function V$(a){a=a|0;return 10316}function Ui(a){v[a>>2]=0;return a}function Ro(a){v[a>>2]=v[a>>2]+16}function Ri(a,b){return(b<<2)+a|0}function Re(a){return Qf(a)&65535}function RO(a){v[a>>2]=v[a>>2]+52}function Qh(a){return a-48>>>0<10}function OT(a){return v[wb(a)>>2]}function Km(a){u[a>>1]=0;return a}function Gh(a){v[a>>2]=1;return a}function EC(a,b,c){return zn(b,c)}function Dy(a,b){return ZN(a,b)^1}function Bh(a){v[a>>2]=v[a>>2]+20}function B4(a){a=a|0;return 10430}function zp(a){Ng(a);sc(a);Ng(a)}function z4(a){a=a|0;return 7510}function yH(a){a=a|0;rm(a);Xb(a)}function yA(a){t[a|0]=0;return a}function xk(a){ye(a);Nb(a);ye(a)}function wH(a){a=a|0;Xp(a);Xb(a)}function vu(a){v[a>>2]=v[a>>2]+8}function vr(a){pc(a);BF(a);iK(a)}function ul(a){a=a|0;jf(a);Xb(a)}function uL(a){a=a|0;Fy(a);Xb(a)}function t4(a){a=a|0;return 3920}function rt(a){bg(a);pc(a);bg(a)}function oR(a){rg(a);qf(a);rg(a)}function o9(a){a=a|0;Ey(a);Xb(a)}function mU(a){return w[a|0]<129}function lE(a){Yl(a);$e(a);Yl(a)}function kB(a,b,c){ZS(me(a,b),c)}function jD(a){Tj(a);sY(a);rY(a)}function i7(a){a=a|0;OJ(a);Xb(a)}function g5(a){a=a|0;return 7630}function fY(a){gn(a);Tj(a);gn(a)}function fT(a){Yi(a);Ch(a);Yi(a)}function eW(a,b){hc(a,b+4|0,256)}function a7(a){a=a|0;LJ(a);Xb(a)}function _u(a){bi(a);ze(a);bi(a)}function _L(a){a=a|0;Oy(a);Xb(a)}function Y$(a,b){a=a|0;b=b|0;L()}function Xj(a){v[a>>2]=v[a>>2]+6}function W$(a){a=a|0;return 6941}function Vl(a){sc(a);qw(a);xE(a)}function VM(a){Sf(a);NM(a);MM(a)}function RP(a,b,c,d){TP(a,b,c,d)}function R$(a){a=a|0;return 2812}function Oe(a){v[a>>2]=v[a>>2]+4}function Ne(a){v[a>>2]=v[a>>2]+1}function Ko(a,b){u[a>>1]=x[b>>1]}function Jx(a){vi(a);tf(a);vi(a)}function Jv(a){v[a>>2]=v[a>>2]+2}function Jp(a){a=a|0;Zw(a);Xb(a)}function JM(a){vl(a);Sf(a);vl(a)}function HC(a){Sj(a);Ig(a);Sj(a)}function GP(a,b,c,d){oA(a,b,c,d)}function Fw(a){a=a|0;zs(a);Xb(a)}function Fe(a,b){v[a>>2]=v[b>>2]}function FN(a){Ig(a);TW(a);GW(a)}function Eg(a){Nb(a);_q(a);gw(a)}function Dd(a){return v[a>>2]!=0}function DF(a){Tk(a);Vk(a);Tk(a)}function BH(a){v[a+72>>2]=463032}function Ar(a){return Qb(a,0,48)}function AO(a){jk(a);Qf(a);jk(a)}function AH(a){v[a+72>>2]=463116}function zq(a){qR(a+12|0);vR(a)}function xb(a){Ld(a+12|0);Ld(a)}function tl(a,b,c){sd(a,b,1<<c)}function th(a){return a<<24>>24}function rq(a){u[a+480214>>1]=0}function o0(a){a=a|0;vb(464300)}function lp(a,b){return cs(a,b)}function l0(a){a=a|0;Ic(464316)}function kk(a){return!v[a+4>>2]}function kf(a,b){return Lg(a,b)}function kO(a,b){return iO(a,b)}function j0(a){a=a|0;vb(464332)}function ii(a,b,c){of(a,c,13,b)}function h0(a){a=a|0;Ic(464348)}function gr(a,b){return TV(a,b)}function fg(a){return th(Kg(a))}function f0(a){a=a|0;vb(464364)}function d0(a){a=a|0;Ic(464380)}function b0(a){a=a|0;vb(464396)}function _b(a,b){return af(a,b)}function Zl(a,b){return JE(a,b)}function Ze(a){a=a|0;return a|0}function Tr(a,b){return IE(a,b)}function Tl(a){return Fv(sc(a))}function Sm(a){vb(a+12|0);We(a)}function SU(a,b){return Mj(b,a)}function Rh(a,b){return Ri(a,b)}function P6(a){a=a|0;GJ(a-88|0)}function Oi(a){return ze(a)&255}function Od(a,b){return An(a,b)}function Nj(a,b){return CE(a,b)}function Lm(a){vb(a+12|0);vb(a)}function Ky(a,b){return _g(a,b)}function KW(a,b){sd(a,b,b+16|0)}function Jba(a){a=a|0;return 13}function Io(a){return Tm(fe(a))}function Ica(a){a=a|0;Xb(Oy(a))}function Fs(a){a=a|0;return 127}function Ef(a){vb(a+20|0);vb(a)}function DC(a,b){return zn(a,b)}function Aj(a,b){return a>>>b&1}function $M(a,b){return Jj(a,b)}function $$(a){a=a|0;Ic(464412)}function yy(a,b){return b-a>>3}function wca(a){a=a|0;return 6}function vG(a){a=a|0;Xb(ax(a))}function u4(a){a=a|0;Xb(wx(a))}function tM(a){a=a|0;Xb(uM(a))}function tH(){return(db()|0)>0}function o1(a){a=a|0;Xb(DG(a))}function n5(a){a=a|0;Xb(Yt(a))}function m9(a){a=a|0;Xb(Fy(a))}function ku(a,b){return a<<8|b}function k7(a){a=a|0;Xb(PJ(a))}function hM(a){a=a|0;Xb(iM(a))}function fI(a){a=a|0;Xb(lh(a))}function f1(a){a=a|0;Xb(BG(a))}function ec(a,b){v[a+100>>2]=b}function c7(a){a=a|0;Xb(MJ(a))}function b5(a){a=a|0;Xb(FH(a))}function b$(a){a=a|0;Xb(PF(a))}function _4(a){a=a|0;Xb(Bx(a))}function WE(a){return a>>>0>16}function V5(a){a=a|0;Xb(rm(a))}function Uu(a){return a>>>27^a}function Uka(a){a=a|0;return 9}function TV(a,b){return b-a>>2}function T$(a){a=a|0;Xb(Zw(a))}function S_(a){a=a|0;Xb(EF(a))}function SS(a){return a+4896|0}function SL(a){a=a|0;Xb(TL(a))}function S0(a){a=a|0;Xb(yG(a))}function S$(a){a=a|0;Xb(zs(a))}function R5(a){a=a|0;Xb(Xp(a))}function R0(a){a=a|0;Xb(xG(a))}function QM(a){a=a|0;Xb(RM(a))}function O7(a){a=a|0;Xb(Dt(a))}function M_(a){a=a|0;Xb(rF(a))}function K_(a){a=a|0;Xb(qF(a))}function JH(a){a=a|0;Xb(xq(a))}function Ix(a){a=a|0;Xb(Zs(a))}function IH(a){a=a|0;Xb(uf(a))}function GJ(a){a=a|0;Xb(ky(a))}function F1(a){a=a|0;Xb(FG(a))}function Ex(a){a=a|0;Xb(Xs(a))}function DT(a){yB(Qb(a,0,872))}function CM(a){a=a|0;Xb(DM(a))}function Bd(a,b){t[a|0]=w[b|0]}function $L(a){a=a|0;Xb(aM(a))}function zD(a,b){bc(a,b,1954)}function tr(a){Ui(a);return a}function se(a){a=a|0;return 1}function rp(a){return a>>>0<5}function rR(a){Oj(a);return a}function qk(a){return Dd(a)^1}function qe(a){a=a|0;return 2}function qM(a){a=a|0;return 7}function nS(a,b){return b-a|0}function mc(a){Gg(a);return a}function ll(a){return a+120|0}function lc(a,b){return a+b|0}function j9(){return 19923014}function ic(a){a=a|0;return 0}function gi(a){return bd(a)^1}function fA(a){nF(a);return a}function eh(a){cd(a);return a}function dM(a){a=a|0;return 5}function dG(a){a=a|0;return 3}function cd(a){rh(a);return a}function cI(a){a=a|0;return-1}function cC(){return Nc(20,4)}function bf(a,b){u[a+28>>1]=b}function aR(){return Nc(36,4)}function XW(){return Nc(32,4)}function XU(a,b){bc(a,b,1108)}function Sw(){return lb()<<16}function Sv(a){return!v[a>>2]}function SB(a,b){bc(a,b,1024)}function MW(a){Ar(Qb(a,0,48))}function LS(a,b){Qb(a,0,b<<2)}function Iv(a){a=a|0;return 4}function IU(a,b){of(a,b,33,1)}function Eu(a){return a+256|0}function Et(a,b){v[a+32>>2]=b}function Eo(a,b){v[a+36>>2]=b}function E1(){Up(464180,IG())}function Ao(a){mc(a);return a}function zY(a,b){bc(a,b,610)}function zS(a,b,c){Uq(a,c,b)}function zO(a){yO(a,v[a>>2])}function ym(a){v[a>>2]=89036}function xU(a,b){bc(a,b,146)}function x5(a){a=a|0;RY(a,1)}function wM(a,b,c){Fn(a,b,c)}function wC(a,b){Sj(a);Sj(a)}function vt(a){v[a>>2]=56260}function vX(a,b){bc(a,b,218)}function vS(a,b,c){Tq(a,c,b)}function tX(a,b){bc(a,b,157)}function tU(a){return a+48|0}function sY(a){jY(a,v[a>>2])}function sU(a,b){bc(a,b,608)}function qw(a){$E(a,v[a>>2])}function pt(a,b){bg(a);bg(a)}function pq(a,b){z[a+8>>2]=b}function pN(a,b){jk(a);jk(a)}function oX(a,b){bc(a,b,576)}function nq(a,b){z[a+4>>2]=b}function mq(a,b){t[a+33|0]=b}function lV(a,b){bc(a,b,130)}function kR(a){jR(a,v[a>>2])}function jV(a,b){bc(a,b,600)}function j7(a){a=a|0;QJ(a,1)}function ee(a,b){v[a+4>>2]=b}function eL(a){v[a>>2]=55188}function eK(a,b,c){pK(a,b,c)}function dp(a,b){wb(b);wb(a)}function dc(a){return a+12|0}function dV(a,b){bc(a,b,126)}function dS(a){cS(a,v[a>>2])}function bI(a,b){vi(a);vi(a)}function b7(a){a=a|0;Ru(a,1)}function aX(a){GI(a,v[a>>2])}function _q(a){zU(a,v[a>>2])}function _o(a,b){v[a+8>>2]=b}function _m(a,b){ye(a);ye(a)}function _c(a,b){a=a|0;b=b|0}function Yr(a,b){Ng(a);Ng(a)}function YS(a,b){bc(a,b,263)}function YA(a,b){bi(a);bi(a)}function Xe(a,b){t[a+11|0]=b}function Vs(a,b){Up(a,b+4|0)}function TW(a){SW(a,v[a>>2])}function Sp(a){return a+20|0}function RW(a,b){bc(a,b,674)}function RC(a,b){of(a,b,8,2)}function QO(a){v[a>>2]=78412}function Pw(a,b){sg(a);sg(a)}function Pd(a){ee(a,v[a>>2])}function NM(a){KM(a,v[a>>2])}function NC(a,b){iX(a,ce(b))}function Mr(a,b){bc(a,b,192)}function Lw(a,b){XF(a,ce(b))}function Lv(a,b){bc(a,b,512)}function IJ(a){v[a>>2]=60028}function Dp(a){v[a>>2]=27748}function Cz(a,b){t[a+34|0]=b}function Bz(a,b){t[a+32|0]=b}function BF(a){oK(a,v[a>>2])}function Az(a,b){t[a+35|0]=b}function AW(a,b){bc(a,b,128)}function AE(a,b){bc(a,b,497)}function $w(a){return a+32|0}function $T(a,b){bc(a,b,204)}function $D(a,b){Yl(a);Yl(a)}function zla(){return 65534}function zf(a,b){t[a+3|0]=b}function yD(a){Qb(a,0,1954)}function wb(a){return a+8|0}function vv(a,b){bc(a,b,22)}function vq(a){Qb(a,0,8192)}function vp(a,b){t[a+1|0]=b}function sQ(a){return 0-a|0}function sC(a,b){bc(a,b,33)}function pka(a){a=a|0;DT(a)}function od(a){return a+1|0}function nV(a,b){bc(a,b,30)}function kD(a,b){bc(a,b,64)}function k9(){return 393216}function jE(a,b){bc(a,b,38)}function hE(a,b){bc(a,b,41)}function hC(a,b){bc(a,b,40)}function fc(a){return a+4|0}function f6(){return 460692}function ed(a){return!Ab(a)}function cga(a){a=a|0;dA(a)}function bj(a){return a+3|0}function bV(a,b){bc(a,b,32)}function as(a,b){bc(a,b,36)}function aW(a,b){bc(a,b,52)}function _v(a,b){bc(a,b,16)}function ZV(a,b){bc(a,b,80)}function Yv(a,b){bc(a,b,65)}function Yba(){return 65535}function XX(a,b){bc(a,b,12)}function Vy(a){Qb(a,0,2048)}function VO(a){Qb(a,0,1024)}function Uja(a){a=a|0;Po(a)}function Te(a){return a+2|0}function Po(a){Qb(a,0,4096)}function PE(a,b){hw(a,b,22)}function NU(a,b){bc(a,b,96)}function NF(a,b){bc(a,b,24)}function MD(a,b){bc(a,b,11)}function Kg(a){return a&255}function KR(a,b){bc(a,b,27)}function JU(a){if(a){Xb(a)}}function JD(a,b){bc(a,b,17)}function IB(a){v[a+12>>2]=0}function DX(a,b){bc(a,b,98)}function Av(a,b){bc(a,b,66)}function AX(a,b){bc(a,b,48)}function zE(a){Qb(a,0,497)}function yd(a){Vp(a);mF(a)}function yY(a){Qb(a,0,610)}function xE(a){Ng(a);sc(a)}function wU(a){Qb(a,0,146)}function vc(a){v[a+8>>2]=0}function uk(a,b){tp(a,b,0)}function sX(a){Qb(a,0,157)}function sN(a){jk(a);Qf(a)}function rY(a){gn(a);Tj(a)}function rU(a){Qb(a,0,608)}function qR(a){Gq(a,Yd(a))}function qB(a){Qb(a,0,256)}function oq(a,b){z[a>>2]=b}function o4(){return 79512}function nX(a){Qb(a,0,576)}function n4(){return 80288}function m4(){return 81840}function kr(a){gC(a,Yd(a))}function jr(a){fC(a,Yd(a))}function iV(a){Qb(a,0,600)}function iK(a){bg(a);pc(a)}function iB(a){Qb(a,0,512)}function hd(a){lE(a);mE(a)}function gw(a){ye(a);Nb(a)}function gR(a){sg(a);Ec(a)}function fE(a,b){li(a,2,b)}function eP(a){fu(a,Yd(a))}function eC(a,b){bc(a,b,4)}function dn(a){HC(a);pv(a)}function cf(a,b){v[a>>2]=b}function cV(a){Qb(a,0,126)}function bY(a,b){bc(a,b,3)}function bX(a){t[a+31|0]=0}function bS(a){bi(a);ze(a)}function _W(a){BC(a,Yd(a))}function _T(a){Qb(a,0,204)}function Xc(a){a=a|0;Xb(a)}function We(a){zp(a);$r(a)}function Wb(a){Gn(v[a>>2])}function UW(a){CC(a,Yd(a))}function Tn(){ao(8221);L()}function Sc(){pd(4767);L()}function Qx(){ao(4767);L()}function Qv(a,b){bc(a,b,5)}function Qka(a){a=a|0;gb=a}function QW(a){Qb(a,0,192)}function QB(a){Qb(a,0,130)}function OV(a,b){bc(a,b,2)}function MM(a){vl(a);Sf(a)}function Lc(a){xk(a);mv(a)}function Jq(a){Jx(a);yR(a)}function Ila(){return gb|0}function IX(a,b){bc(a,b,6)}function GW(a){Sj(a);Ig(a)}function GT(a){oB(a,Yd(a))}function FT(a){pB(a,Yd(a))}function Dl(a){BA(a,Yd(a))}function Cs(a){a=a|0;Is(a)}function Bp(a,b){bc(a,b,8)}function $f(){pd(8221);L()}function $N(a){xz(a,Yd(a))}function tw(a){Qb(a,0,36)}function tC(a){Qb(a,0,33)}function kC(a){Qb(a,0,80)}function iE(a){Qb(a,0,38)}function gE(a){Qb(a,0,41)}function cD(a){Qb(a,0,66)}function aD(a){Qb(a,0,64)}function Xi(a,b){t[a|0]=b}function OU(a){Qb(a,0,96)}function O8(){return 2048}function CX(a){Qb(a,0,98)}function BX(a){Qb(a,0,48)}function $V(a){Qb(a,0,52)}function zc(a){gc(a+8|0)}function yk(a){vb(a+4|0)}function xR(a){Om(a,0,0)}function uO(a,b){cw(a,b)}function tO(a,b){sO(a,b)}function sq(a,b){Fe(a,b)}function pD(a,b){IY(a,b)}function nB(a,b){yc(a,b)}function jh(a){a=a|0;L()}function hR(a){Hq(a+8|0)}function go(a,b){EH(a,b)}function ep(a,b){Bd(a,b)}function Zv(a){u[a>>1]=0}function Zd(a){xb(a+8|0)}function Yy(a,b){ni(a,b)}function Wh(a,b){Vh(a,b)}function WV(a,b){SV(a,b)}function VW(a,b){cf(a,b)}function VA(a,b){_f(a,b)}function Sk(a,b){ee(a,b)}function Qo(a){v[a>>2]=0}function En(a,b){Hw(a,b)}function Hpa(){ua();L()}function Hf(a){t[a|0]=0}function pO(a){_N(a,0)}function ms(a){XF(a,0)}function hD(a){NX(a,0)}function fn(a){iX(a,0)}function du(a){UO(a,0)}function dq(a){nL(a,0)}function cu(a){TO(a,0)}function Hg(a){$W(a,0)}function Hc(a){Ee(a,0)}function Di(a){oL(a,0)}function Ci(a){mL(a,0)}function lf(a){a=a|0}function eR(a){Xu(a)}function WH(a){GL(a)}function UT(a){cd(a)}function Hb(a){vb(a)}function X$(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var kb=c([null,Pm,Tb,Kt,eg,xL,bo,m6,W5,nT,f5,d4,_2,zT,Pm,N5,sZ,on,fh,Y4,$,sD,jn,p_,Zw,Oc,He,WY,nn,Ze,Xc,zF,es,Hfa,Vpa,Spa,Lpa,Hpa,Epa,tpa,UC,Roa,Ooa,$pa,ypa,HB,c6,Rna,Pna,zW,Of,Xo,fr,Fb,_c,zW,b6,oka,rT,MS,Au,Nq,_5,Y5,Pm,Au,Nq,mi,Dha,eg,Tb,xL,GR,qu,wf,lI,Fq,Yf,jga,IG,iga,Fg,mP,u5,gga,GR,Lfa,lA,lA,kha,dha,Gfa,Cfa,Uga,Nga,$fa,_fa,$4,hga,Yf,sfa,J5,qz,H5,CN,F5,Zea,Qea,t5,Pm,D5,B5,vea,Pt,oea,hea,YM,wp,Pm,Of,Ny,kl,PI,wy,eo,Zh,g8,sy,_c,Zh,Gf,_c,r5,l5,e5,Z4,P4,v4,Ls,Yf,c4,W3,Kh,pi,n$,z3,$G,ZG,f3,Ls,U2,Jn,gx,Cs,bk,Vc,Df,H0,Jn,rs,I1,C1,x0,O2,m0,wG,Z$,wG,x2,AG,U$,P$,K$,Kh,nG,Of,In,Hn,ij,hG,gG,fG,Pt,m$,ia,Kp,Jp,wt,Yc,Pb,j$,Kw,i$,em,h$,_F,g$,Gp,Wk,_F,Vd,ls,Zh,e$,zs,Zh,Iw,U_,T_,df,f$,d$,c$,V_,oi,df,GF,df,zw,eo,eo,P_,O_,N_,eo,Fw,wt,PF,b$,Cp,FL,a$,Ze,Xc,$_,se,se,wt,jy,__,Z_,Y_,jh,X$,X_,W_,EF,S_,Cp,R_,Xc,ic,se,se,ic,ic,Q_,rF,M_,Cp,L_,qF,K_,J_,I_,H_,G_,F_,E_,D_,C_,Gy,Afa,vfa,rfa,bs,JF,x_,CF,hG,_c,oF,u_,t_,Fw,Of,Of,cF,ud,r_,q_,Of,_c,_c,_c,wy,Ny,sy,kl,i_,fr,o_,Fb,j_,Mk,h_,_c,cF,hi,g_,f_,e_,a_,yE,qn,_c,XZ,rE,Rb,VZ,UZ,TZ,SZ,Ie,Bc,RZ,QZ,PZ,OZ,Ag,xg,sh,NZ,aw,pE,MZ,nE,Of,LZ,Xo,Of,Of,HZ,KZ,_c,JZ,yE,IZ,GZ,DZ,CZ,BZ,UD,AZ,Ue,zZ,yZ,xZ,wZ,Nz,MT,PS,vZ,le,uZ,$v,RD,Id,bk,uh,qZ,pZ,Vv,Je,Nr,Bf,CO,oZ,nZ,mZ,ac,QD,lZ,PD,nd,Xv,Um,Lr,Cy,vn,wn,Td,Ve,iZ,Of,wy,Ny,sy,_c,hZ,gZ,Xr,Wc,bw,bZ,Jr,aZ,yg,Pc,Ob,Pf,Df,$Y,Kv,_Y,Vc,Ir,Qha,ZY,YY,Pi,XY,wD,Hr,td,VY,Gr,UY,Jea,Rf,Be,Cm,mo,jz,TY,QY,yM,uD,Hv,Fr,Gk,Df,gqa,fqa,VE,OY,kn,eqa,hh,dqa,cqa,EY,ij,bqa,gG,fG,Pt,Kp,Zpa,Ypa,Xpa,uY,Tpa,Rpa,iD,mf,Qpa,Ppa,Opa,Npa,Go,gB,Mpa,Kpa,Jpa,Ipa,Gf,de,ht,gD,Cv,fD,Dpa,Cpa,Fpa,lY,vn,wn,mY,hp,kl,_c,Nf,ZX,zpa,Fk,upa,spa,rpa,Vd,yf,AY,vpa,TX,qpa,SX,ppa,hB,opa,PX,npa,mpa,lpa,Iw,kpa,vn,bq,hpa,Jr,cp,gpa,fpa,wD,epa,Jk,dpa,cpa,bpa,apa,pn,cr,$oa,_oa,OY,kn,Zoa,VC,ZC,XC,HX,az,Tha,Uj,tv,mz,kq,Tt,$5,PC,Poa,pX,Hh,Loa,Koa,Mfa,Hoa,aga,sv,xp,Goa,Foa,Eoa,zr,NE,Doa,Du,Oo,Coa,Boa,Noa,kX,k_,Aoa,Jo,OE,rv,zoa,Df,yoa,Mc,xoa,woa,jX,voa,d_,uoa,toa,soa,roa,hX,qoa,Pu,poa,Df,ooa,noa,kw,tY,Moa,Df,moa,loa,bq,sp,koa,joa,ioa,BO,MC,hoa,MC,MC,LC,eX,JC,Am,goa,iba,foa,eoa,doa,coa,boa,aoa,$na,aea,dX,Of,NW,id,ap,Vna,xC,Mna,Kr,_na,Of,vC,Lna,Zna,Yna,Xna,_f,bea,Pfa,Tda,Wna,Kt,Una,Tna,Sna,df,Yf,Ze,_c,Qna,_c,_c,Ona,fr,Nna,or,Hna,Gna,Fna,Ena,Dna,Cna,Bna,Ana,zna,wW,vW,yna,xna,wna,vna,una,tna,sna,rna,sW,cn,fW,qC,ona,pC,nna,mr,yS,zr,mna,lna,kna,jna,TC,CS,Rl,Pl,oC,ina,WZ,hna,gna,dW,cW,nC,fna,Ge,ena,Kt,zr,dna,zr,cna,Rr,bna,Df,uY,gv,QV,_ma,Zma,Vd,Yma,Xma,Wma,bC,Vma,dv,Uma,Tma,Sma,Rma,Qma,Pma,sE,Oma,Nma,Xha,Mma,Lma,Kma,Jma,Tja,iha,gha,Ima,p6,FC,q6,Hma,Gma,by,cy,Kfa,Fma,Df,gX,fX,FS,Ema,Dma,Vv,Iw,IV,ir,Cma,Bma,Kh,pi,Ama,Ev,av,Kj,Jh,TB,rma,qma,yma,nv,_c,nma,mma,ND,lma,DO,kma,jma,tN,ap,ima,fV,hma,gma,am,$l,Zu,tA,fma,ema,Ho,dma,Wl,cma,bma,OB,pp,zw,Xla,MB,Wla,Vla,mw,Wr,Ula,Hl,Tla,kn,Jh,Qla,Pla,df,Ola,Nla,TU,df,Vr,Mla,pC,Jla,Ek,rk,Zu,Mc,Hla,Mea,IV,ir,gv,Ela,Dla,iD,WU,MB,Fh,Xv,Cla,Bla,Ala,Yba,zla,yla,xla,Vu,wla,Vu,vla,ns,ula,kn,l_,qla,ola,TB,rla,pla,BU,AU,lla,qC,kla,hla,gla,TS,fV,kX,jha,XQ,dla,Vv,_ka,Zka,QD,eU,Yka,Xka,Wka,Vka,bn,dU,Tka,Ska,Rka,XT,Nka,Mka,Lka,Kka,Jka,Ika,Hka,Xm,Sja,QT,Gka,Fka,Eka,Dka,Cka,Bka,Aka,Uha,_t,Yga,fha,cha,zka,Nea,Vd,yka,pC,xka,wka,vka,nv,DB,uka,JT,xh,tka,ska,uT,rka,qka,Xq,pka,BT,gv,wT,lka,kka,VU,jka,hka,Vha,dka,cka,gfa,bka,aka,$ja,MN,_ja,ffa,NN,Zja,Yja,Xja,V4,NH,Wha,$u,Df,Tfa,Sfa,aT,$S,Of,_c,jB,Rja,Qja,Pja,Oja,Nja,Mja,Lja,Kja,Jja,Ija,Hja,Gja,Fja,Eja,Dja,Cja,Bja,Aja,zja,yja,xja,wja,vja,uja,tja,sja,rja,qja,pja,oja,nja,mja,lja,kja,jja,ija,gja,fja,eja,dja,cja,bja,aja,$ia,_ia,Zia,Yia,Xia,Wia,Via,Uia,Tia,Sia,Ria,Qia,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Fia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,jia,iia,hia,gia,fia,eia,dia,cia,bia,aia,$ha,Zha,Qq,_ha,fS,cj,eE,jS,Rha,Fha,Pha,Oha,Nha,Mha,Lha,hS,Kha,Jha,Iha,Hha,zu,Eha,Gha,QR,Bha,Aha,Ov,IR,Bfa,yha,xha,lq,vz,tz,sz,MA,wha,AR,vha,tha,Of,sha,_c,Co,jq,tR,pha,oha,Ji,nha,Rf,lha,mha,Ze,_c,ot,r6,Wj,hha,Qfa,Vi,Yha,_h,WQ,ika,$h,mfa,eha,xr,bha,Jr,aha,Jh,Kw,$ga,_ga,Zga,Mga,kn,Xga,Jr,Wga,Vga,Kw,Iga,kn,Qga,Pga,MQ,df,nG,In,Hn,Pt,Kh,ru,OQ,Of,Ze,KQ,Of,$o,Hga,s_,Qe,kZ,HQ,Gga,Gpa,GQ,FQ,EQ,DQ,CQ,BQ,AQ,zQ,yQ,xQ,wQ,vQ,uQ,tQ,rQ,qQ,pQ,oQ,nQ,mQ,lQ,kQ,jQ,iQ,hQ,gQ,fQ,eQ,dQ,cQ,bQ,aQ,$P,_P,ZP,YP,XP,WP,VP,UP,Fga,Ega,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,sga,rga,qga,pga,rha,OP,Jz,uu,mR,oga,nga,Iz,zg,yo,Cq,mga,MP,Lo,qA,pA,Jm,Lz,EO,Kz,xo,lu,HP,lga,nA,Hm,cB,FP,dB,SA,xu,Ni,kga,ZO,Sha,Vja,$X,ega,eO,dga,Uja,cga,rf,bga,Zfa,l$,B_,w_,z_,Xfa,v_,A_,k$,y_,Vm,Wfa,AS,tq,Vfa,aA,qfa,cda,Ufa,PO,Cha,Rfa,nea,sea,Ofa,qea,mea,df,df,Ds,Nfa,DS,Jfa,Ifa,xO,fka,eka,Joa,Ioa,jla,ila,cla,bla,qna,pna,$la,_la,Jna,Ina,dZ,cZ,Yoa,Xoa,FZ,EZ,tZ,rZ,Sla,Rla,nla,mla,nka,mka,Wpa,Upa,Bpa,Apa,$Z,_Z,ZZ,YZ,Gla,Fla,tla,sla,pma,oma,Kna,yW,Uoa,Toa,Soa,Qoa,aqa,_pa,jpa,ipa,Lla,Kla,efa,dfa,Rea,Pea,tma,sma,Pka,Oka,Zla,Yla,Woa,Voa,fla,ela,ala,$ka,xpa,wpa,zma,vma,uma,c_,b_,fZ,eZ,ana,$ma,xma,wma,jh,Efa,Dfa,_O,_c,Yf,jB,zfa,ts,xfa,yfa,PQ,ufa,wfa,tfa,Vt,pfa,Rga,Mm,Tga,Sga,ofa,nfa,Pr,Kga,Lga,UQ,lfa,gka,m_,kfa,hF,Ow,pz,RD,jfa,KB,ifa,Oga,hfa,cfa,bfa,iD,afa,Dr,MB,$ea,_ea,Yea,TB,Xea,Jh,Wea,Vea,Uea,Tea,Sea,kn,oJ,t6,s6,Oea,Pq,Lea,Iea,ov,Gea,Fea,Eea,KC,Dea,Xf,Vh,qm,Cea,BN,Bea,wea,Aea,Kea,zea,tea,xea,Hea,uea,ez,fz,mN,Of,cea,fr,cN,pea,_S,gq,kea,jea,iea,gea,fea,kN,rea,iq,_f,jN,dea,rl,Vh,bN,$da,_da,Zda,Yda,Xda,Wda,Wf,Vda,Uda,eea,lea,Rda,Qda,Uh,Pda,Oda,LM,Bda,an,fr,iN,Ada,cN,zda,_c,bN,_c,RM,QM,QM,PM,ic,lf,ic,ic,ic,_c,Iv,Jda,Kda,Mda,Lda,Nda,Ii,es,es,Xy,OM,Xy,Xy,ama,lf,yW,Fda,Eda,Dda,Cda,Ida,Gi,SM,hda,ic,ic,se,Wy,qe,qe,se,Hda,Gda,_c,lf,_c,lf,xda,jda,DM,CM,CM,ida,ic,lf,ic,ic,ic,_c,Uka,HM,vda,lda,kda,wda,Ii,tda,sda,rda,qda,pda,oda,nda,mda,uda,Gi,GM,ic,ic,se,qe,qe,se,FM,EM,eda,zM,Yg,jf,jh,fda,Ry,gda,ic,dda,OM,bda,Yf,NS,ada,$ca,_ca,Zca,zu,Oca,Dca,vca,oca,hca,$ba,Rba,Iba,Bba,fca,Sda,yda,Yca,Xca,mn,vO,uM,tM,tM,PM,ic,lf,ic,ic,ic,_c,dG,Sca,Tca,Vca,Uca,Wca,Ii,Rca,Gi,vM,ic,ic,se,qe,qe,se,Qca,Pca,sM,Py,Oy,Ica,rM,Hca,ic,lf,ic,ic,ic,_c,qM,Lca,Mca,Nca,Ii,Kca,Gi,Jca,ic,ic,se,qe,qe,_c,lf,pM,Gca,Fca,oM,Eca,nM,mM,Cca,iM,hM,hM,xca,ic,lf,ic,ic,ic,_c,wca,zca,Aca,Bca,Ii,yca,Gi,kM,ic,ic,se,qe,qe,uca,ul,ul,pca,ic,lf,ic,ic,ic,_c,dM,rca,sca,tca,Ii,qca,Gi,eM,ic,ic,se,qe,qe,nca,aM,$L,$L,ica,ic,lf,ic,ic,ic,_c,dM,kca,lca,mca,Ii,jca,Gi,bM,ic,ic,se,qe,qe,gca,_L,_L,dca,qM,eca,pM,cca,bca,oM,aca,nM,mM,_ba,ul,ul,Uba,ic,lf,ic,ic,ic,_c,qe,Wba,Xba,Zba,Ii,Vba,Gi,Tba,ic,ic,se,qe,qe,Qba,Sba,TL,SL,SL,Lba,ic,lf,ic,ic,Kba,_c,Jba,Nba,Oba,Pba,Ii,Mba,Gi,Ly,ic,ic,se,qe,qe,_c,lf,Hba,ul,ul,Cba,ic,lf,ic,ic,ic,_c,dG,Eba,Fba,Gba,Ii,Dba,Gi,QL,ic,ic,se,qe,qe,Aba,ul,ul,vba,ic,lf,ic,ic,ic,_c,Iv,xba,yba,zba,Ii,wba,Gi,NL,ic,ic,se,qe,qe,k9,tba,q9,b9,j9,i9,R8,gx,$K,Gt,CL,N8,jba,BL,O8,_K,J8,I8,Ze,fba,eba,CL,H8,F8,yL,bba,Fy,WK,jy,VK,UK,t8,p8,q8,r8,Jy,E8,Naa,sL,D8,C8,B8,A8,z8,y8,x8,w8,v8,u8,o8,Jy,i8,SK,RK,QK,PK,NK,MK,LK,KK,JK,IK,HK,GK,h8,$n,FK,EK,ol,cq,f8,qH,e8,c8,b8,a8,$7,AK,zK,zt,_7,Z7,X7,W7,V7,U7,T7,S7,R7,Q7,V8,jL,hL,gL,fL,S6,R6,yL,Jy,I9,H9,G9,F9,E9,D9,C9,B9,A9,z9,y9,x9,w9,v9,u9,t9,s9,r9,ua,p9,Ey,o9,n9,uL,l9,uL,m9,Iq,h9,Jga,ql,ws,hT,Il,f9,e9,L7,c9,tk,rT,nu,Z8,fga,U8,hI,T8,M5,zha,P7,Kt,uha,qha,Yfa,Y8,g9,a9,oz,mg,W8,Ffa,Q8,qL,pL,_K,M8,P8,ZK,L8,K8,df,X8,S8,_8,bc,G8,s8,KO,n8,m8,l8,U6,Xz,Yz,$8,GO,k8,j8,ho,DK,yea,d8,Qi,Y7,Wc,HO,lz,Wja,kz,K7,J7,I7,nK,H7,fK,xt,fK,xt,aa,n7,m7,d7,l7,jh,Dt,O7,d9,Ze,jh,Ze,Xc,N7,M7,jh,kK,jK,kK,jK,_c,yt,_c,yt,hK,gK,hK,gK,Xc,G7,Ze,Xc,F7,E7,Xc,dK,cK,jh,D7,bK,C7,bK,B7,$J,A7,$J,Xc,z7,y7,Xc,_J,ZJ,st,st,st,st,x7,py,py,py,Xc,w7,v7,Xc,YJ,XJ,u7,WJ,t7,WJ,s7,VJ,r7,VJ,Xc,q7,p7,Xc,UJ,TJ,qt,qt,qt,qt,o7,ny,ny,ny,PJ,k7,Cp,j7,OJ,i7,se,se,h7,g7,wt,f7,e7,jh,MJ,c7,Cp,b7,LJ,a7,se,ic,se,$6,_6,Z6,Y6,X6,W6,V6,jh,_c,yt,_c,yt,ky,GJ,O6,N6,EJ,DJ,CJ,BJ,AJ,zJ,yJ,xJ,wJ,vJ,uJ,tJ,sJ,rJ,qJ,pJ,Q6,P6,M6,L6,K6,J6,I6,G6,F6,E6,D6,C6,B6,A6,z6,y6,x6,w6,Ze,jh,Ze,jh,v6,u6,o6,n6,h6,l6,k6,j6,i6,e6,d6,Os,a6,zI,yI,xI,Si,YM,wp,qo,Fc,L5,K5,I5,G5,E5,C5,A5,Gx,z5,T6,H6,FJ,y5,qo,x5,w5,v5,MH,Ze,rm,V5,_c,Pm,eI,dI,ic,ic,U5,cI,T5,_s,S5,_s,Xp,R5,_c,Pm,eI,dI,ic,ic,Q5,cI,P5,_s,O5,_s,Zs,Ix,$H,_H,Zs,Ix,$H,_H,Xs,Ex,PH,OH,Xs,Ex,PH,OH,Yt,n5,o5,m5,s5,q5,p5,lh,fI,lh,fI,xq,JH,k5,j5,uf,IH,i5,h5,lf,a5,c5,FH,Ze,Xc,g5,E4,D4,C4,d5,b5,Bx,_4,X5,ic,X4,W4,U4,Zt,Zt,Cx,yx,Ys,VH,yH,T4,S4,R4,Q4,wH,O4,N4,M4,L4,yH,K4,uH,J4,I4,wH,H4,uH,G4,F4,Ze,jh,jh,n_,w4,r4,rH,wx,Xc,B4,A4,Xc,z4,x4,y4,u4,Xc,t4,s4,q4,ic,ic,ic,px,Ph,Oh,Ks,Xb,Ps,gk,fk,gl,ox,fl,a4,mj,Tg,_3,Y3,dH,dH,T3,R3,cH,nj,P3,N3,we,L3,p4,sx,Fx,lx,Ph,Oh,Js,pm,bl,om,jn,nm,mj,Tg,aH,nj,w3,r3,q3,l4,vx,g6,LH,l3,Ss,nn,g3,Mn,rx,lf,M2,Gs,L2,K2,J2,I2,G2,E2,D2,cl,C2,B2,z2,Z5,w2,v2,s2,r2,n2,m2,l2,k2,j2,i2,h2,g2,f2,e2,d2,c2,b2,a2,$1,_1,Z1,Y1,X1,W1,V1,U1,T1,S1,R1,Q1,P1,O1,N1,M1,L1,K1,J1,B1,G1,_$,H1,E1,D1,A1,o4,m4,n4,tx,kH,il,jH,Wp,a1,$0,oI,iH,hH,I0,G0,E0,D0,B0,A0,y0,w0,u0,t0,r0,q0,o0,bx,l0,j0,h0,f0,d0,b0,$$,FG,F1,rM,DG,o1,n1,m1,l1,k1,pW,j1,i1,h1,BG,f1,e1,d1,c1,b1,ic,_0,Z0,yG,S0,Q0,P0,DK,N0,L0,xG,R0,jy,jZ,O0,M0,K0,Ze,Xc,Xc,z1,y1,x1,w1,v1,u1,t1,s1,pW,r1,q1,p1,Xc,CG,CG,dx,se,se,g1,se,Xc,Y0,X0,dx,ic,ic,W0,Iv,Xc,V0,U0,dx,ic,ic,T0,Iv,Ze,Xc,k4,j4,i4,Ze,Xc,h4,g4,f4,Xc,e4,b4,$3,Z3,X3,V3,U3,S3,Q3,O3,M3,Xc,K3,J3,I3,H3,G3,F3,E3,D3,C3,B3,A3,Xc,y3,x3,v3,u3,t3,s3,p3,o3,Xc,n3,m3,k3,j3,i3,h3,e3,d3,Ze,Xc,qe,c3,b3,a3,$2,Z2,Y2,J0,C0,v0,g0,c0,p0,k0,Ze,Xc,qe,X2,W2,V2,T2,S2,R2,F0,z0,s0,e0,a0,n0,i0,ax,vG,Q2,ax,vG,P2,Xc,Fs,Fs,Lh,Lh,Lh,RG,ic,$k,$k,Xc,Fs,Fs,Lh,Lh,Lh,RG,ic,$k,$k,Xc,Zr,Zr,Lh,Lh,Lh,QG,ic,$k,$k,Xc,Zr,Zr,Lh,Lh,Lh,QG,ic,$k,$k,Xc,N2,H2,Xc,F2,A2,Xc,y2,u2,Xc,t2,q2,Xc,KG,p2,_c,Xc,KG,o2,_c,Da,Y$,Xc,V$,Xc,W$,T$,S$,Jp,Jp,Jp,Jp,Fw,Xc,R$,Ze,Xc,lf,lf,Q$,F$,I$,O$,Xc,G$,J$,N$,Xc,H$,L$,M$]);function lb(){return s.byteLength/65536|0}function qb(rb){rb=rb|0;var mb=lb()|0;var nb=mb+rb|0;if(mb<nb&&nb<65536){var ob=new ArrayBuffer(B(nb,65536));var pb=new Int8Array(ob);pb.set(t);t=new Int8Array(ob);u=new Int16Array(ob);v=new Int32Array(ob);w=new Uint8Array(ob);x=new Uint16Array(ob);y=new Uint32Array(ob);z=new Float32Array(ob);A=new Float64Array(ob);s=ob;r.buffer=s;e=w}return mb}return{"va":SY,"wa":uba,"xa":sba,"ya":Xc,"za":Xb,"Aa":rba,"Ba":qba,"Ca":pba,"Da":Gt,"Ea":_c,"Fa":oba,"Ga":nba,"Ha":mba,"Ia":es,"Ja":lba,"Ka":FL,"La":kba,"Ma":Ze,"Na":EL,"Oa":DL,"Pa":EL,"Qa":hba,"Ra":C$,"Sa":B$,"Ta":A$,"Ua":gba,"Va":AL,"Wa":dba,"Xa":zL,"Ya":cba,"Za":aba,"_a":$aa,"$a":_aa,"ab":Zaa,"bb":Yaa,"cb":Xaa,"db":Waa,"eb":Vaa,"fb":Uaa,"gb":Taa,"hb":Saa,"ib":Raa,"jb":Qaa,"kb":Paa,"lb":Oaa,"mb":Maa,"nb":Laa,"ob":Kaa,"pb":Jaa,"qb":Iaa,"rb":Haa,"sb":Gaa,"tb":Faa,"ub":Eaa,"vb":Daa,"wb":Caa,"xb":Baa,"yb":Aaa,"zb":zaa,"Ab":yaa,"Bb":xaa,"Cb":waa,"Db":vaa,"Eb":uaa,"Fb":taa,"Gb":saa,"Hb":raa,"Ib":qaa,"Jb":paa,"Kb":oaa,"Lb":naa,"Mb":maa,"Nb":laa,"Ob":kaa,"Pb":jaa,"Qb":iaa,"Rb":haa,"Sb":gaa,"Tb":faa,"Ub":eaa,"Vb":daa,"Wb":caa,"Xb":baa,"Yb":aaa,"Zb":$9,"_b":_9,"$b":Z9,"ac":Y9,"bc":X9,"cc":W9,"dc":V9,"ec":U9,"fc":z$,"gc":T9,"hc":S9,"ic":R9,"jc":Q9,"kc":y$,"lc":P9,"mc":O9,"nc":N9,"oc":M9,"pc":L9,"qc":K9,"rc":J9,"sc":Cd,"tc":f6,"uc":Ila,"vc":Qka,"wc":hja,"xc":E$,"yc":D$,"zc":kb,"Ac":r$,"Bc":x$,"Cc":w$,"Dc":v$,"Ec":u$,"Fc":t$,"Gc":s$,"Hc":r$,"Ic":q$,"Jc":p$,"Kc":o$}}return sb(ub)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


